Class: FdxV660Api::AccountType

Inherits:
Object
  • Object
show all
Defined in:
lib/fdx_v660_api/models/account_type.rb

Overview

The type of an account. | Value | Description | |-----|-----| | 401A | An employer-sponsored money-purchase retirement plan that allows dollar or percentage-based contributions from the employer, the employee, or both | | 401K | An employer-sponsored defined-contribution pension account defined in subsection 401(k) of the Internal Revenue Code | | 403B | A U.S. tax-advantaged retirement savings plan available for public education organizations, some non-profit employers (only Internal Revenue Code 501(c)(3) organizations), cooperative hospital service organizations, and self-employed ministers in the United States | | 529 | A tax-advantaged savings plan designed to help pay for education | | ANNUITY | A form of insurance or investment entitling the investor to a series of annual sums | | AUTOLOAN | A type of loan used to finance a car purchase | | BNPL | Buy Now Pay Later, a type of account that can be used to finance many, individual purchases with independent installment plans per purchase | | BROKERAGEPRODUCT | Investment management offered by a licensed brokerage firm that places trades on behalf of the customer, utilizing any number of investment options | | CD | A certificate of deposit (CD) is a product offered by banks and credit unions that provides an interest rate premium in exchange for the customer agreeing to leave a lump-sum deposit untouched for a predetermined period of time | | CHARGE | An account to which goods and services may be charged on credit | | CHECKING | A deposit account held at a financial institution that allows withdrawals and deposits. Canadian accounts will also use this for chequing account types to ensure interoperability | | COMMERCIALDEPOSIT | Deposit Account for Commercial Customers e.g. Business Trust Account | | COMMERCIALINVESTMENT | Investment Account for Commercial Customers. e.g. Commercial Brokerage Account | | COMMERCIALLINEOFCREDIT | A preset borrowing limit that can be used at any time | | COMMERCIALLOAN | A preset borrowing limit that can be used at any time | | COVERDELL | A trust or custodial account set up in the United States solely for paying qualified education expenses for the designated beneficiary of the account | | CREDITCARD | Allows cardholders to borrow funds with which to pay for goods and services with merchants that accept cards for payment | | DEFERREDPROFITSHARINGPLAN | A deferred profit sharing plan (DPSP) is an employer-sponsored profit sharing plan that is registered with a government agency (such as the Canada Revenue Agency) | | DEFINEDBENEFIT | An employer-sponsored retirement plan where employee benefits are computed using a formula that considers several factors, such as length of employment and salary history | | DIGITALASSET | Encompasses cryptocurrencies as well as other digital assets such as NFTs | | DIGITALWALLET | A digital wallet account enables digital financial transactions through a deposit value and one or more linked funding instruments | | ESCROW | A contractual arrangement in which a third party (the stakeholder or escrow agent) receives and disburses money or property for the primary transacting parties, with the disbursement dependent on conditions agreed to by the transacting parties | | ESOP | An employee stock ownership plan (ESOP) is an employee benefit plan that gives workers ownership interest in the company | | FIRSTHOMESAVINGSACCOUNT | A First Home Savings Account (FHSA), registered with the Canadian federal government, which allows first-time home buyers to save to buy or build their first home tax free | | FIXEDANNUITY | A type of insurance contract that promises to pay the buyer a specific, guaranteed interest rate on their contributions to the account | | GUARDIAN | An account of a child in the parent's name, with legal title to the assets in the account, as well as all capital gains and tax liabilities produced from the account belonging to the parent | | HIGHINTERESTSAVINGSACCOUNT | A High Interest Savings Account (HISA), is an account type recognized in Canada, which allows individuals to save at a higher interest rate than a standard savings account | | HOMEEQUITYLOAN | A type of loan in which the borrower uses the equity of his or her home as collateral | | HOMELINEOFCREDIT | A loan in which the lender agrees to lend a maximum amount within an agreed period, where the collateral is the borrower's equity in their house | | INDIVIDUALPENSIONPLAN | An Individual Pension Plan (IPP) is an employer-sponsored, defined benefit pension plan that can be set up by and for a single person | | INSTALLMENT | A type of agreement or contract involving a loan that is repaid over time with a set number of scheduled payments | | INSTITUTIONALTRUST | A trust account created by an institution to hold assets for the benefit of one or more other institutions | | INVESTMENTACCOUNT | A standard investment account that is not registered | | IRA | An individual retirement account (IRA) is a tax-advantaged account that individuals use to save and invest for retirement | | KEOGH | A tax-deferred pension plan available to self-employed individuals or unincorporated businesses for retirement purposes | | LIFEINCOMEFUND | A Life Income Fund (LIF) is a type of registered retirement income fund (RRIF) that can be used to hold locked-in pension funds as well as other assets for an eventual payout as retirement income | | LIMITEDPURPOSECHECKING | A deposit account with checking features whose outgoing funding or payment use is limited to specific purposes, programs, transaction types, or account relationships | | LINEOFCREDIT | A credit facility extended by a bank or other financial institution to a government, business or individual customer that enables the customer to draw on the facility when the customer needs funds | | LOAN | The lending of money by one or more individuals, organizations, or other entities to other individuals, organizations etc | | LOCKEDINRETIREMENTACCOUNT | A Locked-in Retirement Account (LIRA) is a pension savings account that holds funds that cannot be withdrawn until retirement | | LOCKEDINRETIREMENTINCOMEFUND | A Locked-in Retirement Income Fund (LRIF) is a locked-in account which has been created with funds that originated with a registered pension plan (RPP) | | LOCKEDINRETIREMENTSAVINGSPLAN | A Locked-in Retirement Savings plan (LRSP) is a pension savings account that holds funds that cannot be withdrawn until retirement (similar to LIRA) | | LONGTERMDISABILITY | Insurance that replaces a portion of the policyholder's income due to a disability for an extended period of time, usually more than a year | | MILITARYLOAN | A personal loan to active duty service members, veterans or their family members, typically with preferential terms | | MONEYMARKET | A deposit account that pays interest based on current interest rates in the money markets | | MORTGAGE | A type of loan you can use to buy or refinance a home | | NONQUALIFEDPLAN | A type of tax-deferred employer-sponsored retirement plan that falls outside of ERISA guidelines | | OTHERDEPOSIT | Use when none of the listed enums apply | | OTHERINVESTMENT | Use when none of the listed enums apply | | PERSONALLOAN | A type of debt that is not protected by a guarantor, or collateralized by a lien on specific assets of the borrower | | POOLEDREGISTEREDPENSIONPLAN | A Pooled Registered Pension Plan (PRPP) is a type of pension plan that is similar to a defined contribution plan; however, employer contributions are not mandatory | | PREPAID | An account that is preloaded with funds before first use, such as a gift card | | PRESCRIBEDREGISTEREDRETIREMENTINCOMEFUND | A Prescribed Registered Retirement Income Fund (PRRIF) is a personal retirement income fund that is governed by the federal Income Tax Act (Canada) | | REGISTEREDDISABILITYSAVINGSPLAN | A Registered Disability Savings Plan (RDSP) is a savings plan intended to help parents and others save for the long term financial security of a person who is eligible for the disability tax credit (DTC) | | REGISTEREDEDUCATIONSAVINGSPLAN | A Registered Education Savings Plan (RESP) is a special savings account for parents/custodians/others who want to save for their child's education after high school and is registered with the Canadian federal government | | REGISTEREDPENSIONPLAN | A Registered Pension Plan (RPP) is a pension plan that has been set up by an employer, and registered by the Canadian federal government | | REGISTEREDRETIREMENTINCOMEFUND | A Registered Retirement Income Fund (RRIF) is an arrangement between an individual and a carrier (an insurance company, a trust company or a bank) that is registered with the Canadian federal government | | REGISTEREDRETIREMENTSAVINGSPLAN | A Registered Retirement Savings Plan (RRSP) is a savings plan, registered with the Canadian federal government that you can contribute to for retirement purposes | | RESTRICTEDLIFEINCOMEFUND | Restricted Life Income Fund (RLIF) is a retirement option that operates like a LIF. The RLIF provides a one-time 50% unlocking option | | RESTRICTEDLOCKEDINSAVINGSPLAN | A Restricted Locked-In Savings Plan (RLSP) is an investment account that can only be established as a result of a transfer of funds from an RLIF | | ROLLOVER | A rollover IRA account allows the transfer of assets from an old employer-sponsored retirement account (like 401-k or 403-b or IRA) to a traditional individual IRA | | ROTH | An individual retirement account that offers tax-free growth and tax-free withdrawals in retirement | | SARSEP | A simplified employee pension (SEP) plan set up before 1997 that includes a salary reduction arrangement | | SAVINGS | An interest-bearing deposit account held at a bank or other financial institution | | SMBLOAN | A loan taken out by a Small or Medium-sized Business customer | | SHORTTERMDISABILITY | Insurance that replaces a portion of the policyholder's income due to a disability for a short period of time, usually less than a year | | SPECIFIEDPENSIONPLAN | A Specified Pension Plan (SPP) is a pension plan or similar arrangement that has been prescribed under the Income Tax Regulations as a "specified pension plan" for purposes of the Income Tax Act | | STUDENTLOAN | A type of loan designed to help students pay for post-secondary education and the associated fees, such as tuition, books and supplies, and living expenses | | TAXABLE | A taxable investment account | | TAXFREESAVINGSACCOUNT | A Tax-Free Savings Account (TFSA) is a way for over the age of 18 to set money aside, tax free, throughout their lifetime | | TDA | A Tax Deferred Annuity is a retirement plan offered by employers that allows employees to save for retirement through pre-tax contributions | | TERM | Life insurance that provides coverage at a fixed rate of payments for a limited period of time | | TRUST | A type of financial account that is opened by an individual and managed by a designated trustee for the benefit of a third party in accordance with agreed-upon terms | | UGMA | Uniform Gift to Minors Act defines a custodial account set up for a minor child to hold gifts or assets | | UNIVERSALLIFE | A type of a cash value life insurance where the excess of premium payments above the current cost of insurance is credited to the cash value of the policy, which in turn is credited each month with interest | | UTMA | Uniform Transfers to Minors Act defines an account managed by custodians that allow minors to receive and hold gifts such as money, real estate and fine art without needing a formal trust | | VARIABLEANNUITY | A type of insurance contract that promises to pay back the buyer based on the performance of an underlying portfolio of mutual funds selected by the buyer | | WHOLELIFE | Life insurance which is guaranteed to remain in force for the insured's entire lifetime, provided required premiums are paid, or to the maturity date |

Constant Summary collapse

ACCOUNT_TYPE =
[
  # TODO: Write general description for ENUM_401A
  ENUM_401A = '401A'.freeze,

  # TODO: Write general description for ENUM_401K
  ENUM_401K = '401K'.freeze,

  # TODO: Write general description for ENUM_403B
  ENUM_403B = '403B'.freeze,

  # TODO: Write general description for ENUM_529
  ENUM_529 = '529'.freeze,

  # TODO: Write general description for ANNUITY
  ANNUITY = 'ANNUITY'.freeze,

  # TODO: Write general description for AUTOLOAN
  AUTOLOAN = 'AUTOLOAN'.freeze,

  # TODO: Write general description for BNPL
  BNPL = 'BNPL'.freeze,

  # TODO: Write general description for BROKERAGEPRODUCT
  BROKERAGEPRODUCT = 'BROKERAGEPRODUCT'.freeze,

  # TODO: Write general description for CD
  CD = 'CD'.freeze,

  # TODO: Write general description for CHARGE
  CHARGE = 'CHARGE'.freeze,

  # TODO: Write general description for CHECKING
  CHECKING = 'CHECKING'.freeze,

  # TODO: Write general description for COMMERCIALDEPOSIT
  COMMERCIALDEPOSIT = 'COMMERCIALDEPOSIT'.freeze,

  # TODO: Write general description for COMMERCIALINVESTMENT
  COMMERCIALINVESTMENT = 'COMMERCIALINVESTMENT'.freeze,

  # TODO: Write general description for COMMERCIALLINEOFCREDIT
  COMMERCIALLINEOFCREDIT = 'COMMERCIALLINEOFCREDIT'.freeze,

  # TODO: Write general description for COMMERCIALLOAN
  COMMERCIALLOAN = 'COMMERCIALLOAN'.freeze,

  # TODO: Write general description for COVERDELL
  COVERDELL = 'COVERDELL'.freeze,

  # TODO: Write general description for CREDITCARD
  CREDITCARD = 'CREDITCARD'.freeze,

  # TODO: Write general description for DEFERREDPROFITSHARINGPLAN
  DEFERREDPROFITSHARINGPLAN = 'DEFERREDPROFITSHARINGPLAN'.freeze,

  # TODO: Write general description for DEFINEDBENEFIT
  DEFINEDBENEFIT = 'DEFINEDBENEFIT'.freeze,

  # TODO: Write general description for DIGITALASSET
  DIGITALASSET = 'DIGITALASSET'.freeze,

  # TODO: Write general description for DIGITALWALLET
  DIGITALWALLET = 'DIGITALWALLET'.freeze,

  # TODO: Write general description for ESCROW
  ESCROW = 'ESCROW'.freeze,

  # TODO: Write general description for ESOP
  ESOP = 'ESOP'.freeze,

  # TODO: Write general description for FIRSTHOMESAVINGSACCOUNT
  FIRSTHOMESAVINGSACCOUNT = 'FIRSTHOMESAVINGSACCOUNT'.freeze,

  # TODO: Write general description for FIXEDANNUITY
  FIXEDANNUITY = 'FIXEDANNUITY'.freeze,

  # TODO: Write general description for GUARDIAN
  GUARDIAN = 'GUARDIAN'.freeze,

  # TODO: Write general description for HIGHINTERESTSAVINGSACCOUNT
  HIGHINTERESTSAVINGSACCOUNT = 'HIGHINTERESTSAVINGSACCOUNT'.freeze,

  # TODO: Write general description for HOMEEQUITYLOAN
  HOMEEQUITYLOAN = 'HOMEEQUITYLOAN'.freeze,

  # TODO: Write general description for HOMELINEOFCREDIT
  HOMELINEOFCREDIT = 'HOMELINEOFCREDIT'.freeze,

  # TODO: Write general description for INDIVIDUALPENSIONPLAN
  INDIVIDUALPENSIONPLAN = 'INDIVIDUALPENSIONPLAN'.freeze,

  # TODO: Write general description for INSTALLMENT
  INSTALLMENT = 'INSTALLMENT'.freeze,

  # TODO: Write general description for INSTITUTIONALTRUST
  INSTITUTIONALTRUST = 'INSTITUTIONALTRUST'.freeze,

  # TODO: Write general description for INVESTMENTACCOUNT
  INVESTMENTACCOUNT = 'INVESTMENTACCOUNT'.freeze,

  # TODO: Write general description for IRA
  IRA = 'IRA'.freeze,

  # TODO: Write general description for KEOGH
  KEOGH = 'KEOGH'.freeze,

  # TODO: Write general description for LIFEINCOMEFUND
  LIFEINCOMEFUND = 'LIFEINCOMEFUND'.freeze,

  # TODO: Write general description for LIMITEDPURPOSECHECKING
  LIMITEDPURPOSECHECKING = 'LIMITEDPURPOSECHECKING'.freeze,

  # TODO: Write general description for LINEOFCREDIT
  LINEOFCREDIT = 'LINEOFCREDIT'.freeze,

  # TODO: Write general description for LOAN
  LOAN = 'LOAN'.freeze,

  # TODO: Write general description for LOCKEDINRETIREMENTACCOUNT
  LOCKEDINRETIREMENTACCOUNT = 'LOCKEDINRETIREMENTACCOUNT'.freeze,

  # TODO: Write general description for LOCKEDINRETIREMENTINCOMEFUND
  LOCKEDINRETIREMENTINCOMEFUND = 'LOCKEDINRETIREMENTINCOMEFUND'.freeze,

  # TODO: Write general description for LOCKEDINRETIREMENTSAVINGSPLAN
  LOCKEDINRETIREMENTSAVINGSPLAN = 'LOCKEDINRETIREMENTSAVINGSPLAN'.freeze,

  # TODO: Write general description for LONGTERMDISABILITY
  LONGTERMDISABILITY = 'LONGTERMDISABILITY'.freeze,

  # TODO: Write general description for MILITARYLOAN
  MILITARYLOAN = 'MILITARYLOAN'.freeze,

  # TODO: Write general description for MONEYMARKET
  MONEYMARKET = 'MONEYMARKET'.freeze,

  # TODO: Write general description for MORTGAGE
  MORTGAGE = 'MORTGAGE'.freeze,

  # TODO: Write general description for NONQUALIFIEDPLAN
  NONQUALIFIEDPLAN = 'NONQUALIFIEDPLAN'.freeze,

  # TODO: Write general description for OTHERDEPOSIT
  OTHERDEPOSIT = 'OTHERDEPOSIT'.freeze,

  # TODO: Write general description for OTHERINVESTMENT
  OTHERINVESTMENT = 'OTHERINVESTMENT'.freeze,

  # TODO: Write general description for PERSONALLOAN
  PERSONALLOAN = 'PERSONALLOAN'.freeze,

  # TODO: Write general description for POOLEDREGISTEREDPENSIONPLAN
  POOLEDREGISTEREDPENSIONPLAN = 'POOLEDREGISTEREDPENSIONPLAN'.freeze,

  # TODO: Write general description for PREPAID
  PREPAID = 'PREPAID'.freeze,

  # TODO: Write general description for
  # PRESCRIBEDREGISTEREDRETIREMENTINCOMEFUND
  PRESCRIBEDREGISTEREDRETIREMENTINCOMEFUND = 'PRESCRIBEDREGISTEREDRETIREMENTINCOMEFUND'.freeze,

  # TODO: Write general description for REGISTEREDDISABILITYSAVINGSPLAN
  REGISTEREDDISABILITYSAVINGSPLAN = 'REGISTEREDDISABILITYSAVINGSPLAN'.freeze,

  # TODO: Write general description for REGISTEREDEDUCATIONSAVINGSPLAN
  REGISTEREDEDUCATIONSAVINGSPLAN = 'REGISTEREDEDUCATIONSAVINGSPLAN'.freeze,

  # TODO: Write general description for REGISTEREDPENSIONPLAN
  REGISTEREDPENSIONPLAN = 'REGISTEREDPENSIONPLAN'.freeze,

  # TODO: Write general description for REGISTEREDRETIREMENTINCOMEFUND
  REGISTEREDRETIREMENTINCOMEFUND = 'REGISTEREDRETIREMENTINCOMEFUND'.freeze,

  # TODO: Write general description for REGISTEREDRETIREMENTSAVINGSPLAN
  REGISTEREDRETIREMENTSAVINGSPLAN = 'REGISTEREDRETIREMENTSAVINGSPLAN'.freeze,

  # TODO: Write general description for RESTRICTEDLIFEINCOMEFUND
  RESTRICTEDLIFEINCOMEFUND = 'RESTRICTEDLIFEINCOMEFUND'.freeze,

  # TODO: Write general description for RESTRICTEDLOCKEDINSAVINGSPLAN
  RESTRICTEDLOCKEDINSAVINGSPLAN = 'RESTRICTEDLOCKEDINSAVINGSPLAN'.freeze,

  # TODO: Write general description for ROLLOVER
  ROLLOVER = 'ROLLOVER'.freeze,

  # TODO: Write general description for ROTH
  ROTH = 'ROTH'.freeze,

  # TODO: Write general description for SARSEP
  SARSEP = 'SARSEP'.freeze,

  # TODO: Write general description for SAVINGS
  SAVINGS = 'SAVINGS'.freeze,

  # TODO: Write general description for SHORTTERMDISABILITY
  SHORTTERMDISABILITY = 'SHORTTERMDISABILITY'.freeze,

  # TODO: Write general description for SMBLOAN
  SMBLOAN = 'SMBLOAN'.freeze,

  # TODO: Write general description for SPECIFIEDPENSIONPLAN
  SPECIFIEDPENSIONPLAN = 'SPECIFIEDPENSIONPLAN'.freeze,

  # TODO: Write general description for STUDENTLOAN
  STUDENTLOAN = 'STUDENTLOAN'.freeze,

  # TODO: Write general description for TAXABLE
  TAXABLE = 'TAXABLE'.freeze,

  # TODO: Write general description for TAXFREESAVINGSACCOUNT
  TAXFREESAVINGSACCOUNT = 'TAXFREESAVINGSACCOUNT'.freeze,

  # TODO: Write general description for TDA
  TDA = 'TDA'.freeze,

  # TODO: Write general description for TERM
  TERM = 'TERM'.freeze,

  # TODO: Write general description for TRUST
  TRUST = 'TRUST'.freeze,

  # TODO: Write general description for UGMA
  UGMA = 'UGMA'.freeze,

  # TODO: Write general description for UNIVERSALLIFE
  UNIVERSALLIFE = 'UNIVERSALLIFE'.freeze,

  # TODO: Write general description for UTMA
  UTMA = 'UTMA'.freeze,

  # TODO: Write general description for VARIABLEANNUITY
  VARIABLEANNUITY = 'VARIABLEANNUITY'.freeze,

  # TODO: Write general description for WHOLELIFE
  WHOLELIFE = 'WHOLELIFE'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ENUM_401A) ⇒ Object



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/fdx_v660_api/models/account_type.rb', line 417

def self.from_value(value, default_value = ENUM_401A)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'enum_401a' then ENUM_401A
  when 'enum_401k' then ENUM_401K
  when 'enum_403b' then ENUM_403B
  when 'enum_529' then ENUM_529
  when 'annuity' then ANNUITY
  when 'autoloan' then AUTOLOAN
  when 'bnpl' then BNPL
  when 'brokerageproduct' then BROKERAGEPRODUCT
  when 'cd' then CD
  when 'charge' then CHARGE
  when 'checking' then CHECKING
  when 'commercialdeposit' then COMMERCIALDEPOSIT
  when 'commercialinvestment' then COMMERCIALINVESTMENT
  when 'commerciallineofcredit' then COMMERCIALLINEOFCREDIT
  when 'commercialloan' then COMMERCIALLOAN
  when 'coverdell' then COVERDELL
  when 'creditcard' then CREDITCARD
  when 'deferredprofitsharingplan' then DEFERREDPROFITSHARINGPLAN
  when 'definedbenefit' then DEFINEDBENEFIT
  when 'digitalasset' then DIGITALASSET
  when 'digitalwallet' then DIGITALWALLET
  when 'escrow' then ESCROW
  when 'esop' then ESOP
  when 'firsthomesavingsaccount' then FIRSTHOMESAVINGSACCOUNT
  when 'fixedannuity' then FIXEDANNUITY
  when 'guardian' then GUARDIAN
  when 'highinterestsavingsaccount' then HIGHINTERESTSAVINGSACCOUNT
  when 'homeequityloan' then HOMEEQUITYLOAN
  when 'homelineofcredit' then HOMELINEOFCREDIT
  when 'individualpensionplan' then INDIVIDUALPENSIONPLAN
  when 'installment' then INSTALLMENT
  when 'institutionaltrust' then INSTITUTIONALTRUST
  when 'investmentaccount' then INVESTMENTACCOUNT
  when 'ira' then IRA
  when 'keogh' then KEOGH
  when 'lifeincomefund' then LIFEINCOMEFUND
  when 'limitedpurposechecking' then LIMITEDPURPOSECHECKING
  when 'lineofcredit' then LINEOFCREDIT
  when 'loan' then LOAN
  when 'lockedinretirementaccount' then LOCKEDINRETIREMENTACCOUNT
  when 'lockedinretirementincomefund' then LOCKEDINRETIREMENTINCOMEFUND
  when 'lockedinretirementsavingsplan' then LOCKEDINRETIREMENTSAVINGSPLAN
  when 'longtermdisability' then LONGTERMDISABILITY
  when 'militaryloan' then MILITARYLOAN
  when 'moneymarket' then MONEYMARKET
  when 'mortgage' then MORTGAGE
  when 'nonqualifiedplan' then NONQUALIFIEDPLAN
  when 'otherdeposit' then OTHERDEPOSIT
  when 'otherinvestment' then OTHERINVESTMENT
  when 'personalloan' then PERSONALLOAN
  when 'pooledregisteredpensionplan' then POOLEDREGISTEREDPENSIONPLAN
  when 'prepaid' then PREPAID
  when 'prescribedregisteredretirementincomefund' then PRESCRIBEDREGISTEREDRETIREMENTINCOMEFUND
  when 'registereddisabilitysavingsplan' then REGISTEREDDISABILITYSAVINGSPLAN
  when 'registerededucationsavingsplan' then REGISTEREDEDUCATIONSAVINGSPLAN
  when 'registeredpensionplan' then REGISTEREDPENSIONPLAN
  when 'registeredretirementincomefund' then REGISTEREDRETIREMENTINCOMEFUND
  when 'registeredretirementsavingsplan' then REGISTEREDRETIREMENTSAVINGSPLAN
  when 'restrictedlifeincomefund' then RESTRICTEDLIFEINCOMEFUND
  when 'restrictedlockedinsavingsplan' then RESTRICTEDLOCKEDINSAVINGSPLAN
  when 'rollover' then ROLLOVER
  when 'roth' then ROTH
  when 'sarsep' then SARSEP
  when 'savings' then SAVINGS
  when 'shorttermdisability' then SHORTTERMDISABILITY
  when 'smbloan' then SMBLOAN
  when 'specifiedpensionplan' then SPECIFIEDPENSIONPLAN
  when 'studentloan' then STUDENTLOAN
  when 'taxable' then TAXABLE
  when 'taxfreesavingsaccount' then TAXFREESAVINGSACCOUNT
  when 'tda' then TDA
  when 'term' then TERM
  when 'trust' then TRUST
  when 'ugma' then UGMA
  when 'universallife' then UNIVERSALLIFE
  when 'utma' then UTMA
  when 'variableannuity' then VARIABLEANNUITY
  when 'wholelife' then WHOLELIFE
  else
    default_value
  end
end

.validate(value) ⇒ Object



411
412
413
414
415
# File 'lib/fdx_v660_api/models/account_type.rb', line 411

def self.validate(value)
  return false if value.nil?

  true
end