Class: FdxV660Api::AccountsEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/accounts_entity.rb

Overview

An optionally paginated array of accounts

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(page: SKIP, links: SKIP, accounts: SKIP, additional_properties: nil) ⇒ AccountsEntity

Returns a new instance of AccountsEntity.



49
50
51
52
53
54
55
56
57
58
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 49

def initialize(page: SKIP, links: SKIP, accounts: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @page = page unless page == SKIP
  @links = links unless links == SKIP
  @accounts = accounts unless accounts == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[Object]

An array of accounts with entity types dependent on the account type (deposit, investment, loan, line of credit, annuity, insurance, commercial, or digital wallet)

Returns:

  • (Array[Object])


24
25
26
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 24

def accounts
  @accounts
end

Resource URLs for navigating result sets

Returns:



18
19
20
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 18

def links
  @links
end

#pagePageMetadata

Page keys for navigating result sets

Returns:



14
15
16
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 14

def page
  @page
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  page = PageMetadata.from_hash(hash['page']) if hash['page']
  links = PageMetadataLinks1.from_hash(hash['links']) if hash['links']
  accounts = hash.key?('accounts') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:AccountsEntityAccounts), hash['accounts']
  ) : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountsEntity.new(page: page,
                     links: links,
                     accounts: accounts,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['page'] = 'page'
  @_hash['links'] = 'links'
  @_hash['accounts'] = 'accounts'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 36

def self.optionals
  %w[
    page
    links
    accounts
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (AccountsEntity | Hash)

    value against the validation is performed.



87
88
89
90
91
92
93
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 87

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page.inspect}, links: #{@links.inspect}, accounts:"\
  " #{@accounts.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
# File 'lib/fdx_v660_api/models/accounts_entity.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page}, links: #{@links}, accounts: #{@accounts},"\
  " additional_properties: #{@additional_properties}>"
end