Class: FdxV660Api::Address

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/address.rb

Overview

U.S. domestic address or a foreign address with country other than 'US'

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) ⇒ Address

Returns a new instance of Address.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/fdx_v660_api/models/address.rb', line 78

def initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP,
               region: SKIP, postal_code: SKIP, country: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @line1 = line1 unless line1 == SKIP
  @line2 = line2 unless line2 == SKIP
  @line3 = line3 unless line3 == SKIP
  @city = city unless city == SKIP
  @region = region unless region == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @country = country unless country == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

City

Returns:

  • (String)


26
27
28
# File 'lib/fdx_v660_api/models/address.rb', line 26

def city
  @city
end

#countryIso3166CountryCode1

Country code

Returns:



45
46
47
# File 'lib/fdx_v660_api/models/address.rb', line 45

def country
  @country
end

#line1String

Address line 1

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/address.rb', line 14

def line1
  @line1
end

#line2String

Address line 2

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/address.rb', line 18

def line2
  @line2
end

#line3String

Address line 3

Returns:

  • (String)


22
23
24
# File 'lib/fdx_v660_api/models/address.rb', line 22

def line3
  @line3
end

#postal_codeString

Postal code

Returns:

  • (String)


41
42
43
# File 'lib/fdx_v660_api/models/address.rb', line 41

def postal_code
  @postal_code
end

#regionString

State, Province, Territory, Canton or Prefecture. From [Universal Postal Union](https://www.upu.int/en/Postal-Solutions/Programmes-Services/Address ing-Solutions#addressing-s42-standard) as of 2-26-2020, [S42 International Address Standards](https://www.upu.int/UPU/media/upu/documents/PostCode/S42_Intern ational-Addressing-Standards.pdf). For U.S. addresses can be a 2-character code from StateCode. For Canadian addresses can be a 2-character code from ProvinceTerritoryCode

Returns:

  • (String)


37
38
39
# File 'lib/fdx_v660_api/models/address.rb', line 37

def region
  @region
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/fdx_v660_api/models/address.rb', line 95

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  line1 = hash.key?('line1') ? hash['line1'] : SKIP
  line2 = hash.key?('line2') ? hash['line2'] : SKIP
  line3 = hash.key?('line3') ? hash['line3'] : SKIP
  city = hash.key?('city') ? hash['city'] : SKIP
  region = hash.key?('region') ? hash['region'] : SKIP
  postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP
  country = hash.key?('country') ? hash['country'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Address.new(line1: line1,
              line2: line2,
              line3: line3,
              city: city,
              region: region,
              postal_code: postal_code,
              country: country,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/fdx_v660_api/models/address.rb', line 48

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['line1'] = 'line1'
  @_hash['line2'] = 'line2'
  @_hash['line3'] = 'line3'
  @_hash['city'] = 'city'
  @_hash['region'] = 'region'
  @_hash['postal_code'] = 'postalCode'
  @_hash['country'] = 'country'
  @_hash
end

.nullablesObject

An array for nullable fields



74
75
76
# File 'lib/fdx_v660_api/models/address.rb', line 74

def self.nullables
  []
end

.optionalsObject

An array for optional fields



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/fdx_v660_api/models/address.rb', line 61

def self.optionals
  %w[
    line1
    line2
    line3
    city
    region
    postal_code
    country
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Address | Hash)

    value against the validation is performed.



127
128
129
130
131
132
133
# File 'lib/fdx_v660_api/models/address.rb', line 127

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



144
145
146
147
148
149
150
# File 'lib/fdx_v660_api/models/address.rb', line 144

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} line1: #{@line1.inspect}, line2: #{@line2.inspect}, line3:"\
  " #{@line3.inspect}, city: #{@city.inspect}, region: #{@region.inspect}, postal_code:"\
  " #{@postal_code.inspect}, country: #{@country.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



136
137
138
139
140
141
# File 'lib/fdx_v660_api/models/address.rb', line 136

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} line1: #{@line1}, line2: #{@line2}, line3: #{@line3}, city: #{@city},"\
  " region: #{@region}, postal_code: #{@postal_code}, country: #{@country},"\
  " additional_properties: #{@additional_properties}>"
end