Class: FdxV660Api::AnnuityAccountEntity

Inherits:
AccountEntity show all
Defined in:
lib/fdx_v660_api/models/annuity_account_entity.rb

Overview

An annuity account type

Instance Attribute Summary collapse

Attributes inherited from AccountEntity

#balance_type, #bank_institution_id, #bank_transit_id, #bill_pay_status, #contact, #early_penalty_flag, #interest_rate, #interest_rate_as_of, #interest_rate_index, #interest_rate_type, #last_activity_date, #line_of_business, #line_of_business_type, #micr_number, #prior_interest_rate, #reward_balances, #reward_program_id, #routing_transit_number, #transactions_included, #transfer_in, #transfer_out

Attributes inherited from AccountDescriptorEntity

#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AccountEntity

discriminators, #to_custom_interest_rate_as_of

Methods inherited from AccountDescriptorEntity

discriminators

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(earned_interest: SKIP, payout_type: SKIP, policy_product_type: SKIP, payout_amount: SKIP, payout_mode: SKIP, payout_start_date: SKIP, payout_end_date: SKIP, number_modal_payouts: SKIP, surrender_value: SKIP, payout_change_percentage: SKIP, payout_change_amount: SKIP, period_certain_type: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Annuity Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ AnnuityAccountEntity

Returns a new instance of AnnuityAccountEntity.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 107

def initialize(earned_interest: SKIP, payout_type: SKIP,
               policy_product_type: SKIP, payout_amount: SKIP,
               payout_mode: SKIP, payout_start_date: SKIP,
               payout_end_date: SKIP, number_modal_payouts: SKIP,
               surrender_value: SKIP, payout_change_percentage: SKIP,
               payout_change_amount: SKIP, period_certain_type: SKIP,
               line_of_business: SKIP, line_of_business_type: SKIP,
               routing_transit_number: SKIP, balance_type: SKIP,
               contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP,
               interest_rate_as_of: SKIP, prior_interest_rate: SKIP,
               interest_rate_index: SKIP, early_penalty_flag: SKIP,
               transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP,
               micr_number: SKIP, last_activity_date: SKIP,
               reward_program_id: SKIP, reward_balances: SKIP,
               transactions_included: SKIP, bank_institution_id: SKIP,
               bank_transit_id: SKIP,
               account_category: 'Annuity Account entity', account_id: SKIP,
               parent_account_id: SKIP, error: SKIP, account_type: SKIP,
               domicile: SKIP, account_number: SKIP,
               account_number_display: SKIP, product_id: SKIP,
               product_name: SKIP, nickname: SKIP, status: SKIP,
               description: SKIP, account_open_date: SKIP,
               account_close_date: SKIP, currency: SKIP,
               data_clusters: SKIP, transfer_out_use_cases: SKIP,
               fi_attributes: SKIP, links: SKIP, additional_properties: nil)
  @earned_interest = earned_interest unless earned_interest == SKIP
  @payout_type = payout_type unless payout_type == SKIP
  @policy_product_type = policy_product_type unless policy_product_type == SKIP
  @payout_amount = payout_amount unless payout_amount == SKIP
  @payout_mode = payout_mode unless payout_mode == SKIP
  @payout_start_date = payout_start_date unless payout_start_date == SKIP
  @payout_end_date = payout_end_date unless payout_end_date == SKIP
  @number_modal_payouts = number_modal_payouts unless number_modal_payouts == SKIP
  @surrender_value = surrender_value unless surrender_value == SKIP
  @payout_change_percentage = payout_change_percentage unless payout_change_percentage == SKIP
  @payout_change_amount = payout_change_amount unless payout_change_amount == SKIP
  @period_certain_type = period_certain_type unless period_certain_type == SKIP
  @additional_properties = additional_properties

  # Call the constructor of the base class
  super(line_of_business: line_of_business,
        line_of_business_type: line_of_business_type,
        routing_transit_number: routing_transit_number,
        balance_type: balance_type,
        contact: contact,
        interest_rate: interest_rate,
        interest_rate_type: interest_rate_type,
        interest_rate_as_of: interest_rate_as_of,
        prior_interest_rate: prior_interest_rate,
        interest_rate_index: interest_rate_index,
        early_penalty_flag: early_penalty_flag,
        transfer_in: transfer_in,
        transfer_out: transfer_out,
        bill_pay_status: bill_pay_status,
        micr_number: micr_number,
        last_activity_date: last_activity_date,
        reward_program_id: reward_program_id,
        reward_balances: reward_balances,
        transactions_included: transactions_included,
        bank_institution_id: bank_institution_id,
        bank_transit_id: bank_transit_id,
        account_category: ,
        account_id: ,
        parent_account_id: ,
        error: error,
        account_type: ,
        domicile: domicile,
        account_number: ,
        account_number_display: ,
        product_id: product_id,
        product_name: product_name,
        nickname: nickname,
        status: status,
        description: description,
        account_open_date: ,
        account_close_date: ,
        currency: currency,
        data_clusters: data_clusters,
        transfer_out_use_cases: transfer_out_use_cases,
        fi_attributes: fi_attributes,
        links: links,
        additional_properties: additional_properties)
end

Instance Attribute Details

#earned_interestInterestRateEntity10

The periodic (usually monthly) interest rate earned on the account



14
15
16
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 14

def earned_interest
  @earned_interest
end

#number_modal_payoutsInteger

Total number of payouts

Returns:

  • (Integer)


42
43
44
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 42

def number_modal_payouts
  @number_modal_payouts
end

#payout_amountFloat

Amount paid out, based on mode frequency

Returns:

  • (Float)


26
27
28
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 26

def payout_amount
  @payout_amount
end

#payout_change_amountFloat

Incremental modal amount (positive or negative) by which the payout amount will be changed; used exclusive of payoutPercentage

Returns:

  • (Float)


56
57
58
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 56

def payout_change_amount
  @payout_change_amount
end

#payout_change_percentageFloat

Percentage of the accumulated value to be paid to the payee each year; used exclusive of payoutChangeAmount

Returns:

  • (Float)


51
52
53
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 51

def payout_change_percentage
  @payout_change_percentage
end

#payout_end_dateDate

Date the payout ends

Returns:

  • (Date)


38
39
40
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 38

def payout_end_date
  @payout_end_date
end

#payout_modePayoutMode2

Frequency of annuity payments

Returns:



30
31
32
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 30

def payout_mode
  @payout_mode
end

#payout_start_dateDate

Date the payout starts

Returns:

  • (Date)


34
35
36
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 34

def payout_start_date
  @payout_start_date
end

#payout_typePayoutType2

Indicates type of payout such as immediate or deferred

Returns:



18
19
20
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 18

def payout_type
  @payout_type
end

#period_certain_typePeriodCertainType2

The number of modal periods comprising the duration of the certain period of an annuity payout

Returns:



61
62
63
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 61

def period_certain_type
  @period_certain_type
end

#policy_product_typePolicyProductType2

The type of annuity product, e.g. Fixed or Variable

Returns:



22
23
24
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 22

def policy_product_type
  @policy_product_type
end

#surrender_valueFloat

Cash surrender value (net) available if contract is surrendered

Returns:

  • (Float)


46
47
48
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 46

def surrender_value
  @surrender_value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 192

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  earned_interest = InterestRateEntity10.from_hash(hash['earnedInterest']) if
    hash['earnedInterest']
  payout_type = hash.key?('payoutType') ? hash['payoutType'] : SKIP
  policy_product_type =
    hash.key?('policyProductType') ? hash['policyProductType'] : SKIP
  payout_amount = hash.key?('payoutAmount') ? hash['payoutAmount'] : SKIP
  payout_mode = hash.key?('payoutMode') ? hash['payoutMode'] : SKIP
  payout_start_date =
    hash.key?('payoutStartDate') ? hash['payoutStartDate'] : SKIP
  payout_end_date =
    hash.key?('payoutEndDate') ? hash['payoutEndDate'] : SKIP
  number_modal_payouts =
    hash.key?('numberModalPayouts') ? hash['numberModalPayouts'] : SKIP
  surrender_value =
    hash.key?('surrenderValue') ? hash['surrenderValue'] : SKIP
  payout_change_percentage =
    hash.key?('payoutChangePercentage') ? hash['payoutChangePercentage'] : SKIP
  payout_change_amount =
    hash.key?('payoutChangeAmount') ? hash['payoutChangeAmount'] : SKIP
  period_certain_type =
    hash.key?('periodCertainType') ? hash['periodCertainType'] : SKIP
  line_of_business =
    hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP
  line_of_business_type =
    hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP
  routing_transit_number =
    hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP
  balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP
  contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact']
  interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP
  interest_rate_type =
    hash.key?('interestRateType') ? hash['interestRateType'] : SKIP
  interest_rate_as_of = if hash.key?('interestRateAsOf')
                          (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf'])
                        else
                          SKIP
                        end
  prior_interest_rate =
    hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP
  interest_rate_index =
    hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP
  early_penalty_flag =
    hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP
  transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP
  transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP
  bill_pay_status =
    hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP
  micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP
  last_activity_date =
    hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP
  reward_program_id =
    hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP
  # Parameter is an array, so we need to iterate through it
  reward_balances = nil
  unless hash['rewardBalances'].nil?
    reward_balances = []
    hash['rewardBalances'].each do |structure|
      reward_balances << (RewardBalanceEntity.from_hash(structure) if structure)
    end
  end

  reward_balances = SKIP unless hash.key?('rewardBalances')
  transactions_included =
    hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP
  bank_institution_id =
    hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP
  bank_transit_id =
    hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP
   = hash['accountCategory'] ||= 'Annuity Account entity'
   = hash.key?('accountId') ? hash['accountId'] : SKIP
   =
    hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP
  error = Error3.from_hash(hash['error']) if hash['error']
   = hash.key?('accountType') ? hash['accountType'] : SKIP
  domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile']
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
   =
    hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP
  product_id = hash.key?('productId') ? hash['productId'] : SKIP
  product_name = hash.key?('productName') ? hash['productName'] : SKIP
  nickname = hash.key?('nickname') ? hash['nickname'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  description = hash.key?('description') ? hash['description'] : SKIP
   =
    hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP
   =
    hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP
  currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency']
  data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP
  transfer_out_use_cases =
    hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP
  # Parameter is an array, so we need to iterate through it
  fi_attributes = nil
  unless hash['fiAttributes'].nil?
    fi_attributes = []
    hash['fiAttributes'].each do |structure|
      fi_attributes << (FiAttributeEntity.from_hash(structure) if structure)
    end
  end

  fi_attributes = SKIP unless hash.key?('fiAttributes')
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AnnuityAccountEntity.new(earned_interest: earned_interest,
                           payout_type: payout_type,
                           policy_product_type: policy_product_type,
                           payout_amount: payout_amount,
                           payout_mode: payout_mode,
                           payout_start_date: payout_start_date,
                           payout_end_date: payout_end_date,
                           number_modal_payouts: number_modal_payouts,
                           surrender_value: surrender_value,
                           payout_change_percentage: payout_change_percentage,
                           payout_change_amount: payout_change_amount,
                           period_certain_type: period_certain_type,
                           line_of_business: line_of_business,
                           line_of_business_type: line_of_business_type,
                           routing_transit_number: routing_transit_number,
                           balance_type: balance_type,
                           contact: contact,
                           interest_rate: interest_rate,
                           interest_rate_type: interest_rate_type,
                           interest_rate_as_of: interest_rate_as_of,
                           prior_interest_rate: prior_interest_rate,
                           interest_rate_index: interest_rate_index,
                           early_penalty_flag: early_penalty_flag,
                           transfer_in: transfer_in,
                           transfer_out: transfer_out,
                           bill_pay_status: bill_pay_status,
                           micr_number: micr_number,
                           last_activity_date: last_activity_date,
                           reward_program_id: reward_program_id,
                           reward_balances: reward_balances,
                           transactions_included: transactions_included,
                           bank_institution_id: bank_institution_id,
                           bank_transit_id: bank_transit_id,
                           account_category: ,
                           account_id: ,
                           parent_account_id: ,
                           error: error,
                           account_type: ,
                           domicile: domicile,
                           account_number: ,
                           account_number_display: ,
                           product_id: product_id,
                           product_name: product_name,
                           nickname: nickname,
                           status: status,
                           description: description,
                           account_open_date: ,
                           account_close_date: ,
                           currency: currency,
                           data_clusters: data_clusters,
                           transfer_out_use_cases: transfer_out_use_cases,
                           fi_attributes: fi_attributes,
                           links: links,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 64

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['earned_interest'] = 'earnedInterest'
  @_hash['payout_type'] = 'payoutType'
  @_hash['policy_product_type'] = 'policyProductType'
  @_hash['payout_amount'] = 'payoutAmount'
  @_hash['payout_mode'] = 'payoutMode'
  @_hash['payout_start_date'] = 'payoutStartDate'
  @_hash['payout_end_date'] = 'payoutEndDate'
  @_hash['number_modal_payouts'] = 'numberModalPayouts'
  @_hash['surrender_value'] = 'surrenderValue'
  @_hash['payout_change_percentage'] = 'payoutChangePercentage'
  @_hash['payout_change_amount'] = 'payoutChangeAmount'
  @_hash['period_certain_type'] = 'periodCertainType'
  @_hash = super().merge(@_hash)
  @_hash
end

.nullablesObject

An array for nullable fields



102
103
104
105
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 102

def self.nullables
  _arr = []
  (_arr << super()).flatten!
end

.optionalsObject

An array for optional fields



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 83

def self.optionals
  _arr = %w[
    earned_interest
    payout_type
    policy_product_type
    payout_amount
    payout_mode
    payout_start_date
    payout_end_date
    number_modal_payouts
    surrender_value
    payout_change_percentage
    payout_change_amount
    period_certain_type
  ]
  (_arr << super()).flatten!
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



374
375
376
377
378
379
380
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 374

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 396

def inspect
  class_name = self.class.name.split('::').last
  super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '')
  "<#{class_name} #{super_string}, earned_interest: #{@earned_interest.inspect}, payout_type:"\
  " #{@payout_type.inspect}, policy_product_type: #{@policy_product_type.inspect},"\
  " payout_amount: #{@payout_amount.inspect}, payout_mode: #{@payout_mode.inspect},"\
  " payout_start_date: #{@payout_start_date.inspect}, payout_end_date:"\
  " #{@payout_end_date.inspect}, number_modal_payouts: #{@number_modal_payouts.inspect},"\
  " surrender_value: #{@surrender_value.inspect}, payout_change_percentage:"\
  " #{@payout_change_percentage.inspect}, payout_change_amount:"\
  " #{@payout_change_amount.inspect}, period_certain_type: #{@period_certain_type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



383
384
385
386
387
388
389
390
391
392
393
# File 'lib/fdx_v660_api/models/annuity_account_entity.rb', line 383

def to_s
  class_name = self.class.name.split('::').last
  super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '')
  "<#{class_name} #{super_string}, earned_interest: #{@earned_interest}, payout_type:"\
  " #{@payout_type}, policy_product_type: #{@policy_product_type}, payout_amount:"\
  " #{@payout_amount}, payout_mode: #{@payout_mode}, payout_start_date: #{@payout_start_date},"\
  " payout_end_date: #{@payout_end_date}, number_modal_payouts: #{@number_modal_payouts},"\
  " surrender_value: #{@surrender_value}, payout_change_percentage:"\
  " #{@payout_change_percentage}, payout_change_amount: #{@payout_change_amount},"\
  " period_certain_type: #{@period_certain_type}>"
end