Class: FdxV660Api::BalanceTransferAndCashAdvanceType

Inherits:
Object
  • Object
show all
Defined in:
lib/fdx_v660_api/models/balance_transfer_and_cash_advance_type.rb

Overview

The categories of balance transfers and cash advances. One of: * BALANCE_TRANSFER: Balance transfers * CASH_ADVANCE: Other cash advance

  • CHECK_CASH_ADVANCE: Cash advance in the form of a check * DIRECT_DEPOSIT_CASH_ADVANCE: Cash advance in the form of direct deposit to an account * OTC_CASH_ADVANCE: Over the counter (OTC) cash advance at a bank or financial institution branch

Constant Summary collapse

BALANCE_TRANSFER_AND_CASH_ADVANCE_TYPE =
[
  # TODO: Write general description for BALANCE_TRANSFER
  BALANCE_TRANSFER = 'BALANCE_TRANSFER'.freeze,

  # TODO: Write general description for CASH_ADVANCE
  CASH_ADVANCE = 'CASH_ADVANCE'.freeze,

  # TODO: Write general description for CHECK_CASH_ADVANCE
  CHECK_CASH_ADVANCE = 'CHECK_CASH_ADVANCE'.freeze,

  # TODO: Write general description for DIRECT_DEPOSIT_CASH_ADVANCE
  DIRECT_DEPOSIT_CASH_ADVANCE = 'DIRECT_DEPOSIT_CASH_ADVANCE'.freeze,

  # TODO: Write general description for OTC_CASH_ADVANCE
  OTC_CASH_ADVANCE = 'OTC_CASH_ADVANCE'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = BALANCE_TRANSFER) ⇒ Object



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/fdx_v660_api/models/balance_transfer_and_cash_advance_type.rb', line 37

def self.from_value(value, default_value = BALANCE_TRANSFER)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'balance_transfer' then BALANCE_TRANSFER
  when 'cash_advance' then CASH_ADVANCE
  when 'check_cash_advance' then CHECK_CASH_ADVANCE
  when 'direct_deposit_cash_advance' then DIRECT_DEPOSIT_CASH_ADVANCE
  when 'otc_cash_advance' then OTC_CASH_ADVANCE
  else
    default_value
  end
end

.validate(value) ⇒ Object



31
32
33
34
35
# File 'lib/fdx_v660_api/models/balance_transfer_and_cash_advance_type.rb', line 31

def self.validate(value)
  return false if value.nil?

  true
end