Class: FdxV660Api::BasicAuthForQr

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/basic_auth_for_qr.rb

Overview

Tax form credentials container for QR Code purposes

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(basic_auth: SKIP, version: SKIP, software_id: SKIP, additional_properties: nil) ⇒ BasicAuthForQr

Returns a new instance of BasicAuthForQr.



48
49
50
51
52
53
54
55
56
57
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 48

def initialize(basic_auth: SKIP, version: SKIP, software_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @basic_auth = basic_auth unless basic_auth == SKIP
  @version = version unless version == SKIP
  @software_id = software_id unless software_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#basic_authBasicAuthCredentials1

The Basic Authentication credentials to retrieve a tax form



14
15
16
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 14

def basic_auth
  @basic_auth
end

#software_idString

The FDX registration ID of company or software generating this tax data

Returns:

  • (String)


23
24
25
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 23

def software_id
  @software_id
end

#versionFdxVersion1

Financial Data Exchange (FDX) schema version number (e.g. "V5.0").

Returns:



19
20
21
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 19

def version
  @version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  basic_auth = BasicAuthCredentials1.from_hash(hash['basicAuth']) if hash['basicAuth']
  version = hash.key?('version') ? hash['version'] : SKIP
  software_id = hash.key?('softwareId') ? hash['softwareId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BasicAuthForQr.new(basic_auth: basic_auth,
                     version: version,
                     software_id: software_id,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['basic_auth'] = 'basicAuth'
  @_hash['version'] = 'version'
  @_hash['software_id'] = 'softwareId'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 35

def self.optionals
  %w[
    basic_auth
    version
    software_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} basic_auth: #{@basic_auth.inspect}, version: #{@version.inspect},"\
  " software_id: #{@software_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/fdx_v660_api/models/basic_auth_for_qr.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} basic_auth: #{@basic_auth}, version: #{@version}, software_id:"\
  " #{@software_id}, additional_properties: #{@additional_properties}>"
end