Class: FdxV660Api::BranchEntity1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/branch_entity1.rb

Overview

Branch details associated with this account

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(branch_id: SKIP, name: SKIP, locations: SKIP, financial_institution: SKIP, additional_properties: nil) ⇒ BranchEntity1

Returns a new instance of BranchEntity1.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 53

def initialize(branch_id: SKIP, name: SKIP, locations: SKIP,
               financial_institution: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @branch_id = branch_id unless branch_id == SKIP
  @name = name unless name == SKIP
  @locations = locations unless locations == SKIP
  @financial_institution = financial_institution unless financial_institution == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#branch_idString

Branch number

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 14

def branch_id
  @branch_id
end

#financial_institutionFinancialInstitutionEntity2

Financial institution associated with the branch



26
27
28
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 26

def financial_institution
  @financial_institution
end

#locationsArray[PaymentDeliveryAddressEntity]

Location of the branch

Returns:



22
23
24
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 22

def locations
  @locations
end

#nameString

Name of the branch

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  branch_id = hash.key?('branchId') ? hash['branchId'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  # Parameter is an array, so we need to iterate through it
  locations = nil
  unless hash['locations'].nil?
    locations = []
    hash['locations'].each do |structure|
      locations << (PaymentDeliveryAddressEntity.from_hash(structure) if structure)
    end
  end

  locations = SKIP unless hash.key?('locations')
  financial_institution = FinancialInstitutionEntity2.from_hash(hash['financialInstitution']) if
    hash['financialInstitution']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BranchEntity1.new(branch_id: branch_id,
                    name: name,
                    locations: locations,
                    financial_institution: financial_institution,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['branch_id'] = 'branchId'
  @_hash['name'] = 'name'
  @_hash['locations'] = 'locations'
  @_hash['financial_institution'] = 'financialInstitution'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 39

def self.optionals
  %w[
    branch_id
    name
    locations
    financial_institution
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (BranchEntity1 | Hash)

    value against the validation is performed.



102
103
104
105
106
107
108
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 102

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
124
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} branch_id: #{@branch_id.inspect}, name: #{@name.inspect}, locations:"\
  " #{@locations.inspect}, financial_institution: #{@financial_institution.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
116
# File 'lib/fdx_v660_api/models/branch_entity1.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} branch_id: #{@branch_id}, name: #{@name}, locations: #{@locations},"\
  " financial_institution: #{@financial_institution}, additional_properties:"\
  " #{@additional_properties}>"
end