Class: FdxV660Api::BuyNowPayLaterAccountEntity

Inherits:
AccountEntity show all
Defined in:
lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb

Overview

A Buy Now, Pay Later account. Represents a type of credit account where purchases are paid back on independent schedules instead of a standard recurring interval or date, which are commonly used by loan or line of credit accounts.

Instance Attribute Summary collapse

Attributes inherited from AccountEntity

#balance_type, #bank_institution_id, #bank_transit_id, #bill_pay_status, #contact, #early_penalty_flag, #interest_rate, #interest_rate_as_of, #interest_rate_index, #interest_rate_type, #last_activity_date, #line_of_business, #line_of_business_type, #micr_number, #prior_interest_rate, #reward_balances, #reward_program_id, #routing_transit_number, #transactions_included, #transfer_in, #transfer_out

Attributes inherited from AccountDescriptorEntity

#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AccountEntity

discriminators, #to_custom_interest_rate_as_of

Methods inherited from AccountDescriptorEntity

discriminators

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(balance_as_of: SKIP, credit_line: SKIP, available_credit: SKIP, principal_balance: SKIP, current_balance: SKIP, finance_charges: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Buy Now Pay Later Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ BuyNowPayLaterAccountEntity

Returns a new instance of BuyNowPayLaterAccountEntity.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 73

def initialize(balance_as_of: SKIP, credit_line: SKIP,
               available_credit: SKIP, principal_balance: SKIP,
               current_balance: SKIP, finance_charges: SKIP,
               line_of_business: SKIP, line_of_business_type: SKIP,
               routing_transit_number: SKIP, balance_type: SKIP,
               contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP,
               interest_rate_as_of: SKIP, prior_interest_rate: SKIP,
               interest_rate_index: SKIP, early_penalty_flag: SKIP,
               transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP,
               micr_number: SKIP, last_activity_date: SKIP,
               reward_program_id: SKIP, reward_balances: SKIP,
               transactions_included: SKIP, bank_institution_id: SKIP,
               bank_transit_id: SKIP,
               account_category: 'Buy Now Pay Later Account entity',
               account_id: SKIP, parent_account_id: SKIP, error: SKIP,
               account_type: SKIP, domicile: SKIP, account_number: SKIP,
               account_number_display: SKIP, product_id: SKIP,
               product_name: SKIP, nickname: SKIP, status: SKIP,
               description: SKIP, account_open_date: SKIP,
               account_close_date: SKIP, currency: SKIP,
               data_clusters: SKIP, transfer_out_use_cases: SKIP,
               fi_attributes: SKIP, links: SKIP, additional_properties: nil)
  @balance_as_of = balance_as_of unless balance_as_of == SKIP
  @credit_line = credit_line unless credit_line == SKIP
  @available_credit = available_credit unless available_credit == SKIP
  @principal_balance = principal_balance unless principal_balance == SKIP
  @current_balance = current_balance unless current_balance == SKIP
  @finance_charges = finance_charges unless finance_charges == SKIP
  @additional_properties = additional_properties

  # Call the constructor of the base class
  super(line_of_business: line_of_business,
        line_of_business_type: line_of_business_type,
        routing_transit_number: routing_transit_number,
        balance_type: balance_type,
        contact: contact,
        interest_rate: interest_rate,
        interest_rate_type: interest_rate_type,
        interest_rate_as_of: interest_rate_as_of,
        prior_interest_rate: prior_interest_rate,
        interest_rate_index: interest_rate_index,
        early_penalty_flag: early_penalty_flag,
        transfer_in: transfer_in,
        transfer_out: transfer_out,
        bill_pay_status: bill_pay_status,
        micr_number: micr_number,
        last_activity_date: last_activity_date,
        reward_program_id: reward_program_id,
        reward_balances: reward_balances,
        transactions_included: transactions_included,
        bank_institution_id: bank_institution_id,
        bank_transit_id: bank_transit_id,
        account_category: ,
        account_id: ,
        parent_account_id: ,
        error: error,
        account_type: ,
        domicile: domicile,
        account_number: ,
        account_number_display: ,
        product_id: product_id,
        product_name: product_name,
        nickname: nickname,
        status: status,
        description: description,
        account_open_date: ,
        account_close_date: ,
        currency: currency,
        data_clusters: data_clusters,
        transfer_out_use_cases: transfer_out_use_cases,
        fi_attributes: fi_attributes,
        links: links,
        additional_properties: additional_properties)
end

Instance Attribute Details

#available_creditFloat

How much the customer can currently spend on new buy now pay later purchases

Returns:

  • (Float)


27
28
29
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 27

def available_credit
  @available_credit
end

#balance_as_ofDateTime

As-of date for balances

Returns:

  • (DateTime)


17
18
19
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 17

def balance_as_of
  @balance_as_of
end

#credit_lineFloat

Maximum amount the customer can spend using buy now pay later. This is the same as a "credit limit" on a Line of Credit account

Returns:

  • (Float)


22
23
24
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 22

def credit_line
  @credit_line
end

#current_balanceFloat

Current balance of the buy now pay later account

Returns:

  • (Float)


35
36
37
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 35

def current_balance
  @current_balance
end

#finance_chargesFloat

Finance charges

Returns:

  • (Float)


39
40
41
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 39

def finance_charges
  @finance_charges
end

#principal_balanceFloat

Amount the customer owes excluding fees and interest

Returns:

  • (Float)


31
32
33
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 31

def principal_balance
  @principal_balance
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 149

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  balance_as_of = if hash.key?('balanceAsOf')
                    (DateTimeHelper.from_rfc3339(hash['balanceAsOf']) if hash['balanceAsOf'])
                  else
                    SKIP
                  end
  credit_line = hash.key?('creditLine') ? hash['creditLine'] : SKIP
  available_credit =
    hash.key?('availableCredit') ? hash['availableCredit'] : SKIP
  principal_balance =
    hash.key?('principalBalance') ? hash['principalBalance'] : SKIP
  current_balance =
    hash.key?('currentBalance') ? hash['currentBalance'] : SKIP
  finance_charges =
    hash.key?('financeCharges') ? hash['financeCharges'] : SKIP
  line_of_business =
    hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP
  line_of_business_type =
    hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP
  routing_transit_number =
    hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP
  balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP
  contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact']
  interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP
  interest_rate_type =
    hash.key?('interestRateType') ? hash['interestRateType'] : SKIP
  interest_rate_as_of = if hash.key?('interestRateAsOf')
                          (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf'])
                        else
                          SKIP
                        end
  prior_interest_rate =
    hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP
  interest_rate_index =
    hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP
  early_penalty_flag =
    hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP
  transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP
  transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP
  bill_pay_status =
    hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP
  micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP
  last_activity_date =
    hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP
  reward_program_id =
    hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP
  # Parameter is an array, so we need to iterate through it
  reward_balances = nil
  unless hash['rewardBalances'].nil?
    reward_balances = []
    hash['rewardBalances'].each do |structure|
      reward_balances << (RewardBalanceEntity.from_hash(structure) if structure)
    end
  end

  reward_balances = SKIP unless hash.key?('rewardBalances')
  transactions_included =
    hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP
  bank_institution_id =
    hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP
  bank_transit_id =
    hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP
   =
    hash['accountCategory'] ||= 'Buy Now Pay Later Account entity'
   = hash.key?('accountId') ? hash['accountId'] : SKIP
   =
    hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP
  error = Error3.from_hash(hash['error']) if hash['error']
   = hash.key?('accountType') ? hash['accountType'] : SKIP
  domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile']
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
   =
    hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP
  product_id = hash.key?('productId') ? hash['productId'] : SKIP
  product_name = hash.key?('productName') ? hash['productName'] : SKIP
  nickname = hash.key?('nickname') ? hash['nickname'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  description = hash.key?('description') ? hash['description'] : SKIP
   =
    hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP
   =
    hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP
  currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency']
  data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP
  transfer_out_use_cases =
    hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP
  # Parameter is an array, so we need to iterate through it
  fi_attributes = nil
  unless hash['fiAttributes'].nil?
    fi_attributes = []
    hash['fiAttributes'].each do |structure|
      fi_attributes << (FiAttributeEntity.from_hash(structure) if structure)
    end
  end

  fi_attributes = SKIP unless hash.key?('fiAttributes')
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BuyNowPayLaterAccountEntity.new(balance_as_of: balance_as_of,
                                  credit_line: credit_line,
                                  available_credit: available_credit,
                                  principal_balance: principal_balance,
                                  current_balance: current_balance,
                                  finance_charges: finance_charges,
                                  line_of_business: line_of_business,
                                  line_of_business_type: line_of_business_type,
                                  routing_transit_number: routing_transit_number,
                                  balance_type: balance_type,
                                  contact: contact,
                                  interest_rate: interest_rate,
                                  interest_rate_type: interest_rate_type,
                                  interest_rate_as_of: interest_rate_as_of,
                                  prior_interest_rate: prior_interest_rate,
                                  interest_rate_index: interest_rate_index,
                                  early_penalty_flag: early_penalty_flag,
                                  transfer_in: transfer_in,
                                  transfer_out: transfer_out,
                                  bill_pay_status: bill_pay_status,
                                  micr_number: micr_number,
                                  last_activity_date: last_activity_date,
                                  reward_program_id: reward_program_id,
                                  reward_balances: reward_balances,
                                  transactions_included: transactions_included,
                                  bank_institution_id: bank_institution_id,
                                  bank_transit_id: bank_transit_id,
                                  account_category: ,
                                  account_id: ,
                                  parent_account_id: ,
                                  error: error,
                                  account_type: ,
                                  domicile: domicile,
                                  account_number: ,
                                  account_number_display: ,
                                  product_id: product_id,
                                  product_name: product_name,
                                  nickname: nickname,
                                  status: status,
                                  description: description,
                                  account_open_date: ,
                                  account_close_date: ,
                                  currency: currency,
                                  data_clusters: data_clusters,
                                  transfer_out_use_cases: transfer_out_use_cases,
                                  fi_attributes: fi_attributes,
                                  links: links,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



42
43
44
45
46
47
48
49
50
51
52
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 42

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['balance_as_of'] = 'balanceAsOf'
  @_hash['credit_line'] = 'creditLine'
  @_hash['available_credit'] = 'availableCredit'
  @_hash['principal_balance'] = 'principalBalance'
  @_hash['current_balance'] = 'currentBalance'
  @_hash['finance_charges'] = 'financeCharges'
  @_hash = super().merge(@_hash)
  @_hash
end

.nullablesObject

An array for nullable fields



68
69
70
71
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 68

def self.nullables
  _arr = []
  (_arr << super()).flatten!
end

.optionalsObject

An array for optional fields



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 55

def self.optionals
  _arr = %w[
    balance_as_of
    credit_line
    available_credit
    principal_balance
    current_balance
    finance_charges
  ]
  (_arr << super()).flatten!
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



323
324
325
326
327
328
329
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 323

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



342
343
344
345
346
347
348
349
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 342

def inspect
  class_name = self.class.name.split('::').last
  super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '')
  "<#{class_name} #{super_string}, balance_as_of: #{@balance_as_of.inspect}, credit_line:"\
  " #{@credit_line.inspect}, available_credit: #{@available_credit.inspect},"\
  " principal_balance: #{@principal_balance.inspect}, current_balance:"\
  " #{@current_balance.inspect}, finance_charges: #{@finance_charges.inspect}>"
end

#to_custom_balance_as_ofObject



317
318
319
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 317

def to_custom_balance_as_of
  DateTimeHelper.to_rfc3339(balance_as_of)
end

#to_sObject

Provides a human-readable string representation of the object.



332
333
334
335
336
337
338
339
# File 'lib/fdx_v660_api/models/buy_now_pay_later_account_entity.rb', line 332

def to_s
  class_name = self.class.name.split('::').last
  super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '')
  "<#{class_name} #{super_string}, balance_as_of: #{@balance_as_of}, credit_line:"\
  " #{@credit_line}, available_credit: #{@available_credit}, principal_balance:"\
  " #{@principal_balance}, current_balance: #{@current_balance}, finance_charges:"\
  " #{@finance_charges}>"
end