Class: FdxV660Api::ConsentGrantsEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/consent_grants_entity.rb

Overview

Array of customer Consent Grants

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(consent_grants: SKIP, additional_properties: nil) ⇒ ConsentGrantsEntity

Returns a new instance of ConsentGrantsEntity.



35
36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 35

def initialize(consent_grants: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @consent_grants = consent_grants unless consent_grants == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

The list of consent grants for the requested customer id

Returns:



14
15
16
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 14

def consent_grants
  @consent_grants
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  consent_grants = nil
  unless hash['consentGrants'].nil?
    consent_grants = []
    hash['consentGrants'].each do |structure|
      consent_grants << (ConsentGrantEntity.from_hash(structure) if structure)
    end
  end

  consent_grants = SKIP unless hash.key?('consentGrants')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsentGrantsEntity.new(consent_grants: consent_grants,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['consent_grants'] = 'consentGrants'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 24

def self.optionals
  %w[
    consent_grants
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} consent_grants: #{@consent_grants.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/fdx_v660_api/models/consent_grants_entity.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} consent_grants: #{@consent_grants}, additional_properties:"\
  " #{@additional_properties}>"
end