Class: FdxV660Api::ConsentResourceEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/consent_resource_entity.rb

Overview

Details of requested or granted resource and data clusters

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(resource_type:, resource_id:, data_clusters:, additional_properties: nil) ⇒ ConsentResourceEntity

Returns a new instance of ConsentResourceEntity.



43
44
45
46
47
48
49
50
51
52
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 43

def initialize(resource_type:, resource_id:, data_clusters:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @resource_type = resource_type
  @resource_id = resource_id
  @data_clusters = data_clusters
  @additional_properties = additional_properties
end

Instance Attribute Details

#data_clustersArray[DataCluster]

Names of clusters for the permissioned resource

Returns:



22
23
24
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 22

def data_clusters
  @data_clusters
end

#resource_idString

Identifier of resource being permissioned

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 18

def resource_id
  @resource_id
end

#resource_typeConsentResourceType2

Type of resource for this permission



14
15
16
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 14

def resource_type
  @resource_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  resource_type = hash.key?('resourceType') ? hash['resourceType'] : nil
  resource_id = hash.key?('resourceId') ? hash['resourceId'] : nil
  data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsentResourceEntity.new(resource_type: resource_type,
                            resource_id: resource_id,
                            data_clusters: data_clusters,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['resource_type'] = 'resourceType'
  @_hash['resource_id'] = 'resourceId'
  @_hash['data_clusters'] = 'dataClusters'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
90
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} resource_type: #{@resource_type.inspect}, resource_id:"\
  " #{@resource_id.inspect}, data_clusters: #{@data_clusters.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/fdx_v660_api/models/consent_resource_entity.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} resource_type: #{@resource_type}, resource_id: #{@resource_id},"\
  " data_clusters: #{@data_clusters}, additional_properties: #{@additional_properties}>"
end