Class: FdxV660Api::ContactsEntity1
- Defined in:
- lib/fdx_v660_api/models/contacts_entity1.rb
Overview
Employer's various contact information
Instance Attribute Summary collapse
-
#addresses ⇒ Array[DeliveryAddress]
Array of the contact physical addresses.
-
#emails ⇒ Array[String]
Array of the contact email addresses.
-
#telephones ⇒ Array[TelephoneNumberPlusExtension]
Array of the contact telephone numbers, with extension if any.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(emails: SKIP, addresses: SKIP, telephones: SKIP, additional_properties: nil) ⇒ ContactsEntity1
constructor
A new instance of ContactsEntity1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(emails: SKIP, addresses: SKIP, telephones: SKIP, additional_properties: nil) ⇒ ContactsEntity1
Returns a new instance of ContactsEntity1.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 47 def initialize(emails: SKIP, addresses: SKIP, telephones: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @emails = emails unless emails == SKIP @addresses = addresses unless addresses == SKIP @telephones = telephones unless telephones == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#addresses ⇒ Array[DeliveryAddress]
Array of the contact physical addresses
18 19 20 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 18 def addresses @addresses end |
#emails ⇒ Array[String]
Array of the contact email addresses
14 15 16 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 14 def emails @emails end |
#telephones ⇒ Array[TelephoneNumberPlusExtension]
Array of the contact telephone numbers, with extension if any
22 23 24 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 22 def telephones @telephones end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. emails = hash.key?('emails') ? hash['emails'] : SKIP # Parameter is an array, so we need to iterate through it addresses = nil unless hash['addresses'].nil? addresses = [] hash['addresses'].each do |structure| addresses << (DeliveryAddress.from_hash(structure) if structure) end end addresses = SKIP unless hash.key?('addresses') # Parameter is an array, so we need to iterate through it telephones = nil unless hash['telephones'].nil? telephones = [] hash['telephones'].each do |structure| telephones << (TelephoneNumberPlusExtension.from_hash(structure) if structure) end end telephones = SKIP unless hash.key?('telephones') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ContactsEntity1.new(emails: emails, addresses: addresses, telephones: telephones, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['emails'] = 'emails' @_hash['addresses'] = 'addresses' @_hash['telephones'] = 'telephones' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 34 def self.optionals %w[ emails addresses telephones ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} emails: #{@emails.inspect}, addresses: #{@addresses.inspect}, telephones:"\ " #{@telephones.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 |
# File 'lib/fdx_v660_api/models/contacts_entity1.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} emails: #{@emails}, addresses: #{@addresses}, telephones: #{@telephones},"\ " additional_properties: #{@additional_properties}>" end |