Class: FdxV660Api::CryptocurrencyTaxStatementList1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb

Overview

Cryptocurrency Tax Statement list. Replaced summer of 2025 by Tax1099Da for IRS form 1099-DA

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, gains_and_losses: SKIP, additional_properties: nil) ⇒ CryptocurrencyTaxStatementList1

Returns a new instance of CryptocurrencyTaxStatementList1.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 121

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, gains_and_losses: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @gains_and_losses = gains_and_losses unless gains_and_losses == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


24
25
26
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 24

def 
  @account_id
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


38
39
40
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 38

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



64
65
66
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 64

def attributes
  @attributes
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 19

def corrected
  @corrected
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



68
69
70
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 68

def error
  @error
end

#gains_and_lossesArray[GainOrLossFromCryptocurrencyTransaction]

The list of cryptocurrency gains and losses



76
77
78
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 76

def gains_and_losses
  @gains_and_losses
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



48
49
50
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 48

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



72
73
74
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 72

def links
  @links
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



54
55
56
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 54

def recipient
  @recipient
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


34
35
36
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 34

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


30
31
32
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 30

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



42
43
44
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 42

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


15
16
17
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 15

def tax_year
  @tax_year
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 147

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
  # Parameter is an array, so we need to iterate through it
  gains_and_losses = nil
  unless hash['gainsAndLosses'].nil?
    gains_and_losses = []
    hash['gainsAndLosses'].each do |structure|
      gains_and_losses << (GainOrLossFromCryptocurrencyTransaction.from_hash(structure) if structure)
    end
  end

  gains_and_losses = SKIP unless hash.key?('gainsAndLosses')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CryptocurrencyTaxStatementList1.new(tax_year: tax_year,
                                      corrected: corrected,
                                      account_id: ,
                                      tax_form_id: tax_form_id,
                                      tax_form_date: tax_form_date,
                                      additional_information: additional_information,
                                      tax_form_type: tax_form_type,
                                      issuer: issuer,
                                      recipient: recipient,
                                      attributes: attributes,
                                      error: error,
                                      links: links,
                                      gains_and_losses: gains_and_losses,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 79

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['gains_and_losses'] = 'gainsAndLosses'
  @_hash
end

.nullablesObject

An array for nullable fields



117
118
119
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 117

def self.nullables
  []
end

.optionalsObject

An array for optional fields



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 98

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    gains_and_losses
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



229
230
231
232
233
234
235
236
237
238
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 229

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, gains_and_losses: #{@gains_and_losses.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



218
219
220
221
222
223
224
225
226
# File 'lib/fdx_v660_api/models/cryptocurrency_tax_statement_list1.rb', line 218

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, gains_and_losses: #{@gains_and_losses},"\
  " additional_properties: #{@additional_properties}>"
end