Class: FdxV660Api::CustomerNameEntity3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/customer_name_entity3.rb

Overview

The customer's name

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first: SKIP, middle: SKIP, last: SKIP, suffix: SKIP, prefix: SKIP, company: SKIP, additional_properties: nil) ⇒ CustomerNameEntity3

Returns a new instance of CustomerNameEntity3.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 65

def initialize(first: SKIP, middle: SKIP, last: SKIP, suffix: SKIP,
               prefix: SKIP, company: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first = first unless first == SKIP
  @middle = middle unless middle == SKIP
  @last = last unless last == SKIP
  @suffix = suffix unless suffix == SKIP
  @prefix = prefix unless prefix == SKIP
  @company = company unless company == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#companyString

Company name

Returns:

  • (String)


34
35
36
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 34

def company
  @company
end

#firstString

First name

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 14

def first
  @first
end

#lastString

Last name

Returns:

  • (String)


22
23
24
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 22

def last
  @last
end

#middleString

Middle initial

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 18

def middle
  @middle
end

#prefixString

Name prefix, e.g. Mr.

Returns:

  • (String)


30
31
32
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 30

def prefix
  @prefix
end

#suffixString

Generational or academic suffix

Returns:

  • (String)


26
27
28
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 26

def suffix
  @suffix
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first = hash.key?('first') ? hash['first'] : SKIP
  middle = hash.key?('middle') ? hash['middle'] : SKIP
  last = hash.key?('last') ? hash['last'] : SKIP
  suffix = hash.key?('suffix') ? hash['suffix'] : SKIP
  prefix = hash.key?('prefix') ? hash['prefix'] : SKIP
  company = hash.key?('company') ? hash['company'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CustomerNameEntity3.new(first: first,
                          middle: middle,
                          last: last,
                          suffix: suffix,
                          prefix: prefix,
                          company: company,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first'] = 'first'
  @_hash['middle'] = 'middle'
  @_hash['last'] = 'last'
  @_hash['suffix'] = 'suffix'
  @_hash['prefix'] = 'prefix'
  @_hash['company'] = 'company'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 49

def self.optionals
  %w[
    first
    middle
    last
    suffix
    prefix
    company
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



110
111
112
113
114
115
116
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 110

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first: #{@first.inspect}, middle: #{@middle.inspect}, last:"\
  " #{@last.inspect}, suffix: #{@suffix.inspect}, prefix: #{@prefix.inspect}, company:"\
  " #{@company.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
124
# File 'lib/fdx_v660_api/models/customer_name_entity3.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first: #{@first}, middle: #{@middle}, last: #{@last}, suffix: #{@suffix},"\
  " prefix: #{@prefix}, company: #{@company}, additional_properties:"\
  " #{@additional_properties}>"
end