Class: FdxV660Api::CustomerToAccountRelationshipEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb

Overview

Describes an account related to a customer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id: SKIP, links: SKIP, relationship: SKIP, additional_properties: nil) ⇒ CustomerToAccountRelationshipEntity

Returns a new instance of CustomerToAccountRelationshipEntity.



47
48
49
50
51
52
53
54
55
56
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 47

def initialize(account_id: SKIP, links: SKIP, relationship: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id =  unless  == SKIP
  @links = links unless links == SKIP
  @relationship = relationship unless relationship == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Account ID of the related account

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 14

def 
  @account_id
end

Links to the account, or to invoke other APIs

Returns:



18
19
20
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 18

def links
  @links
end

#relationshipAccountHolderRelationship3

Type of relationship to the account



22
23
24
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 22

def relationship
  @relationship
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
  relationship = hash.key?('relationship') ? hash['relationship'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CustomerToAccountRelationshipEntity.new(account_id: ,
                                          links: links,
                                          relationship: relationship,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'accountId'
  @_hash['links'] = 'links'
  @_hash['relationship'] = 'relationship'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 34

def self.optionals
  %w[
    account_id
    links
    relationship
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



92
93
94
95
96
97
98
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 92

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, links: #{@links.inspect}, relationship:"\
  " #{@relationship.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/fdx_v660_api/models/customer_to_account_relationship_entity.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, links: #{@links}, relationship:"\
  " #{@relationship}, additional_properties: #{@additional_properties}>"
end