Class: FdxV660Api::DataProviderRecordsAtEcosystemRegistry

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb

Overview

Data provider records at Ecosystem Registry. Properties in this structure use 'snake_case' names to match the properties in IETF RFC 7591.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(data_providers:, page: SKIP, links: SKIP, additional_properties: nil) ⇒ DataProviderRecordsAtEcosystemRegistry

Returns a new instance of DataProviderRecordsAtEcosystemRegistry.



48
49
50
51
52
53
54
55
56
57
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 48

def initialize(data_providers:, page: SKIP, links: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @page = page unless page == SKIP
  @links = links unless links == SKIP
  @data_providers = data_providers
  @additional_properties = additional_properties
end

Instance Attribute Details

#data_providersArray[DataProviderAtEcosystemRegistry]

Data providers retrieved by the operation



24
25
26
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 24

def data_providers
  @data_providers
end

Resource URLs for navigating result sets

Returns:



20
21
22
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 20

def links
  @links
end

#pagePageMetadata

Page keys for navigating result sets

Returns:



16
17
18
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 16

def page
  @page
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  data_providers = nil
  unless hash['data_providers'].nil?
    data_providers = []
    hash['data_providers'].each do |structure|
      data_providers << (DataProviderAtEcosystemRegistry.from_hash(structure) if structure)
    end
  end

  data_providers = nil unless hash.key?('data_providers')
  page = PageMetadata.from_hash(hash['page']) if hash['page']
  links = PageMetadataLinks1.from_hash(hash['links']) if hash['links']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DataProviderRecordsAtEcosystemRegistry.new(data_providers: data_providers,
                                             page: page,
                                             links: links,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['page'] = 'page'
  @_hash['links'] = 'links'
  @_hash['data_providers'] = 'data_providers'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 36

def self.optionals
  %w[
    page
    links
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page.inspect}, links: #{@links.inspect}, data_providers:"\
  " #{@data_providers.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/fdx_v660_api/models/data_provider_records_at_ecosystem_registry.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page}, links: #{@links}, data_providers: #{@data_providers},"\
  " additional_properties: #{@additional_properties}>"
end