Class: FdxV660Api::DateAndAmount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/date_and_amount.rb

Overview

Date, description, and amount. When used in 1098-Q, description is optional

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(date: SKIP, description: SKIP, amount: SKIP, additional_properties: nil) ⇒ DateAndAmount

Returns a new instance of DateAndAmount.



47
48
49
50
51
52
53
54
55
56
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 47

def initialize(date: SKIP, description: SKIP, amount: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @date = date unless date == SKIP
  @description = description unless description == SKIP
  @amount = amount unless amount == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountFloat

Amount of payment or receipt. When used in 1098-Q, monthly total

Returns:

  • (Float)


22
23
24
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 22

def amount
  @amount
end

#dateDate

Date of amount. When used in 1098-Q, date of last payment in month

Returns:

  • (Date)


14
15
16
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 14

def date
  @date
end

#descriptionString

Description of amount. When used in 1098-Q, may use MonthAbbreviation

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 18

def description
  @description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  date = hash.key?('date') ? hash['date'] : SKIP
  description = hash.key?('description') ? hash['description'] : SKIP
  amount = hash.key?('amount') ? hash['amount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DateAndAmount.new(date: date,
                    description: description,
                    amount: amount,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['date'] = 'date'
  @_hash['description'] = 'description'
  @_hash['amount'] = 'amount'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 34

def self.optionals
  %w[
    date
    description
    amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date.inspect}, description: #{@description.inspect}, amount:"\
  " #{@amount.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/fdx_v660_api/models/date_and_amount.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} date: #{@date}, description: #{@description}, amount: #{@amount},"\
  " additional_properties: #{@additional_properties}>"
end