Class: FdxV660Api::DescriptionAndAmount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::DescriptionAndAmount
- Defined in:
- lib/fdx_v660_api/models/description_and_amount.rb
Overview
Description and amount pair used on IRS W-2, etc.
Instance Attribute Summary collapse
-
#amount ⇒ Float
Amount.
-
#description ⇒ String
Description.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(description: SKIP, amount: SKIP, additional_properties: nil) ⇒ DescriptionAndAmount
constructor
A new instance of DescriptionAndAmount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(description: SKIP, amount: SKIP, additional_properties: nil) ⇒ DescriptionAndAmount
Returns a new instance of DescriptionAndAmount.
41 42 43 44 45 46 47 48 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 41 def initialize(description: SKIP, amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @description = description unless description == SKIP @amount = amount unless amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
Amount
18 19 20 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 18 def amount @amount end |
#description ⇒ String
Description
14 15 16 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 14 def description @description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. description = hash.key?('description') ? hash['description'] : SKIP amount = hash.key?('amount') ? hash['amount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DescriptionAndAmount.new(description: description, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['description'] = 'description' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 29 def self.optionals %w[ description amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} description: #{@description.inspect}, amount: #{@amount.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/fdx_v660_api/models/description_and_amount.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} description: #{@description}, amount: #{@amount}, additional_properties:"\ " #{@additional_properties}>" end |