Class: FdxV660Api::DomicileEntity
- Defined in:
- lib/fdx_v660_api/models/domicile_entity.rb
Overview
Country and region of country for the legal jurisdiction of an entity
Instance Attribute Summary collapse
-
#country ⇒ Iso3166CountryCode7
ISO 3166 Country Code.
-
#region ⇒ String
Country sub-division; state or province or territory.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(region: SKIP, country: SKIP, additional_properties: nil) ⇒ DomicileEntity
constructor
A new instance of DomicileEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(region: SKIP, country: SKIP, additional_properties: nil) ⇒ DomicileEntity
Returns a new instance of DomicileEntity.
43 44 45 46 47 48 49 50 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 43 def initialize(region: SKIP, country: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @region = region unless region == SKIP @country = country unless country == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ Iso3166CountryCode7
ISO 3166 Country Code
20 21 22 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 20 def country @country end |
#region ⇒ String
Country sub-division; state or province or territory. For U.S. addresses
can be a 2-character code from StateCode. For Canadian addresses can be
a 2-character code from ProvinceTerritoryCode
16 17 18 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 16 def region @region end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. region = hash.key?('region') ? hash['region'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DomicileEntity.new(region: region, country: country, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['region'] = 'region' @_hash['country'] = 'country' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 31 def self.optionals %w[ region country ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} region: #{@region.inspect}, country: #{@country.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/fdx_v660_api/models/domicile_entity.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} region: #{@region}, country: #{@country}, additional_properties:"\ " #{@additional_properties}>" end |