Class: FdxV660Api::DomicileEntity1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/domicile_entity1.rb

Overview

The country and region of the business customer's location

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(region: SKIP, country: SKIP, additional_properties: nil) ⇒ DomicileEntity1

Returns a new instance of DomicileEntity1.



43
44
45
46
47
48
49
50
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 43

def initialize(region: SKIP, country: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @region = region unless region == SKIP
  @country = country unless country == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#countryIso3166CountryCode7

ISO 3166 Country Code

Returns:



20
21
22
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 20

def country
  @country
end

#regionString

Country sub-division; state or province or territory. For U.S. addresses can be a 2-character code from StateCode. For Canadian addresses can be a 2-character code from ProvinceTerritoryCode

Returns:

  • (String)


16
17
18
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 16

def region
  @region
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  region = hash.key?('region') ? hash['region'] : SKIP
  country = hash.key?('country') ? hash['country'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DomicileEntity1.new(region: region,
                      country: country,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['region'] = 'region'
  @_hash['country'] = 'country'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 31

def self.optionals
  %w[
    region
    country
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (DomicileEntity1 | Hash)

    value against the validation is performed.



75
76
77
78
79
80
81
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 75

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} region: #{@region.inspect}, country: #{@country.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/fdx_v660_api/models/domicile_entity1.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} region: #{@region}, country: #{@country}, additional_properties:"\
  " #{@additional_properties}>"
end