Class: FdxV660Api::FdxApiActorType
- Inherits:
-
Object
- Object
- FdxV660Api::FdxApiActorType
- Defined in:
- lib/fdx_v660_api/models/fdx_api_actor_type.rb
Overview
Indicates whether a customer is present and has requested the operation (USER), or if a batch job has requested the operation (BATCH)
Constant Summary collapse
- FDX_API_ACTOR_TYPE =
[ # TODO: Write general description for BATCH BATCH = 'BATCH'.freeze, # TODO: Write general description for USER USER = 'USER'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = BATCH) ⇒ Object
24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/fdx_v660_api/models/fdx_api_actor_type.rb', line 24 def self.from_value(value, default_value = BATCH) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'batch' then BATCH when 'user' then USER else default_value end end |
.validate(value) ⇒ Object
18 19 20 21 22 |
# File 'lib/fdx_v660_api/models/fdx_api_actor_type.rb', line 18 def self.validate(value) return false if value.nil? true end |