Class: FdxV660Api::FinancialInstitutionEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::FinancialInstitutionEntity
- Defined in:
- lib/fdx_v660_api/models/financial_institution_entity.rb
Overview
Details of the Financial Institution that is owning the destination account
Instance Attribute Summary collapse
-
#fi_id ⇒ Object
Financial institution identifier.
-
#locations ⇒ Array[PaymentDeliveryAddressEntity]
Location of the financial institution.
-
#name ⇒ String
Name of the financial institution.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name: SKIP, fi_id: SKIP, locations: SKIP, additional_properties: nil) ⇒ FinancialInstitutionEntity
constructor
A new instance of FinancialInstitutionEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, fi_id: SKIP, locations: SKIP, additional_properties: nil) ⇒ FinancialInstitutionEntity
Returns a new instance of FinancialInstitutionEntity.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 47 def initialize(name: SKIP, fi_id: SKIP, locations: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @fi_id = fi_id unless fi_id == SKIP @locations = locations unless locations == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fi_id ⇒ Object
Financial institution identifier
18 19 20 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 18 def fi_id @fi_id end |
#locations ⇒ Array[PaymentDeliveryAddressEntity]
Location of the financial institution
22 23 24 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 22 def locations @locations end |
#name ⇒ String
Name of the financial institution
14 15 16 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 14 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP fi_id = hash.key?('fiId') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:FinancialInstitutionEntityFiId), hash['fiId'] ) : SKIP # Parameter is an array, so we need to iterate through it locations = nil unless hash['locations'].nil? locations = [] hash['locations'].each do |structure| locations << (PaymentDeliveryAddressEntity.from_hash(structure) if structure) end end locations = SKIP unless hash.key?('locations') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FinancialInstitutionEntity.new(name: name, fi_id: fi_id, locations: locations, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['fi_id'] = 'fiId' @_hash['locations'] = 'locations' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 34 def self.optionals %w[ name fi_id locations ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
94 95 96 97 98 99 100 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 94 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, fi_id: #{@fi_id.inspect}, locations:"\ " #{@locations.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/fdx_v660_api/models/financial_institution_entity.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, fi_id: #{@fi_id}, locations: #{@locations},"\ " additional_properties: #{@additional_properties}>" end |