Class: FdxV660Api::Form1095B
- Defined in:
- lib/fdx_v660_api/models/form1095_b.rb
Overview
Health Coverage, from Issuer (boxes 16-22) to Responsible Individual (boxes 1-2, 4-7 as recipient)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#covered_individuals ⇒ Array[HealthInsuranceCoveredIndividual]
Boxes 23+, Covered Individuals.
-
#employer ⇒ TaxParty3
Boxes 10-15, Employer EIN, name and address.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#origin_of_health_coverage_code ⇒ String
Box 8, Enter letter identifying Origin of the Health Coverage.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#responsible_date_of_birth ⇒ Date
Box 3, Date of birth (if SSN or other TIN is not available).
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, responsible_date_of_birth: SKIP, origin_of_health_coverage_code: SKIP, employer: SKIP, covered_individuals: SKIP, additional_properties: nil) ⇒ Form1095B
constructor
A new instance of Form1095B.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, responsible_date_of_birth: SKIP, origin_of_health_coverage_code: SKIP, employer: SKIP, covered_individuals: SKIP, additional_properties: nil) ⇒ Form1095B
Returns a new instance of Form1095B.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 139 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, responsible_date_of_birth: SKIP, origin_of_health_coverage_code: SKIP, employer: SKIP, covered_individuals: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP unless responsible_date_of_birth == SKIP @responsible_date_of_birth = responsible_date_of_birth end unless origin_of_health_coverage_code == SKIP @origin_of_health_coverage_code = origin_of_health_coverage_code end @employer = employer unless employer == SKIP @covered_individuals = covered_individuals unless covered_individuals == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 24 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 19 def corrected @corrected end |
#covered_individuals ⇒ Array[HealthInsuranceCoveredIndividual]
Boxes 23+, Covered Individuals
88 89 90 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 88 def covered_individuals @covered_individuals end |
#employer ⇒ TaxParty3
Boxes 10-15, Employer EIN, name and address
84 85 86 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 84 def employer @employer end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 68 def error @error end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 72 def links @links end |
#origin_of_health_coverage_code ⇒ String
Box 8, Enter letter identifying Origin of the Health Coverage
80 81 82 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 80 def origin_of_health_coverage_code @origin_of_health_coverage_code end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 54 def recipient @recipient end |
#responsible_date_of_birth ⇒ Date
Box 3, Date of birth (if SSN or other TIN is not available)
76 77 78 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 76 def responsible_date_of_birth @responsible_date_of_birth end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 15 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 175 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') responsible_date_of_birth = hash.key?('responsibleDateOfBirth') ? hash['responsibleDateOfBirth'] : SKIP origin_of_health_coverage_code = hash.key?('originOfHealthCoverageCode') ? hash['originOfHealthCoverageCode'] : SKIP employer = TaxParty3.from_hash(hash['employer']) if hash['employer'] # Parameter is an array, so we need to iterate through it covered_individuals = nil unless hash['coveredIndividuals'].nil? covered_individuals = [] hash['coveredIndividuals'].each do |structure| covered_individuals << (HealthInsuranceCoveredIndividual.from_hash(structure) if structure) end end covered_individuals = SKIP unless hash.key?('coveredIndividuals') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1095B.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, responsible_date_of_birth: responsible_date_of_birth, origin_of_health_coverage_code: origin_of_health_coverage_code, employer: employer, covered_individuals: covered_individuals, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 91 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['responsible_date_of_birth'] = 'responsibleDateOfBirth' @_hash['origin_of_health_coverage_code'] = 'originOfHealthCoverageCode' @_hash['employer'] = 'employer' @_hash['covered_individuals'] = 'coveredIndividuals' @_hash end |
.nullables ⇒ Object
An array for nullable fields
135 136 137 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 135 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 113 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links responsible_date_of_birth origin_of_health_coverage_code employer covered_individuals ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 267 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, responsible_date_of_birth:"\ " #{@responsible_date_of_birth.inspect}, origin_of_health_coverage_code:"\ " #{@origin_of_health_coverage_code.inspect}, employer: #{@employer.inspect},"\ " covered_individuals: #{@covered_individuals.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/fdx_v660_api/models/form1095_b.rb', line 254 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, responsible_date_of_birth: #{@responsible_date_of_birth},"\ " origin_of_health_coverage_code: #{@origin_of_health_coverage_code}, employer:"\ " #{@employer}, covered_individuals: #{@covered_individuals}, additional_properties:"\ " #{@additional_properties}>" end |