Class: FdxV660Api::Form1095C

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1095_c.rb

Overview

Employer-Provided Health Insurance Offer and Coverage, from Employer (boxes 7-13 as issuer) to Employee (boxes 1-6 as recipient)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, self_insured_coverage: SKIP, offers_of_coverage: SKIP, employee_age: SKIP, plan_start_month: SKIP, covered_individuals: SKIP, additional_properties: nil) ⇒ Form1095C

Returns a new instance of Form1095C.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 145

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, self_insured_coverage: SKIP,
               offers_of_coverage: SKIP, employee_age: SKIP,
               plan_start_month: SKIP, covered_individuals: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @self_insured_coverage = self_insured_coverage unless self_insured_coverage == SKIP
  @offers_of_coverage = offers_of_coverage unless offers_of_coverage == SKIP
  @employee_age = employee_age unless employee_age == SKIP
  @plan_start_month = plan_start_month unless plan_start_month == SKIP
  @covered_individuals = covered_individuals unless covered_individuals == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


24
25
26
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 24

def 
  @account_id
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


38
39
40
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 38

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



64
65
66
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 64

def attributes
  @attributes
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 19

def corrected
  @corrected
end

#covered_individualsArray[HealthInsuranceCoveredIndividual]

Boxes 17+, Covered Individuals



92
93
94
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 92

def covered_individuals
  @covered_individuals
end

#employee_ageInteger

Employee's Age on January 1

Returns:

  • (Integer)


84
85
86
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 84

def employee_age
  @employee_age
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



68
69
70
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 68

def error
  @error
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



48
49
50
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 48

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



72
73
74
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 72

def links
  @links
end

#offers_of_coverageArray[OfferOfHealthInsuranceCoverage]

Boxes 14-16, Employee Offer of Coverage

Returns:



80
81
82
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 80

def offers_of_coverage
  @offers_of_coverage
end

#plan_start_monthInteger

Plan Start Month

Returns:

  • (Integer)


88
89
90
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 88

def plan_start_month
  @plan_start_month
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



54
55
56
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 54

def recipient
  @recipient
end

#self_insured_coverageTrueClass | FalseClass

Self Insured Coverage

Returns:

  • (TrueClass | FalseClass)


76
77
78
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 76

def self_insured_coverage
  @self_insured_coverage
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


34
35
36
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 34

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


30
31
32
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 30

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



42
43
44
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 42

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


15
16
17
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 15

def tax_year
  @tax_year
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 177

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
  self_insured_coverage =
    hash.key?('selfInsuredCoverage') ? hash['selfInsuredCoverage'] : SKIP
  # Parameter is an array, so we need to iterate through it
  offers_of_coverage = nil
  unless hash['offersOfCoverage'].nil?
    offers_of_coverage = []
    hash['offersOfCoverage'].each do |structure|
      offers_of_coverage << (OfferOfHealthInsuranceCoverage.from_hash(structure) if structure)
    end
  end

  offers_of_coverage = SKIP unless hash.key?('offersOfCoverage')
  employee_age = hash.key?('employeeAge') ? hash['employeeAge'] : SKIP
  plan_start_month =
    hash.key?('planStartMonth') ? hash['planStartMonth'] : SKIP
  # Parameter is an array, so we need to iterate through it
  covered_individuals = nil
  unless hash['coveredIndividuals'].nil?
    covered_individuals = []
    hash['coveredIndividuals'].each do |structure|
      covered_individuals << (HealthInsuranceCoveredIndividual.from_hash(structure) if structure)
    end
  end

  covered_individuals = SKIP unless hash.key?('coveredIndividuals')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1095C.new(tax_year: tax_year,
                corrected: corrected,
                account_id: ,
                tax_form_id: tax_form_id,
                tax_form_date: tax_form_date,
                additional_information: additional_information,
                tax_form_type: tax_form_type,
                issuer: issuer,
                recipient: recipient,
                attributes: attributes,
                error: error,
                links: links,
                self_insured_coverage: self_insured_coverage,
                offers_of_coverage: offers_of_coverage,
                employee_age: employee_age,
                plan_start_month: plan_start_month,
                covered_individuals: covered_individuals,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 95

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['self_insured_coverage'] = 'selfInsuredCoverage'
  @_hash['offers_of_coverage'] = 'offersOfCoverage'
  @_hash['employee_age'] = 'employeeAge'
  @_hash['plan_start_month'] = 'planStartMonth'
  @_hash['covered_individuals'] = 'coveredIndividuals'
  @_hash
end

.nullablesObject

An array for nullable fields



141
142
143
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 141

def self.nullables
  []
end

.optionalsObject

An array for optional fields



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 118

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    self_insured_coverage
    offers_of_coverage
    employee_age
    plan_start_month
    covered_individuals
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 280

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, self_insured_coverage: #{@self_insured_coverage.inspect},"\
  " offers_of_coverage: #{@offers_of_coverage.inspect}, employee_age:"\
  " #{@employee_age.inspect}, plan_start_month: #{@plan_start_month.inspect},"\
  " covered_individuals: #{@covered_individuals.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



267
268
269
270
271
272
273
274
275
276
277
# File 'lib/fdx_v660_api/models/form1095_c.rb', line 267

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, self_insured_coverage: #{@self_insured_coverage},"\
  " offers_of_coverage: #{@offers_of_coverage}, employee_age: #{@employee_age},"\
  " plan_start_month: #{@plan_start_month}, covered_individuals: #{@covered_individuals},"\
  " additional_properties: #{@additional_properties}>"
end