Class: FdxV660Api::Form1097Btc1
- Defined in:
- lib/fdx_v660_api/models/form1097_btc1.rb
Overview
Bond Tax Credit
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#amounts ⇒ Array[MonthAndAmount]
Box 5, Amounts by month.
-
#as_nominee ⇒ TrueClass | FalseClass
Form 1097-BTC issuer is: An entity or a person that received or should have received a current year Form 1097-BTC and is distributing part or all of that credit to others.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#bond_code ⇒ String
Box 2a, Code.
-
#bond_type ⇒ String
Box 3, Bond type.
-
#comments ⇒ String
Box 6, Comments.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#filing_for_credit ⇒ TrueClass | FalseClass
Form 1097-BTC issuer is: Issuer of bond or its agent filing current year Form 1097-BTC for credit being reported.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#total ⇒ Float
Box 1, Total.
-
#unique_id ⇒ String
Box 2b, Unique Identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, filing_for_credit: SKIP, as_nominee: SKIP, total: SKIP, bond_code: SKIP, unique_id: SKIP, bond_type: SKIP, amounts: SKIP, comments: SKIP, additional_properties: nil) ⇒ Form1097Btc1
constructor
A new instance of Form1097Btc1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, filing_for_credit: SKIP, as_nominee: SKIP, total: SKIP, bond_code: SKIP, unique_id: SKIP, bond_type: SKIP, amounts: SKIP, comments: SKIP, additional_properties: nil) ⇒ Form1097Btc1
Returns a new instance of Form1097Btc1.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 165 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, filing_for_credit: SKIP, as_nominee: SKIP, total: SKIP, bond_code: SKIP, unique_id: SKIP, bond_type: SKIP, amounts: SKIP, comments: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @filing_for_credit = filing_for_credit unless filing_for_credit == SKIP @as_nominee = as_nominee unless as_nominee == SKIP @total = total unless total == SKIP @bond_code = bond_code unless bond_code == SKIP @unique_id = unique_id unless unique_id == SKIP @bond_type = bond_type unless bond_type == SKIP @amounts = amounts unless amounts == SKIP @comments = comments unless comments == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 37 def additional_information @additional_information end |
#amounts ⇒ Array[MonthAndAmount]
Box 5, Amounts by month
102 103 104 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 102 def amounts @amounts end |
#as_nominee ⇒ TrueClass | FalseClass
Form 1097-BTC issuer is: An entity or a person that received or should have received a current year Form 1097-BTC and is distributing part or all of that credit to others
82 83 84 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 82 def as_nominee @as_nominee end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 63 def attributes @attributes end |
#bond_code ⇒ String
Box 2a, Code
90 91 92 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 90 def bond_code @bond_code end |
#bond_type ⇒ String
Box 3, Bond type
98 99 100 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 98 def bond_type @bond_type end |
#comments ⇒ String
Box 6, Comments
106 107 108 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 106 def comments @comments end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 18 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 67 def error @error end |
#filing_for_credit ⇒ TrueClass | FalseClass
Form 1097-BTC issuer is: Issuer of bond or its agent filing current year Form 1097-BTC for credit being reported
76 77 78 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 76 def filing_for_credit @filing_for_credit end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 71 def links @links end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 53 def recipient @recipient end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 14 def tax_year @tax_year end |
#total ⇒ Float
Box 1, Total
86 87 88 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 86 def total @total end |
#unique_id ⇒ String
Box 2b, Unique Identifier
94 95 96 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 94 def unique_id @unique_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 200 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') filing_for_credit = hash.key?('filingForCredit') ? hash['filingForCredit'] : SKIP as_nominee = hash.key?('asNominee') ? hash['asNominee'] : SKIP total = hash.key?('total') ? hash['total'] : SKIP bond_code = hash.key?('bondCode') ? hash['bondCode'] : SKIP unique_id = hash.key?('uniqueId') ? hash['uniqueId'] : SKIP bond_type = hash.key?('bondType') ? hash['bondType'] : SKIP # Parameter is an array, so we need to iterate through it amounts = nil unless hash['amounts'].nil? amounts = [] hash['amounts'].each do |structure| amounts << (MonthAndAmount.from_hash(structure) if structure) end end amounts = SKIP unless hash.key?('amounts') comments = hash.key?('comments') ? hash['comments'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1097Btc1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, filing_for_credit: filing_for_credit, as_nominee: as_nominee, total: total, bond_code: bond_code, unique_id: unique_id, bond_type: bond_type, amounts: amounts, comments: comments, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 109 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['filing_for_credit'] = 'filingForCredit' @_hash['as_nominee'] = 'asNominee' @_hash['total'] = 'total' @_hash['bond_code'] = 'bondCode' @_hash['unique_id'] = 'uniqueId' @_hash['bond_type'] = 'bondType' @_hash['amounts'] = 'amounts' @_hash['comments'] = 'comments' @_hash end |
.nullables ⇒ Object
An array for nullable fields
161 162 163 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 161 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 135 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links filing_for_credit as_nominee total bond_code unique_id bond_type amounts comments ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 299 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, filing_for_credit: #{@filing_for_credit.inspect}, as_nominee:"\ " #{@as_nominee.inspect}, total: #{@total.inspect}, bond_code: #{@bond_code.inspect},"\ " unique_id: #{@unique_id.inspect}, bond_type: #{@bond_type.inspect}, amounts:"\ " #{@amounts.inspect}, comments: #{@comments.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/fdx_v660_api/models/form1097_btc1.rb', line 286 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, filing_for_credit: #{@filing_for_credit}, as_nominee:"\ " #{@as_nominee}, total: #{@total}, bond_code: #{@bond_code}, unique_id: #{@unique_id},"\ " bond_type: #{@bond_type}, amounts: #{@amounts}, comments: #{@comments},"\ " additional_properties: #{@additional_properties}>" end |