Class: FdxV660Api::Form1098
- Defined in:
- lib/fdx_v660_api/models/form1098.rb
Overview
Mortgage Interest Statement, from RECIPIENT/LENDER (1st-2nd boxes as issuer) to PAYER/BORROWER (3rd-6th boxes as recipient)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#acquisition_date ⇒ Date
Box 11, Mortgage acquisition date.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#is_property_address_same_as_borrower_address ⇒ TrueClass | FalseClass
Box 7, Is address of property securing mortgage same as PAYER'S/BORROWER'S address.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#mortgage_insurance ⇒ Float
Box 5, Mortgage insurance premiums.
-
#mortgage_interest ⇒ Float
Box 1, Mortgage interest received from borrower.
-
#mortgaged_properties ⇒ Integer
Box 9, Number of properties securing the mortgage.
-
#origination_date ⇒ Date
Box 3, Mortgage origination date.
-
#other_information ⇒ String
Box 10, Other (property tax).
-
#outstanding_principal ⇒ Float
Box 2, Outstanding mortgage principal.
-
#overpaid_refund ⇒ Float
Box 4, Refund of overpaid interest.
-
#points_paid ⇒ Float
Box 6, Points paid on purchase of principal residence.
-
#property_address ⇒ TaxFormAddress3
Box 8, Address of property securing mortgage.
-
#property_description ⇒ String
Box 8, Description of property securing mortgage, if property securing mortgage has no address.
-
#property_tax ⇒ Float
Box 10, Property tax, if
othervalue is a property tax. -
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, mortgage_interest: SKIP, outstanding_principal: SKIP, origination_date: SKIP, overpaid_refund: SKIP, mortgage_insurance: SKIP, points_paid: SKIP, is_property_address_same_as_borrower_address: SKIP, property_address: SKIP, property_description: SKIP, mortgaged_properties: SKIP, other_information: SKIP, property_tax: SKIP, acquisition_date: SKIP, additional_properties: nil) ⇒ Form1098
constructor
A new instance of Form1098.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, mortgage_interest: SKIP, outstanding_principal: SKIP, origination_date: SKIP, overpaid_refund: SKIP, mortgage_insurance: SKIP, points_paid: SKIP, is_property_address_same_as_borrower_address: SKIP, property_address: SKIP, property_description: SKIP, mortgaged_properties: SKIP, other_information: SKIP, property_tax: SKIP, acquisition_date: SKIP, additional_properties: nil) ⇒ Form1098
Returns a new instance of Form1098.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 203 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, mortgage_interest: SKIP, outstanding_principal: SKIP, origination_date: SKIP, overpaid_refund: SKIP, mortgage_insurance: SKIP, points_paid: SKIP, is_property_address_same_as_borrower_address: SKIP, property_address: SKIP, property_description: SKIP, mortgaged_properties: SKIP, other_information: SKIP, property_tax: SKIP, acquisition_date: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @mortgage_interest = mortgage_interest unless mortgage_interest == SKIP @outstanding_principal = outstanding_principal unless outstanding_principal == SKIP @origination_date = origination_date unless origination_date == SKIP @overpaid_refund = overpaid_refund unless overpaid_refund == SKIP @mortgage_insurance = mortgage_insurance unless mortgage_insurance == SKIP @points_paid = points_paid unless points_paid == SKIP unless is_property_address_same_as_borrower_address == SKIP @is_property_address_same_as_borrower_address = is_property_address_same_as_borrower_address end @property_address = property_address unless property_address == SKIP @property_description = property_description unless property_description == SKIP @mortgaged_properties = mortgaged_properties unless mortgaged_properties == SKIP @other_information = other_information unless other_information == SKIP @property_tax = property_tax unless property_tax == SKIP @acquisition_date = acquisition_date unless acquisition_date == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 76 def account_number @account_number end |
#acquisition_date ⇒ Date
Box 11, Mortgage acquisition date
131 132 133 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 131 def acquisition_date @acquisition_date end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 19 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 68 def error @error end |
#is_property_address_same_as_borrower_address ⇒ TrueClass | FalseClass
Box 7, Is address of property securing mortgage same as PAYER'S/BORROWER'S address
105 106 107 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 105 def is_property_address_same_as_borrower_address @is_property_address_same_as_borrower_address end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 72 def links @links end |
#mortgage_insurance ⇒ Float
Box 5, Mortgage insurance premiums
96 97 98 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 96 def mortgage_insurance @mortgage_insurance end |
#mortgage_interest ⇒ Float
Box 1, Mortgage interest received from borrower
80 81 82 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 80 def mortgage_interest @mortgage_interest end |
#mortgaged_properties ⇒ Integer
Box 9, Number of properties securing the mortgage
118 119 120 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 118 def mortgaged_properties @mortgaged_properties end |
#origination_date ⇒ Date
Box 3, Mortgage origination date
88 89 90 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 88 def origination_date @origination_date end |
#other_information ⇒ String
Box 10, Other (property tax). Use field propertyTax if other value is
a property tax
123 124 125 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 123 def other_information @other_information end |
#outstanding_principal ⇒ Float
Box 2, Outstanding mortgage principal
84 85 86 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 84 def outstanding_principal @outstanding_principal end |
#overpaid_refund ⇒ Float
Box 4, Refund of overpaid interest
92 93 94 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 92 def overpaid_refund @overpaid_refund end |
#points_paid ⇒ Float
Box 6, Points paid on purchase of principal residence
100 101 102 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 100 def points_paid @points_paid end |
#property_address ⇒ TaxFormAddress3
Box 8, Address of property securing mortgage
109 110 111 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 109 def property_address @property_address end |
#property_description ⇒ String
Box 8, Description of property securing mortgage, if property securing mortgage has no address
114 115 116 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 114 def property_description @property_description end |
#property_tax ⇒ Float
Box 10, Property tax, if other value is a property tax
127 128 129 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 127 def property_tax @property_tax end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 54 def recipient @recipient end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 15 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 252 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP mortgage_interest = hash.key?('mortgageInterest') ? hash['mortgageInterest'] : SKIP outstanding_principal = hash.key?('outstandingPrincipal') ? hash['outstandingPrincipal'] : SKIP origination_date = hash.key?('originationDate') ? hash['originationDate'] : SKIP overpaid_refund = hash.key?('overpaidRefund') ? hash['overpaidRefund'] : SKIP mortgage_insurance = hash.key?('mortgageInsurance') ? hash['mortgageInsurance'] : SKIP points_paid = hash.key?('pointsPaid') ? hash['pointsPaid'] : SKIP is_property_address_same_as_borrower_address = hash.key?('isPropertyAddressSameAsBorrowerAddress') ? hash['isPropertyAddressSameAsBorrowerAddress'] : SKIP property_address = TaxFormAddress3.from_hash(hash['propertyAddress']) if hash['propertyAddress'] property_description = hash.key?('propertyDescription') ? hash['propertyDescription'] : SKIP mortgaged_properties = hash.key?('mortgagedProperties') ? hash['mortgagedProperties'] : SKIP other_information = hash.key?('otherInformation') ? hash['otherInformation'] : SKIP property_tax = hash.key?('propertyTax') ? hash['propertyTax'] : SKIP acquisition_date = hash.key?('acquisitionDate') ? hash['acquisitionDate'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1098.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, mortgage_interest: mortgage_interest, outstanding_principal: outstanding_principal, origination_date: origination_date, overpaid_refund: overpaid_refund, mortgage_insurance: mortgage_insurance, points_paid: points_paid, is_property_address_same_as_borrower_address: is_property_address_same_as_borrower_address, property_address: property_address, property_description: property_description, mortgaged_properties: mortgaged_properties, other_information: other_information, property_tax: property_tax, acquisition_date: acquisition_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 134 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['mortgage_interest'] = 'mortgageInterest' @_hash['outstanding_principal'] = 'outstandingPrincipal' @_hash['origination_date'] = 'originationDate' @_hash['overpaid_refund'] = 'overpaidRefund' @_hash['mortgage_insurance'] = 'mortgageInsurance' @_hash['points_paid'] = 'pointsPaid' @_hash['is_property_address_same_as_borrower_address'] = 'isPropertyAddressSameAsBorrowerAddress' @_hash['property_address'] = 'propertyAddress' @_hash['property_description'] = 'propertyDescription' @_hash['mortgaged_properties'] = 'mortgagedProperties' @_hash['other_information'] = 'otherInformation' @_hash['property_tax'] = 'propertyTax' @_hash['acquisition_date'] = 'acquisitionDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
199 200 201 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 199 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 167 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number mortgage_interest outstanding_principal origination_date overpaid_refund mortgage_insurance points_paid is_property_address_same_as_borrower_address property_address property_description mortgaged_properties other_information property_tax acquisition_date ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 370 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, mortgage_interest:"\ " #{@mortgage_interest.inspect}, outstanding_principal: #{@outstanding_principal.inspect},"\ " origination_date: #{@origination_date.inspect}, overpaid_refund:"\ " #{@overpaid_refund.inspect}, mortgage_insurance: #{@mortgage_insurance.inspect},"\ " points_paid: #{@points_paid.inspect}, is_property_address_same_as_borrower_address:"\ " #{@is_property_address_same_as_borrower_address.inspect}, property_address:"\ " #{@property_address.inspect}, property_description: #{@property_description.inspect},"\ " mortgaged_properties: #{@mortgaged_properties.inspect}, other_information:"\ " #{@other_information.inspect}, property_tax: #{@property_tax.inspect}, acquisition_date:"\ " #{@acquisition_date.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/fdx_v660_api/models/form1098.rb', line 351 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, mortgage_interest:"\ " #{@mortgage_interest}, outstanding_principal: #{@outstanding_principal}, origination_date:"\ " #{@origination_date}, overpaid_refund: #{@overpaid_refund}, mortgage_insurance:"\ " #{@mortgage_insurance}, points_paid: #{@points_paid},"\ ' is_property_address_same_as_borrower_address:'\ " #{@is_property_address_same_as_borrower_address}, property_address: #{@property_address},"\ " property_description: #{@property_description}, mortgaged_properties:"\ " #{@mortgaged_properties}, other_information: #{@other_information}, property_tax:"\ " #{@property_tax}, acquisition_date: #{@acquisition_date}, additional_properties:"\ " #{@additional_properties}>" end |