Class: FdxV660Api::Form1098C1
- Defined in:
- lib/fdx_v660_api/models/form1098_c1.rb
Overview
Contributions of Motor Vehicles, Boats, and Airplanes
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#arms_length_transaction ⇒ TrueClass | FalseClass
Box 4a, Donee certifies that vehicle was sold in arm's length transaction to unrelated party.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#car_year ⇒ Integer
Box 2b, Year.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#date_of_contribution ⇒ Date
Box 1, Date of contribution.
-
#date_of_sale ⇒ Date
Box 4b, Date of sale.
-
#description_of_goods ⇒ String
Box 6c, Describe the goods and services, if any, that were provided.
-
#description_of_improvements ⇒ String
Box 5c, Donee certifies the following detailed description of material improvements or significant intervening use and duration of use.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#goods_in_exchange ⇒ TrueClass | FalseClass
Box 6a, Did you provide goods or services in exchange for the vehicle? Yes.
-
#gross_proceeds ⇒ Float
Box 4c, Gross proceeds from sale (see instructions).
-
#intangible_religious ⇒ TrueClass | FalseClass
Box 6c, If this box is checked, donee certifies that the goods and services consisted solely of intangible religious benefits.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#make ⇒ String
Box 2c, Make.
-
#max_deduction_applies ⇒ TrueClass | FalseClass
Box 7, Under the law, the donor may not claim a deduction of more than $500 for this vehicle if this box is checked.
-
#model ⇒ String
Box 2d, Model.
-
#needy_individual ⇒ TrueClass | FalseClass
Box 5b, Donee certifies that vehicle is to be transferred to a needy individual for significantly below fair market value in furtherance of donee's charitable purpose.
-
#not_transferred_before ⇒ TrueClass | FalseClass
Box 5a, Donee certifies that vehicle will not be transferred for money, other property, or services before completion of material improvements or significant intervening use.
-
#odometer_mileage ⇒ Integer
Box 2a, Odometer mileage.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#value_of_exchange ⇒ Float
Box 6b, Value of goods and services provided in exchange for the vehicle.
-
#vin ⇒ String
Box 3, Vehicle or other identification number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, date_of_contribution: SKIP, odometer_mileage: SKIP, car_year: SKIP, make: SKIP, model: SKIP, vin: SKIP, arms_length_transaction: SKIP, date_of_sale: SKIP, gross_proceeds: SKIP, not_transferred_before: SKIP, needy_individual: SKIP, description_of_improvements: SKIP, goods_in_exchange: SKIP, value_of_exchange: SKIP, intangible_religious: SKIP, description_of_goods: SKIP, max_deduction_applies: SKIP, additional_properties: nil) ⇒ Form1098C1
constructor
A new instance of Form1098C1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, date_of_contribution: SKIP, odometer_mileage: SKIP, car_year: SKIP, make: SKIP, model: SKIP, vin: SKIP, arms_length_transaction: SKIP, date_of_sale: SKIP, gross_proceeds: SKIP, not_transferred_before: SKIP, needy_individual: SKIP, description_of_improvements: SKIP, goods_in_exchange: SKIP, value_of_exchange: SKIP, intangible_religious: SKIP, description_of_goods: SKIP, max_deduction_applies: SKIP, additional_properties: nil) ⇒ Form1098C1
Returns a new instance of Form1098C1.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 224 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, date_of_contribution: SKIP, odometer_mileage: SKIP, car_year: SKIP, make: SKIP, model: SKIP, vin: SKIP, arms_length_transaction: SKIP, date_of_sale: SKIP, gross_proceeds: SKIP, not_transferred_before: SKIP, needy_individual: SKIP, description_of_improvements: SKIP, goods_in_exchange: SKIP, value_of_exchange: SKIP, intangible_religious: SKIP, description_of_goods: SKIP, max_deduction_applies: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @date_of_contribution = date_of_contribution unless date_of_contribution == SKIP @odometer_mileage = odometer_mileage unless odometer_mileage == SKIP @car_year = car_year unless car_year == SKIP @make = make unless make == SKIP @model = model unless model == SKIP @vin = vin unless vin == SKIP @arms_length_transaction = arms_length_transaction unless arms_length_transaction == SKIP @date_of_sale = date_of_sale unless date_of_sale == SKIP @gross_proceeds = gross_proceeds unless gross_proceeds == SKIP @not_transferred_before = not_transferred_before unless not_transferred_before == SKIP @needy_individual = needy_individual unless needy_individual == SKIP unless description_of_improvements == SKIP @description_of_improvements = description_of_improvements end @goods_in_exchange = goods_in_exchange unless goods_in_exchange == SKIP @value_of_exchange = value_of_exchange unless value_of_exchange == SKIP @intangible_religious = intangible_religious unless intangible_religious == SKIP @description_of_goods = description_of_goods unless description_of_goods == SKIP @max_deduction_applies = max_deduction_applies unless max_deduction_applies == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 37 def additional_information @additional_information end |
#arms_length_transaction ⇒ TrueClass | FalseClass
Box 4a, Donee certifies that vehicle was sold in arm's length transaction to unrelated party
100 101 102 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 100 def arms_length_transaction @arms_length_transaction end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 63 def attributes @attributes end |
#car_year ⇒ Integer
Box 2b, Year
83 84 85 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 83 def car_year @car_year end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 18 def corrected @corrected end |
#date_of_contribution ⇒ Date
Box 1, Date of contribution
75 76 77 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 75 def date_of_contribution @date_of_contribution end |
#date_of_sale ⇒ Date
Box 4b, Date of sale
104 105 106 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 104 def date_of_sale @date_of_sale end |
#description_of_goods ⇒ String
Box 6c, Describe the goods and services, if any, that were provided
142 143 144 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 142 def description_of_goods @description_of_goods end |
#description_of_improvements ⇒ String
Box 5c, Donee certifies the following detailed description of material improvements or significant intervening use and duration of use
125 126 127 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 125 def description_of_improvements @description_of_improvements end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 67 def error @error end |
#goods_in_exchange ⇒ TrueClass | FalseClass
Box 6a, Did you provide goods or services in exchange for the vehicle? Yes
129 130 131 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 129 def goods_in_exchange @goods_in_exchange end |
#gross_proceeds ⇒ Float
Box 4c, Gross proceeds from sale (see instructions)
108 109 110 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 108 def gross_proceeds @gross_proceeds end |
#intangible_religious ⇒ TrueClass | FalseClass
Box 6c, If this box is checked, donee certifies that the goods and services consisted solely of intangible religious benefits
138 139 140 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 138 def intangible_religious @intangible_religious end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 71 def links @links end |
#make ⇒ String
Box 2c, Make
87 88 89 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 87 def make @make end |
#max_deduction_applies ⇒ TrueClass | FalseClass
Box 7, Under the law, the donor may not claim a deduction of more than $500 for this vehicle if this box is checked
147 148 149 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 147 def max_deduction_applies @max_deduction_applies end |
#model ⇒ String
Box 2d, Model
91 92 93 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 91 def model @model end |
#needy_individual ⇒ TrueClass | FalseClass
Box 5b, Donee certifies that vehicle is to be transferred to a needy individual for significantly below fair market value in furtherance of donee's charitable purpose
120 121 122 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 120 def needy_individual @needy_individual end |
#not_transferred_before ⇒ TrueClass | FalseClass
Box 5a, Donee certifies that vehicle will not be transferred for money, other property, or services before completion of material improvements or significant intervening use
114 115 116 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 114 def not_transferred_before @not_transferred_before end |
#odometer_mileage ⇒ Integer
Box 2a, Odometer mileage
79 80 81 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 79 def odometer_mileage @odometer_mileage end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 53 def recipient @recipient end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 14 def tax_year @tax_year end |
#value_of_exchange ⇒ Float
Box 6b, Value of goods and services provided in exchange for the vehicle
133 134 135 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 133 def value_of_exchange @value_of_exchange end |
#vin ⇒ String
Box 3, Vehicle or other identification number
95 96 97 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 95 def vin @vin end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 276 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') date_of_contribution = hash.key?('dateOfContribution') ? hash['dateOfContribution'] : SKIP odometer_mileage = hash.key?('odometerMileage') ? hash['odometerMileage'] : SKIP car_year = hash.key?('carYear') ? hash['carYear'] : SKIP make = hash.key?('make') ? hash['make'] : SKIP model = hash.key?('model') ? hash['model'] : SKIP vin = hash.key?('vin') ? hash['vin'] : SKIP arms_length_transaction = hash.key?('armsLengthTransaction') ? hash['armsLengthTransaction'] : SKIP date_of_sale = hash.key?('dateOfSale') ? hash['dateOfSale'] : SKIP gross_proceeds = hash.key?('grossProceeds') ? hash['grossProceeds'] : SKIP not_transferred_before = hash.key?('notTransferredBefore') ? hash['notTransferredBefore'] : SKIP needy_individual = hash.key?('needyIndividual') ? hash['needyIndividual'] : SKIP description_of_improvements = hash.key?('descriptionOfImprovements') ? hash['descriptionOfImprovements'] : SKIP goods_in_exchange = hash.key?('goodsInExchange') ? hash['goodsInExchange'] : SKIP value_of_exchange = hash.key?('valueOfExchange') ? hash['valueOfExchange'] : SKIP intangible_religious = hash.key?('intangibleReligious') ? hash['intangibleReligious'] : SKIP description_of_goods = hash.key?('descriptionOfGoods') ? hash['descriptionOfGoods'] : SKIP max_deduction_applies = hash.key?('maxDeductionApplies') ? hash['maxDeductionApplies'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1098C1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, date_of_contribution: date_of_contribution, odometer_mileage: odometer_mileage, car_year: car_year, make: make, model: model, vin: vin, arms_length_transaction: arms_length_transaction, date_of_sale: date_of_sale, gross_proceeds: gross_proceeds, not_transferred_before: not_transferred_before, needy_individual: needy_individual, description_of_improvements: description_of_improvements, goods_in_exchange: goods_in_exchange, value_of_exchange: value_of_exchange, intangible_religious: intangible_religious, description_of_goods: description_of_goods, max_deduction_applies: max_deduction_applies, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 150 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['date_of_contribution'] = 'dateOfContribution' @_hash['odometer_mileage'] = 'odometerMileage' @_hash['car_year'] = 'carYear' @_hash['make'] = 'make' @_hash['model'] = 'model' @_hash['vin'] = 'vin' @_hash['arms_length_transaction'] = 'armsLengthTransaction' @_hash['date_of_sale'] = 'dateOfSale' @_hash['gross_proceeds'] = 'grossProceeds' @_hash['not_transferred_before'] = 'notTransferredBefore' @_hash['needy_individual'] = 'needyIndividual' @_hash['description_of_improvements'] = 'descriptionOfImprovements' @_hash['goods_in_exchange'] = 'goodsInExchange' @_hash['value_of_exchange'] = 'valueOfExchange' @_hash['intangible_religious'] = 'intangibleReligious' @_hash['description_of_goods'] = 'descriptionOfGoods' @_hash['max_deduction_applies'] = 'maxDeductionApplies' @_hash end |
.nullables ⇒ Object
An array for nullable fields
220 221 222 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 220 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 185 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links date_of_contribution odometer_mileage car_year make model vin arms_length_transaction date_of_sale gross_proceeds not_transferred_before needy_individual description_of_improvements goods_in_exchange value_of_exchange intangible_religious description_of_goods max_deduction_applies ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 400 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, date_of_contribution: #{@date_of_contribution.inspect},"\ " odometer_mileage: #{@odometer_mileage.inspect}, car_year: #{@car_year.inspect}, make:"\ " #{@make.inspect}, model: #{@model.inspect}, vin: #{@vin.inspect}, arms_length_transaction:"\ " #{@arms_length_transaction.inspect}, date_of_sale: #{@date_of_sale.inspect},"\ " gross_proceeds: #{@gross_proceeds.inspect}, not_transferred_before:"\ " #{@not_transferred_before.inspect}, needy_individual: #{@needy_individual.inspect},"\ " description_of_improvements: #{@description_of_improvements.inspect}, goods_in_exchange:"\ " #{@goods_in_exchange.inspect}, value_of_exchange: #{@value_of_exchange.inspect},"\ " intangible_religious: #{@intangible_religious.inspect}, description_of_goods:"\ " #{@description_of_goods.inspect}, max_deduction_applies:"\ " #{@max_deduction_applies.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/fdx_v660_api/models/form1098_c1.rb', line 381 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, date_of_contribution: #{@date_of_contribution},"\ " odometer_mileage: #{@odometer_mileage}, car_year: #{@car_year}, make: #{@make}, model:"\ " #{@model}, vin: #{@vin}, arms_length_transaction: #{@arms_length_transaction},"\ " date_of_sale: #{@date_of_sale}, gross_proceeds: #{@gross_proceeds},"\ " not_transferred_before: #{@not_transferred_before}, needy_individual:"\ " #{@needy_individual}, description_of_improvements: #{@description_of_improvements},"\ " goods_in_exchange: #{@goods_in_exchange}, value_of_exchange: #{@value_of_exchange},"\ " intangible_religious: #{@intangible_religious}, description_of_goods:"\ " #{@description_of_goods}, max_deduction_applies: #{@max_deduction_applies},"\ " additional_properties: #{@additional_properties}>" end |