Class: FdxV660Api::Form1098Vli1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1098_vli1.rb

Overview

Vehicle Loan Interest Statement

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, vehicle_loan_interest: SKIP, car_year: SKIP, make: SKIP, model: SKIP, vin: SKIP, origination_date: SKIP, acquisition_date: SKIP, outstanding_principal: SKIP, interest_refund: SKIP, additional_properties: nil) ⇒ Form1098Vli1

Returns a new instance of Form1098Vli1.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 174

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, account_number: SKIP,
               vehicle_loan_interest: SKIP, car_year: SKIP, make: SKIP,
               model: SKIP, vin: SKIP, origination_date: SKIP,
               acquisition_date: SKIP, outstanding_principal: SKIP,
               interest_refund: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @account_number =  unless  == SKIP
  @vehicle_loan_interest = vehicle_loan_interest unless vehicle_loan_interest == SKIP
  @car_year = car_year unless car_year == SKIP
  @make = make unless make == SKIP
  @model = model unless model == SKIP
  @vin = vin unless vin == SKIP
  @origination_date = origination_date unless origination_date == SKIP
  @acquisition_date = acquisition_date unless acquisition_date == SKIP
  @outstanding_principal = outstanding_principal unless outstanding_principal == SKIP
  @interest_refund = interest_refund unless interest_refund == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


23
24
25
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 23

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


75
76
77
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 75

def 
  @account_number
end

#acquisition_dateDate

Box 3b, Loan acquisition date

Returns:

  • (Date)


103
104
105
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 103

def acquisition_date
  @acquisition_date
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


37
38
39
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 37

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



63
64
65
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 63

def attributes
  @attributes
end

#car_yearInteger

Box 2a, Year

Returns:

  • (Integer)


83
84
85
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 83

def car_year
  @car_year
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 18

def corrected
  @corrected
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



67
68
69
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 67

def error
  @error
end

#interest_refundFloat

Box 5, Refund of overpaid interest

Returns:

  • (Float)


111
112
113
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 111

def interest_refund
  @interest_refund
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



47
48
49
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 47

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



71
72
73
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 71

def links
  @links
end

#makeString

Box 2b, Make

Returns:

  • (String)


87
88
89
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 87

def make
  @make
end

#modelString

Box 2c, Model

Returns:

  • (String)


91
92
93
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 91

def model
  @model
end

#origination_dateDate

Box 3a, Loan origination date

Returns:

  • (Date)


99
100
101
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 99

def origination_date
  @origination_date
end

#outstanding_principalFloat

Box 4, Outstanding principal

Returns:

  • (Float)


107
108
109
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 107

def outstanding_principal
  @outstanding_principal
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



53
54
55
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 53

def recipient
  @recipient
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


33
34
35
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 33

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


29
30
31
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 29

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



41
42
43
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 41

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


14
15
16
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 14

def tax_year
  @tax_year
end

#vehicle_loan_interestFloat

Box 1, Vehicle loan interest received by lender

Returns:

  • (Float)


79
80
81
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 79

def vehicle_loan_interest
  @vehicle_loan_interest
end

#vinString

Box 2d, Vehicle or other identification number (VIN)

Returns:

  • (String)


95
96
97
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 95

def vin
  @vin
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 212

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  vehicle_loan_interest =
    hash.key?('vehicleLoanInterest') ? hash['vehicleLoanInterest'] : SKIP
  car_year = hash.key?('carYear') ? hash['carYear'] : SKIP
  make = hash.key?('make') ? hash['make'] : SKIP
  model = hash.key?('model') ? hash['model'] : SKIP
  vin = hash.key?('vin') ? hash['vin'] : SKIP
  origination_date =
    hash.key?('originationDate') ? hash['originationDate'] : SKIP
  acquisition_date =
    hash.key?('acquisitionDate') ? hash['acquisitionDate'] : SKIP
  outstanding_principal =
    hash.key?('outstandingPrincipal') ? hash['outstandingPrincipal'] : SKIP
  interest_refund =
    hash.key?('interestRefund') ? hash['interestRefund'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1098Vli1.new(tax_year: tax_year,
                   corrected: corrected,
                   account_id: ,
                   tax_form_id: tax_form_id,
                   tax_form_date: tax_form_date,
                   additional_information: additional_information,
                   tax_form_type: tax_form_type,
                   issuer: issuer,
                   recipient: recipient,
                   attributes: attributes,
                   error: error,
                   links: links,
                   account_number: ,
                   vehicle_loan_interest: vehicle_loan_interest,
                   car_year: car_year,
                   make: make,
                   model: model,
                   vin: vin,
                   origination_date: origination_date,
                   acquisition_date: acquisition_date,
                   outstanding_principal: outstanding_principal,
                   interest_refund: interest_refund,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 114

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['account_number'] = 'accountNumber'
  @_hash['vehicle_loan_interest'] = 'vehicleLoanInterest'
  @_hash['car_year'] = 'carYear'
  @_hash['make'] = 'make'
  @_hash['model'] = 'model'
  @_hash['vin'] = 'vin'
  @_hash['origination_date'] = 'originationDate'
  @_hash['acquisition_date'] = 'acquisitionDate'
  @_hash['outstanding_principal'] = 'outstandingPrincipal'
  @_hash['interest_refund'] = 'interestRefund'
  @_hash
end

.nullablesObject

An array for nullable fields



170
171
172
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 170

def self.nullables
  []
end

.optionalsObject

An array for optional fields



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 142

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    account_number
    vehicle_loan_interest
    car_year
    make
    model
    vin
    origination_date
    acquisition_date
    outstanding_principal
    interest_refund
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 311

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, account_number: #{@account_number.inspect},"\
  " vehicle_loan_interest: #{@vehicle_loan_interest.inspect}, car_year: #{@car_year.inspect},"\
  " make: #{@make.inspect}, model: #{@model.inspect}, vin: #{@vin.inspect}, origination_date:"\
  " #{@origination_date.inspect}, acquisition_date: #{@acquisition_date.inspect},"\
  " outstanding_principal: #{@outstanding_principal.inspect}, interest_refund:"\
  " #{@interest_refund.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/fdx_v660_api/models/form1098_vli1.rb', line 297

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, account_number: #{@account_number}, vehicle_loan_interest:"\
  " #{@vehicle_loan_interest}, car_year: #{@car_year}, make: #{@make}, model: #{@model}, vin:"\
  " #{@vin}, origination_date: #{@origination_date}, acquisition_date: #{@acquisition_date},"\
  " outstanding_principal: #{@outstanding_principal}, interest_refund: #{@interest_refund},"\
  " additional_properties: #{@additional_properties}>"
end