Class: FdxV660Api::Form1099B

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1099_b.rb

Overview

Proceeds From Broker and Barter Exchange Transactions, from PAYER (1st-9th boxes as issuer) to RECIPIENT (10th-17th boxes). If reported on Form 1099-DA, use Tax1099Da and DigitalAssetDetail instead

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, state_and_local: SKIP, federal_tax_withheld: SKIP, profit_on_closed_contracts: SKIP, unrealized_profit_open_contracts_begin: SKIP, unrealized_profit_open_contracts_end: SKIP, aggregate_profit_on_contracts: SKIP, bartering: SKIP, security_details: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099B

Returns a new instance of Form1099B.



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 178

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, account_number: SKIP, state_and_local: SKIP,
               federal_tax_withheld: SKIP, profit_on_closed_contracts: SKIP,
               unrealized_profit_open_contracts_begin: SKIP,
               unrealized_profit_open_contracts_end: SKIP,
               aggregate_profit_on_contracts: SKIP, bartering: SKIP,
               security_details: SKIP, second_tin_notice: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @account_number =  unless  == SKIP
  @state_and_local = state_and_local unless state_and_local == SKIP
  @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP
  unless profit_on_closed_contracts == SKIP
    @profit_on_closed_contracts =
      profit_on_closed_contracts
  end
  unless unrealized_profit_open_contracts_begin == SKIP
    @unrealized_profit_open_contracts_begin =
      unrealized_profit_open_contracts_begin
  end
  unless unrealized_profit_open_contracts_end == SKIP
    @unrealized_profit_open_contracts_end =
      unrealized_profit_open_contracts_end
  end
  unless aggregate_profit_on_contracts == SKIP
    @aggregate_profit_on_contracts =
      aggregate_profit_on_contracts
  end
  @bartering = bartering unless bartering == SKIP
  @security_details = security_details unless security_details == SKIP
  @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


25
26
27
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 25

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


77
78
79
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 77

def 
  @account_number
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


39
40
41
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 39

def additional_information
  @additional_information
end

#aggregate_profit_on_contractsFloat

Box 11, Aggregate profit or (loss) on contracts

Returns:

  • (Float)


101
102
103
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 101

def aggregate_profit_on_contracts
  @aggregate_profit_on_contracts
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



65
66
67
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 65

def attributes
  @attributes
end

#barteringFloat

Box 13, Bartering

Returns:

  • (Float)


105
106
107
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 105

def bartering
  @bartering
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


20
21
22
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 20

def corrected
  @corrected
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



69
70
71
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 69

def error
  @error
end

#federal_tax_withheldFloat

Box 4, Federal income tax withheld

Returns:

  • (Float)


85
86
87
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 85

def federal_tax_withheld
  @federal_tax_withheld
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



49
50
51
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 49

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



73
74
75
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 73

def links
  @links
end

#profit_on_closed_contractsFloat

Box 8, Profit or (loss) realized in current year on closed contracts

Returns:

  • (Float)


89
90
91
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 89

def profit_on_closed_contracts
  @profit_on_closed_contracts
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



55
56
57
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 55

def recipient
  @recipient
end

#second_tin_noticeTrueClass | FalseClass

Second TIN Notice

Returns:

  • (TrueClass | FalseClass)


113
114
115
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 113

def second_tin_notice
  @second_tin_notice
end

#security_detailsArray[SecurityDetailIrsForm1099B]

Boxes 1-3, 5-7, 12, Security details

Returns:



109
110
111
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 109

def security_details
  @security_details
end

#state_and_localArray[StateAndLocalTaxWithholding]

Boxes 14-16, State and Local tax withholding

Returns:



81
82
83
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 81

def state_and_local
  @state_and_local
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


35
36
37
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 35

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


31
32
33
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 31

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



43
44
45
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 43

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


16
17
18
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 16

def tax_year
  @tax_year
end

#unrealized_profit_open_contracts_beginFloat

Box 9, Unrealized profit or loss on open contracts at end of last year

Returns:

  • (Float)


93
94
95
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 93

def unrealized_profit_open_contracts_begin
  @unrealized_profit_open_contracts_begin
end

#unrealized_profit_open_contracts_endFloat

Box 10, Unrealized profit or loss on open contracts at end of current year

Returns:

  • (Float)


97
98
99
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 97

def unrealized_profit_open_contracts_end
  @unrealized_profit_open_contracts_end
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 230

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  # Parameter is an array, so we need to iterate through it
  state_and_local = nil
  unless hash['stateAndLocal'].nil?
    state_and_local = []
    hash['stateAndLocal'].each do |structure|
      state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure)
    end
  end

  state_and_local = SKIP unless hash.key?('stateAndLocal')
  federal_tax_withheld =
    hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP
  profit_on_closed_contracts =
    hash.key?('profitOnClosedContracts') ? hash['profitOnClosedContracts'] : SKIP
  unrealized_profit_open_contracts_begin =
    hash.key?('unrealizedProfitOpenContractsBegin') ? hash['unrealizedProfitOpenContractsBegin'] : SKIP
  unrealized_profit_open_contracts_end =
    hash.key?('unrealizedProfitOpenContractsEnd') ? hash['unrealizedProfitOpenContractsEnd'] : SKIP
  aggregate_profit_on_contracts =
    hash.key?('aggregateProfitOnContracts') ? hash['aggregateProfitOnContracts'] : SKIP
  bartering = hash.key?('bartering') ? hash['bartering'] : SKIP
  # Parameter is an array, so we need to iterate through it
  security_details = nil
  unless hash['securityDetails'].nil?
    security_details = []
    hash['securityDetails'].each do |structure|
      security_details << (SecurityDetailIrsForm1099B.from_hash(structure) if structure)
    end
  end

  security_details = SKIP unless hash.key?('securityDetails')
  second_tin_notice =
    hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1099B.new(tax_year: tax_year,
                corrected: corrected,
                account_id: ,
                tax_form_id: tax_form_id,
                tax_form_date: tax_form_date,
                additional_information: additional_information,
                tax_form_type: tax_form_type,
                issuer: issuer,
                recipient: recipient,
                attributes: attributes,
                error: error,
                links: links,
                account_number: ,
                state_and_local: state_and_local,
                federal_tax_withheld: federal_tax_withheld,
                profit_on_closed_contracts: profit_on_closed_contracts,
                unrealized_profit_open_contracts_begin: unrealized_profit_open_contracts_begin,
                unrealized_profit_open_contracts_end: unrealized_profit_open_contracts_end,
                aggregate_profit_on_contracts: aggregate_profit_on_contracts,
                bartering: bartering,
                security_details: security_details,
                second_tin_notice: second_tin_notice,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 116

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['account_number'] = 'accountNumber'
  @_hash['state_and_local'] = 'stateAndLocal'
  @_hash['federal_tax_withheld'] = 'federalTaxWithheld'
  @_hash['profit_on_closed_contracts'] = 'profitOnClosedContracts'
  @_hash['unrealized_profit_open_contracts_begin'] =
    'unrealizedProfitOpenContractsBegin'
  @_hash['unrealized_profit_open_contracts_end'] =
    'unrealizedProfitOpenContractsEnd'
  @_hash['aggregate_profit_on_contracts'] = 'aggregateProfitOnContracts'
  @_hash['bartering'] = 'bartering'
  @_hash['security_details'] = 'securityDetails'
  @_hash['second_tin_notice'] = 'secondTinNotice'
  @_hash
end

.nullablesObject

An array for nullable fields



174
175
176
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 174

def self.nullables
  []
end

.optionalsObject

An array for optional fields



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 146

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    account_number
    state_and_local
    federal_tax_withheld
    profit_on_closed_contracts
    unrealized_profit_open_contracts_begin
    unrealized_profit_open_contracts_end
    aggregate_profit_on_contracts
    bartering
    security_details
    second_tin_notice
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 351

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, account_number: #{@account_number.inspect}, state_and_local:"\
  " #{@state_and_local.inspect}, federal_tax_withheld: #{@federal_tax_withheld.inspect},"\
  " profit_on_closed_contracts: #{@profit_on_closed_contracts.inspect},"\
  ' unrealized_profit_open_contracts_begin:'\
  " #{@unrealized_profit_open_contracts_begin.inspect}, unrealized_profit_open_contracts_end:"\
  " #{@unrealized_profit_open_contracts_end.inspect}, aggregate_profit_on_contracts:"\
  " #{@aggregate_profit_on_contracts.inspect}, bartering: #{@bartering.inspect},"\
  " security_details: #{@security_details.inspect}, second_tin_notice:"\
  " #{@second_tin_notice.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/fdx_v660_api/models/form1099_b.rb', line 334

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, account_number: #{@account_number}, state_and_local:"\
  " #{@state_and_local}, federal_tax_withheld: #{@federal_tax_withheld},"\
  " profit_on_closed_contracts: #{@profit_on_closed_contracts},"\
  " unrealized_profit_open_contracts_begin: #{@unrealized_profit_open_contracts_begin},"\
  " unrealized_profit_open_contracts_end: #{@unrealized_profit_open_contracts_end},"\
  " aggregate_profit_on_contracts: #{@aggregate_profit_on_contracts}, bartering:"\
  " #{@bartering}, security_details: #{@security_details}, second_tin_notice:"\
  " #{@second_tin_notice}, additional_properties: #{@additional_properties}>"
end