Class: FdxV660Api::Form1099B1
- Defined in:
- lib/fdx_v660_api/models/form1099_b1.rb
Overview
Proceeds From Broker and Barter Exchange Transactions
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#aggregate_profit_on_contracts ⇒ Float
Box 11, Aggregate profit or (loss) on contracts.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#bartering ⇒ Float
Box 13, Bartering.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#profit_on_closed_contracts ⇒ Float
Box 8, Profit or (loss) realized in current year on closed contracts.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice.
-
#security_details ⇒ Array[SecurityDetailIrsForm1099B]
Boxes 1-3, 5-7, 12, Security details.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 14-16, State and Local tax withholding.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#unrealized_profit_open_contracts_begin ⇒ Float
Box 9, Unrealized profit or loss on open contracts at end of last year.
-
#unrealized_profit_open_contracts_end ⇒ Float
Box 10, Unrealized profit or loss on open contracts at end of current year.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, state_and_local: SKIP, federal_tax_withheld: SKIP, profit_on_closed_contracts: SKIP, unrealized_profit_open_contracts_begin: SKIP, unrealized_profit_open_contracts_end: SKIP, aggregate_profit_on_contracts: SKIP, bartering: SKIP, security_details: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099B1
constructor
A new instance of Form1099B1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, state_and_local: SKIP, federal_tax_withheld: SKIP, profit_on_closed_contracts: SKIP, unrealized_profit_open_contracts_begin: SKIP, unrealized_profit_open_contracts_end: SKIP, aggregate_profit_on_contracts: SKIP, bartering: SKIP, security_details: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099B1
Returns a new instance of Form1099B1.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 176 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, state_and_local: SKIP, federal_tax_withheld: SKIP, profit_on_closed_contracts: SKIP, unrealized_profit_open_contracts_begin: SKIP, unrealized_profit_open_contracts_end: SKIP, aggregate_profit_on_contracts: SKIP, bartering: SKIP, security_details: SKIP, second_tin_notice: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP unless profit_on_closed_contracts == SKIP @profit_on_closed_contracts = profit_on_closed_contracts end unless unrealized_profit_open_contracts_begin == SKIP @unrealized_profit_open_contracts_begin = unrealized_profit_open_contracts_begin end unless unrealized_profit_open_contracts_end == SKIP @unrealized_profit_open_contracts_end = unrealized_profit_open_contracts_end end unless aggregate_profit_on_contracts == SKIP @aggregate_profit_on_contracts = aggregate_profit_on_contracts end @bartering = unless == SKIP @security_details = security_details unless security_details == SKIP @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 23 def account_id @account_id end |
#account_number ⇒ String
Account number
75 76 77 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 75 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 37 def additional_information @additional_information end |
#aggregate_profit_on_contracts ⇒ Float
Box 11, Aggregate profit or (loss) on contracts
99 100 101 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 99 def aggregate_profit_on_contracts @aggregate_profit_on_contracts end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 63 def attributes @attributes end |
#bartering ⇒ Float
Box 13, Bartering
103 104 105 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 103 def @bartering end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 18 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 67 def error @error end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
83 84 85 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 83 def federal_tax_withheld @federal_tax_withheld end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 71 def links @links end |
#profit_on_closed_contracts ⇒ Float
Box 8, Profit or (loss) realized in current year on closed contracts
87 88 89 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 87 def profit_on_closed_contracts @profit_on_closed_contracts end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 53 def recipient @recipient end |
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice
111 112 113 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 111 def second_tin_notice @second_tin_notice end |
#security_details ⇒ Array[SecurityDetailIrsForm1099B]
Boxes 1-3, 5-7, 12, Security details
107 108 109 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 107 def security_details @security_details end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 14-16, State and Local tax withholding
79 80 81 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 79 def state_and_local @state_and_local end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 14 def tax_year @tax_year end |
#unrealized_profit_open_contracts_begin ⇒ Float
Box 9, Unrealized profit or loss on open contracts at end of last year
91 92 93 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 91 def unrealized_profit_open_contracts_begin @unrealized_profit_open_contracts_begin end |
#unrealized_profit_open_contracts_end ⇒ Float
Box 10, Unrealized profit or loss on open contracts at end of current year
95 96 97 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 95 def unrealized_profit_open_contracts_end @unrealized_profit_open_contracts_end end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 228 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP profit_on_closed_contracts = hash.key?('profitOnClosedContracts') ? hash['profitOnClosedContracts'] : SKIP unrealized_profit_open_contracts_begin = hash.key?('unrealizedProfitOpenContractsBegin') ? hash['unrealizedProfitOpenContractsBegin'] : SKIP unrealized_profit_open_contracts_end = hash.key?('unrealizedProfitOpenContractsEnd') ? hash['unrealizedProfitOpenContractsEnd'] : SKIP aggregate_profit_on_contracts = hash.key?('aggregateProfitOnContracts') ? hash['aggregateProfitOnContracts'] : SKIP = hash.key?('bartering') ? hash['bartering'] : SKIP # Parameter is an array, so we need to iterate through it security_details = nil unless hash['securityDetails'].nil? security_details = [] hash['securityDetails'].each do |structure| security_details << (SecurityDetailIrsForm1099B.from_hash(structure) if structure) end end security_details = SKIP unless hash.key?('securityDetails') second_tin_notice = hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099B1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, state_and_local: state_and_local, federal_tax_withheld: federal_tax_withheld, profit_on_closed_contracts: profit_on_closed_contracts, unrealized_profit_open_contracts_begin: unrealized_profit_open_contracts_begin, unrealized_profit_open_contracts_end: unrealized_profit_open_contracts_end, aggregate_profit_on_contracts: aggregate_profit_on_contracts, bartering: , security_details: security_details, second_tin_notice: second_tin_notice, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 114 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['state_and_local'] = 'stateAndLocal' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['profit_on_closed_contracts'] = 'profitOnClosedContracts' @_hash['unrealized_profit_open_contracts_begin'] = 'unrealizedProfitOpenContractsBegin' @_hash['unrealized_profit_open_contracts_end'] = 'unrealizedProfitOpenContractsEnd' @_hash['aggregate_profit_on_contracts'] = 'aggregateProfitOnContracts' @_hash['bartering'] = 'bartering' @_hash['security_details'] = 'securityDetails' @_hash['second_tin_notice'] = 'secondTinNotice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
172 173 174 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 172 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 144 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number state_and_local federal_tax_withheld profit_on_closed_contracts unrealized_profit_open_contracts_begin unrealized_profit_open_contracts_end aggregate_profit_on_contracts bartering security_details second_tin_notice ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 349 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, state_and_local:"\ " #{@state_and_local.inspect}, federal_tax_withheld: #{@federal_tax_withheld.inspect},"\ " profit_on_closed_contracts: #{@profit_on_closed_contracts.inspect},"\ ' unrealized_profit_open_contracts_begin:'\ " #{@unrealized_profit_open_contracts_begin.inspect}, unrealized_profit_open_contracts_end:"\ " #{@unrealized_profit_open_contracts_end.inspect}, aggregate_profit_on_contracts:"\ " #{@aggregate_profit_on_contracts.inspect}, bartering: #{@bartering.inspect},"\ " security_details: #{@security_details.inspect}, second_tin_notice:"\ " #{@second_tin_notice.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/fdx_v660_api/models/form1099_b1.rb', line 332 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, state_and_local:"\ " #{@state_and_local}, federal_tax_withheld: #{@federal_tax_withheld},"\ " profit_on_closed_contracts: #{@profit_on_closed_contracts},"\ " unrealized_profit_open_contracts_begin: #{@unrealized_profit_open_contracts_begin},"\ " unrealized_profit_open_contracts_end: #{@unrealized_profit_open_contracts_end},"\ " aggregate_profit_on_contracts: #{@aggregate_profit_on_contracts}, bartering:"\ " #{@bartering}, security_details: #{@security_details}, second_tin_notice:"\ " #{@second_tin_notice}, additional_properties: #{@additional_properties}>" end |