Class: FdxV660Api::Form1099ConsolidatedStatement

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1099_consolidated_statement.rb

Overview

Various tax-related items reported on consolidated brokerage or mutual fund statements not on the base 1099 forms. The component 1099 forms are delivered as their own Tax1099Xxx entities as usual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, margin_interest_paid: SKIP, payment_in_lieu_paid: SKIP, advisor_fees_paid: SKIP, other_fees_paid: SKIP, corporate_bond_interest_paid: SKIP, us_bond_interest_paid: SKIP, tax_exempt_interest_paid: SKIP, specified_pab_interest_paid: SKIP, additional_properties: nil) ⇒ Form1099ConsolidatedStatement

Returns a new instance of Form1099ConsolidatedStatement.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 168

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, margin_interest_paid: SKIP,
               payment_in_lieu_paid: SKIP, advisor_fees_paid: SKIP,
               other_fees_paid: SKIP, corporate_bond_interest_paid: SKIP,
               us_bond_interest_paid: SKIP, tax_exempt_interest_paid: SKIP,
               specified_pab_interest_paid: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @margin_interest_paid = margin_interest_paid unless margin_interest_paid == SKIP
  @payment_in_lieu_paid = payment_in_lieu_paid unless payment_in_lieu_paid == SKIP
  @advisor_fees_paid = advisor_fees_paid unless advisor_fees_paid == SKIP
  @other_fees_paid = other_fees_paid unless other_fees_paid == SKIP
  unless corporate_bond_interest_paid == SKIP
    @corporate_bond_interest_paid =
      corporate_bond_interest_paid
  end
  @us_bond_interest_paid = us_bond_interest_paid unless us_bond_interest_paid == SKIP
  @tax_exempt_interest_paid = tax_exempt_interest_paid unless tax_exempt_interest_paid == SKIP
  unless specified_pab_interest_paid == SKIP
    @specified_pab_interest_paid =
      specified_pab_interest_paid
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


25
26
27
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 25

def 
  @account_id
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


39
40
41
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 39

def additional_information
  @additional_information
end

#advisor_fees_paidFloat

Advisor fees paid

Returns:

  • (Float)


85
86
87
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 85

def advisor_fees_paid
  @advisor_fees_paid
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



65
66
67
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 65

def attributes
  @attributes
end

#corporate_bond_interest_paidFloat

Accrued Interest Paid offset to form 1099-INT box 1, Corporate bond interest income

Returns:

  • (Float)


94
95
96
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 94

def corporate_bond_interest_paid
  @corporate_bond_interest_paid
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


20
21
22
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 20

def corrected
  @corrected
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



69
70
71
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 69

def error
  @error
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



49
50
51
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 49

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



73
74
75
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 73

def links
  @links
end

#margin_interest_paidFloat

Interest paid on margin account

Returns:

  • (Float)


77
78
79
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 77

def margin_interest_paid
  @margin_interest_paid
end

#other_fees_paidFloat

Other fees paid

Returns:

  • (Float)


89
90
91
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 89

def other_fees_paid
  @other_fees_paid
end

#payment_in_lieu_paidFloat

Payment in lieu of dividends paid

Returns:

  • (Float)


81
82
83
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 81

def payment_in_lieu_paid
  @payment_in_lieu_paid
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



55
56
57
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 55

def recipient
  @recipient
end

#specified_pab_interest_paidFloat

Accrued Interest Paid offset to form 1099-INT box 9, tax exempt interest income from Private Activity Bonds

Returns:

  • (Float)


109
110
111
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 109

def specified_pab_interest_paid
  @specified_pab_interest_paid
end

#tax_exempt_interest_paidFloat

Accrued Interest Paid offset to form 1099-INT box 8, tax exempt interest income from municipal bonds

Returns:

  • (Float)


104
105
106
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 104

def tax_exempt_interest_paid
  @tax_exempt_interest_paid
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


35
36
37
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 35

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


31
32
33
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 31

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



43
44
45
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 43

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


16
17
18
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 16

def tax_year
  @tax_year
end

#us_bond_interest_paidFloat

Accrued Interest Paid offset to form 1099-INT box 3, accrued U.S. Treasury Notes and Bonds interest income

Returns:

  • (Float)


99
100
101
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 99

def us_bond_interest_paid
  @us_bond_interest_paid
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 211

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
  margin_interest_paid =
    hash.key?('marginInterestPaid') ? hash['marginInterestPaid'] : SKIP
  payment_in_lieu_paid =
    hash.key?('paymentInLieuPaid') ? hash['paymentInLieuPaid'] : SKIP
  advisor_fees_paid =
    hash.key?('advisorFeesPaid') ? hash['advisorFeesPaid'] : SKIP
  other_fees_paid =
    hash.key?('otherFeesPaid') ? hash['otherFeesPaid'] : SKIP
  corporate_bond_interest_paid =
    hash.key?('corporateBondInterestPaid') ? hash['corporateBondInterestPaid'] : SKIP
  us_bond_interest_paid =
    hash.key?('usBondInterestPaid') ? hash['usBondInterestPaid'] : SKIP
  tax_exempt_interest_paid =
    hash.key?('taxExemptInterestPaid') ? hash['taxExemptInterestPaid'] : SKIP
  specified_pab_interest_paid =
    hash.key?('specifiedPabInterestPaid') ? hash['specifiedPabInterestPaid'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1099ConsolidatedStatement.new(tax_year: tax_year,
                                    corrected: corrected,
                                    account_id: ,
                                    tax_form_id: tax_form_id,
                                    tax_form_date: tax_form_date,
                                    additional_information: additional_information,
                                    tax_form_type: tax_form_type,
                                    issuer: issuer,
                                    recipient: recipient,
                                    attributes: attributes,
                                    error: error,
                                    links: links,
                                    margin_interest_paid: margin_interest_paid,
                                    payment_in_lieu_paid: payment_in_lieu_paid,
                                    advisor_fees_paid: advisor_fees_paid,
                                    other_fees_paid: other_fees_paid,
                                    corporate_bond_interest_paid: corporate_bond_interest_paid,
                                    us_bond_interest_paid: us_bond_interest_paid,
                                    tax_exempt_interest_paid: tax_exempt_interest_paid,
                                    specified_pab_interest_paid: specified_pab_interest_paid,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 112

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['margin_interest_paid'] = 'marginInterestPaid'
  @_hash['payment_in_lieu_paid'] = 'paymentInLieuPaid'
  @_hash['advisor_fees_paid'] = 'advisorFeesPaid'
  @_hash['other_fees_paid'] = 'otherFeesPaid'
  @_hash['corporate_bond_interest_paid'] = 'corporateBondInterestPaid'
  @_hash['us_bond_interest_paid'] = 'usBondInterestPaid'
  @_hash['tax_exempt_interest_paid'] = 'taxExemptInterestPaid'
  @_hash['specified_pab_interest_paid'] = 'specifiedPabInterestPaid'
  @_hash
end

.nullablesObject

An array for nullable fields



164
165
166
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 164

def self.nullables
  []
end

.optionalsObject

An array for optional fields



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 138

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    margin_interest_paid
    payment_in_lieu_paid
    advisor_fees_paid
    other_fees_paid
    corporate_bond_interest_paid
    us_bond_interest_paid
    tax_exempt_interest_paid
    specified_pab_interest_paid
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 310

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, margin_interest_paid: #{@margin_interest_paid.inspect},"\
  " payment_in_lieu_paid: #{@payment_in_lieu_paid.inspect}, advisor_fees_paid:"\
  " #{@advisor_fees_paid.inspect}, other_fees_paid: #{@other_fees_paid.inspect},"\
  " corporate_bond_interest_paid: #{@corporate_bond_interest_paid.inspect},"\
  " us_bond_interest_paid: #{@us_bond_interest_paid.inspect}, tax_exempt_interest_paid:"\
  " #{@tax_exempt_interest_paid.inspect}, specified_pab_interest_paid:"\
  " #{@specified_pab_interest_paid.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement.rb', line 295

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, margin_interest_paid: #{@margin_interest_paid},"\
  " payment_in_lieu_paid: #{@payment_in_lieu_paid}, advisor_fees_paid: #{@advisor_fees_paid},"\
  " other_fees_paid: #{@other_fees_paid}, corporate_bond_interest_paid:"\
  " #{@corporate_bond_interest_paid}, us_bond_interest_paid: #{@us_bond_interest_paid},"\
  " tax_exempt_interest_paid: #{@tax_exempt_interest_paid}, specified_pab_interest_paid:"\
  " #{@specified_pab_interest_paid}, additional_properties: #{@additional_properties}>"
end