Class: FdxV660Api::Form1099ConsolidatedStatement1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::Form1099ConsolidatedStatement1
- Defined in:
- lib/fdx_v660_api/models/form1099_consolidated_statement1.rb
Overview
Consolidated Statement for combined IRS Form 1099s
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#advisor_fees_paid ⇒ Float
Advisor fees paid.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corporate_bond_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 1, Corporate bond interest income.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#margin_interest_paid ⇒ Float
Interest paid on margin account.
-
#other_fees_paid ⇒ Float
Other fees paid.
-
#payment_in_lieu_paid ⇒ Float
Payment in lieu of dividends paid.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#specified_pab_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 9, tax exempt interest income from Private Activity Bonds.
-
#tax_exempt_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 8, tax exempt interest income from municipal bonds.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#us_bond_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 3, accrued U.S.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, margin_interest_paid: SKIP, payment_in_lieu_paid: SKIP, advisor_fees_paid: SKIP, other_fees_paid: SKIP, corporate_bond_interest_paid: SKIP, us_bond_interest_paid: SKIP, tax_exempt_interest_paid: SKIP, specified_pab_interest_paid: SKIP, additional_properties: nil) ⇒ Form1099ConsolidatedStatement1
constructor
A new instance of Form1099ConsolidatedStatement1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, margin_interest_paid: SKIP, payment_in_lieu_paid: SKIP, advisor_fees_paid: SKIP, other_fees_paid: SKIP, corporate_bond_interest_paid: SKIP, us_bond_interest_paid: SKIP, tax_exempt_interest_paid: SKIP, specified_pab_interest_paid: SKIP, additional_properties: nil) ⇒ Form1099ConsolidatedStatement1
Returns a new instance of Form1099ConsolidatedStatement1.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 166 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, margin_interest_paid: SKIP, payment_in_lieu_paid: SKIP, advisor_fees_paid: SKIP, other_fees_paid: SKIP, corporate_bond_interest_paid: SKIP, us_bond_interest_paid: SKIP, tax_exempt_interest_paid: SKIP, specified_pab_interest_paid: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @margin_interest_paid = margin_interest_paid unless margin_interest_paid == SKIP @payment_in_lieu_paid = payment_in_lieu_paid unless payment_in_lieu_paid == SKIP @advisor_fees_paid = advisor_fees_paid unless advisor_fees_paid == SKIP @other_fees_paid = other_fees_paid unless other_fees_paid == SKIP unless corporate_bond_interest_paid == SKIP @corporate_bond_interest_paid = corporate_bond_interest_paid end @us_bond_interest_paid = us_bond_interest_paid unless us_bond_interest_paid == SKIP @tax_exempt_interest_paid = tax_exempt_interest_paid unless tax_exempt_interest_paid == SKIP unless specified_pab_interest_paid == SKIP @specified_pab_interest_paid = specified_pab_interest_paid end @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 37 def additional_information @additional_information end |
#advisor_fees_paid ⇒ Float
Advisor fees paid
83 84 85 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 83 def advisor_fees_paid @advisor_fees_paid end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 63 def attributes @attributes end |
#corporate_bond_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 1, Corporate bond interest income
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 92 def corporate_bond_interest_paid @corporate_bond_interest_paid end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 18 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 67 def error @error end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 71 def links @links end |
#margin_interest_paid ⇒ Float
Interest paid on margin account
75 76 77 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 75 def margin_interest_paid @margin_interest_paid end |
#other_fees_paid ⇒ Float
Other fees paid
87 88 89 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 87 def other_fees_paid @other_fees_paid end |
#payment_in_lieu_paid ⇒ Float
Payment in lieu of dividends paid
79 80 81 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 79 def payment_in_lieu_paid @payment_in_lieu_paid end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 53 def recipient @recipient end |
#specified_pab_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 9, tax exempt interest income from Private Activity Bonds
107 108 109 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 107 def specified_pab_interest_paid @specified_pab_interest_paid end |
#tax_exempt_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 8, tax exempt interest income from municipal bonds
102 103 104 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 102 def tax_exempt_interest_paid @tax_exempt_interest_paid end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 14 def tax_year @tax_year end |
#us_bond_interest_paid ⇒ Float
Accrued Interest Paid offset to form 1099-INT box 3, accrued U.S. Treasury Notes and Bonds interest income
97 98 99 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 97 def us_bond_interest_paid @us_bond_interest_paid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 209 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') margin_interest_paid = hash.key?('marginInterestPaid') ? hash['marginInterestPaid'] : SKIP payment_in_lieu_paid = hash.key?('paymentInLieuPaid') ? hash['paymentInLieuPaid'] : SKIP advisor_fees_paid = hash.key?('advisorFeesPaid') ? hash['advisorFeesPaid'] : SKIP other_fees_paid = hash.key?('otherFeesPaid') ? hash['otherFeesPaid'] : SKIP corporate_bond_interest_paid = hash.key?('corporateBondInterestPaid') ? hash['corporateBondInterestPaid'] : SKIP us_bond_interest_paid = hash.key?('usBondInterestPaid') ? hash['usBondInterestPaid'] : SKIP tax_exempt_interest_paid = hash.key?('taxExemptInterestPaid') ? hash['taxExemptInterestPaid'] : SKIP specified_pab_interest_paid = hash.key?('specifiedPabInterestPaid') ? hash['specifiedPabInterestPaid'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099ConsolidatedStatement1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, margin_interest_paid: margin_interest_paid, payment_in_lieu_paid: payment_in_lieu_paid, advisor_fees_paid: advisor_fees_paid, other_fees_paid: other_fees_paid, corporate_bond_interest_paid: corporate_bond_interest_paid, us_bond_interest_paid: us_bond_interest_paid, tax_exempt_interest_paid: tax_exempt_interest_paid, specified_pab_interest_paid: specified_pab_interest_paid, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 110 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['margin_interest_paid'] = 'marginInterestPaid' @_hash['payment_in_lieu_paid'] = 'paymentInLieuPaid' @_hash['advisor_fees_paid'] = 'advisorFeesPaid' @_hash['other_fees_paid'] = 'otherFeesPaid' @_hash['corporate_bond_interest_paid'] = 'corporateBondInterestPaid' @_hash['us_bond_interest_paid'] = 'usBondInterestPaid' @_hash['tax_exempt_interest_paid'] = 'taxExemptInterestPaid' @_hash['specified_pab_interest_paid'] = 'specifiedPabInterestPaid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
162 163 164 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 162 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 136 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links margin_interest_paid payment_in_lieu_paid advisor_fees_paid other_fees_paid corporate_bond_interest_paid us_bond_interest_paid tax_exempt_interest_paid specified_pab_interest_paid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 308 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, margin_interest_paid: #{@margin_interest_paid.inspect},"\ " payment_in_lieu_paid: #{@payment_in_lieu_paid.inspect}, advisor_fees_paid:"\ " #{@advisor_fees_paid.inspect}, other_fees_paid: #{@other_fees_paid.inspect},"\ " corporate_bond_interest_paid: #{@corporate_bond_interest_paid.inspect},"\ " us_bond_interest_paid: #{@us_bond_interest_paid.inspect}, tax_exempt_interest_paid:"\ " #{@tax_exempt_interest_paid.inspect}, specified_pab_interest_paid:"\ " #{@specified_pab_interest_paid.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/fdx_v660_api/models/form1099_consolidated_statement1.rb', line 293 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, margin_interest_paid: #{@margin_interest_paid},"\ " payment_in_lieu_paid: #{@payment_in_lieu_paid}, advisor_fees_paid: #{@advisor_fees_paid},"\ " other_fees_paid: #{@other_fees_paid}, corporate_bond_interest_paid:"\ " #{@corporate_bond_interest_paid}, us_bond_interest_paid: #{@us_bond_interest_paid},"\ " tax_exempt_interest_paid: #{@tax_exempt_interest_paid}, specified_pab_interest_paid:"\ " #{@specified_pab_interest_paid}, additional_properties: #{@additional_properties}>" end |