Class: FdxV660Api::Form1099G

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1099_g.rb

Overview

Certain Government Payments, from PAYER (1st-9th boxes as issuer) to RECIPIENT (10th-17th boxes)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, unemployment_compensation: SKIP, tax_refund: SKIP, refund_year: SKIP, federal_tax_withheld: SKIP, rtaa_payments: SKIP, grants: SKIP, agriculture_payments: SKIP, business_income: SKIP, market_gain: SKIP, family_leave_benefits: SKIP, state_and_local: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099G

Returns a new instance of Form1099G.



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 193

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, account_number: SKIP,
               unemployment_compensation: SKIP, tax_refund: SKIP,
               refund_year: SKIP, federal_tax_withheld: SKIP,
               rtaa_payments: SKIP, grants: SKIP,
               agriculture_payments: SKIP, business_income: SKIP,
               market_gain: SKIP, family_leave_benefits: SKIP,
               state_and_local: SKIP, second_tin_notice: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @account_number =  unless  == SKIP
  unless unemployment_compensation == SKIP
    @unemployment_compensation =
      unemployment_compensation
  end
  @tax_refund = tax_refund unless tax_refund == SKIP
  @refund_year = refund_year unless refund_year == SKIP
  @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP
  @rtaa_payments = rtaa_payments unless rtaa_payments == SKIP
  @grants = grants unless grants == SKIP
  @agriculture_payments = agriculture_payments unless agriculture_payments == SKIP
  @business_income = business_income unless business_income == SKIP
  @market_gain = market_gain unless market_gain == SKIP
  @family_leave_benefits = family_leave_benefits unless family_leave_benefits == SKIP
  @state_and_local = state_and_local unless state_and_local == SKIP
  @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


24
25
26
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 24

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


76
77
78
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 76

def 
  @account_number
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


38
39
40
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 38

def additional_information
  @additional_information
end

#agriculture_paymentsFloat

Box 7, Agriculture payments

Returns:

  • (Float)


104
105
106
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 104

def agriculture_payments
  @agriculture_payments
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



64
65
66
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 64

def attributes
  @attributes
end

#business_incomeTrueClass | FalseClass

Box 8, If checked, box 2 is trade or business income

Returns:

  • (TrueClass | FalseClass)


108
109
110
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 108

def business_income
  @business_income
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 19

def corrected
  @corrected
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



68
69
70
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 68

def error
  @error
end

#family_leave_benefitsFloat

Box 10, Family leave benefits

Returns:

  • (Float)


116
117
118
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 116

def family_leave_benefits
  @family_leave_benefits
end

#federal_tax_withheldFloat

Box 4, Federal income tax withheld

Returns:

  • (Float)


92
93
94
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 92

def federal_tax_withheld
  @federal_tax_withheld
end

#grantsFloat

Box 6, Taxable grants

Returns:

  • (Float)


100
101
102
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 100

def grants
  @grants
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



48
49
50
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 48

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



72
73
74
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 72

def links
  @links
end

#market_gainFloat

Box 9, Market gain

Returns:

  • (Float)


112
113
114
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 112

def market_gain
  @market_gain
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



54
55
56
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 54

def recipient
  @recipient
end

#refund_yearInteger

Box 3, Box 2 amount is for tax year

Returns:

  • (Integer)


88
89
90
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 88

def refund_year
  @refund_year
end

#rtaa_paymentsFloat

Box 5, RTAA payments

Returns:

  • (Float)


96
97
98
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 96

def rtaa_payments
  @rtaa_payments
end

#second_tin_noticeTrueClass | FalseClass

Second TIN Notice

Returns:

  • (TrueClass | FalseClass)


124
125
126
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 124

def second_tin_notice
  @second_tin_notice
end

#state_and_localArray[StateAndLocalTaxWithholding]

Boxes 11-12, State and Local tax withholding

Returns:



120
121
122
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 120

def state_and_local
  @state_and_local
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


34
35
36
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 34

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


30
31
32
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 30

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



42
43
44
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 42

def tax_form_type
  @tax_form_type
end

#tax_refundFloat

Box 2, State or local income tax refunds, credits, or offsets

Returns:

  • (Float)


84
85
86
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 84

def tax_refund
  @tax_refund
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


15
16
17
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 15

def tax_year
  @tax_year
end

#unemployment_compensationFloat

Box 1, Unemployment compensation

Returns:

  • (Float)


80
81
82
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 80

def unemployment_compensation
  @unemployment_compensation
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 240

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  unemployment_compensation =
    hash.key?('unemploymentCompensation') ? hash['unemploymentCompensation'] : SKIP
  tax_refund = hash.key?('taxRefund') ? hash['taxRefund'] : SKIP
  refund_year = hash.key?('refundYear') ? hash['refundYear'] : SKIP
  federal_tax_withheld =
    hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP
  rtaa_payments = hash.key?('rtaaPayments') ? hash['rtaaPayments'] : SKIP
  grants = hash.key?('grants') ? hash['grants'] : SKIP
  agriculture_payments =
    hash.key?('agriculturePayments') ? hash['agriculturePayments'] : SKIP
  business_income =
    hash.key?('businessIncome') ? hash['businessIncome'] : SKIP
  market_gain = hash.key?('marketGain') ? hash['marketGain'] : SKIP
  family_leave_benefits =
    hash.key?('familyLeaveBenefits') ? hash['familyLeaveBenefits'] : SKIP
  # Parameter is an array, so we need to iterate through it
  state_and_local = nil
  unless hash['stateAndLocal'].nil?
    state_and_local = []
    hash['stateAndLocal'].each do |structure|
      state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure)
    end
  end

  state_and_local = SKIP unless hash.key?('stateAndLocal')
  second_tin_notice =
    hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1099G.new(tax_year: tax_year,
                corrected: corrected,
                account_id: ,
                tax_form_id: tax_form_id,
                tax_form_date: tax_form_date,
                additional_information: additional_information,
                tax_form_type: tax_form_type,
                issuer: issuer,
                recipient: recipient,
                attributes: attributes,
                error: error,
                links: links,
                account_number: ,
                unemployment_compensation: unemployment_compensation,
                tax_refund: tax_refund,
                refund_year: refund_year,
                federal_tax_withheld: federal_tax_withheld,
                rtaa_payments: rtaa_payments,
                grants: grants,
                agriculture_payments: agriculture_payments,
                business_income: business_income,
                market_gain: market_gain,
                family_leave_benefits: family_leave_benefits,
                state_and_local: state_and_local,
                second_tin_notice: second_tin_notice,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 127

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['account_number'] = 'accountNumber'
  @_hash['unemployment_compensation'] = 'unemploymentCompensation'
  @_hash['tax_refund'] = 'taxRefund'
  @_hash['refund_year'] = 'refundYear'
  @_hash['federal_tax_withheld'] = 'federalTaxWithheld'
  @_hash['rtaa_payments'] = 'rtaaPayments'
  @_hash['grants'] = 'grants'
  @_hash['agriculture_payments'] = 'agriculturePayments'
  @_hash['business_income'] = 'businessIncome'
  @_hash['market_gain'] = 'marketGain'
  @_hash['family_leave_benefits'] = 'familyLeaveBenefits'
  @_hash['state_and_local'] = 'stateAndLocal'
  @_hash['second_tin_notice'] = 'secondTinNotice'
  @_hash
end

.nullablesObject

An array for nullable fields



189
190
191
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 189

def self.nullables
  []
end

.optionalsObject

An array for optional fields



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 158

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    account_number
    unemployment_compensation
    tax_refund
    refund_year
    federal_tax_withheld
    rtaa_payments
    grants
    agriculture_payments
    business_income
    market_gain
    family_leave_benefits
    state_and_local
    second_tin_notice
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 358

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, account_number: #{@account_number.inspect},"\
  " unemployment_compensation: #{@unemployment_compensation.inspect}, tax_refund:"\
  " #{@tax_refund.inspect}, refund_year: #{@refund_year.inspect}, federal_tax_withheld:"\
  " #{@federal_tax_withheld.inspect}, rtaa_payments: #{@rtaa_payments.inspect}, grants:"\
  " #{@grants.inspect}, agriculture_payments: #{@agriculture_payments.inspect},"\
  " business_income: #{@business_income.inspect}, market_gain: #{@market_gain.inspect},"\
  " family_leave_benefits: #{@family_leave_benefits.inspect}, state_and_local:"\
  " #{@state_and_local.inspect}, second_tin_notice: #{@second_tin_notice.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/fdx_v660_api/models/form1099_g.rb', line 341

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, account_number: #{@account_number},"\
  " unemployment_compensation: #{@unemployment_compensation}, tax_refund: #{@tax_refund},"\
  " refund_year: #{@refund_year}, federal_tax_withheld: #{@federal_tax_withheld},"\
  " rtaa_payments: #{@rtaa_payments}, grants: #{@grants}, agriculture_payments:"\
  " #{@agriculture_payments}, business_income: #{@business_income}, market_gain:"\
  " #{@market_gain}, family_leave_benefits: #{@family_leave_benefits}, state_and_local:"\
  " #{@state_and_local}, second_tin_notice: #{@second_tin_notice}, additional_properties:"\
  " #{@additional_properties}>"
end