Class: FdxV660Api::Form1099Int1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1099_int1.rb

Overview

Interest Income

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, foreign_account_tax_compliance: SKIP, account_number: SKIP, payer_rtn: SKIP, interest_income: SKIP, early_withdrawal_penalty: SKIP, us_bond_interest: SKIP, federal_tax_withheld: SKIP, investment_expenses: SKIP, foreign_tax_paid: SKIP, foreign_country: SKIP, tax_exempt_interest: SKIP, specified_pab_interest: SKIP, market_discount: SKIP, bond_premium: SKIP, us_bond_premium: SKIP, tax_exempt_bond_premium: SKIP, cusip_number: SKIP, state_and_local: SKIP, foreign_incomes: SKIP, state_tax_exempt_income: SKIP, nominee_adjustment: SKIP, oid_adjustment: SKIP, bond_premium_adjustment: SKIP, us_bond_premium_adjustment: SKIP, exempt_bond_premium_adjustment: SKIP, private_activity_bond_adjustment: SKIP, accrued_interest_adjustment: SKIP, us_savings_bond_adjustment: SKIP, other_adjustment: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099Int1

Returns a new instance of Form1099Int1.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 296

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, foreign_account_tax_compliance: SKIP,
               account_number: SKIP, payer_rtn: SKIP, interest_income: SKIP,
               early_withdrawal_penalty: SKIP, us_bond_interest: SKIP,
               federal_tax_withheld: SKIP, investment_expenses: SKIP,
               foreign_tax_paid: SKIP, foreign_country: SKIP,
               tax_exempt_interest: SKIP, specified_pab_interest: SKIP,
               market_discount: SKIP, bond_premium: SKIP,
               us_bond_premium: SKIP, tax_exempt_bond_premium: SKIP,
               cusip_number: SKIP, state_and_local: SKIP,
               foreign_incomes: SKIP, state_tax_exempt_income: SKIP,
               nominee_adjustment: SKIP, oid_adjustment: SKIP,
               bond_premium_adjustment: SKIP,
               us_bond_premium_adjustment: SKIP,
               exempt_bond_premium_adjustment: SKIP,
               private_activity_bond_adjustment: SKIP,
               accrued_interest_adjustment: SKIP,
               us_savings_bond_adjustment: SKIP, other_adjustment: SKIP,
               second_tin_notice: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  unless  == SKIP
    @foreign_account_tax_compliance =
      
  end
  @account_number =  unless  == SKIP
  @payer_rtn = payer_rtn unless payer_rtn == SKIP
  @interest_income = interest_income unless interest_income == SKIP
  @early_withdrawal_penalty = early_withdrawal_penalty unless early_withdrawal_penalty == SKIP
  @us_bond_interest = us_bond_interest unless us_bond_interest == SKIP
  @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP
  @investment_expenses = investment_expenses unless investment_expenses == SKIP
  @foreign_tax_paid = foreign_tax_paid unless foreign_tax_paid == SKIP
  @foreign_country = foreign_country unless foreign_country == SKIP
  @tax_exempt_interest = tax_exempt_interest unless tax_exempt_interest == SKIP
  @specified_pab_interest = specified_pab_interest unless specified_pab_interest == SKIP
  @market_discount = market_discount unless market_discount == SKIP
  @bond_premium = bond_premium unless bond_premium == SKIP
  @us_bond_premium = us_bond_premium unless us_bond_premium == SKIP
  @tax_exempt_bond_premium = tax_exempt_bond_premium unless tax_exempt_bond_premium == SKIP
  @cusip_number = cusip_number unless cusip_number == SKIP
  @state_and_local = state_and_local unless state_and_local == SKIP
  @foreign_incomes = foreign_incomes unless foreign_incomes == SKIP
  @state_tax_exempt_income = state_tax_exempt_income unless state_tax_exempt_income == SKIP
  @nominee_adjustment = nominee_adjustment unless nominee_adjustment == SKIP
  @oid_adjustment = oid_adjustment unless oid_adjustment == SKIP
  @bond_premium_adjustment = bond_premium_adjustment unless bond_premium_adjustment == SKIP
  unless us_bond_premium_adjustment == SKIP
    @us_bond_premium_adjustment =
      us_bond_premium_adjustment
  end
  unless exempt_bond_premium_adjustment == SKIP
    @exempt_bond_premium_adjustment =
      exempt_bond_premium_adjustment
  end
  unless private_activity_bond_adjustment == SKIP
    @private_activity_bond_adjustment =
      private_activity_bond_adjustment
  end
  unless accrued_interest_adjustment == SKIP
    @accrued_interest_adjustment =
      accrued_interest_adjustment
  end
  unless us_savings_bond_adjustment == SKIP
    @us_savings_bond_adjustment =
      us_savings_bond_adjustment
  end
  @other_adjustment = other_adjustment unless other_adjustment == SKIP
  @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


23
24
25
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 23

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


79
80
81
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 79

def 
  @account_number
end

#accrued_interest_adjustmentFloat

Adjustment for accrued interest

Returns:

  • (Float)


180
181
182
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 180

def accrued_interest_adjustment
  @accrued_interest_adjustment
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


37
38
39
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 37

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



63
64
65
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 63

def attributes
  @attributes
end

#bond_premiumFloat

Box 11, Bond premium

Returns:

  • (Float)


127
128
129
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 127

def bond_premium
  @bond_premium
end

#bond_premium_adjustmentFloat

Adjustment for amortizable bond premium

Returns:

  • (Float)


163
164
165
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 163

def bond_premium_adjustment
  @bond_premium_adjustment
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 18

def corrected
  @corrected
end

#cusip_numberString

Box 14, Tax-exempt bond CUSIP no.

Returns:

  • (String)


139
140
141
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 139

def cusip_number
  @cusip_number
end

#early_withdrawal_penaltyFloat

Box 2, Early withdrawal penalty

Returns:

  • (Float)


91
92
93
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 91

def early_withdrawal_penalty
  @early_withdrawal_penalty
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



67
68
69
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 67

def error
  @error
end

#exempt_bond_premium_adjustmentFloat

Adjustment for amortizable bond premium on tax-exempt bonds

Returns:

  • (Float)


171
172
173
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 171

def exempt_bond_premium_adjustment
  @exempt_bond_premium_adjustment
end

#federal_tax_withheldFloat

Box 4, Federal income tax withheld

Returns:

  • (Float)


99
100
101
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 99

def federal_tax_withheld
  @federal_tax_withheld
end

#foreign_account_tax_complianceTrueClass | FalseClass

FATCA filing requirement

Returns:

  • (TrueClass | FalseClass)


75
76
77
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 75

def 
  @foreign_account_tax_compliance
end

#foreign_countryString

Box 7, Foreign country or U.S. possession

Returns:

  • (String)


111
112
113
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 111

def foreign_country
  @foreign_country
end

#foreign_incomesArray[DescriptionAndAmount]

Supplemental foreign income amount information (description is country)

Returns:



147
148
149
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 147

def foreign_incomes
  @foreign_incomes
end

#foreign_tax_paidFloat

Box 6, Foreign tax paid

Returns:

  • (Float)


107
108
109
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 107

def foreign_tax_paid
  @foreign_tax_paid
end

#interest_incomeFloat

Box 1, Interest income

Returns:

  • (Float)


87
88
89
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 87

def interest_income
  @interest_income
end

#investment_expensesFloat

Box 5, Investment expenses

Returns:

  • (Float)


103
104
105
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 103

def investment_expenses
  @investment_expenses
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



47
48
49
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 47

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



71
72
73
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 71

def links
  @links
end

#market_discountFloat

Box 10, Market discount

Returns:

  • (Float)


123
124
125
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 123

def market_discount
  @market_discount
end

#nominee_adjustmentFloat

Adjustment for interest received as nominee

Returns:

  • (Float)


155
156
157
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 155

def nominee_adjustment
  @nominee_adjustment
end

#oid_adjustmentFloat

Adjustment for original issue discount

Returns:

  • (Float)


159
160
161
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 159

def oid_adjustment
  @oid_adjustment
end

#other_adjustmentFloat

Other adjustment

Returns:

  • (Float)


188
189
190
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 188

def other_adjustment
  @other_adjustment
end

#payer_rtnString

Payer's RTN

Returns:

  • (String)


83
84
85
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 83

def payer_rtn
  @payer_rtn
end

#private_activity_bond_adjustmentFloat

Adjustment for amortizable bond premium on specified private activity bonds

Returns:

  • (Float)


176
177
178
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 176

def private_activity_bond_adjustment
  @private_activity_bond_adjustment
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



53
54
55
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 53

def recipient
  @recipient
end

#second_tin_noticeTrueClass | FalseClass

Second TIN Notice

Returns:

  • (TrueClass | FalseClass)


192
193
194
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 192

def second_tin_notice
  @second_tin_notice
end

#specified_pab_interestFloat

Box 9, Specified private activity bond interest

Returns:

  • (Float)


119
120
121
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 119

def specified_pab_interest
  @specified_pab_interest
end

#state_and_localArray[StateAndLocalTaxWithholding]

Boxes 15-17, State and Local tax withholding

Returns:



143
144
145
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 143

def state_and_local
  @state_and_local
end

#state_tax_exempt_incomeArray[DescriptionAndAmount]

Supplemental tax-exempt income by state (description is state)

Returns:



151
152
153
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 151

def state_tax_exempt_income
  @state_tax_exempt_income
end

#tax_exempt_bond_premiumFloat

Box 13, Bond premium on tax-exempt bond

Returns:

  • (Float)


135
136
137
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 135

def tax_exempt_bond_premium
  @tax_exempt_bond_premium
end

#tax_exempt_interestFloat

Box 8, Tax-exempt interest

Returns:

  • (Float)


115
116
117
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 115

def tax_exempt_interest
  @tax_exempt_interest
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


33
34
35
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 33

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


29
30
31
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 29

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



41
42
43
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 41

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


14
15
16
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 14

def tax_year
  @tax_year
end

#us_bond_interestFloat

Box 3, Interest on U.S. Savings Bonds and Treasury obligations

Returns:

  • (Float)


95
96
97
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 95

def us_bond_interest
  @us_bond_interest
end

#us_bond_premiumFloat

Box 12, Bond premium on Treasury obligations

Returns:

  • (Float)


131
132
133
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 131

def us_bond_premium
  @us_bond_premium
end

#us_bond_premium_adjustmentFloat

Adjustment for amortizable bond premium on US obligations

Returns:

  • (Float)


167
168
169
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 167

def us_bond_premium_adjustment
  @us_bond_premium_adjustment
end

#us_savings_bond_adjustmentFloat

Adjustment for US savings bond interest previously reported

Returns:

  • (Float)


184
185
186
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 184

def us_savings_bond_adjustment
  @us_savings_bond_adjustment
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 385

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   =
    hash.key?('foreignAccountTaxCompliance') ? hash['foreignAccountTaxCompliance'] : SKIP
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  payer_rtn = hash.key?('payerRtn') ? hash['payerRtn'] : SKIP
  interest_income =
    hash.key?('interestIncome') ? hash['interestIncome'] : SKIP
  early_withdrawal_penalty =
    hash.key?('earlyWithdrawalPenalty') ? hash['earlyWithdrawalPenalty'] : SKIP
  us_bond_interest =
    hash.key?('usBondInterest') ? hash['usBondInterest'] : SKIP
  federal_tax_withheld =
    hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP
  investment_expenses =
    hash.key?('investmentExpenses') ? hash['investmentExpenses'] : SKIP
  foreign_tax_paid =
    hash.key?('foreignTaxPaid') ? hash['foreignTaxPaid'] : SKIP
  foreign_country =
    hash.key?('foreignCountry') ? hash['foreignCountry'] : SKIP
  tax_exempt_interest =
    hash.key?('taxExemptInterest') ? hash['taxExemptInterest'] : SKIP
  specified_pab_interest =
    hash.key?('specifiedPabInterest') ? hash['specifiedPabInterest'] : SKIP
  market_discount =
    hash.key?('marketDiscount') ? hash['marketDiscount'] : SKIP
  bond_premium = hash.key?('bondPremium') ? hash['bondPremium'] : SKIP
  us_bond_premium =
    hash.key?('usBondPremium') ? hash['usBondPremium'] : SKIP
  tax_exempt_bond_premium =
    hash.key?('taxExemptBondPremium') ? hash['taxExemptBondPremium'] : SKIP
  cusip_number = hash.key?('cusipNumber') ? hash['cusipNumber'] : SKIP
  # Parameter is an array, so we need to iterate through it
  state_and_local = nil
  unless hash['stateAndLocal'].nil?
    state_and_local = []
    hash['stateAndLocal'].each do |structure|
      state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure)
    end
  end

  state_and_local = SKIP unless hash.key?('stateAndLocal')
  # Parameter is an array, so we need to iterate through it
  foreign_incomes = nil
  unless hash['foreignIncomes'].nil?
    foreign_incomes = []
    hash['foreignIncomes'].each do |structure|
      foreign_incomes << (DescriptionAndAmount.from_hash(structure) if structure)
    end
  end

  foreign_incomes = SKIP unless hash.key?('foreignIncomes')
  # Parameter is an array, so we need to iterate through it
  state_tax_exempt_income = nil
  unless hash['stateTaxExemptIncome'].nil?
    state_tax_exempt_income = []
    hash['stateTaxExemptIncome'].each do |structure|
      state_tax_exempt_income << (DescriptionAndAmount.from_hash(structure) if structure)
    end
  end

  state_tax_exempt_income = SKIP unless hash.key?('stateTaxExemptIncome')
  nominee_adjustment =
    hash.key?('nomineeAdjustment') ? hash['nomineeAdjustment'] : SKIP
  oid_adjustment = hash.key?('oidAdjustment') ? hash['oidAdjustment'] : SKIP
  bond_premium_adjustment =
    hash.key?('bondPremiumAdjustment') ? hash['bondPremiumAdjustment'] : SKIP
  us_bond_premium_adjustment =
    hash.key?('usBondPremiumAdjustment') ? hash['usBondPremiumAdjustment'] : SKIP
  exempt_bond_premium_adjustment =
    hash.key?('exemptBondPremiumAdjustment') ? hash['exemptBondPremiumAdjustment'] : SKIP
  private_activity_bond_adjustment =
    hash.key?('privateActivityBondAdjustment') ? hash['privateActivityBondAdjustment'] : SKIP
  accrued_interest_adjustment =
    hash.key?('accruedInterestAdjustment') ? hash['accruedInterestAdjustment'] : SKIP
  us_savings_bond_adjustment =
    hash.key?('usSavingsBondAdjustment') ? hash['usSavingsBondAdjustment'] : SKIP
  other_adjustment =
    hash.key?('otherAdjustment') ? hash['otherAdjustment'] : SKIP
  second_tin_notice =
    hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1099Int1.new(tax_year: tax_year,
                   corrected: corrected,
                   account_id: ,
                   tax_form_id: tax_form_id,
                   tax_form_date: tax_form_date,
                   additional_information: additional_information,
                   tax_form_type: tax_form_type,
                   issuer: issuer,
                   recipient: recipient,
                   attributes: attributes,
                   error: error,
                   links: links,
                   foreign_account_tax_compliance: ,
                   account_number: ,
                   payer_rtn: payer_rtn,
                   interest_income: interest_income,
                   early_withdrawal_penalty: early_withdrawal_penalty,
                   us_bond_interest: us_bond_interest,
                   federal_tax_withheld: federal_tax_withheld,
                   investment_expenses: investment_expenses,
                   foreign_tax_paid: foreign_tax_paid,
                   foreign_country: foreign_country,
                   tax_exempt_interest: tax_exempt_interest,
                   specified_pab_interest: specified_pab_interest,
                   market_discount: market_discount,
                   bond_premium: bond_premium,
                   us_bond_premium: us_bond_premium,
                   tax_exempt_bond_premium: tax_exempt_bond_premium,
                   cusip_number: cusip_number,
                   state_and_local: state_and_local,
                   foreign_incomes: foreign_incomes,
                   state_tax_exempt_income: state_tax_exempt_income,
                   nominee_adjustment: nominee_adjustment,
                   oid_adjustment: oid_adjustment,
                   bond_premium_adjustment: bond_premium_adjustment,
                   us_bond_premium_adjustment: us_bond_premium_adjustment,
                   exempt_bond_premium_adjustment: exempt_bond_premium_adjustment,
                   private_activity_bond_adjustment: private_activity_bond_adjustment,
                   accrued_interest_adjustment: accrued_interest_adjustment,
                   us_savings_bond_adjustment: us_savings_bond_adjustment,
                   other_adjustment: other_adjustment,
                   second_tin_notice: second_tin_notice,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 195

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['foreign_account_tax_compliance'] = 'foreignAccountTaxCompliance'
  @_hash['account_number'] = 'accountNumber'
  @_hash['payer_rtn'] = 'payerRtn'
  @_hash['interest_income'] = 'interestIncome'
  @_hash['early_withdrawal_penalty'] = 'earlyWithdrawalPenalty'
  @_hash['us_bond_interest'] = 'usBondInterest'
  @_hash['federal_tax_withheld'] = 'federalTaxWithheld'
  @_hash['investment_expenses'] = 'investmentExpenses'
  @_hash['foreign_tax_paid'] = 'foreignTaxPaid'
  @_hash['foreign_country'] = 'foreignCountry'
  @_hash['tax_exempt_interest'] = 'taxExemptInterest'
  @_hash['specified_pab_interest'] = 'specifiedPabInterest'
  @_hash['market_discount'] = 'marketDiscount'
  @_hash['bond_premium'] = 'bondPremium'
  @_hash['us_bond_premium'] = 'usBondPremium'
  @_hash['tax_exempt_bond_premium'] = 'taxExemptBondPremium'
  @_hash['cusip_number'] = 'cusipNumber'
  @_hash['state_and_local'] = 'stateAndLocal'
  @_hash['foreign_incomes'] = 'foreignIncomes'
  @_hash['state_tax_exempt_income'] = 'stateTaxExemptIncome'
  @_hash['nominee_adjustment'] = 'nomineeAdjustment'
  @_hash['oid_adjustment'] = 'oidAdjustment'
  @_hash['bond_premium_adjustment'] = 'bondPremiumAdjustment'
  @_hash['us_bond_premium_adjustment'] = 'usBondPremiumAdjustment'
  @_hash['exempt_bond_premium_adjustment'] = 'exemptBondPremiumAdjustment'
  @_hash['private_activity_bond_adjustment'] =
    'privateActivityBondAdjustment'
  @_hash['accrued_interest_adjustment'] = 'accruedInterestAdjustment'
  @_hash['us_savings_bond_adjustment'] = 'usSavingsBondAdjustment'
  @_hash['other_adjustment'] = 'otherAdjustment'
  @_hash['second_tin_notice'] = 'secondTinNotice'
  @_hash
end

.nullablesObject

An array for nullable fields



292
293
294
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 292

def self.nullables
  []
end

.optionalsObject

An array for optional fields



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 244

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    foreign_account_tax_compliance
    account_number
    payer_rtn
    interest_income
    early_withdrawal_penalty
    us_bond_interest
    federal_tax_withheld
    investment_expenses
    foreign_tax_paid
    foreign_country
    tax_exempt_interest
    specified_pab_interest
    market_discount
    bond_premium
    us_bond_premium
    tax_exempt_bond_premium
    cusip_number
    state_and_local
    foreign_incomes
    state_tax_exempt_income
    nominee_adjustment
    oid_adjustment
    bond_premium_adjustment
    us_bond_premium_adjustment
    exempt_bond_premium_adjustment
    private_activity_bond_adjustment
    accrued_interest_adjustment
    us_savings_bond_adjustment
    other_adjustment
    second_tin_notice
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 582

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, foreign_account_tax_compliance:"\
  " #{@foreign_account_tax_compliance.inspect}, account_number: #{@account_number.inspect},"\
  " payer_rtn: #{@payer_rtn.inspect}, interest_income: #{@interest_income.inspect},"\
  " early_withdrawal_penalty: #{@early_withdrawal_penalty.inspect}, us_bond_interest:"\
  " #{@us_bond_interest.inspect}, federal_tax_withheld: #{@federal_tax_withheld.inspect},"\
  " investment_expenses: #{@investment_expenses.inspect}, foreign_tax_paid:"\
  " #{@foreign_tax_paid.inspect}, foreign_country: #{@foreign_country.inspect},"\
  " tax_exempt_interest: #{@tax_exempt_interest.inspect}, specified_pab_interest:"\
  " #{@specified_pab_interest.inspect}, market_discount: #{@market_discount.inspect},"\
  " bond_premium: #{@bond_premium.inspect}, us_bond_premium: #{@us_bond_premium.inspect},"\
  " tax_exempt_bond_premium: #{@tax_exempt_bond_premium.inspect}, cusip_number:"\
  " #{@cusip_number.inspect}, state_and_local: #{@state_and_local.inspect}, foreign_incomes:"\
  " #{@foreign_incomes.inspect}, state_tax_exempt_income: #{@state_tax_exempt_income.inspect},"\
  " nominee_adjustment: #{@nominee_adjustment.inspect}, oid_adjustment:"\
  " #{@oid_adjustment.inspect}, bond_premium_adjustment: #{@bond_premium_adjustment.inspect},"\
  " us_bond_premium_adjustment: #{@us_bond_premium_adjustment.inspect},"\
  " exempt_bond_premium_adjustment: #{@exempt_bond_premium_adjustment.inspect},"\
  " private_activity_bond_adjustment: #{@private_activity_bond_adjustment.inspect},"\
  " accrued_interest_adjustment: #{@accrued_interest_adjustment.inspect},"\
  " us_savings_bond_adjustment: #{@us_savings_bond_adjustment.inspect}, other_adjustment:"\
  " #{@other_adjustment.inspect}, second_tin_notice: #{@second_tin_notice.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/fdx_v660_api/models/form1099_int1.rb', line 554

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, foreign_account_tax_compliance:"\
  " #{@foreign_account_tax_compliance}, account_number: #{@account_number}, payer_rtn:"\
  " #{@payer_rtn}, interest_income: #{@interest_income}, early_withdrawal_penalty:"\
  " #{@early_withdrawal_penalty}, us_bond_interest: #{@us_bond_interest},"\
  " federal_tax_withheld: #{@federal_tax_withheld}, investment_expenses:"\
  " #{@investment_expenses}, foreign_tax_paid: #{@foreign_tax_paid}, foreign_country:"\
  " #{@foreign_country}, tax_exempt_interest: #{@tax_exempt_interest}, specified_pab_interest:"\
  " #{@specified_pab_interest}, market_discount: #{@market_discount}, bond_premium:"\
  " #{@bond_premium}, us_bond_premium: #{@us_bond_premium}, tax_exempt_bond_premium:"\
  " #{@tax_exempt_bond_premium}, cusip_number: #{@cusip_number}, state_and_local:"\
  " #{@state_and_local}, foreign_incomes: #{@foreign_incomes}, state_tax_exempt_income:"\
  " #{@state_tax_exempt_income}, nominee_adjustment: #{@nominee_adjustment}, oid_adjustment:"\
  " #{@oid_adjustment}, bond_premium_adjustment: #{@bond_premium_adjustment},"\
  " us_bond_premium_adjustment: #{@us_bond_premium_adjustment},"\
  " exempt_bond_premium_adjustment: #{@exempt_bond_premium_adjustment},"\
  " private_activity_bond_adjustment: #{@private_activity_bond_adjustment},"\
  " accrued_interest_adjustment: #{@accrued_interest_adjustment}, us_savings_bond_adjustment:"\
  " #{@us_savings_bond_adjustment}, other_adjustment: #{@other_adjustment}, second_tin_notice:"\
  " #{@second_tin_notice}, additional_properties: #{@additional_properties}>"
end