Class: FdxV660Api::Form1099Ltc
- Defined in:
- lib/fdx_v660_api/models/form1099_ltc.rb
Overview
Long-Term Care and Accelerated Death Benefits, from PAYER (1st-2nd boxes as issuer) to POLICY HOLDER (3rd-4th boxes as recipient)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#chronically_ill ⇒ TrueClass | FalseClass
Box 5, Chronically ill.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#date_certified ⇒ Date
Date certified.
-
#death_benefits ⇒ Float
Box 2, Accelerated death benefits paid.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#insured ⇒ TaxParty5
All form data for the INSURED party, 1st-4th boxes after Box 3.
-
#insured_id ⇒ String
INSURED'S taxpayer identification no.
-
#insured_name_address ⇒ NameAndAddress1
INSURED'S name and address.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#ltc_benefits ⇒ Float
Box 1, Gross long-term care benefits paid.
-
#per_diem ⇒ TrueClass | FalseClass
Box 3, Per diem.
-
#qualified_contract ⇒ TrueClass | FalseClass
Box 4, Qualified contract.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#reimbursed_amount ⇒ TrueClass | FalseClass
Box 3, Reimbursed amount.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#terminally_ill ⇒ TrueClass | FalseClass
Box 5, Terminally ill.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ltc_benefits: SKIP, death_benefits: SKIP, per_diem: SKIP, reimbursed_amount: SKIP, insured: SKIP, insured_id: SKIP, insured_name_address: SKIP, qualified_contract: SKIP, chronically_ill: SKIP, terminally_ill: SKIP, date_certified: SKIP, additional_properties: nil) ⇒ Form1099Ltc
constructor
A new instance of Form1099Ltc.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ltc_benefits: SKIP, death_benefits: SKIP, per_diem: SKIP, reimbursed_amount: SKIP, insured: SKIP, insured_id: SKIP, insured_name_address: SKIP, qualified_contract: SKIP, chronically_ill: SKIP, terminally_ill: SKIP, date_certified: SKIP, additional_properties: nil) ⇒ Form1099Ltc
Returns a new instance of Form1099Ltc.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 189 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ltc_benefits: SKIP, death_benefits: SKIP, per_diem: SKIP, reimbursed_amount: SKIP, insured: SKIP, insured_id: SKIP, insured_name_address: SKIP, qualified_contract: SKIP, chronically_ill: SKIP, terminally_ill: SKIP, date_certified: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @ltc_benefits = ltc_benefits unless ltc_benefits == SKIP @death_benefits = death_benefits unless death_benefits == SKIP @per_diem = per_diem unless per_diem == SKIP @reimbursed_amount = reimbursed_amount unless reimbursed_amount == SKIP @insured = insured unless insured == SKIP @insured_id = insured_id unless insured_id == SKIP @insured_name_address = insured_name_address unless insured_name_address == SKIP @qualified_contract = qualified_contract unless qualified_contract == SKIP @chronically_ill = chronically_ill unless chronically_ill == SKIP @terminally_ill = terminally_ill unless terminally_ill == SKIP @date_certified = date_certified unless date_certified == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 64 def attributes @attributes end |
#chronically_ill ⇒ TrueClass | FalseClass
Box 5, Chronically ill
114 115 116 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 114 def chronically_ill @chronically_ill end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 19 def corrected @corrected end |
#date_certified ⇒ Date
Date certified
122 123 124 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 122 def date_certified @date_certified end |
#death_benefits ⇒ Float
Box 2, Accelerated death benefits paid
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 84 def death_benefits @death_benefits end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 68 def error @error end |
#insured ⇒ TaxParty5
All form data for the INSURED party, 1st-4th boxes after Box 3
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 96 def insured @insured end |
#insured_id ⇒ String
INSURED'S taxpayer identification no. Deprecated with FDX V6.6, instead
use the tin field on insured
101 102 103 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 101 def insured_id @insured_id end |
#insured_name_address ⇒ NameAndAddress1
INSURED'S name and address. Deprecated with FDX V6.6, instead use
individualName and address fields on insured
106 107 108 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 106 def insured_name_address @insured_name_address end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 72 def links @links end |
#ltc_benefits ⇒ Float
Box 1, Gross long-term care benefits paid
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 80 def ltc_benefits @ltc_benefits end |
#per_diem ⇒ TrueClass | FalseClass
Box 3, Per diem
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 88 def per_diem @per_diem end |
#qualified_contract ⇒ TrueClass | FalseClass
Box 4, Qualified contract
110 111 112 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 110 def qualified_contract @qualified_contract end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 54 def recipient @recipient end |
#reimbursed_amount ⇒ TrueClass | FalseClass
Box 3, Reimbursed amount
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 92 def reimbursed_amount @reimbursed_amount end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 15 def tax_year @tax_year end |
#terminally_ill ⇒ TrueClass | FalseClass
Box 5, Terminally ill
118 119 120 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 118 def terminally_ill @terminally_ill end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 230 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP ltc_benefits = hash.key?('ltcBenefits') ? hash['ltcBenefits'] : SKIP death_benefits = hash.key?('deathBenefits') ? hash['deathBenefits'] : SKIP per_diem = hash.key?('perDiem') ? hash['perDiem'] : SKIP reimbursed_amount = hash.key?('reimbursedAmount') ? hash['reimbursedAmount'] : SKIP insured = TaxParty5.from_hash(hash['insured']) if hash['insured'] insured_id = hash.key?('insuredId') ? hash['insuredId'] : SKIP insured_name_address = NameAndAddress1.from_hash(hash['insuredNameAddress']) if hash['insuredNameAddress'] qualified_contract = hash.key?('qualifiedContract') ? hash['qualifiedContract'] : SKIP chronically_ill = hash.key?('chronicallyIll') ? hash['chronicallyIll'] : SKIP terminally_ill = hash.key?('terminallyIll') ? hash['terminallyIll'] : SKIP date_certified = hash.key?('dateCertified') ? hash['dateCertified'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099Ltc.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, ltc_benefits: ltc_benefits, death_benefits: death_benefits, per_diem: per_diem, reimbursed_amount: reimbursed_amount, insured: insured, insured_id: insured_id, insured_name_address: insured_name_address, qualified_contract: qualified_contract, chronically_ill: chronically_ill, terminally_ill: terminally_ill, date_certified: date_certified, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 125 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['ltc_benefits'] = 'ltcBenefits' @_hash['death_benefits'] = 'deathBenefits' @_hash['per_diem'] = 'perDiem' @_hash['reimbursed_amount'] = 'reimbursedAmount' @_hash['insured'] = 'insured' @_hash['insured_id'] = 'insuredId' @_hash['insured_name_address'] = 'insuredNameAddress' @_hash['qualified_contract'] = 'qualifiedContract' @_hash['chronically_ill'] = 'chronicallyIll' @_hash['terminally_ill'] = 'terminallyIll' @_hash['date_certified'] = 'dateCertified' @_hash end |
.nullables ⇒ Object
An array for nullable fields
185 186 187 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 185 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 155 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number ltc_benefits death_benefits per_diem reimbursed_amount insured insured_id insured_name_address qualified_contract chronically_ill terminally_ill date_certified ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 334 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, ltc_benefits:"\ " #{@ltc_benefits.inspect}, death_benefits: #{@death_benefits.inspect}, per_diem:"\ " #{@per_diem.inspect}, reimbursed_amount: #{@reimbursed_amount.inspect}, insured:"\ " #{@insured.inspect}, insured_id: #{@insured_id.inspect}, insured_name_address:"\ " #{@insured_name_address.inspect}, qualified_contract: #{@qualified_contract.inspect},"\ " chronically_ill: #{@chronically_ill.inspect}, terminally_ill: #{@terminally_ill.inspect},"\ " date_certified: #{@date_certified.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/fdx_v660_api/models/form1099_ltc.rb', line 318 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, ltc_benefits:"\ " #{@ltc_benefits}, death_benefits: #{@death_benefits}, per_diem: #{@per_diem},"\ " reimbursed_amount: #{@reimbursed_amount}, insured: #{@insured}, insured_id:"\ " #{@insured_id}, insured_name_address: #{@insured_name_address}, qualified_contract:"\ " #{@qualified_contract}, chronically_ill: #{@chronically_ill}, terminally_ill:"\ " #{@terminally_ill}, date_certified: #{@date_certified}, additional_properties:"\ " #{@additional_properties}>" end |