Class: FdxV660Api::Form1099Misc1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form1099_misc1.rb

Overview

Miscellaneous Income

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, rents: SKIP, royalties: SKIP, other_income: SKIP, federal_tax_withheld: SKIP, fishing_boat_proceeds: SKIP, medical_health_payment: SKIP, payer_direct_sales: SKIP, substitute_payments: SKIP, crop_insurance: SKIP, second_tin_notice: SKIP, gross_attorney: SKIP, fish_purchased: SKIP, section409_a_deferrals: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, foreign_account_tax_compliance: SKIP, excess_golden: SKIP, non_qualified_deferred_compensation: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099Misc1

Returns a new instance of Form1099Misc1.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 243

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, account_number: SKIP, rents: SKIP,
               royalties: SKIP, other_income: SKIP,
               federal_tax_withheld: SKIP, fishing_boat_proceeds: SKIP,
               medical_health_payment: SKIP, payer_direct_sales: SKIP,
               substitute_payments: SKIP, crop_insurance: SKIP,
               second_tin_notice: SKIP, gross_attorney: SKIP,
               fish_purchased: SKIP, section409_a_deferrals: SKIP,
               tips: SKIP, occupation_codes: SKIP, overtime: SKIP,
               foreign_account_tax_compliance: SKIP, excess_golden: SKIP,
               non_qualified_deferred_compensation: SKIP,
               state_and_local: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @account_number =  unless  == SKIP
  @rents = rents unless rents == SKIP
  @royalties = royalties unless royalties == SKIP
  @other_income = other_income unless other_income == SKIP
  @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP
  @fishing_boat_proceeds = fishing_boat_proceeds unless fishing_boat_proceeds == SKIP
  @medical_health_payment = medical_health_payment unless medical_health_payment == SKIP
  @payer_direct_sales = payer_direct_sales unless payer_direct_sales == SKIP
  @substitute_payments = substitute_payments unless substitute_payments == SKIP
  @crop_insurance = crop_insurance unless crop_insurance == SKIP
  @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP
  @gross_attorney = gross_attorney unless gross_attorney == SKIP
  @fish_purchased = fish_purchased unless fish_purchased == SKIP
  @section409_a_deferrals = section409_a_deferrals unless section409_a_deferrals == SKIP
  @tips = tips unless tips == SKIP
  @occupation_codes = occupation_codes unless occupation_codes == SKIP
  @overtime = overtime unless overtime == SKIP
  unless  == SKIP
    @foreign_account_tax_compliance =
      
  end
  @excess_golden = excess_golden unless excess_golden == SKIP
  unless non_qualified_deferred_compensation == SKIP
    @non_qualified_deferred_compensation =
      non_qualified_deferred_compensation
  end
  @state_and_local = state_and_local unless state_and_local == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


23
24
25
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 23

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


75
76
77
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 75

def 
  @account_number
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


37
38
39
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 37

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



63
64
65
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 63

def attributes
  @attributes
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 18

def corrected
  @corrected
end

#crop_insuranceFloat

Box 9, Crop insurance proceeds

Returns:

  • (Float)


112
113
114
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 112

def crop_insurance
  @crop_insurance
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



67
68
69
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 67

def error
  @error
end

#excess_goldenFloat

Excess golden parachute payments. Moved to 1099-NEC Box 3 for tax year 2025

Returns:

  • (Float)


149
150
151
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 149

def excess_golden
  @excess_golden
end

#federal_tax_withheldFloat

Box 4, Federal income tax withheld

Returns:

  • (Float)


91
92
93
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 91

def federal_tax_withheld
  @federal_tax_withheld
end

#fish_purchasedFloat

Box 11, Fish purchased for resale

Returns:

  • (Float)


124
125
126
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 124

def fish_purchased
  @fish_purchased
end

#fishing_boat_proceedsFloat

Box 5, Fishing boat proceeds

Returns:

  • (Float)


95
96
97
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 95

def fishing_boat_proceeds
  @fishing_boat_proceeds
end

#foreign_account_tax_complianceTrueClass | FalseClass

FATCA filing requirement

Returns:

  • (TrueClass | FalseClass)


144
145
146
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 144

def 
  @foreign_account_tax_compliance
end

#gross_attorneyFloat

Box 10, Gross proceeds paid to an attorney

Returns:

  • (Float)


120
121
122
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 120

def gross_attorney
  @gross_attorney
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



47
48
49
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 47

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



71
72
73
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 71

def links
  @links
end

#medical_health_paymentFloat

Box 6, Medical and health care payments

Returns:

  • (Float)


99
100
101
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 99

def medical_health_payment
  @medical_health_payment
end

#non_qualified_deferred_compensationFloat

Box 15, Nonqualified Deferred Compensation

Returns:

  • (Float)


153
154
155
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 153

def non_qualified_deferred_compensation
  @non_qualified_deferred_compensation
end

#occupation_codesArray[String]

Box 13b, Treasury Tipped Occupation Codes (TTOC)

Returns:

  • (Array[String])


136
137
138
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 136

def occupation_codes
  @occupation_codes
end

#other_incomeFloat

Box 3, Other income

Returns:

  • (Float)


87
88
89
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 87

def other_income
  @other_income
end

#overtimeFloat

Box 14, Overtime compensation

Returns:

  • (Float)


140
141
142
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 140

def overtime
  @overtime
end

#payer_direct_salesTrueClass | FalseClass

Box 7, Payer made direct sales of $5,000 or more of consumer products to a buyer (recipient) for resale

Returns:

  • (TrueClass | FalseClass)


104
105
106
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 104

def payer_direct_sales
  @payer_direct_sales
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



53
54
55
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 53

def recipient
  @recipient
end

#rentsFloat

Box 1, Rents

Returns:

  • (Float)


79
80
81
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 79

def rents
  @rents
end

#royaltiesFloat

Box 2, Royalties

Returns:

  • (Float)


83
84
85
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 83

def royalties
  @royalties
end

#second_tin_noticeTrueClass | FalseClass

Second TIN Notice

Returns:

  • (TrueClass | FalseClass)


116
117
118
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 116

def second_tin_notice
  @second_tin_notice
end

#section409_a_deferralsFloat

Box 12, Section 409A deferrals

Returns:

  • (Float)


128
129
130
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 128

def section409_a_deferrals
  @section409_a_deferrals
end

#state_and_localArray[StateAndLocalTaxWithholding]

Boxes 16-18, State and Local tax withholding

Returns:



157
158
159
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 157

def state_and_local
  @state_and_local
end

#substitute_paymentsFloat

Box 8, Substitute payments in lieu of dividends or interest

Returns:

  • (Float)


108
109
110
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 108

def substitute_payments
  @substitute_payments
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


33
34
35
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 33

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


29
30
31
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 29

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



41
42
43
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 41

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


14
15
16
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 14

def tax_year
  @tax_year
end

#tipsFloat

Box 13a, Cash tips

Returns:

  • (Float)


132
133
134
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 132

def tips
  @tips
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 304

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  rents = hash.key?('rents') ? hash['rents'] : SKIP
  royalties = hash.key?('royalties') ? hash['royalties'] : SKIP
  other_income = hash.key?('otherIncome') ? hash['otherIncome'] : SKIP
  federal_tax_withheld =
    hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP
  fishing_boat_proceeds =
    hash.key?('fishingBoatProceeds') ? hash['fishingBoatProceeds'] : SKIP
  medical_health_payment =
    hash.key?('medicalHealthPayment') ? hash['medicalHealthPayment'] : SKIP
  payer_direct_sales =
    hash.key?('payerDirectSales') ? hash['payerDirectSales'] : SKIP
  substitute_payments =
    hash.key?('substitutePayments') ? hash['substitutePayments'] : SKIP
  crop_insurance = hash.key?('cropInsurance') ? hash['cropInsurance'] : SKIP
  second_tin_notice =
    hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP
  gross_attorney = hash.key?('grossAttorney') ? hash['grossAttorney'] : SKIP
  fish_purchased = hash.key?('fishPurchased') ? hash['fishPurchased'] : SKIP
  section409_a_deferrals =
    hash.key?('section409ADeferrals') ? hash['section409ADeferrals'] : SKIP
  tips = hash.key?('tips') ? hash['tips'] : SKIP
  occupation_codes =
    hash.key?('occupationCodes') ? hash['occupationCodes'] : SKIP
  overtime = hash.key?('overtime') ? hash['overtime'] : SKIP
   =
    hash.key?('foreignAccountTaxCompliance') ? hash['foreignAccountTaxCompliance'] : SKIP
  excess_golden = hash.key?('excessGolden') ? hash['excessGolden'] : SKIP
  non_qualified_deferred_compensation =
    hash.key?('nonQualifiedDeferredCompensation') ? hash['nonQualifiedDeferredCompensation'] : SKIP
  # Parameter is an array, so we need to iterate through it
  state_and_local = nil
  unless hash['stateAndLocal'].nil?
    state_and_local = []
    hash['stateAndLocal'].each do |structure|
      state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure)
    end
  end

  state_and_local = SKIP unless hash.key?('stateAndLocal')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form1099Misc1.new(tax_year: tax_year,
                    corrected: corrected,
                    account_id: ,
                    tax_form_id: tax_form_id,
                    tax_form_date: tax_form_date,
                    additional_information: additional_information,
                    tax_form_type: tax_form_type,
                    issuer: issuer,
                    recipient: recipient,
                    attributes: attributes,
                    error: error,
                    links: links,
                    account_number: ,
                    rents: rents,
                    royalties: royalties,
                    other_income: other_income,
                    federal_tax_withheld: federal_tax_withheld,
                    fishing_boat_proceeds: fishing_boat_proceeds,
                    medical_health_payment: medical_health_payment,
                    payer_direct_sales: payer_direct_sales,
                    substitute_payments: substitute_payments,
                    crop_insurance: crop_insurance,
                    second_tin_notice: second_tin_notice,
                    gross_attorney: gross_attorney,
                    fish_purchased: fish_purchased,
                    section409_a_deferrals: section409_a_deferrals,
                    tips: tips,
                    occupation_codes: occupation_codes,
                    overtime: overtime,
                    foreign_account_tax_compliance: ,
                    excess_golden: excess_golden,
                    non_qualified_deferred_compensation: non_qualified_deferred_compensation,
                    state_and_local: state_and_local,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 160

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['account_number'] = 'accountNumber'
  @_hash['rents'] = 'rents'
  @_hash['royalties'] = 'royalties'
  @_hash['other_income'] = 'otherIncome'
  @_hash['federal_tax_withheld'] = 'federalTaxWithheld'
  @_hash['fishing_boat_proceeds'] = 'fishingBoatProceeds'
  @_hash['medical_health_payment'] = 'medicalHealthPayment'
  @_hash['payer_direct_sales'] = 'payerDirectSales'
  @_hash['substitute_payments'] = 'substitutePayments'
  @_hash['crop_insurance'] = 'cropInsurance'
  @_hash['second_tin_notice'] = 'secondTinNotice'
  @_hash['gross_attorney'] = 'grossAttorney'
  @_hash['fish_purchased'] = 'fishPurchased'
  @_hash['section409_a_deferrals'] = 'section409ADeferrals'
  @_hash['tips'] = 'tips'
  @_hash['occupation_codes'] = 'occupationCodes'
  @_hash['overtime'] = 'overtime'
  @_hash['foreign_account_tax_compliance'] = 'foreignAccountTaxCompliance'
  @_hash['excess_golden'] = 'excessGolden'
  @_hash['non_qualified_deferred_compensation'] =
    'nonQualifiedDeferredCompensation'
  @_hash['state_and_local'] = 'stateAndLocal'
  @_hash
end

.nullablesObject

An array for nullable fields



239
240
241
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 239

def self.nullables
  []
end

.optionalsObject

An array for optional fields



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 200

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    account_number
    rents
    royalties
    other_income
    federal_tax_withheld
    fishing_boat_proceeds
    medical_health_payment
    payer_direct_sales
    substitute_payments
    crop_insurance
    second_tin_notice
    gross_attorney
    fish_purchased
    section409_a_deferrals
    tips
    occupation_codes
    overtime
    foreign_account_tax_compliance
    excess_golden
    non_qualified_deferred_compensation
    state_and_local
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 446

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, account_number: #{@account_number.inspect}, rents:"\
  " #{@rents.inspect}, royalties: #{@royalties.inspect}, other_income:"\
  " #{@other_income.inspect}, federal_tax_withheld: #{@federal_tax_withheld.inspect},"\
  " fishing_boat_proceeds: #{@fishing_boat_proceeds.inspect}, medical_health_payment:"\
  " #{@medical_health_payment.inspect}, payer_direct_sales: #{@payer_direct_sales.inspect},"\
  " substitute_payments: #{@substitute_payments.inspect}, crop_insurance:"\
  " #{@crop_insurance.inspect}, second_tin_notice: #{@second_tin_notice.inspect},"\
  " gross_attorney: #{@gross_attorney.inspect}, fish_purchased: #{@fish_purchased.inspect},"\
  " section409_a_deferrals: #{@section409_a_deferrals.inspect}, tips: #{@tips.inspect},"\
  " occupation_codes: #{@occupation_codes.inspect}, overtime: #{@overtime.inspect},"\
  " foreign_account_tax_compliance: #{@foreign_account_tax_compliance.inspect}, excess_golden:"\
  " #{@excess_golden.inspect}, non_qualified_deferred_compensation:"\
  " #{@non_qualified_deferred_compensation.inspect}, state_and_local:"\
  " #{@state_and_local.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/fdx_v660_api/models/form1099_misc1.rb', line 425

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, account_number: #{@account_number}, rents: #{@rents},"\
  " royalties: #{@royalties}, other_income: #{@other_income}, federal_tax_withheld:"\
  " #{@federal_tax_withheld}, fishing_boat_proceeds: #{@fishing_boat_proceeds},"\
  " medical_health_payment: #{@medical_health_payment}, payer_direct_sales:"\
  " #{@payer_direct_sales}, substitute_payments: #{@substitute_payments}, crop_insurance:"\
  " #{@crop_insurance}, second_tin_notice: #{@second_tin_notice}, gross_attorney:"\
  " #{@gross_attorney}, fish_purchased: #{@fish_purchased}, section409_a_deferrals:"\
  " #{@section409_a_deferrals}, tips: #{@tips}, occupation_codes: #{@occupation_codes},"\
  " overtime: #{@overtime}, foreign_account_tax_compliance:"\
  " #{@foreign_account_tax_compliance}, excess_golden: #{@excess_golden},"\
  " non_qualified_deferred_compensation: #{@non_qualified_deferred_compensation},"\
  " state_and_local: #{@state_and_local}, additional_properties: #{@additional_properties}>"
end