Class: FdxV660Api::Form1099S1
- Defined in:
- lib/fdx_v660_api/models/form1099_s1.rb
Overview
Proceeds From Real Estate Transactions
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account or escrow number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#address_or_legal_description ⇒ String
Box 3, Address or legal description.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#cash_proceeds ⇒ Float
Box 2b, Cash gross proceeds.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#date_of_closing ⇒ Date
Box 1, Date of closing.
-
#digital_asset_code ⇒ String
Box 8a, Code for digital asset received as consideration.
-
#digital_asset_date_received ⇒ Date
Box 8d, Date digital asset received, or to be received, as consideration.
-
#digital_asset_name ⇒ String
Box 8b, Name of digital asset received as consideration.
-
#digital_asset_proceeds ⇒ Float
Box 2c, Digital asset gross proceeds.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#foreign_person ⇒ TrueClass | FalseClass
Box 7, If checked, transferor is a foreign person (nonresident alien, foreign partnership, foreign estate, or foreign trust).
-
#gross_proceeds ⇒ Float
Box 2a, Total gross proceeds.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#real_estate_tax ⇒ Float
Box 4, Buyer's part of real estate tax.
-
#received_other_consideration ⇒ TrueClass | FalseClass
Box 6, If checked, transferor received or will receive services or property (other than cash, notes, or digital assets) as part of the consideration.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#units ⇒ String
Box 8c, Number of digital asset units received as consideration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, date_of_closing: SKIP, gross_proceeds: SKIP, cash_proceeds: SKIP, digital_asset_proceeds: SKIP, address_or_legal_description: SKIP, real_estate_tax: SKIP, received_other_consideration: SKIP, foreign_person: SKIP, digital_asset_code: SKIP, digital_asset_name: SKIP, units: SKIP, digital_asset_date_received: SKIP, additional_properties: nil) ⇒ Form1099S1
constructor
A new instance of Form1099S1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, date_of_closing: SKIP, gross_proceeds: SKIP, cash_proceeds: SKIP, digital_asset_proceeds: SKIP, address_or_legal_description: SKIP, real_estate_tax: SKIP, received_other_consideration: SKIP, foreign_person: SKIP, digital_asset_code: SKIP, digital_asset_name: SKIP, units: SKIP, digital_asset_date_received: SKIP, additional_properties: nil) ⇒ Form1099S1
Returns a new instance of Form1099S1.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 195 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, date_of_closing: SKIP, gross_proceeds: SKIP, cash_proceeds: SKIP, digital_asset_proceeds: SKIP, address_or_legal_description: SKIP, real_estate_tax: SKIP, received_other_consideration: SKIP, foreign_person: SKIP, digital_asset_code: SKIP, digital_asset_name: SKIP, units: SKIP, digital_asset_date_received: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @date_of_closing = date_of_closing unless date_of_closing == SKIP @gross_proceeds = gross_proceeds unless gross_proceeds == SKIP @cash_proceeds = cash_proceeds unless cash_proceeds == SKIP @digital_asset_proceeds = digital_asset_proceeds unless digital_asset_proceeds == SKIP unless address_or_legal_description == SKIP @address_or_legal_description = address_or_legal_description end @real_estate_tax = real_estate_tax unless real_estate_tax == SKIP unless received_other_consideration == SKIP @received_other_consideration = received_other_consideration end @foreign_person = foreign_person unless foreign_person == SKIP @digital_asset_code = digital_asset_code unless digital_asset_code == SKIP @digital_asset_name = digital_asset_name unless digital_asset_name == SKIP @units = units unless units == SKIP unless digital_asset_date_received == SKIP @digital_asset_date_received = digital_asset_date_received end @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 23 def account_id @account_id end |
#account_number ⇒ String
Account or escrow number
75 76 77 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 75 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 37 def additional_information @additional_information end |
#address_or_legal_description ⇒ String
Box 3, Address or legal description
95 96 97 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 95 def address_or_legal_description @address_or_legal_description end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 63 def attributes @attributes end |
#cash_proceeds ⇒ Float
Box 2b, Cash gross proceeds
87 88 89 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 87 def cash_proceeds @cash_proceeds end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 18 def corrected @corrected end |
#date_of_closing ⇒ Date
Box 1, Date of closing
79 80 81 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 79 def date_of_closing @date_of_closing end |
#digital_asset_code ⇒ String
Box 8a, Code for digital asset received as consideration
114 115 116 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 114 def digital_asset_code @digital_asset_code end |
#digital_asset_date_received ⇒ Date
Box 8d, Date digital asset received, or to be received, as consideration
126 127 128 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 126 def digital_asset_date_received @digital_asset_date_received end |
#digital_asset_name ⇒ String
Box 8b, Name of digital asset received as consideration
118 119 120 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 118 def digital_asset_name @digital_asset_name end |
#digital_asset_proceeds ⇒ Float
Box 2c, Digital asset gross proceeds
91 92 93 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 91 def digital_asset_proceeds @digital_asset_proceeds end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 67 def error @error end |
#foreign_person ⇒ TrueClass | FalseClass
Box 7, If checked, transferor is a foreign person (nonresident alien, foreign partnership, foreign estate, or foreign trust)
110 111 112 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 110 def foreign_person @foreign_person end |
#gross_proceeds ⇒ Float
Box 2a, Total gross proceeds
83 84 85 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 83 def gross_proceeds @gross_proceeds end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 71 def links @links end |
#real_estate_tax ⇒ Float
Box 4, Buyer's part of real estate tax
99 100 101 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 99 def real_estate_tax @real_estate_tax end |
#received_other_consideration ⇒ TrueClass | FalseClass
Box 6, If checked, transferor received or will receive services or property (other than cash, notes, or digital assets) as part of the consideration
105 106 107 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 105 def received_other_consideration @received_other_consideration end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 53 def recipient @recipient end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 14 def tax_year @tax_year end |
#units ⇒ String
Box 8c, Number of digital asset units received as consideration
122 123 124 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 122 def units @units end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 248 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP date_of_closing = hash.key?('dateOfClosing') ? hash['dateOfClosing'] : SKIP gross_proceeds = hash.key?('grossProceeds') ? hash['grossProceeds'] : SKIP cash_proceeds = hash.key?('cashProceeds') ? hash['cashProceeds'] : SKIP digital_asset_proceeds = hash.key?('digitalAssetProceeds') ? hash['digitalAssetProceeds'] : SKIP address_or_legal_description = hash.key?('addressOrLegalDescription') ? hash['addressOrLegalDescription'] : SKIP real_estate_tax = hash.key?('realEstateTax') ? hash['realEstateTax'] : SKIP received_other_consideration = hash.key?('receivedOtherConsideration') ? hash['receivedOtherConsideration'] : SKIP foreign_person = hash.key?('foreignPerson') ? hash['foreignPerson'] : SKIP digital_asset_code = hash.key?('digitalAssetCode') ? hash['digitalAssetCode'] : SKIP digital_asset_name = hash.key?('digitalAssetName') ? hash['digitalAssetName'] : SKIP units = hash.key?('units') ? hash['units'] : SKIP digital_asset_date_received = hash.key?('digitalAssetDateReceived') ? hash['digitalAssetDateReceived'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099S1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, date_of_closing: date_of_closing, gross_proceeds: gross_proceeds, cash_proceeds: cash_proceeds, digital_asset_proceeds: digital_asset_proceeds, address_or_legal_description: address_or_legal_description, real_estate_tax: real_estate_tax, received_other_consideration: received_other_consideration, foreign_person: foreign_person, digital_asset_code: digital_asset_code, digital_asset_name: digital_asset_name, units: units, digital_asset_date_received: digital_asset_date_received, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 129 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['date_of_closing'] = 'dateOfClosing' @_hash['gross_proceeds'] = 'grossProceeds' @_hash['cash_proceeds'] = 'cashProceeds' @_hash['digital_asset_proceeds'] = 'digitalAssetProceeds' @_hash['address_or_legal_description'] = 'addressOrLegalDescription' @_hash['real_estate_tax'] = 'realEstateTax' @_hash['received_other_consideration'] = 'receivedOtherConsideration' @_hash['foreign_person'] = 'foreignPerson' @_hash['digital_asset_code'] = 'digitalAssetCode' @_hash['digital_asset_name'] = 'digitalAssetName' @_hash['units'] = 'units' @_hash['digital_asset_date_received'] = 'digitalAssetDateReceived' @_hash end |
.nullables ⇒ Object
An array for nullable fields
191 192 193 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 191 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 160 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number date_of_closing gross_proceeds cash_proceeds digital_asset_proceeds address_or_legal_description real_estate_tax received_other_consideration foreign_person digital_asset_code digital_asset_name units digital_asset_date_received ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 359 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, date_of_closing:"\ " #{@date_of_closing.inspect}, gross_proceeds: #{@gross_proceeds.inspect}, cash_proceeds:"\ " #{@cash_proceeds.inspect}, digital_asset_proceeds: #{@digital_asset_proceeds.inspect},"\ " address_or_legal_description: #{@address_or_legal_description.inspect}, real_estate_tax:"\ " #{@real_estate_tax.inspect}, received_other_consideration:"\ " #{@received_other_consideration.inspect}, foreign_person: #{@foreign_person.inspect},"\ " digital_asset_code: #{@digital_asset_code.inspect}, digital_asset_name:"\ " #{@digital_asset_name.inspect}, units: #{@units.inspect}, digital_asset_date_received:"\ " #{@digital_asset_date_received.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/fdx_v660_api/models/form1099_s1.rb', line 342 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, date_of_closing:"\ " #{@date_of_closing}, gross_proceeds: #{@gross_proceeds}, cash_proceeds: #{@cash_proceeds},"\ " digital_asset_proceeds: #{@digital_asset_proceeds}, address_or_legal_description:"\ " #{@address_or_legal_description}, real_estate_tax: #{@real_estate_tax},"\ " received_other_consideration: #{@received_other_consideration}, foreign_person:"\ " #{@foreign_person}, digital_asset_code: #{@digital_asset_code}, digital_asset_name:"\ " #{@digital_asset_name}, units: #{@units}, digital_asset_date_received:"\ " #{@digital_asset_date_received}, additional_properties: #{@additional_properties}>" end |