Class: FdxV660Api::Form39221
- Defined in:
- lib/fdx_v660_api/models/form39221.rb
Overview
Transfer of Stock Acquired Through an Employee Stock Purchase Plan under Section 423(c)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#exercise_market_value ⇒ Float
Box 4, Fair market value per share on exercise date.
-
#exercise_price ⇒ Float
Box 5, Exercise price paid per share.
-
#grant_date_exercise_price ⇒ Float
Box 8, Exercise price per share determined as if the option was exercised on the option granted date.
-
#grant_market_value ⇒ Float
Box 3, Fair market value per share on grant date.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#number_of_shares ⇒ Float
Box 6, Number of shares transferred.
-
#option_exercise_date ⇒ Date
Box 2, Date option exercised.
-
#option_grant_date ⇒ Date
Box 1, Date option granted.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#title_transfer_date ⇒ Date
Box 7, Date legal title transferred.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, option_grant_date: SKIP, option_exercise_date: SKIP, grant_market_value: SKIP, exercise_market_value: SKIP, exercise_price: SKIP, number_of_shares: SKIP, title_transfer_date: SKIP, grant_date_exercise_price: SKIP, additional_properties: nil) ⇒ Form39221
constructor
A new instance of Form39221.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, option_grant_date: SKIP, option_exercise_date: SKIP, grant_market_value: SKIP, exercise_market_value: SKIP, exercise_price: SKIP, number_of_shares: SKIP, title_transfer_date: SKIP, grant_date_exercise_price: SKIP, additional_properties: nil) ⇒ Form39221
Returns a new instance of Form39221.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 170 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, option_grant_date: SKIP, option_exercise_date: SKIP, grant_market_value: SKIP, exercise_market_value: SKIP, exercise_price: SKIP, number_of_shares: SKIP, title_transfer_date: SKIP, grant_date_exercise_price: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @option_grant_date = option_grant_date unless option_grant_date == SKIP @option_exercise_date = option_exercise_date unless option_exercise_date == SKIP @grant_market_value = grant_market_value unless grant_market_value == SKIP @exercise_market_value = exercise_market_value unless exercise_market_value == SKIP @exercise_price = exercise_price unless exercise_price == SKIP @number_of_shares = number_of_shares unless number_of_shares == SKIP @title_transfer_date = title_transfer_date unless title_transfer_date == SKIP unless grant_date_exercise_price == SKIP @grant_date_exercise_price = grant_date_exercise_price end @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 19 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 68 def error @error end |
#exercise_market_value ⇒ Float
Box 4, Fair market value per share on exercise date
92 93 94 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 92 def exercise_market_value @exercise_market_value end |
#exercise_price ⇒ Float
Box 5, Exercise price paid per share
96 97 98 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 96 def exercise_price @exercise_price end |
#grant_date_exercise_price ⇒ Float
Box 8, Exercise price per share determined as if the option was exercised on the option granted date
109 110 111 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 109 def grant_date_exercise_price @grant_date_exercise_price end |
#grant_market_value ⇒ Float
Box 3, Fair market value per share on grant date
88 89 90 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 88 def grant_market_value @grant_market_value end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 72 def links @links end |
#number_of_shares ⇒ Float
Box 6, Number of shares transferred
100 101 102 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 100 def number_of_shares @number_of_shares end |
#option_exercise_date ⇒ Date
Box 2, Date option exercised
84 85 86 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 84 def option_exercise_date @option_exercise_date end |
#option_grant_date ⇒ Date
Box 1, Date option granted
80 81 82 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 80 def option_grant_date @option_grant_date end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 54 def recipient @recipient end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 15 def tax_year @tax_year end |
#title_transfer_date ⇒ Date
Box 7, Date legal title transferred
104 105 106 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 104 def title_transfer_date @title_transfer_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 210 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP option_grant_date = hash.key?('optionGrantDate') ? hash['optionGrantDate'] : SKIP option_exercise_date = hash.key?('optionExerciseDate') ? hash['optionExerciseDate'] : SKIP grant_market_value = hash.key?('grantMarketValue') ? hash['grantMarketValue'] : SKIP exercise_market_value = hash.key?('exerciseMarketValue') ? hash['exerciseMarketValue'] : SKIP exercise_price = hash.key?('exercisePrice') ? hash['exercisePrice'] : SKIP number_of_shares = hash.key?('numberOfShares') ? hash['numberOfShares'] : SKIP title_transfer_date = hash.key?('titleTransferDate') ? hash['titleTransferDate'] : SKIP grant_date_exercise_price = hash.key?('grantDateExercisePrice') ? hash['grantDateExercisePrice'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form39221.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, option_grant_date: option_grant_date, option_exercise_date: option_exercise_date, grant_market_value: grant_market_value, exercise_market_value: exercise_market_value, exercise_price: exercise_price, number_of_shares: number_of_shares, title_transfer_date: title_transfer_date, grant_date_exercise_price: grant_date_exercise_price, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 112 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['option_grant_date'] = 'optionGrantDate' @_hash['option_exercise_date'] = 'optionExerciseDate' @_hash['grant_market_value'] = 'grantMarketValue' @_hash['exercise_market_value'] = 'exerciseMarketValue' @_hash['exercise_price'] = 'exercisePrice' @_hash['number_of_shares'] = 'numberOfShares' @_hash['title_transfer_date'] = 'titleTransferDate' @_hash['grant_date_exercise_price'] = 'grantDateExercisePrice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
166 167 168 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 166 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 139 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number option_grant_date option_exercise_date grant_market_value exercise_market_value exercise_price number_of_shares title_transfer_date grant_date_exercise_price ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 310 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, option_grant_date:"\ " #{@option_grant_date.inspect}, option_exercise_date: #{@option_exercise_date.inspect},"\ " grant_market_value: #{@grant_market_value.inspect}, exercise_market_value:"\ " #{@exercise_market_value.inspect}, exercise_price: #{@exercise_price.inspect},"\ " number_of_shares: #{@number_of_shares.inspect}, title_transfer_date:"\ " #{@title_transfer_date.inspect}, grant_date_exercise_price:"\ " #{@grant_date_exercise_price.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/fdx_v660_api/models/form39221.rb', line 295 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, option_grant_date:"\ " #{@option_grant_date}, option_exercise_date: #{@option_exercise_date}, grant_market_value:"\ " #{@grant_market_value}, exercise_market_value: #{@exercise_market_value}, exercise_price:"\ " #{@exercise_price}, number_of_shares: #{@number_of_shares}, title_transfer_date:"\ " #{@title_transfer_date}, grant_date_exercise_price: #{@grant_date_exercise_price},"\ " additional_properties: #{@additional_properties}>" end |