Class: FdxV660Api::Form54981

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form54981.rb

Overview

IRA Contribution Information

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ira_contributions: SKIP, rollover_contributions: SKIP, roth_ira_conversion: SKIP, recharacterized_contributions: SKIP, fair_market_value: SKIP, life_insurance_cost: SKIP, ira: SKIP, sep: SKIP, simple: SKIP, roth_ira: SKIP, sep_contributions: SKIP, simple_contributions: SKIP, roth_ira_contributions: SKIP, rmd_next_year: SKIP, rmd_date: SKIP, rmd_amount: SKIP, postponed_contribution: SKIP, postponed_year: SKIP, postponed_code: SKIP, repayments: SKIP, repay_code: SKIP, fmv_specified_assets: SKIP, specified_codes: SKIP, additional_properties: nil) ⇒ Form54981

Returns a new instance of Form54981.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/fdx_v660_api/models/form54981.rb', line 258

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, account_number: SKIP, ira_contributions: SKIP,
               rollover_contributions: SKIP, roth_ira_conversion: SKIP,
               recharacterized_contributions: SKIP, fair_market_value: SKIP,
               life_insurance_cost: SKIP, ira: SKIP, sep: SKIP,
               simple: SKIP, roth_ira: SKIP, sep_contributions: SKIP,
               simple_contributions: SKIP, roth_ira_contributions: SKIP,
               rmd_next_year: SKIP, rmd_date: SKIP, rmd_amount: SKIP,
               postponed_contribution: SKIP, postponed_year: SKIP,
               postponed_code: SKIP, repayments: SKIP, repay_code: SKIP,
               fmv_specified_assets: SKIP, specified_codes: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @account_number =  unless  == SKIP
  @ira_contributions = ira_contributions unless ira_contributions == SKIP
  @rollover_contributions = rollover_contributions unless rollover_contributions == SKIP
  @roth_ira_conversion = roth_ira_conversion unless roth_ira_conversion == SKIP
  unless recharacterized_contributions == SKIP
    @recharacterized_contributions =
      recharacterized_contributions
  end
  @fair_market_value = fair_market_value unless fair_market_value == SKIP
  @life_insurance_cost = life_insurance_cost unless life_insurance_cost == SKIP
  @ira = ira unless ira == SKIP
  @sep = sep unless sep == SKIP
  @simple = simple unless simple == SKIP
  @roth_ira = roth_ira unless roth_ira == SKIP
  @sep_contributions = sep_contributions unless sep_contributions == SKIP
  @simple_contributions = simple_contributions unless simple_contributions == SKIP
  @roth_ira_contributions = roth_ira_contributions unless roth_ira_contributions == SKIP
  @rmd_next_year = rmd_next_year unless rmd_next_year == SKIP
  @rmd_date = rmd_date unless rmd_date == SKIP
  @rmd_amount = rmd_amount unless rmd_amount == SKIP
  @postponed_contribution = postponed_contribution unless postponed_contribution == SKIP
  @postponed_year = postponed_year unless postponed_year == SKIP
  @postponed_code = postponed_code unless postponed_code == SKIP
  @repayments = repayments unless repayments == SKIP
  @repay_code = repay_code unless repay_code == SKIP
  @fmv_specified_assets = fmv_specified_assets unless fmv_specified_assets == SKIP
  @specified_codes = specified_codes unless specified_codes == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


23
24
25
# File 'lib/fdx_v660_api/models/form54981.rb', line 23

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


75
76
77
# File 'lib/fdx_v660_api/models/form54981.rb', line 75

def 
  @account_number
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


37
38
39
# File 'lib/fdx_v660_api/models/form54981.rb', line 37

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



63
64
65
# File 'lib/fdx_v660_api/models/form54981.rb', line 63

def attributes
  @attributes
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/fdx_v660_api/models/form54981.rb', line 18

def corrected
  @corrected
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



67
68
69
# File 'lib/fdx_v660_api/models/form54981.rb', line 67

def error
  @error
end

#fair_market_valueFloat

Box 5, Fair market value of account

Returns:

  • (Float)


95
96
97
# File 'lib/fdx_v660_api/models/form54981.rb', line 95

def fair_market_value
  @fair_market_value
end

#fmv_specified_assetsFloat

Box 15a, FMV of certain specified assets

Returns:

  • (Float)


163
164
165
# File 'lib/fdx_v660_api/models/form54981.rb', line 163

def fmv_specified_assets
  @fmv_specified_assets
end

#iraTrueClass | FalseClass

Box 7a, IRA

Returns:

  • (TrueClass | FalseClass)


103
104
105
# File 'lib/fdx_v660_api/models/form54981.rb', line 103

def ira
  @ira
end

#ira_contributionsFloat

Box 1, IRA contributions

Returns:

  • (Float)


79
80
81
# File 'lib/fdx_v660_api/models/form54981.rb', line 79

def ira_contributions
  @ira_contributions
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



47
48
49
# File 'lib/fdx_v660_api/models/form54981.rb', line 47

def issuer
  @issuer
end

#life_insurance_costFloat

Box 6, Life insurance cost included in box 1

Returns:

  • (Float)


99
100
101
# File 'lib/fdx_v660_api/models/form54981.rb', line 99

def life_insurance_cost
  @life_insurance_cost
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



71
72
73
# File 'lib/fdx_v660_api/models/form54981.rb', line 71

def links
  @links
end

#postponed_codeString

Box 13c, Code

Returns:

  • (String)


151
152
153
# File 'lib/fdx_v660_api/models/form54981.rb', line 151

def postponed_code
  @postponed_code
end

#postponed_contributionFloat

Box 13a, Postponed contribution

Returns:

  • (Float)


143
144
145
# File 'lib/fdx_v660_api/models/form54981.rb', line 143

def postponed_contribution
  @postponed_contribution
end

#postponed_yearInteger

Box 13b, Year

Returns:

  • (Integer)


147
148
149
# File 'lib/fdx_v660_api/models/form54981.rb', line 147

def postponed_year
  @postponed_year
end

#recharacterized_contributionsFloat

Box 4, Recharacterized contributions

Returns:

  • (Float)


91
92
93
# File 'lib/fdx_v660_api/models/form54981.rb', line 91

def recharacterized_contributions
  @recharacterized_contributions
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



53
54
55
# File 'lib/fdx_v660_api/models/form54981.rb', line 53

def recipient
  @recipient
end

#repay_codeString

Box 14b, Code

Returns:

  • (String)


159
160
161
# File 'lib/fdx_v660_api/models/form54981.rb', line 159

def repay_code
  @repay_code
end

#repaymentsFloat

Box 14a, Repayments

Returns:

  • (Float)


155
156
157
# File 'lib/fdx_v660_api/models/form54981.rb', line 155

def repayments
  @repayments
end

#rmd_amountFloat

Box 12b, RMD amount

Returns:

  • (Float)


139
140
141
# File 'lib/fdx_v660_api/models/form54981.rb', line 139

def rmd_amount
  @rmd_amount
end

#rmd_dateDate

Box 12a, RMD date

Returns:

  • (Date)


135
136
137
# File 'lib/fdx_v660_api/models/form54981.rb', line 135

def rmd_date
  @rmd_date
end

#rmd_next_yearTrueClass | FalseClass

Box 11, If checked, required minimum distribution for next year

Returns:

  • (TrueClass | FalseClass)


131
132
133
# File 'lib/fdx_v660_api/models/form54981.rb', line 131

def rmd_next_year
  @rmd_next_year
end

#rollover_contributionsFloat

Box 2, Rollover contributions

Returns:

  • (Float)


83
84
85
# File 'lib/fdx_v660_api/models/form54981.rb', line 83

def rollover_contributions
  @rollover_contributions
end

#roth_iraTrueClass | FalseClass

Box 7d, Roth IRA

Returns:

  • (TrueClass | FalseClass)


115
116
117
# File 'lib/fdx_v660_api/models/form54981.rb', line 115

def roth_ira
  @roth_ira
end

#roth_ira_contributionsFloat

Box 10, Roth IRA contributions

Returns:

  • (Float)


127
128
129
# File 'lib/fdx_v660_api/models/form54981.rb', line 127

def roth_ira_contributions
  @roth_ira_contributions
end

#roth_ira_conversionFloat

Box 3, Roth IRA conversion amount

Returns:

  • (Float)


87
88
89
# File 'lib/fdx_v660_api/models/form54981.rb', line 87

def roth_ira_conversion
  @roth_ira_conversion
end

#sepTrueClass | FalseClass

Box 7b, SEP

Returns:

  • (TrueClass | FalseClass)


107
108
109
# File 'lib/fdx_v660_api/models/form54981.rb', line 107

def sep
  @sep
end

#sep_contributionsFloat

Box 8, SEP contributions

Returns:

  • (Float)


119
120
121
# File 'lib/fdx_v660_api/models/form54981.rb', line 119

def sep_contributions
  @sep_contributions
end

#simpleTrueClass | FalseClass

Box 7c, SIMPLE

Returns:

  • (TrueClass | FalseClass)


111
112
113
# File 'lib/fdx_v660_api/models/form54981.rb', line 111

def simple
  @simple
end

#simple_contributionsFloat

Box 9, SIMPLE contributions

Returns:

  • (Float)


123
124
125
# File 'lib/fdx_v660_api/models/form54981.rb', line 123

def simple_contributions
  @simple_contributions
end

#specified_codesString

Box 15b, Code(s)

Returns:

  • (String)


167
168
169
# File 'lib/fdx_v660_api/models/form54981.rb', line 167

def specified_codes
  @specified_codes
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


33
34
35
# File 'lib/fdx_v660_api/models/form54981.rb', line 33

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


29
30
31
# File 'lib/fdx_v660_api/models/form54981.rb', line 29

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



41
42
43
# File 'lib/fdx_v660_api/models/form54981.rb', line 41

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


14
15
16
# File 'lib/fdx_v660_api/models/form54981.rb', line 14

def tax_year
  @tax_year
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/fdx_v660_api/models/form54981.rb', line 319

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  ira_contributions =
    hash.key?('iraContributions') ? hash['iraContributions'] : SKIP
  rollover_contributions =
    hash.key?('rolloverContributions') ? hash['rolloverContributions'] : SKIP
  roth_ira_conversion =
    hash.key?('rothIraConversion') ? hash['rothIraConversion'] : SKIP
  recharacterized_contributions =
    hash.key?('recharacterizedContributions') ? hash['recharacterizedContributions'] : SKIP
  fair_market_value =
    hash.key?('fairMarketValue') ? hash['fairMarketValue'] : SKIP
  life_insurance_cost =
    hash.key?('lifeInsuranceCost') ? hash['lifeInsuranceCost'] : SKIP
  ira = hash.key?('ira') ? hash['ira'] : SKIP
  sep = hash.key?('sep') ? hash['sep'] : SKIP
  simple = hash.key?('simple') ? hash['simple'] : SKIP
  roth_ira = hash.key?('rothIra') ? hash['rothIra'] : SKIP
  sep_contributions =
    hash.key?('sepContributions') ? hash['sepContributions'] : SKIP
  simple_contributions =
    hash.key?('simpleContributions') ? hash['simpleContributions'] : SKIP
  roth_ira_contributions =
    hash.key?('rothIraContributions') ? hash['rothIraContributions'] : SKIP
  rmd_next_year = hash.key?('rmdNextYear') ? hash['rmdNextYear'] : SKIP
  rmd_date = hash.key?('rmdDate') ? hash['rmdDate'] : SKIP
  rmd_amount = hash.key?('rmdAmount') ? hash['rmdAmount'] : SKIP
  postponed_contribution =
    hash.key?('postponedContribution') ? hash['postponedContribution'] : SKIP
  postponed_year = hash.key?('postponedYear') ? hash['postponedYear'] : SKIP
  postponed_code = hash.key?('postponedCode') ? hash['postponedCode'] : SKIP
  repayments = hash.key?('repayments') ? hash['repayments'] : SKIP
  repay_code = hash.key?('repayCode') ? hash['repayCode'] : SKIP
  fmv_specified_assets =
    hash.key?('fmvSpecifiedAssets') ? hash['fmvSpecifiedAssets'] : SKIP
  specified_codes =
    hash.key?('specifiedCodes') ? hash['specifiedCodes'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form54981.new(tax_year: tax_year,
                corrected: corrected,
                account_id: ,
                tax_form_id: tax_form_id,
                tax_form_date: tax_form_date,
                additional_information: additional_information,
                tax_form_type: tax_form_type,
                issuer: issuer,
                recipient: recipient,
                attributes: attributes,
                error: error,
                links: links,
                account_number: ,
                ira_contributions: ira_contributions,
                rollover_contributions: rollover_contributions,
                roth_ira_conversion: roth_ira_conversion,
                recharacterized_contributions: recharacterized_contributions,
                fair_market_value: fair_market_value,
                life_insurance_cost: life_insurance_cost,
                ira: ira,
                sep: sep,
                simple: simple,
                roth_ira: roth_ira,
                sep_contributions: sep_contributions,
                simple_contributions: simple_contributions,
                roth_ira_contributions: roth_ira_contributions,
                rmd_next_year: rmd_next_year,
                rmd_date: rmd_date,
                rmd_amount: rmd_amount,
                postponed_contribution: postponed_contribution,
                postponed_year: postponed_year,
                postponed_code: postponed_code,
                repayments: repayments,
                repay_code: repay_code,
                fmv_specified_assets: fmv_specified_assets,
                specified_codes: specified_codes,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/fdx_v660_api/models/form54981.rb', line 170

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['account_number'] = 'accountNumber'
  @_hash['ira_contributions'] = 'iraContributions'
  @_hash['rollover_contributions'] = 'rolloverContributions'
  @_hash['roth_ira_conversion'] = 'rothIraConversion'
  @_hash['recharacterized_contributions'] = 'recharacterizedContributions'
  @_hash['fair_market_value'] = 'fairMarketValue'
  @_hash['life_insurance_cost'] = 'lifeInsuranceCost'
  @_hash['ira'] = 'ira'
  @_hash['sep'] = 'sep'
  @_hash['simple'] = 'simple'
  @_hash['roth_ira'] = 'rothIra'
  @_hash['sep_contributions'] = 'sepContributions'
  @_hash['simple_contributions'] = 'simpleContributions'
  @_hash['roth_ira_contributions'] = 'rothIraContributions'
  @_hash['rmd_next_year'] = 'rmdNextYear'
  @_hash['rmd_date'] = 'rmdDate'
  @_hash['rmd_amount'] = 'rmdAmount'
  @_hash['postponed_contribution'] = 'postponedContribution'
  @_hash['postponed_year'] = 'postponedYear'
  @_hash['postponed_code'] = 'postponedCode'
  @_hash['repayments'] = 'repayments'
  @_hash['repay_code'] = 'repayCode'
  @_hash['fmv_specified_assets'] = 'fmvSpecifiedAssets'
  @_hash['specified_codes'] = 'specifiedCodes'
  @_hash
end

.nullablesObject

An array for nullable fields



254
255
256
# File 'lib/fdx_v660_api/models/form54981.rb', line 254

def self.nullables
  []
end

.optionalsObject

An array for optional fields



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/fdx_v660_api/models/form54981.rb', line 212

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    account_number
    ira_contributions
    rollover_contributions
    roth_ira_conversion
    recharacterized_contributions
    fair_market_value
    life_insurance_cost
    ira
    sep
    simple
    roth_ira
    sep_contributions
    simple_contributions
    roth_ira_contributions
    rmd_next_year
    rmd_date
    rmd_amount
    postponed_contribution
    postponed_year
    postponed_code
    repayments
    repay_code
    fmv_specified_assets
    specified_codes
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/fdx_v660_api/models/form54981.rb', line 461

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, account_number: #{@account_number.inspect}, ira_contributions:"\
  " #{@ira_contributions.inspect}, rollover_contributions: #{@rollover_contributions.inspect},"\
  " roth_ira_conversion: #{@roth_ira_conversion.inspect}, recharacterized_contributions:"\
  " #{@recharacterized_contributions.inspect}, fair_market_value:"\
  " #{@fair_market_value.inspect}, life_insurance_cost: #{@life_insurance_cost.inspect}, ira:"\
  " #{@ira.inspect}, sep: #{@sep.inspect}, simple: #{@simple.inspect}, roth_ira:"\
  " #{@roth_ira.inspect}, sep_contributions: #{@sep_contributions.inspect},"\
  " simple_contributions: #{@simple_contributions.inspect}, roth_ira_contributions:"\
  " #{@roth_ira_contributions.inspect}, rmd_next_year: #{@rmd_next_year.inspect}, rmd_date:"\
  " #{@rmd_date.inspect}, rmd_amount: #{@rmd_amount.inspect}, postponed_contribution:"\
  " #{@postponed_contribution.inspect}, postponed_year: #{@postponed_year.inspect},"\
  " postponed_code: #{@postponed_code.inspect}, repayments: #{@repayments.inspect},"\
  " repay_code: #{@repay_code.inspect}, fmv_specified_assets:"\
  " #{@fmv_specified_assets.inspect}, specified_codes: #{@specified_codes.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/fdx_v660_api/models/form54981.rb', line 439

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, account_number: #{@account_number}, ira_contributions:"\
  " #{@ira_contributions}, rollover_contributions: #{@rollover_contributions},"\
  " roth_ira_conversion: #{@roth_ira_conversion}, recharacterized_contributions:"\
  " #{@recharacterized_contributions}, fair_market_value: #{@fair_market_value},"\
  " life_insurance_cost: #{@life_insurance_cost}, ira: #{@ira}, sep: #{@sep}, simple:"\
  " #{@simple}, roth_ira: #{@roth_ira}, sep_contributions: #{@sep_contributions},"\
  " simple_contributions: #{@simple_contributions}, roth_ira_contributions:"\
  " #{@roth_ira_contributions}, rmd_next_year: #{@rmd_next_year}, rmd_date: #{@rmd_date},"\
  " rmd_amount: #{@rmd_amount}, postponed_contribution: #{@postponed_contribution},"\
  " postponed_year: #{@postponed_year}, postponed_code: #{@postponed_code}, repayments:"\
  " #{@repayments}, repay_code: #{@repay_code}, fmv_specified_assets:"\
  " #{@fmv_specified_assets}, specified_codes: #{@specified_codes}, additional_properties:"\
  " #{@additional_properties}>"
end