Class: FdxV660Api::Form5498Qa

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/form5498_qa.rb

Overview

ABLE Account Contribution Information, from ISSUER (1st-8th boxes) to BENEFICIARY (9th-16th boxes as recipient)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, able_contributions: SKIP, rollovers: SKIP, cumulative_contributions: SKIP, fair_market_value: SKIP, opened_in_tax_year: SKIP, basis_of_disability_code: SKIP, type_of_disability_code: SKIP, trump_account_rollovers: SKIP, additional_properties: nil) ⇒ Form5498Qa

Returns a new instance of Form5498Qa.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 169

def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP,
               tax_form_id: SKIP, tax_form_date: SKIP,
               additional_information: SKIP, tax_form_type: SKIP,
               issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP,
               links: SKIP, account_number: SKIP, able_contributions: SKIP,
               rollovers: SKIP, cumulative_contributions: SKIP,
               fair_market_value: SKIP, opened_in_tax_year: SKIP,
               basis_of_disability_code: SKIP,
               type_of_disability_code: SKIP, trump_account_rollovers: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_year = tax_year unless tax_year == SKIP
  @corrected = corrected unless corrected == SKIP
  @account_id =  unless  == SKIP
  @tax_form_id = tax_form_id unless tax_form_id == SKIP
  @tax_form_date = tax_form_date unless tax_form_date == SKIP
  @additional_information = additional_information unless additional_information == SKIP
  @tax_form_type = tax_form_type unless tax_form_type == SKIP
  @issuer = issuer unless issuer == SKIP
  @recipient = recipient unless recipient == SKIP
  @attributes = attributes unless attributes == SKIP
  @error = error unless error == SKIP
  @links = links unless links == SKIP
  @account_number =  unless  == SKIP
  @able_contributions = able_contributions unless able_contributions == SKIP
  @rollovers = rollovers unless rollovers == SKIP
  @cumulative_contributions = cumulative_contributions unless cumulative_contributions == SKIP
  @fair_market_value = fair_market_value unless fair_market_value == SKIP
  @opened_in_tax_year = opened_in_tax_year unless opened_in_tax_year == SKIP
  @basis_of_disability_code = basis_of_disability_code unless basis_of_disability_code == SKIP
  @type_of_disability_code = type_of_disability_code unless type_of_disability_code == SKIP
  @trump_account_rollovers =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#able_contributionsFloat

Box 1, ABLE contributions

Returns:

  • (Float)


80
81
82
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 80

def able_contributions
  @able_contributions
end

#account_idString

Long-term persistent identity of the source account. Not the account number

Returns:

  • (String)


24
25
26
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 24

def 
  @account_id
end

#account_numberString

Account number

Returns:

  • (String)


76
77
78
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 76

def 
  @account_number
end

#additional_informationString

Additional explanation text or content about this tax form

Returns:

  • (String)


38
39
40
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 38

def additional_information
  @additional_information
end

#attributesArray[TaxFormAttribute]

Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.

Returns:



64
65
66
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 64

def attributes
  @attributes
end

#basis_of_disability_codeString

Box 6, Basis of eligibility

Returns:

  • (String)


100
101
102
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 100

def basis_of_disability_code
  @basis_of_disability_code
end

#correctedTrueClass | FalseClass

True to indicate this is a corrected tax form

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 19

def corrected
  @corrected
end

#cumulative_contributionsFloat

Box 3, Cumulative contributions

Returns:

  • (Float)


88
89
90
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 88

def cumulative_contributions
  @cumulative_contributions
end

#errorError2

Present if an error was encountered while retrieving this form

Returns:



68
69
70
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 68

def error
  @error
end

#fair_market_valueFloat

Box 4, Fair market value

Returns:

  • (Float)


92
93
94
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 92

def fair_market_value
  @fair_market_value
end

#issuerTaxParty8

Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



48
49
50
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 48

def issuer
  @issuer
end

Links to retrieve this form as data or image, or to invoke other APIs

Returns:



72
73
74
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 72

def links
  @links
end

#opened_in_tax_yearTrueClass | FalseClass

Box 5, Check if account opened in current tax year

Returns:

  • (TrueClass | FalseClass)


96
97
98
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 96

def opened_in_tax_year
  @opened_in_tax_year
end

#recipientTaxParty1

Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.

Returns:



54
55
56
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 54

def recipient
  @recipient
end

#rolloversFloat

Box 2, ABLE to ABLE Rollovers

Returns:

  • (Float)


84
85
86
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 84

def rollovers
  @rollovers
end

#tax_form_dateDate

Date of production or delivery of the tax form

Returns:

  • (Date)


34
35
36
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 34

def tax_form_date
  @tax_form_date
end

#tax_form_idString

Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.

Returns:

  • (String)


30
31
32
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 30

def tax_form_id
  @tax_form_id
end

#tax_form_typeTypeFormType1

Enumerated name of the tax form entity e.g. "TaxW2"

Returns:



42
43
44
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 42

def tax_form_type
  @tax_form_type
end

#tax_yearInteger

Year for which taxes are being paid

Returns:

  • (Integer)


15
16
17
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 15

def tax_year
  @tax_year
end

#trump_account_rolloversFloat

Box 8, Trump account to ABLE Rollovers

Returns:

  • (Float)


108
109
110
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 108

def 
  @trump_account_rollovers
end

#type_of_disability_codeString

Box 7, Code

Returns:

  • (String)


104
105
106
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 104

def type_of_disability_code
  @type_of_disability_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 207

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP
  corrected = hash.key?('corrected') ? hash['corrected'] : SKIP
   = hash.key?('accountId') ? hash['accountId'] : SKIP
  tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP
  tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP
  additional_information =
    hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP
  tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP
  issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer']
  recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient']
  # Parameter is an array, so we need to iterate through it
  attributes = nil
  unless hash['attributes'].nil?
    attributes = []
    hash['attributes'].each do |structure|
      attributes << (TaxFormAttribute.from_hash(structure) if structure)
    end
  end

  attributes = SKIP unless hash.key?('attributes')
  error = Error2.from_hash(hash['error']) if hash['error']
  # Parameter is an array, so we need to iterate through it
  links = nil
  unless hash['links'].nil?
    links = []
    hash['links'].each do |structure|
      links << (HateoasLink.from_hash(structure) if structure)
    end
  end

  links = SKIP unless hash.key?('links')
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
  able_contributions =
    hash.key?('ableContributions') ? hash['ableContributions'] : SKIP
  rollovers = hash.key?('rollovers') ? hash['rollovers'] : SKIP
  cumulative_contributions =
    hash.key?('cumulativeContributions') ? hash['cumulativeContributions'] : SKIP
  fair_market_value =
    hash.key?('fairMarketValue') ? hash['fairMarketValue'] : SKIP
  opened_in_tax_year =
    hash.key?('openedInTaxYear') ? hash['openedInTaxYear'] : SKIP
  basis_of_disability_code =
    hash.key?('basisOfDisabilityCode') ? hash['basisOfDisabilityCode'] : SKIP
  type_of_disability_code =
    hash.key?('typeOfDisabilityCode') ? hash['typeOfDisabilityCode'] : SKIP
   =
    hash.key?('trumpAccountRollovers') ? hash['trumpAccountRollovers'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Form5498Qa.new(tax_year: tax_year,
                 corrected: corrected,
                 account_id: ,
                 tax_form_id: tax_form_id,
                 tax_form_date: tax_form_date,
                 additional_information: additional_information,
                 tax_form_type: tax_form_type,
                 issuer: issuer,
                 recipient: recipient,
                 attributes: attributes,
                 error: error,
                 links: links,
                 account_number: ,
                 able_contributions: able_contributions,
                 rollovers: rollovers,
                 cumulative_contributions: cumulative_contributions,
                 fair_market_value: fair_market_value,
                 opened_in_tax_year: opened_in_tax_year,
                 basis_of_disability_code: basis_of_disability_code,
                 type_of_disability_code: type_of_disability_code,
                 trump_account_rollovers: ,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 111

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_year'] = 'taxYear'
  @_hash['corrected'] = 'corrected'
  @_hash['account_id'] = 'accountId'
  @_hash['tax_form_id'] = 'taxFormId'
  @_hash['tax_form_date'] = 'taxFormDate'
  @_hash['additional_information'] = 'additionalInformation'
  @_hash['tax_form_type'] = 'taxFormType'
  @_hash['issuer'] = 'issuer'
  @_hash['recipient'] = 'recipient'
  @_hash['attributes'] = 'attributes'
  @_hash['error'] = 'error'
  @_hash['links'] = 'links'
  @_hash['account_number'] = 'accountNumber'
  @_hash['able_contributions'] = 'ableContributions'
  @_hash['rollovers'] = 'rollovers'
  @_hash['cumulative_contributions'] = 'cumulativeContributions'
  @_hash['fair_market_value'] = 'fairMarketValue'
  @_hash['opened_in_tax_year'] = 'openedInTaxYear'
  @_hash['basis_of_disability_code'] = 'basisOfDisabilityCode'
  @_hash['type_of_disability_code'] = 'typeOfDisabilityCode'
  @_hash['trump_account_rollovers'] = 'trumpAccountRollovers'
  @_hash
end

.nullablesObject

An array for nullable fields



165
166
167
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 165

def self.nullables
  []
end

.optionalsObject

An array for optional fields



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 138

def self.optionals
  %w[
    tax_year
    corrected
    account_id
    tax_form_id
    tax_form_date
    additional_information
    tax_form_type
    issuer
    recipient
    attributes
    error
    links
    account_number
    able_contributions
    rollovers
    cumulative_contributions
    fair_market_value
    opened_in_tax_year
    basis_of_disability_code
    type_of_disability_code
    trump_account_rollovers
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 308

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\
  " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\
  " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\
  " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\
  " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\
  " links: #{@links.inspect}, account_number: #{@account_number.inspect}, able_contributions:"\
  " #{@able_contributions.inspect}, rollovers: #{@rollovers.inspect},"\
  " cumulative_contributions: #{@cumulative_contributions.inspect}, fair_market_value:"\
  " #{@fair_market_value.inspect}, opened_in_tax_year: #{@opened_in_tax_year.inspect},"\
  " basis_of_disability_code: #{@basis_of_disability_code.inspect}, type_of_disability_code:"\
  " #{@type_of_disability_code.inspect}, trump_account_rollovers:"\
  " #{@trump_account_rollovers.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/fdx_v660_api/models/form5498_qa.rb', line 292

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\
  " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\
  " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\
  " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\
  " #{@error}, links: #{@links}, account_number: #{@account_number}, able_contributions:"\
  " #{@able_contributions}, rollovers: #{@rollovers}, cumulative_contributions:"\
  " #{@cumulative_contributions}, fair_market_value: #{@fair_market_value},"\
  " opened_in_tax_year: #{@opened_in_tax_year}, basis_of_disability_code:"\
  " #{@basis_of_disability_code}, type_of_disability_code: #{@type_of_disability_code},"\
  " trump_account_rollovers: #{@trump_account_rollovers}, additional_properties:"\
  " #{@additional_properties}>"
end