Class: FdxV660Api::FormW22
- Defined in:
- lib/fdx_v660_api/models/form_w22.rb
Overview
Boxes 1-20 of Correct information Wage and Tax Statement
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#allocated_tips ⇒ Float
Box 8, Allocated tips.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#codes ⇒ Array[CodeAndAmount]
Box 12, Codes and amounts.
-
#control_number ⇒ String
Box d, Control number.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#dependent_care_benefit ⇒ Float
Box 10, Dependent care benefits.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#espp_non_qualified ⇒ Float
Employee Stock Purchase Plan Nonqualified Disposition amount.
-
#espp_qualified ⇒ Float
Employee Stock Purchase Plan Qualified Disposition amount.
-
#federal_tax_withheld ⇒ Float
Box 2, Federal income tax withheld.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#medicare_tax_withheld ⇒ Float
Box 6, Medicare tax withheld.
-
#medicare_wages ⇒ Float
Box 5, Medicare wages and tips.
-
#non_qualified_plan ⇒ Float
Box 11, Nonqualified plans.
-
#occupation_codes ⇒ Array[String]
Box 14b, Treasury Tipped Occupation Codes (TTOC).
-
#other ⇒ Array[DescriptionAndAmount]
Box 14a, Other descriptions and amounts.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#retirement_plan ⇒ TrueClass | FalseClass
Box 13, Retirement plan.
-
#social_security_tax_withheld ⇒ Float
Box 4, Social security tax withheld.
-
#social_security_tips ⇒ Float
Box 7, Social security tips.
-
#social_security_wages ⇒ Float
Box 3, Social security wages.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 15-20, State and Local tax withholding.
-
#statutory ⇒ TrueClass | FalseClass
Box 13, Statutory employee.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#third_party_sick_pay ⇒ TrueClass | FalseClass
Box 13, Third-party sick pay.
-
#wages ⇒ Float
Box 1, Wages, tips, other compensation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, control_number: SKIP, wages: SKIP, federal_tax_withheld: SKIP, social_security_wages: SKIP, social_security_tax_withheld: SKIP, medicare_wages: SKIP, medicare_tax_withheld: SKIP, social_security_tips: SKIP, allocated_tips: SKIP, dependent_care_benefit: SKIP, non_qualified_plan: SKIP, codes: SKIP, statutory: SKIP, retirement_plan: SKIP, third_party_sick_pay: SKIP, espp_qualified: SKIP, espp_non_qualified: SKIP, other: SKIP, occupation_codes: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ FormW22
constructor
A new instance of FormW22.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, control_number: SKIP, wages: SKIP, federal_tax_withheld: SKIP, social_security_wages: SKIP, social_security_tax_withheld: SKIP, medicare_wages: SKIP, medicare_tax_withheld: SKIP, social_security_tips: SKIP, allocated_tips: SKIP, dependent_care_benefit: SKIP, non_qualified_plan: SKIP, codes: SKIP, statutory: SKIP, retirement_plan: SKIP, third_party_sick_pay: SKIP, espp_qualified: SKIP, espp_non_qualified: SKIP, other: SKIP, occupation_codes: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ FormW22
Returns a new instance of FormW22.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 234 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, control_number: SKIP, wages: SKIP, federal_tax_withheld: SKIP, social_security_wages: SKIP, social_security_tax_withheld: SKIP, medicare_wages: SKIP, medicare_tax_withheld: SKIP, social_security_tips: SKIP, allocated_tips: SKIP, dependent_care_benefit: SKIP, non_qualified_plan: SKIP, codes: SKIP, statutory: SKIP, retirement_plan: SKIP, third_party_sick_pay: SKIP, espp_qualified: SKIP, espp_non_qualified: SKIP, other: SKIP, occupation_codes: SKIP, state_and_local: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @control_number = control_number unless control_number == SKIP @wages = wages unless wages == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @social_security_wages = unless == SKIP unless == SKIP @social_security_tax_withheld = end @medicare_wages = medicare_wages unless medicare_wages == SKIP @medicare_tax_withheld = medicare_tax_withheld unless medicare_tax_withheld == SKIP @social_security_tips = unless == SKIP @allocated_tips = allocated_tips unless allocated_tips == SKIP @dependent_care_benefit = dependent_care_benefit unless dependent_care_benefit == SKIP @non_qualified_plan = non_qualified_plan unless non_qualified_plan == SKIP @codes = codes unless codes == SKIP @statutory = statutory unless statutory == SKIP @retirement_plan = retirement_plan unless retirement_plan == SKIP @third_party_sick_pay = third_party_sick_pay unless third_party_sick_pay == SKIP @espp_qualified = espp_qualified unless espp_qualified == SKIP @espp_non_qualified = espp_non_qualified unless espp_non_qualified == SKIP @other = other unless other == SKIP @occupation_codes = occupation_codes unless occupation_codes == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 37 def additional_information @additional_information end |
#allocated_tips ⇒ Float
Box 8, Allocated tips
107 108 109 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 107 def allocated_tips @allocated_tips end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 63 def attributes @attributes end |
#codes ⇒ Array[CodeAndAmount]
Box 12, Codes and amounts
119 120 121 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 119 def codes @codes end |
#control_number ⇒ String
Box d, Control number
75 76 77 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 75 def control_number @control_number end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 18 def corrected @corrected end |
#dependent_care_benefit ⇒ Float
Box 10, Dependent care benefits
111 112 113 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 111 def dependent_care_benefit @dependent_care_benefit end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 67 def error @error end |
#espp_non_qualified ⇒ Float
Employee Stock Purchase Plan Nonqualified Disposition amount
139 140 141 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 139 def espp_non_qualified @espp_non_qualified end |
#espp_qualified ⇒ Float
Employee Stock Purchase Plan Qualified Disposition amount
135 136 137 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 135 def espp_qualified @espp_qualified end |
#federal_tax_withheld ⇒ Float
Box 2, Federal income tax withheld
83 84 85 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 83 def federal_tax_withheld @federal_tax_withheld end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 71 def links @links end |
#medicare_tax_withheld ⇒ Float
Box 6, Medicare tax withheld
99 100 101 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 99 def medicare_tax_withheld @medicare_tax_withheld end |
#medicare_wages ⇒ Float
Box 5, Medicare wages and tips
95 96 97 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 95 def medicare_wages @medicare_wages end |
#non_qualified_plan ⇒ Float
Box 11, Nonqualified plans
115 116 117 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 115 def non_qualified_plan @non_qualified_plan end |
#occupation_codes ⇒ Array[String]
Box 14b, Treasury Tipped Occupation Codes (TTOC)
147 148 149 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 147 def occupation_codes @occupation_codes end |
#other ⇒ Array[DescriptionAndAmount]
Box 14a, Other descriptions and amounts
143 144 145 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 143 def other @other end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 53 def recipient @recipient end |
#retirement_plan ⇒ TrueClass | FalseClass
Box 13, Retirement plan
127 128 129 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 127 def retirement_plan @retirement_plan end |
#social_security_tax_withheld ⇒ Float
Box 4, Social security tax withheld
91 92 93 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 91 def @social_security_tax_withheld end |
#social_security_tips ⇒ Float
Box 7, Social security tips
103 104 105 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 103 def @social_security_tips end |
#social_security_wages ⇒ Float
Box 3, Social security wages
87 88 89 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 87 def @social_security_wages end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 15-20, State and Local tax withholding
151 152 153 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 151 def state_and_local @state_and_local end |
#statutory ⇒ TrueClass | FalseClass
Box 13, Statutory employee
123 124 125 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 123 def statutory @statutory end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 14 def tax_year @tax_year end |
#third_party_sick_pay ⇒ TrueClass | FalseClass
Box 13, Third-party sick pay
131 132 133 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 131 def third_party_sick_pay @third_party_sick_pay end |
#wages ⇒ Float
Box 1, Wages, tips, other compensation
79 80 81 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 79 def wages @wages end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 290 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') control_number = hash.key?('controlNumber') ? hash['controlNumber'] : SKIP wages = hash.key?('wages') ? hash['wages'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP = hash.key?('socialSecurityWages') ? hash['socialSecurityWages'] : SKIP = hash.key?('socialSecurityTaxWithheld') ? hash['socialSecurityTaxWithheld'] : SKIP medicare_wages = hash.key?('medicareWages') ? hash['medicareWages'] : SKIP medicare_tax_withheld = hash.key?('medicareTaxWithheld') ? hash['medicareTaxWithheld'] : SKIP = hash.key?('socialSecurityTips') ? hash['socialSecurityTips'] : SKIP allocated_tips = hash.key?('allocatedTips') ? hash['allocatedTips'] : SKIP dependent_care_benefit = hash.key?('dependentCareBenefit') ? hash['dependentCareBenefit'] : SKIP non_qualified_plan = hash.key?('nonQualifiedPlan') ? hash['nonQualifiedPlan'] : SKIP # Parameter is an array, so we need to iterate through it codes = nil unless hash['codes'].nil? codes = [] hash['codes'].each do |structure| codes << (CodeAndAmount.from_hash(structure) if structure) end end codes = SKIP unless hash.key?('codes') statutory = hash.key?('statutory') ? hash['statutory'] : SKIP retirement_plan = hash.key?('retirementPlan') ? hash['retirementPlan'] : SKIP third_party_sick_pay = hash.key?('thirdPartySickPay') ? hash['thirdPartySickPay'] : SKIP espp_qualified = hash.key?('esppQualified') ? hash['esppQualified'] : SKIP espp_non_qualified = hash.key?('esppNonQualified') ? hash['esppNonQualified'] : SKIP # Parameter is an array, so we need to iterate through it other = nil unless hash['other'].nil? other = [] hash['other'].each do |structure| other << (DescriptionAndAmount.from_hash(structure) if structure) end end other = SKIP unless hash.key?('other') occupation_codes = hash.key?('occupationCodes') ? hash['occupationCodes'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FormW22.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, control_number: control_number, wages: wages, federal_tax_withheld: federal_tax_withheld, social_security_wages: , social_security_tax_withheld: , medicare_wages: medicare_wages, medicare_tax_withheld: medicare_tax_withheld, social_security_tips: , allocated_tips: allocated_tips, dependent_care_benefit: dependent_care_benefit, non_qualified_plan: non_qualified_plan, codes: codes, statutory: statutory, retirement_plan: retirement_plan, third_party_sick_pay: third_party_sick_pay, espp_qualified: espp_qualified, espp_non_qualified: espp_non_qualified, other: other, occupation_codes: occupation_codes, state_and_local: state_and_local, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 154 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['control_number'] = 'controlNumber' @_hash['wages'] = 'wages' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['social_security_wages'] = 'socialSecurityWages' @_hash['social_security_tax_withheld'] = 'socialSecurityTaxWithheld' @_hash['medicare_wages'] = 'medicareWages' @_hash['medicare_tax_withheld'] = 'medicareTaxWithheld' @_hash['social_security_tips'] = 'socialSecurityTips' @_hash['allocated_tips'] = 'allocatedTips' @_hash['dependent_care_benefit'] = 'dependentCareBenefit' @_hash['non_qualified_plan'] = 'nonQualifiedPlan' @_hash['codes'] = 'codes' @_hash['statutory'] = 'statutory' @_hash['retirement_plan'] = 'retirementPlan' @_hash['third_party_sick_pay'] = 'thirdPartySickPay' @_hash['espp_qualified'] = 'esppQualified' @_hash['espp_non_qualified'] = 'esppNonQualified' @_hash['other'] = 'other' @_hash['occupation_codes'] = 'occupationCodes' @_hash['state_and_local'] = 'stateAndLocal' @_hash end |
.nullables ⇒ Object
An array for nullable fields
230 231 232 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 230 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 192 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links control_number wages federal_tax_withheld social_security_wages social_security_tax_withheld medicare_wages medicare_tax_withheld social_security_tips allocated_tips dependent_care_benefit non_qualified_plan codes statutory retirement_plan third_party_sick_pay espp_qualified espp_non_qualified other occupation_codes state_and_local ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 448 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, control_number: #{@control_number.inspect}, wages:"\ " #{@wages.inspect}, federal_tax_withheld: #{@federal_tax_withheld.inspect},"\ " social_security_wages: #{@social_security_wages.inspect}, social_security_tax_withheld:"\ " #{@social_security_tax_withheld.inspect}, medicare_wages: #{@medicare_wages.inspect},"\ " medicare_tax_withheld: #{@medicare_tax_withheld.inspect}, social_security_tips:"\ " #{@social_security_tips.inspect}, allocated_tips: #{@allocated_tips.inspect},"\ " dependent_care_benefit: #{@dependent_care_benefit.inspect}, non_qualified_plan:"\ " #{@non_qualified_plan.inspect}, codes: #{@codes.inspect}, statutory:"\ " #{@statutory.inspect}, retirement_plan: #{@retirement_plan.inspect}, third_party_sick_pay:"\ " #{@third_party_sick_pay.inspect}, espp_qualified: #{@espp_qualified.inspect},"\ " espp_non_qualified: #{@espp_non_qualified.inspect}, other: #{@other.inspect},"\ " occupation_codes: #{@occupation_codes.inspect}, state_and_local:"\ " #{@state_and_local.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/fdx_v660_api/models/form_w22.rb', line 428 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, control_number: #{@control_number}, wages: #{@wages},"\ " federal_tax_withheld: #{@federal_tax_withheld}, social_security_wages:"\ " #{@social_security_wages}, social_security_tax_withheld: #{@social_security_tax_withheld},"\ " medicare_wages: #{@medicare_wages}, medicare_tax_withheld: #{@medicare_tax_withheld},"\ " social_security_tips: #{@social_security_tips}, allocated_tips: #{@allocated_tips},"\ " dependent_care_benefit: #{@dependent_care_benefit}, non_qualified_plan:"\ " #{@non_qualified_plan}, codes: #{@codes}, statutory: #{@statutory}, retirement_plan:"\ " #{@retirement_plan}, third_party_sick_pay: #{@third_party_sick_pay}, espp_qualified:"\ " #{@espp_qualified}, espp_non_qualified: #{@espp_non_qualified}, other: #{@other},"\ " occupation_codes: #{@occupation_codes}, state_and_local: #{@state_and_local},"\ " additional_properties: #{@additional_properties}>" end |