Class: FdxV660Api::GenericFinancialInstitutionIdEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb

Overview

Generic financial institution identifier entity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(fi_id: SKIP, issuer_name: SKIP, id_scheme: SKIP, additional_properties: nil) ⇒ GenericFinancialInstitutionIdEntity

Returns a new instance of GenericFinancialInstitutionIdEntity.



47
48
49
50
51
52
53
54
55
56
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 47

def initialize(fi_id: SKIP, issuer_name: SKIP, id_scheme: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @fi_id = fi_id unless fi_id == SKIP
  @issuer_name = issuer_name unless issuer_name == SKIP
  @id_scheme = id_scheme unless id_scheme == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fi_idString

Financial institution identifier

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 14

def fi_id
  @fi_id
end

#id_schemeObject

Identification scheme associated with the generic financial institution

Returns:

  • (Object)


22
23
24
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 22

def id_scheme
  @id_scheme
end

#issuer_nameString

Issuer name

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 18

def issuer_name
  @issuer_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  fi_id = hash.key?('fiId') ? hash['fiId'] : SKIP
  issuer_name = hash.key?('issuerName') ? hash['issuerName'] : SKIP
  id_scheme = hash.key?('idScheme') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:GenericFinancialInstitutionIdEntityIdScheme), hash['idScheme']
  ) : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GenericFinancialInstitutionIdEntity.new(fi_id: fi_id,
                                          issuer_name: issuer_name,
                                          id_scheme: id_scheme,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['fi_id'] = 'fiId'
  @_hash['issuer_name'] = 'issuerName'
  @_hash['id_scheme'] = 'idScheme'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 34

def self.optionals
  %w[
    fi_id
    issuer_name
    id_scheme
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



85
86
87
88
89
90
91
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 85

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} fi_id: #{@fi_id.inspect}, issuer_name: #{@issuer_name.inspect}, id_scheme:"\
  " #{@id_scheme.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
# File 'lib/fdx_v660_api/models/generic_financial_institution_id_entity.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} fi_id: #{@fi_id}, issuer_name: #{@issuer_name}, id_scheme: #{@id_scheme},"\
  " additional_properties: #{@additional_properties}>"
end