Class: FdxV660Api::IncomingAndOutgoingTransferLimits2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::IncomingAndOutgoingTransferLimits2
- Defined in:
- lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb
Overview
The amount limits for transfers over this payment network
Instance Attribute Summary collapse
-
#min ⇒ TimeAndOccurrenceBasedTransferLimits1
Limits for incoming transfers to the account.
-
#out ⇒ TimeAndOccurrenceBasedTransferLimits3
Limits for outgoing transfers from the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(out: SKIP, min: SKIP, additional_properties: nil) ⇒ IncomingAndOutgoingTransferLimits2
constructor
A new instance of IncomingAndOutgoingTransferLimits2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(out: SKIP, min: SKIP, additional_properties: nil) ⇒ IncomingAndOutgoingTransferLimits2
Returns a new instance of IncomingAndOutgoingTransferLimits2.
41 42 43 44 45 46 47 48 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 41 def initialize(out: SKIP, min: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @out = out unless out == SKIP @min = min unless min == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#min ⇒ TimeAndOccurrenceBasedTransferLimits1
Limits for incoming transfers to the account
18 19 20 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 18 def min @min end |
#out ⇒ TimeAndOccurrenceBasedTransferLimits3
Limits for outgoing transfers from the account
14 15 16 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 14 def out @out end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. out = TimeAndOccurrenceBasedTransferLimits3.from_hash(hash['out']) if hash['out'] min = TimeAndOccurrenceBasedTransferLimits1.from_hash(hash['in']) if hash['in'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomingAndOutgoingTransferLimits2.new(out: out, min: min, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['out'] = 'out' @_hash['min'] = 'in' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 29 def self.optionals %w[ out min ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} out: #{@out.inspect}, min: #{@min.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/fdx_v660_api/models/incoming_and_outgoing_transfer_limits2.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} out: #{@out}, min: #{@min}, additional_properties:"\ " #{@additional_properties}>" end |