Class: FdxV660Api::IndividualName

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/individual_name.rb

Overview

First name, middle initial, last name, suffix fields. Japanese participants should send 'Kana' values in name fields using the character set defined by Zengin (Japanese Banks' Payment Clearing Network)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first: SKIP, middle: SKIP, last: SKIP, suffix: SKIP, additional_properties: nil) ⇒ IndividualName

Returns a new instance of IndividualName.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/fdx_v660_api/models/individual_name.rb', line 55

def initialize(first: SKIP, middle: SKIP, last: SKIP, suffix: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first = first unless first == SKIP
  @middle = middle unless middle == SKIP
  @last = last unless last == SKIP
  @suffix = suffix unless suffix == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#firstString

First name

Returns:

  • (String)


16
17
18
# File 'lib/fdx_v660_api/models/individual_name.rb', line 16

def first
  @first
end

#lastString

Last name

Returns:

  • (String)


24
25
26
# File 'lib/fdx_v660_api/models/individual_name.rb', line 24

def last
  @last
end

#middleString

Middle initial

Returns:

  • (String)


20
21
22
# File 'lib/fdx_v660_api/models/individual_name.rb', line 20

def middle
  @middle
end

#suffixString

Generational or academic suffix

Returns:

  • (String)


28
29
30
# File 'lib/fdx_v660_api/models/individual_name.rb', line 28

def suffix
  @suffix
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/fdx_v660_api/models/individual_name.rb', line 68

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first = hash.key?('first') ? hash['first'] : SKIP
  middle = hash.key?('middle') ? hash['middle'] : SKIP
  last = hash.key?('last') ? hash['last'] : SKIP
  suffix = hash.key?('suffix') ? hash['suffix'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IndividualName.new(first: first,
                     middle: middle,
                     last: last,
                     suffix: suffix,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
37
38
# File 'lib/fdx_v660_api/models/individual_name.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first'] = 'first'
  @_hash['middle'] = 'middle'
  @_hash['last'] = 'last'
  @_hash['suffix'] = 'suffix'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/fdx_v660_api/models/individual_name.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



41
42
43
44
45
46
47
48
# File 'lib/fdx_v660_api/models/individual_name.rb', line 41

def self.optionals
  %w[
    first
    middle
    last
    suffix
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (IndividualName | Hash)

    value against the validation is performed.



94
95
96
97
98
99
100
# File 'lib/fdx_v660_api/models/individual_name.rb', line 94

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



110
111
112
113
114
115
# File 'lib/fdx_v660_api/models/individual_name.rb', line 110

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first: #{@first.inspect}, middle: #{@middle.inspect}, last:"\
  " #{@last.inspect}, suffix: #{@suffix.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
# File 'lib/fdx_v660_api/models/individual_name.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first: #{@first}, middle: #{@middle}, last: #{@last}, suffix: #{@suffix},"\
  " additional_properties: #{@additional_properties}>"
end