Class: FdxV660Api::IndividualName6

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/individual_name6.rb

Overview

Box g, Employee's previously reported name

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first: SKIP, middle: SKIP, last: SKIP, suffix: SKIP, additional_properties: nil) ⇒ IndividualName6

Returns a new instance of IndividualName6.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 53

def initialize(first: SKIP, middle: SKIP, last: SKIP, suffix: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first = first unless first == SKIP
  @middle = middle unless middle == SKIP
  @last = last unless last == SKIP
  @suffix = suffix unless suffix == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#firstString

First name

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 14

def first
  @first
end

#lastString

Last name

Returns:

  • (String)


22
23
24
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 22

def last
  @last
end

#middleString

Middle initial

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 18

def middle
  @middle
end

#suffixString

Generational or academic suffix

Returns:

  • (String)


26
27
28
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 26

def suffix
  @suffix
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first = hash.key?('first') ? hash['first'] : SKIP
  middle = hash.key?('middle') ? hash['middle'] : SKIP
  last = hash.key?('last') ? hash['last'] : SKIP
  suffix = hash.key?('suffix') ? hash['suffix'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IndividualName6.new(first: first,
                      middle: middle,
                      last: last,
                      suffix: suffix,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first'] = 'first'
  @_hash['middle'] = 'middle'
  @_hash['last'] = 'last'
  @_hash['suffix'] = 'suffix'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 39

def self.optionals
  %w[
    first
    middle
    last
    suffix
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (IndividualName6 | Hash)

    value against the validation is performed.



92
93
94
95
96
97
98
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 92

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first: #{@first.inspect}, middle: #{@middle.inspect}, last:"\
  " #{@last.inspect}, suffix: #{@suffix.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/fdx_v660_api/models/individual_name6.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first: #{@first}, middle: #{@middle}, last: #{@last}, suffix: #{@suffix},"\
  " additional_properties: #{@additional_properties}>"
end