Class: FdxV660Api::InterestRateTier
- Defined in:
- lib/fdx_v660_api/models/interest_rate_tier.rb
Overview
The rate offered on account whose minimum balance within the statement
period meets or exceeds the tier's minimumBalance (and not also the
minimumBalance of a higher tier)
Instance Attribute Summary collapse
-
#apy ⇒ Float
The annual percentage yield (APY): the effective yield from interest, including compounding, as a percentage.
-
#minimum_balance ⇒ Float
The minimum balance that the account must hold to earn the rate in this tier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(apy: SKIP, minimum_balance: SKIP, additional_properties: nil) ⇒ InterestRateTier
constructor
A new instance of InterestRateTier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(apy: SKIP, minimum_balance: SKIP, additional_properties: nil) ⇒ InterestRateTier
Returns a new instance of InterestRateTier.
45 46 47 48 49 50 51 52 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 45 def initialize(apy: SKIP, minimum_balance: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @apy = apy unless apy == SKIP @minimum_balance = minimum_balance unless minimum_balance == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#apy ⇒ Float
The annual percentage yield (APY): the effective yield from interest, including compounding, as a percentage
17 18 19 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 17 def apy @apy end |
#minimum_balance ⇒ Float
The minimum balance that the account must hold to earn the rate in this tier
22 23 24 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 22 def minimum_balance @minimum_balance end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. apy = hash.key?('apy') ? hash['apy'] : SKIP minimum_balance = hash.key?('minimumBalance') ? hash['minimumBalance'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InterestRateTier.new(apy: apy, minimum_balance: minimum_balance, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['apy'] = 'apy' @_hash['minimum_balance'] = 'minimumBalance' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 33 def self.optionals %w[ apy minimum_balance ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
78 79 80 81 82 83 84 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 78 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} apy: #{@apy.inspect}, minimum_balance: #{@minimum_balance.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/fdx_v660_api/models/interest_rate_tier.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} apy: #{@apy}, minimum_balance: #{@minimum_balance}, additional_properties:"\ " #{@additional_properties}>" end |