Class: FdxV660Api::Iso93622014BusinessIdentifierCodeEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb

Overview

[ISO 9362:2014](https://www.swift.com/standards/data-standards/bic-business-ident ifier-code) Business Identifier Code for Financial Institutions (see whitepaper) Deprecated and superseded by Iso9362BusinessIdCode2022 (ISO 9362:2022). BICFIDec2014Identifier will be removed after multi-year transition from 9362:2014, expected to end by or before EOY 2026

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bic_fi_dec2014_id: SKIP, additional_properties: nil) ⇒ Iso93622014BusinessIdentifierCodeEntity

Returns a new instance of Iso93622014BusinessIdentifierCodeEntity.



41
42
43
44
45
46
47
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 41

def initialize(bic_fi_dec2014_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bic_fi_dec2014_id = bic_fi_dec2014_id unless bic_fi_dec2014_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bic_fi_dec2014_idString

Business identifier code of the financial institution

Returns:

  • (String)


20
21
22
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 20

def bic_fi_dec2014_id
  @bic_fi_dec2014_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  bic_fi_dec2014_id =
    hash.key?('bicFIDec2014Id') ? hash['bicFIDec2014Id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Iso93622014BusinessIdentifierCodeEntity.new(bic_fi_dec2014_id: bic_fi_dec2014_id,
                                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bic_fi_dec2014_id'] = 'bicFIDec2014Id'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 30

def self.optionals
  %w[
    bic_fi_dec2014_id
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



71
72
73
74
75
76
77
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 71

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bic_fi_dec2014_id: #{@bic_fi_dec2014_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/fdx_v660_api/models/iso93622014_business_identifier_code_entity.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bic_fi_dec2014_id: #{@bic_fi_dec2014_id}, additional_properties:"\
  " #{@additional_properties}>"
end