Class: FdxV660Api::K1AlternativeMinimumTaxDrilling
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::K1AlternativeMinimumTaxDrilling
- Defined in:
- lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb
Overview
Supplemental Alternative Minimum Tax Information for Oil and Gas or Geothermal drilling for Form 1065 Schedule K-1 box 17 or Form 1120-S Schedule K-1 box 15
Instance Attribute Summary collapse
-
#deductions ⇒ Float
Oil and gas or Geothermal deductions included in 1065 K-1 box 17 or 1120-S K-1 box 15.
-
#excess_depletion ⇒ Float
Oil and gas excess depletion included in 1065 K-1 box 17 or 1120-S K-1 box 15.
-
#excess_idc ⇒ Float
Oil and gas or Geothermal excess Intangible Drilling Costs (IDC) included in 1065 K-1 box 17 or 1120-S K-1 box 15.
-
#gross_income ⇒ Float
Oil and gas or Geothermal gross income included in 1065 K-1 box 17 or 1120-S K-1 box 15.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gross_income: SKIP, deductions: SKIP, excess_idc: SKIP, excess_depletion: SKIP, additional_properties: nil) ⇒ K1AlternativeMinimumTaxDrilling
constructor
A new instance of K1AlternativeMinimumTaxDrilling.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gross_income: SKIP, deductions: SKIP, excess_idc: SKIP, excess_depletion: SKIP, additional_properties: nil) ⇒ K1AlternativeMinimumTaxDrilling
Returns a new instance of K1AlternativeMinimumTaxDrilling.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 59 def initialize(gross_income: SKIP, deductions: SKIP, excess_idc: SKIP, excess_depletion: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @gross_income = gross_income unless gross_income == SKIP @deductions = deductions unless deductions == SKIP @excess_idc = excess_idc unless excess_idc == SKIP @excess_depletion = excess_depletion unless excess_depletion == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#deductions ⇒ Float
Oil and gas or Geothermal deductions included in 1065 K-1 box 17 or 1120-S K-1 box 15
22 23 24 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 22 def deductions @deductions end |
#excess_depletion ⇒ Float
Oil and gas excess depletion included in 1065 K-1 box 17 or 1120-S K-1 box 15
32 33 34 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 32 def excess_depletion @excess_depletion end |
#excess_idc ⇒ Float
Oil and gas or Geothermal excess Intangible Drilling Costs (IDC) included in 1065 K-1 box 17 or 1120-S K-1 box 15
27 28 29 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 27 def excess_idc @excess_idc end |
#gross_income ⇒ Float
Oil and gas or Geothermal gross income included in 1065 K-1 box 17 or 1120-S K-1 box 15
17 18 19 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 17 def gross_income @gross_income end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 72 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gross_income = hash.key?('grossIncome') ? hash['grossIncome'] : SKIP deductions = hash.key?('deductions') ? hash['deductions'] : SKIP excess_idc = hash.key?('excessIdc') ? hash['excessIdc'] : SKIP excess_depletion = hash.key?('excessDepletion') ? hash['excessDepletion'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. K1AlternativeMinimumTaxDrilling.new(gross_income: gross_income, deductions: deductions, excess_idc: excess_idc, excess_depletion: excess_depletion, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['gross_income'] = 'grossIncome' @_hash['deductions'] = 'deductions' @_hash['excess_idc'] = 'excessIdc' @_hash['excess_depletion'] = 'excessDepletion' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 51 52 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 45 def self.optionals %w[ gross_income deductions excess_idc excess_depletion ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
106 107 108 109 110 111 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 106 def inspect class_name = self.class.name.split('::').last "<#{class_name} gross_income: #{@gross_income.inspect}, deductions: #{@deductions.inspect},"\ " excess_idc: #{@excess_idc.inspect}, excess_depletion: #{@excess_depletion.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 102 103 |
# File 'lib/fdx_v660_api/models/k1_alternative_minimum_tax_drilling.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} gross_income: #{@gross_income}, deductions: #{@deductions}, excess_idc:"\ " #{@excess_idc}, excess_depletion: #{@excess_depletion}, additional_properties:"\ " #{@additional_properties}>" end |