Class: FdxV660Api::K1OtherIncome
- Defined in:
- lib/fdx_v660_api/models/k1_other_income.rb
Overview
Supplemental other income information for Form 1065 Schedule K-1 box 11 code F and 1120-S Schedule K-1 box 10 code I
Instance Attribute Summary collapse
-
#gambling_losses ⇒ Float
Gambling losses included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I.
-
#gambling_winnings ⇒ Float
Gambling winnings included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I.
-
#recoveries ⇒ Float
Recoveries of tax benefit items.
-
#remic_excess_inclusion ⇒ Float
Real Estate Mortgage Investment Conduit (REMIC) excess inclusion included in 1065 K-1 box 11 code A or 1120-S K-1 box 10 code A.
-
#remic_section212 ⇒ Float
Real Estate Mortgage Investment Conduit (REMIC) section 212 expenses included in 1065 K-1 box 11 code A or 1120-S K-1 box 10 code A.
-
#remic_taxable_income ⇒ Float
Real Estate Mortgage Investment Conduit (REMIC) taxable income (loss) included in 1065 K-1 box 11 code A or 1120-S K-1 box 10 code A.
-
#section751b ⇒ Float
Section 751(b) receivables, inventory.
-
#specially_allocated28_percent ⇒ Float
Specially allocated 28% rate included in net long-term gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I.
-
#specially_allocated_long_term ⇒ Float
Specially allocated net long-term capital gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I.
-
#specially_allocated_ordinary ⇒ Float
Specially allocated ordinary gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I.
-
#specially_allocated_short_term ⇒ Float
Specially allocated net short-term capital gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(remic_taxable_income: SKIP, remic_excess_inclusion: SKIP, remic_section212: SKIP, recoveries: SKIP, gambling_winnings: SKIP, gambling_losses: SKIP, section751b: SKIP, specially_allocated_ordinary: SKIP, specially_allocated_short_term: SKIP, specially_allocated_long_term: SKIP, specially_allocated28_percent: SKIP, additional_properties: nil) ⇒ K1OtherIncome
constructor
A new instance of K1OtherIncome.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(remic_taxable_income: SKIP, remic_excess_inclusion: SKIP, remic_section212: SKIP, recoveries: SKIP, gambling_winnings: SKIP, gambling_losses: SKIP, section751b: SKIP, specially_allocated_ordinary: SKIP, specially_allocated_short_term: SKIP, specially_allocated_long_term: SKIP, specially_allocated28_percent: SKIP, additional_properties: nil) ⇒ K1OtherIncome
Returns a new instance of K1OtherIncome.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 105 def initialize(remic_taxable_income: SKIP, remic_excess_inclusion: SKIP, remic_section212: SKIP, recoveries: SKIP, gambling_winnings: SKIP, gambling_losses: SKIP, section751b: SKIP, specially_allocated_ordinary: SKIP, specially_allocated_short_term: SKIP, specially_allocated_long_term: SKIP, specially_allocated28_percent: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @remic_taxable_income = remic_taxable_income unless remic_taxable_income == SKIP @remic_excess_inclusion = remic_excess_inclusion unless remic_excess_inclusion == SKIP @remic_section212 = remic_section212 unless remic_section212 == SKIP @recoveries = recoveries unless recoveries == SKIP @gambling_winnings = gambling_winnings unless gambling_winnings == SKIP @gambling_losses = gambling_losses unless gambling_losses == SKIP @section751b = section751b unless section751b == SKIP unless specially_allocated_ordinary == SKIP @specially_allocated_ordinary = specially_allocated_ordinary end unless specially_allocated_short_term == SKIP @specially_allocated_short_term = specially_allocated_short_term end unless specially_allocated_long_term == SKIP @specially_allocated_long_term = specially_allocated_long_term end unless specially_allocated28_percent == SKIP @specially_allocated28_percent = specially_allocated28_percent end @additional_properties = additional_properties end |
Instance Attribute Details
#gambling_losses ⇒ Float
Gambling losses included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I
40 41 42 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 40 def gambling_losses @gambling_losses end |
#gambling_winnings ⇒ Float
Gambling winnings included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I
35 36 37 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 35 def gambling_winnings @gambling_winnings end |
#recoveries ⇒ Float
Recoveries of tax benefit items
30 31 32 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 30 def recoveries @recoveries end |
#remic_excess_inclusion ⇒ Float
Real Estate Mortgage Investment Conduit (REMIC) excess inclusion included in 1065 K-1 box 11 code A or 1120-S K-1 box 10 code A
21 22 23 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 21 def remic_excess_inclusion @remic_excess_inclusion end |
#remic_section212 ⇒ Float
Real Estate Mortgage Investment Conduit (REMIC) section 212 expenses included in 1065 K-1 box 11 code A or 1120-S K-1 box 10 code A
26 27 28 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 26 def remic_section212 @remic_section212 end |
#remic_taxable_income ⇒ Float
Real Estate Mortgage Investment Conduit (REMIC) taxable income (loss) included in 1065 K-1 box 11 code A or 1120-S K-1 box 10 code A
16 17 18 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 16 def remic_taxable_income @remic_taxable_income end |
#section751b ⇒ Float
Section 751(b) receivables, inventory
44 45 46 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 44 def section751b @section751b end |
#specially_allocated28_percent ⇒ Float
Specially allocated 28% rate included in net long-term gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I
64 65 66 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 64 def specially_allocated28_percent @specially_allocated28_percent end |
#specially_allocated_long_term ⇒ Float
Specially allocated net long-term capital gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I
59 60 61 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 59 def specially_allocated_long_term @specially_allocated_long_term end |
#specially_allocated_ordinary ⇒ Float
Specially allocated ordinary gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I
49 50 51 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 49 def specially_allocated_ordinary @specially_allocated_ordinary end |
#specially_allocated_short_term ⇒ Float
Specially allocated net short-term capital gain (loss) included in 1065 K-1 box 11 code F or 1120-S K-1 box 10 code I
54 55 56 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 54 def specially_allocated_short_term @specially_allocated_short_term end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 143 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. remic_taxable_income = hash.key?('remicTaxableIncome') ? hash['remicTaxableIncome'] : SKIP remic_excess_inclusion = hash.key?('remicExcessInclusion') ? hash['remicExcessInclusion'] : SKIP remic_section212 = hash.key?('remicSection212') ? hash['remicSection212'] : SKIP recoveries = hash.key?('recoveries') ? hash['recoveries'] : SKIP gambling_winnings = hash.key?('gamblingWinnings') ? hash['gamblingWinnings'] : SKIP gambling_losses = hash.key?('gamblingLosses') ? hash['gamblingLosses'] : SKIP section751b = hash.key?('section751b') ? hash['section751b'] : SKIP specially_allocated_ordinary = hash.key?('speciallyAllocatedOrdinary') ? hash['speciallyAllocatedOrdinary'] : SKIP specially_allocated_short_term = hash.key?('speciallyAllocatedShortTerm') ? hash['speciallyAllocatedShortTerm'] : SKIP specially_allocated_long_term = hash.key?('speciallyAllocatedLongTerm') ? hash['speciallyAllocatedLongTerm'] : SKIP specially_allocated28_percent = hash.key?('speciallyAllocated28Percent') ? hash['speciallyAllocated28Percent'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. K1OtherIncome.new(remic_taxable_income: remic_taxable_income, remic_excess_inclusion: remic_excess_inclusion, remic_section212: remic_section212, recoveries: recoveries, gambling_winnings: gambling_winnings, gambling_losses: gambling_losses, section751b: section751b, specially_allocated_ordinary: specially_allocated_ordinary, specially_allocated_short_term: specially_allocated_short_term, specially_allocated_long_term: specially_allocated_long_term, specially_allocated28_percent: specially_allocated28_percent, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 67 def self.names @_hash = {} if @_hash.nil? @_hash['remic_taxable_income'] = 'remicTaxableIncome' @_hash['remic_excess_inclusion'] = 'remicExcessInclusion' @_hash['remic_section212'] = 'remicSection212' @_hash['recoveries'] = 'recoveries' @_hash['gambling_winnings'] = 'gamblingWinnings' @_hash['gambling_losses'] = 'gamblingLosses' @_hash['section751b'] = 'section751b' @_hash['specially_allocated_ordinary'] = 'speciallyAllocatedOrdinary' @_hash['specially_allocated_short_term'] = 'speciallyAllocatedShortTerm' @_hash['specially_allocated_long_term'] = 'speciallyAllocatedLongTerm' @_hash['specially_allocated28_percent'] = 'speciallyAllocated28Percent' @_hash end |
.nullables ⇒ Object
An array for nullable fields
101 102 103 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 101 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 84 def self.optionals %w[ remic_taxable_income remic_excess_inclusion remic_section212 recoveries gambling_winnings gambling_losses section751b specially_allocated_ordinary specially_allocated_short_term specially_allocated_long_term specially_allocated28_percent ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 204 def inspect class_name = self.class.name.split('::').last "<#{class_name} remic_taxable_income: #{@remic_taxable_income.inspect},"\ " remic_excess_inclusion: #{@remic_excess_inclusion.inspect}, remic_section212:"\ " #{@remic_section212.inspect}, recoveries: #{@recoveries.inspect}, gambling_winnings:"\ " #{@gambling_winnings.inspect}, gambling_losses: #{@gambling_losses.inspect}, section751b:"\ " #{@section751b.inspect}, specially_allocated_ordinary:"\ " #{@specially_allocated_ordinary.inspect}, specially_allocated_short_term:"\ " #{@specially_allocated_short_term.inspect}, specially_allocated_long_term:"\ " #{@specially_allocated_long_term.inspect}, specially_allocated28_percent:"\ " #{@specially_allocated28_percent.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/fdx_v660_api/models/k1_other_income.rb', line 191 def to_s class_name = self.class.name.split('::').last "<#{class_name} remic_taxable_income: #{@remic_taxable_income}, remic_excess_inclusion:"\ " #{@remic_excess_inclusion}, remic_section212: #{@remic_section212}, recoveries:"\ " #{@recoveries}, gambling_winnings: #{@gambling_winnings}, gambling_losses:"\ " #{@gambling_losses}, section751b: #{@section751b}, specially_allocated_ordinary:"\ " #{@specially_allocated_ordinary}, specially_allocated_short_term:"\ " #{@specially_allocated_short_term}, specially_allocated_long_term:"\ " #{@specially_allocated_long_term}, specially_allocated28_percent:"\ " #{@specially_allocated28_percent}, additional_properties: #{@additional_properties}>" end |