Class: FdxV660Api::LineOfBusinessType2

Inherits:
Object
  • Object
show all
Defined in:
lib/fdx_v660_api/models/line_of_business_type2.rb

Overview

The enumerated line of business of this account, one of COMMERCIAL, CONSUMER, SMALL_BUSINESS, OTHER. For type OTHER, add your other line of business name in property lineOfBusiness

Constant Summary collapse

LINE_OF_BUSINESS_TYPE2 =
[
  # TODO: Write general description for COMMERCIAL
  COMMERCIAL = 'COMMERCIAL'.freeze,

  # TODO: Write general description for CONSUMER
  CONSUMER = 'CONSUMER'.freeze,

  # TODO: Write general description for OTHER
  OTHER = 'OTHER'.freeze,

  # TODO: Write general description for SMALL_BUSINESS
  SMALL_BUSINESS = 'SMALL_BUSINESS'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = COMMERCIAL) ⇒ Object



31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/fdx_v660_api/models/line_of_business_type2.rb', line 31

def self.from_value(value, default_value = COMMERCIAL)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'commercial' then COMMERCIAL
  when 'consumer' then CONSUMER
  when 'other' then OTHER
  when 'small_business' then SMALL_BUSINESS
  else
    default_value
  end
end

.validate(value) ⇒ Object



25
26
27
28
29
# File 'lib/fdx_v660_api/models/line_of_business_type2.rb', line 25

def self.validate(value)
  return false if value.nil?

  true
end