Class: FdxV660Api::NameAddressAndPhone
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::NameAddressAndPhone
- Defined in:
- lib/fdx_v660_api/models/name_address_and_phone.rb
Overview
Contact phone number with name and address
Instance Attribute Summary collapse
-
#city ⇒ String
City.
-
#country ⇒ Iso3166CountryCode1
Country code.
-
#line1 ⇒ String
Address line 1.
-
#line2 ⇒ String
Address line 2.
-
#line3 ⇒ String
Address line 3.
-
#name1 ⇒ String
Name line 1.
-
#name2 ⇒ String
Name line 2.
-
#phone ⇒ TelephoneNumberPlusExtension2
Phone number.
-
#postal_code ⇒ String
Postal code.
-
#region ⇒ String
State, Province, Territory, Canton or Prefecture.
-
#unit_number ⇒ String
The number component of the address location's unit, can contain letters as appropriate.
-
#unit_type ⇒ String
Text name for type of unit, such as Suite, Apt./Apartment, Room, Floor, or Dept./Department.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, unit_type: SKIP, unit_number: SKIP, name1: SKIP, name2: SKIP, phone: SKIP, additional_properties: nil) ⇒ NameAddressAndPhone
constructor
A new instance of NameAddressAndPhone.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, unit_type: SKIP, unit_number: SKIP, name1: SKIP, name2: SKIP, phone: SKIP, additional_properties: nil) ⇒ NameAddressAndPhone
Returns a new instance of NameAddressAndPhone.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 111 def initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, unit_type: SKIP, unit_number: SKIP, name1: SKIP, name2: SKIP, phone: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @line1 = line1 unless line1 == SKIP @line2 = line2 unless line2 == SKIP @line3 = line3 unless line3 == SKIP @city = city unless city == SKIP @region = region unless region == SKIP @postal_code = postal_code unless postal_code == SKIP @country = country unless country == SKIP @unit_type = unit_type unless unit_type == SKIP @unit_number = unit_number unless unit_number == SKIP @name1 = name1 unless name1 == SKIP @name2 = name2 unless name2 == SKIP @phone = phone unless phone == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
City
26 27 28 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 26 def city @city end |
#country ⇒ Iso3166CountryCode1
Country code
45 46 47 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 45 def country @country end |
#line1 ⇒ String
Address line 1
14 15 16 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 14 def line1 @line1 end |
#line2 ⇒ String
Address line 2
18 19 20 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 18 def line2 @line2 end |
#line3 ⇒ String
Address line 3
22 23 24 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 22 def line3 @line3 end |
#name1 ⇒ String
Name line 1
60 61 62 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 60 def name1 @name1 end |
#name2 ⇒ String
Name line 2
64 65 66 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 64 def name2 @name2 end |
#phone ⇒ TelephoneNumberPlusExtension2
Phone number
68 69 70 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 68 def phone @phone end |
#postal_code ⇒ String
Postal code
41 42 43 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 41 def postal_code @postal_code end |
#region ⇒ String
State, Province, Territory, Canton or Prefecture. From [Universal Postal
Union](https://www.upu.int/en/Postal-Solutions/Programmes-Services/Address
ing-Solutions#addressing-s42-standard) as of 2-26-2020, [S42 International
Address
Standards](https://www.upu.int/UPU/media/upu/documents/PostCode/S42_Intern
ational-Addressing-Standards.pdf). For U.S. addresses can be a 2-character
code from StateCode. For Canadian addresses can be a 2-character code
from ProvinceTerritoryCode
37 38 39 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 37 def region @region end |
#unit_number ⇒ String
The number component of the address location's unit, can contain letters as appropriate
56 57 58 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 56 def unit_number @unit_number end |
#unit_type ⇒ String
Text name for type of unit, such as Suite, Apt./Apartment, Room, Floor, or Dept./Department. Does not appear on tax forms, for use in creating a postal address from a tax form recipient address
51 52 53 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 51 def unit_type @unit_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 134 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. line1 = hash.key?('line1') ? hash['line1'] : SKIP line2 = hash.key?('line2') ? hash['line2'] : SKIP line3 = hash.key?('line3') ? hash['line3'] : SKIP city = hash.key?('city') ? hash['city'] : SKIP region = hash.key?('region') ? hash['region'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP unit_type = hash.key?('unitType') ? hash['unitType'] : SKIP unit_number = hash.key?('unitNumber') ? hash['unitNumber'] : SKIP name1 = hash.key?('name1') ? hash['name1'] : SKIP name2 = hash.key?('name2') ? hash['name2'] : SKIP phone = TelephoneNumberPlusExtension2.from_hash(hash['phone']) if hash['phone'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NameAddressAndPhone.new(line1: line1, line2: line2, line3: line3, city: city, region: region, postal_code: postal_code, country: country, unit_type: unit_type, unit_number: unit_number, name1: name1, name2: name2, phone: phone, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 71 def self.names @_hash = {} if @_hash.nil? @_hash['line1'] = 'line1' @_hash['line2'] = 'line2' @_hash['line3'] = 'line3' @_hash['city'] = 'city' @_hash['region'] = 'region' @_hash['postal_code'] = 'postalCode' @_hash['country'] = 'country' @_hash['unit_type'] = 'unitType' @_hash['unit_number'] = 'unitNumber' @_hash['name1'] = 'name1' @_hash['name2'] = 'name2' @_hash['phone'] = 'phone' @_hash end |
.nullables ⇒ Object
An array for nullable fields
107 108 109 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 107 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 89 def self.optionals %w[ line1 line2 line3 city region postal_code country unit_type unit_number name1 name2 phone ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
184 185 186 187 188 189 190 191 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 184 def inspect class_name = self.class.name.split('::').last "<#{class_name} line1: #{@line1.inspect}, line2: #{@line2.inspect}, line3:"\ " #{@line3.inspect}, city: #{@city.inspect}, region: #{@region.inspect}, postal_code:"\ " #{@postal_code.inspect}, country: #{@country.inspect}, unit_type: #{@unit_type.inspect},"\ " unit_number: #{@unit_number.inspect}, name1: #{@name1.inspect}, name2: #{@name2.inspect},"\ " phone: #{@phone.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
175 176 177 178 179 180 181 |
# File 'lib/fdx_v660_api/models/name_address_and_phone.rb', line 175 def to_s class_name = self.class.name.split('::').last "<#{class_name} line1: #{@line1}, line2: #{@line2}, line3: #{@line3}, city: #{@city},"\ " region: #{@region}, postal_code: #{@postal_code}, country: #{@country}, unit_type:"\ " #{@unit_type}, unit_number: #{@unit_number}, name1: #{@name1}, name2: #{@name2}, phone:"\ " #{@phone}, additional_properties: #{@additional_properties}>" end |