Class: FdxV660Api::OrganizationNameEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/organization_name_entity.rb

Overview

Logical grouping of name attributes that are particular to an Organization type of payment initiation party. Japanese participants should send 'Kana' values in name fields using the character set defined by Zengin (Japanese Banks' Payment Clearing Network)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(company_name: SKIP, additional_properties: nil) ⇒ OrganizationNameEntity

Returns a new instance of OrganizationNameEntity.



38
39
40
41
42
43
44
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 38

def initialize(company_name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @company_name = company_name unless company_name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#company_nameString

Name value of the organization

Returns:

  • (String)


17
18
19
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 17

def company_name
  @company_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  company_name = hash.key?('companyName') ? hash['companyName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrganizationNameEntity.new(company_name: company_name,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['company_name'] = 'companyName'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
30
31
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 27

def self.optionals
  %w[
    company_name
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



67
68
69
70
71
72
73
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 67

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} company_name: #{@company_name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/fdx_v660_api/models/organization_name_entity.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} company_name: #{@company_name}, additional_properties:"\
  " #{@additional_properties}>"
end