Class: FdxV660Api::PageMetadataLinks1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/page_metadata_links1.rb

Overview

Resource URLs for navigating result sets

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mnext: SKIP, prev: SKIP, additional_properties: nil) ⇒ PageMetadataLinks1

Returns a new instance of PageMetadataLinks1.



41
42
43
44
45
46
47
48
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 41

def initialize(mnext: SKIP, prev: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mnext = mnext unless mnext == SKIP
  @prev = prev unless prev == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#mnextHateoasLink1

Resource URL for retrieving next dataset

Returns:



14
15
16
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 14

def mnext
  @mnext
end

#prevHateoasLink2

Resource URL for retrieving previous dataset

Returns:



18
19
20
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 18

def prev
  @prev
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mnext = HateoasLink1.from_hash(hash['next']) if hash['next']
  prev = HateoasLink2.from_hash(hash['prev']) if hash['prev']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PageMetadataLinks1.new(mnext: mnext,
                         prev: prev,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mnext'] = 'next'
  @_hash['prev'] = 'prev'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 29

def self.optionals
  %w[
    mnext
    prev
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



73
74
75
76
77
78
79
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 73

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mnext: #{@mnext.inspect}, prev: #{@prev.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/fdx_v660_api/models/page_metadata_links1.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mnext: #{@mnext}, prev: #{@prev}, additional_properties:"\
  " #{@additional_properties}>"
end