Class: FdxV660Api::PaginatedArray
- Defined in:
- lib/fdx_v660_api/models/paginated_array.rb
Overview
Base class for results that may be paginated
Instance Attribute Summary collapse
-
#links ⇒ PageMetadataLinks1
Resource URLs for navigating result sets.
-
#page ⇒ PageMetadata
Page keys for navigating result sets.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(page: SKIP, links: SKIP, additional_properties: nil) ⇒ PaginatedArray
constructor
A new instance of PaginatedArray.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(page: SKIP, links: SKIP, additional_properties: nil) ⇒ PaginatedArray
Returns a new instance of PaginatedArray.
41 42 43 44 45 46 47 48 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 41 def initialize(page: SKIP, links: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @page = page unless page == SKIP @links = links unless links == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#links ⇒ PageMetadataLinks1
Resource URLs for navigating result sets
18 19 20 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 18 def links @links end |
#page ⇒ PageMetadata
Page keys for navigating result sets
14 15 16 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 14 def page @page end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. page = PageMetadata.from_hash(hash['page']) if hash['page'] links = PageMetadataLinks1.from_hash(hash['links']) if hash['links'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaginatedArray.new(page: page, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['page'] = 'page' @_hash['links'] = 'links' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 29 def self.optionals %w[ page links ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} page: #{@page.inspect}, links: #{@links.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/fdx_v660_api/models/paginated_array.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} page: #{@page}, links: #{@links}, additional_properties:"\ " #{@additional_properties}>" end |