Class: FdxV660Api::PartyGroupEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/party_group_entity.rb

Overview

Entity that allows payment initiation parties to be grouped using specific business rules. Each payment initiation party can belong to many groups.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(group_id: SKIP, name: SKIP, additional_properties: nil) ⇒ PartyGroupEntity

Returns a new instance of PartyGroupEntity.



42
43
44
45
46
47
48
49
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 42

def initialize(group_id: SKIP, name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @group_id = group_id unless group_id == SKIP
  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#group_idString

Unique identifier of a group of payment initiation parties

Returns:

  • (String)


15
16
17
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 15

def group_id
  @group_id
end

#nameString

Associated name with the group of payment initiation parties

Returns:

  • (String)


19
20
21
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 19

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  group_id = hash.key?('groupId') ? hash['groupId'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartyGroupEntity.new(group_id: group_id,
                       name: name,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['group_id'] = 'groupId'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 30

def self.optionals
  %w[
    group_id
    name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} group_id: #{@group_id.inspect}, name: #{@name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/fdx_v660_api/models/party_group_entity.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} group_id: #{@group_id}, name: #{@name}, additional_properties:"\
  " #{@additional_properties}>"
end