Class: FdxV660Api::PartyStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/fdx_v660_api/models/party_status.rb

Overview

Defines the party lifecycle. * ACTIVE: Party is ready to participate in money movement * DELETED: Party has been deleted and will not move into any other state * PENDING: Party is not yet ready to participate in money movement * REJECTED: Party was found to be invalid and cannot participate in money movement

Constant Summary collapse

PARTY_STATUS =
[
  # TODO: Write general description for ACTIVE
  ACTIVE = 'ACTIVE'.freeze,

  # TODO: Write general description for DELETED
  DELETED = 'DELETED'.freeze,

  # TODO: Write general description for PENDING
  PENDING = 'PENDING'.freeze,

  # TODO: Write general description for REJECTED
  REJECTED = 'REJECTED'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ACTIVE) ⇒ Object



33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/fdx_v660_api/models/party_status.rb', line 33

def self.from_value(value, default_value = ACTIVE)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'active' then ACTIVE
  when 'deleted' then DELETED
  when 'pending' then PENDING
  when 'rejected' then REJECTED
  else
    default_value
  end
end

.validate(value) ⇒ Object



27
28
29
30
31
# File 'lib/fdx_v660_api/models/party_status.rb', line 27

def self.validate(value)
  return false if value.nil?

  true
end