Class: FdxV660Api::PayeeEntity1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payee_entity1.rb

Overview

The payee merchant to receive funds from the payment, can be extended to support additional types of payees

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(merchant:, additional_properties: nil) ⇒ PayeeEntity1

Returns a new instance of PayeeEntity1.



35
36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 35

def initialize(merchant:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @merchant = merchant
  @additional_properties = additional_properties
end

Instance Attribute Details

#merchantMerchantEntity1

When payee is a merchant, typically a business from which goods or services are rendered, this field will be populated

Returns:



16
17
18
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 16

def merchant
  @merchant
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  merchant = MerchantEntity1.from_hash(hash['merchant']) if hash['merchant']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PayeeEntity1.new(merchant: merchant,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['merchant'] = 'merchant'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 26

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant: #{@merchant.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/fdx_v660_api/models/payee_entity1.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant: #{@merchant}, additional_properties: #{@additional_properties}>"
end