Class: FdxV660Api::PaymentDeliveryAddressEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payment_delivery_address_entity.rb

Overview

A single location for a party. A party (e.g. Branch) can have multiple registered locations; street addresses, email addresses and/or telephone numbers

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, address: SKIP, additional_properties: nil) ⇒ PaymentDeliveryAddressEntity

Returns a new instance of PaymentDeliveryAddressEntity.



43
44
45
46
47
48
49
50
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 43

def initialize(type: SKIP, address: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @address = address unless address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressObject

Value of the address

Returns:

  • (Object)


20
21
22
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 20

def address
  @address
end

#typeDeliveryAddressType2

Type of delivery address



16
17
18
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 16

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP
  address = hash.key?('address') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:PaymentDeliveryAddressEntityAddress), hash['address']
  ) : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentDeliveryAddressEntity.new(type: type,
                                   address: address,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['address'] = 'address'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 31

def self.optionals
  %w[
    type
    address
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



77
78
79
80
81
82
83
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 77

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, address: #{@address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/fdx_v660_api/models/payment_delivery_address_entity.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, address: #{@address}, additional_properties:"\
  " #{@additional_properties}>"
end