Class: FdxV660Api::PaymentInitiationPartyContactMethodEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb

Overview

A contact method for a payment initiation party.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, address: SKIP, additional_properties: nil) ⇒ PaymentInitiationPartyContactMethodEntity

Returns a new instance of PaymentInitiationPartyContactMethodEntity.



41
42
43
44
45
46
47
48
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 41

def initialize(type: SKIP, address: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @address = address unless address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressObject

Address details associated with this contact preference

Returns:

  • (Object)


18
19
20
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 18

def address
  @address
end

#typeContactPreferencesType2

Type of the contact preference



14
15
16
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 14

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP
  address = hash.key?('address') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:PaymentInitiationPartyContactMethodEntityAddress), hash['address']
  ) : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInitiationPartyContactMethodEntity.new(type: type,
                                                address: address,
                                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['address'] = 'address'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 29

def self.optionals
  %w[
    type
    address
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



75
76
77
78
79
80
81
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 75

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, address: #{@address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/fdx_v660_api/models/payment_initiation_party_contact_method_entity.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, address: #{@address}, additional_properties:"\
  " #{@additional_properties}>"
end