Class: FdxV660Api::PaymentInitiationPartyNameEntity3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb

Overview

Details of the name

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(alias_name: SKIP, detail: SKIP, additional_properties: nil) ⇒ PaymentInitiationPartyNameEntity3

Returns a new instance of PaymentInitiationPartyNameEntity3.



41
42
43
44
45
46
47
48
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 41

def initialize(alias_name: SKIP, detail: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @alias_name = alias_name unless alias_name == SKIP
  @detail = detail unless detail == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#alias_nameString

Alias name

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 14

def alias_name
  @alias_name
end

#detailObject

Details of the name

Returns:

  • (Object)


18
19
20
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 18

def detail
  @detail
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  alias_name = hash.key?('aliasName') ? hash['aliasName'] : SKIP
  detail = hash.key?('detail') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:PaymentInitiationPartyNameEntity3Detail), hash['detail']
  ) : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInitiationPartyNameEntity3.new(alias_name: alias_name,
                                        detail: detail,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['alias_name'] = 'aliasName'
  @_hash['detail'] = 'detail'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 29

def self.optionals
  %w[
    alias_name
    detail
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



75
76
77
78
79
80
81
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 75

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} alias_name: #{@alias_name.inspect}, detail: #{@detail.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/fdx_v660_api/models/payment_initiation_party_name_entity3.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} alias_name: #{@alias_name}, detail: #{@detail}, additional_properties:"\
  " #{@additional_properties}>"
end