Class: FdxV660Api::PaymentMethodDebitAccountEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payment_method_debit_account_entity.rb

Overview

A payment initiation party's payment method that debits an account

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_registration_id: SKIP, sending_account: SKIP, additional_properties: nil) ⇒ PaymentMethodDebitAccountEntity

Returns a new instance of PaymentMethodDebitAccountEntity.



42
43
44
45
46
47
48
49
50
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 42

def initialize(account_registration_id: SKIP, sending_account: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_registration_id =  unless  == SKIP
  @sending_account =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_registration_idString

Unique identifier of the registration of the sending account to the payment method associated with a particular payment initiation party

Returns:

  • (String)


15
16
17
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 15

def 
  @account_registration_id
end

#sending_accountPaymentGenericAccountEntity2

Sending account details



19
20
21
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 19

def 
  @sending_account
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   =
    hash.key?('accountRegistrationId') ? hash['accountRegistrationId'] : SKIP
   = PaymentGenericAccountEntity2.from_hash(hash['sendingAccount']) if
    hash['sendingAccount']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentMethodDebitAccountEntity.new(account_registration_id: ,
                                      sending_account: ,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_registration_id'] = 'accountRegistrationId'
  @_hash['sending_account'] = 'sendingAccount'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 30

def self.optionals
  %w[
    account_registration_id
    sending_account
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



77
78
79
80
81
82
83
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 77

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_registration_id: #{@account_registration_id.inspect},"\
  " sending_account: #{@sending_account.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/fdx_v660_api/models/payment_method_debit_account_entity.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_registration_id: #{@account_registration_id}, sending_account:"\
  " #{@sending_account}, additional_properties: #{@additional_properties}>"
end