Class: FdxV660Api::PaymentMethodSystemProprietary

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payment_method_system_proprietary.rb

Overview

Proprietary identifier of the external clearing system when the payment rail is not part of the ISO 20022 scope

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(external_clearing_system_identification1_proprietary: SKIP, additional_properties: nil) ⇒ PaymentMethodSystemProprietary

Returns a new instance of PaymentMethodSystemProprietary.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 37

def initialize(external_clearing_system_identification1_proprietary: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless external_clearing_system_identification1_proprietary == SKIP
    @external_clearing_system_identification1_proprietary =
      external_clearing_system_identification1_proprietary
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#external_clearing_system_identification1_proprietaryString

For few examples where the payment rail is not part of the ISO 20022 scope

Returns:

  • (String)


15
16
17
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 15

def external_clearing_system_identification1_proprietary
  @external_clearing_system_identification1_proprietary
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  external_clearing_system_identification1_proprietary =
    hash.key?('externalClearingSystemIdentification1Proprietary') ? hash['externalClearingSystemIdentification1Proprietary'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentMethodSystemProprietary.new(external_clearing_system_identification1_proprietary: external_clearing_system_identification1_proprietary,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
23
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['external_clearing_system_identification1_proprietary'] =
    'externalClearingSystemIdentification1Proprietary'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 26

def self.optionals
  %w[
    external_clearing_system_identification1_proprietary
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
83
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} external_clearing_system_identification1_proprietary:"\
  " #{@external_clearing_system_identification1_proprietary.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
75
# File 'lib/fdx_v660_api/models/payment_method_system_proprietary.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} external_clearing_system_identification1_proprietary:"\
  " #{@external_clearing_system_identification1_proprietary}, additional_properties:"\
  " #{@additional_properties}>"
end