Class: FdxV660Api::PayrollReportListEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/payroll_report_list_entity.rb

Overview

Response object for /payroll/reports API with list of reports available

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(result_type: ResultType1::LIGHTWEIGHT, summaries: SKIP, reports: SKIP, additional_properties: nil) ⇒ PayrollReportListEntity

Returns a new instance of PayrollReportListEntity.



48
49
50
51
52
53
54
55
56
57
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 48

def initialize(result_type: ResultType1::LIGHTWEIGHT, summaries: SKIP,
               reports: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @result_type = result_type unless result_type == SKIP
  @summaries = summaries unless summaries == SKIP
  @reports = reports unless reports == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reportsArray[PayrollReportEntity]

Zero or more PayrollReports, for details response

Returns:



23
24
25
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 23

def reports
  @reports
end

#result_typeResultType1

Indicates whether response array of lightweight payroll report summaries or of detail full payroll reports is being returned

Returns:



15
16
17
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 15

def result_type
  @result_type
end

#summariesArray[PayrollReportSummaryEntity]

Zero or more PayrollReportSummaries for lightweight response

Returns:



19
20
21
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 19

def summaries
  @summaries
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  result_type = hash['resultType'] ||= ResultType1::LIGHTWEIGHT
  # Parameter is an array, so we need to iterate through it
  summaries = nil
  unless hash['summaries'].nil?
    summaries = []
    hash['summaries'].each do |structure|
      summaries << (PayrollReportSummaryEntity.from_hash(structure) if structure)
    end
  end

  summaries = SKIP unless hash.key?('summaries')
  # Parameter is an array, so we need to iterate through it
  reports = nil
  unless hash['reports'].nil?
    reports = []
    hash['reports'].each do |structure|
      reports << (PayrollReportEntity.from_hash(structure) if structure)
    end
  end

  reports = SKIP unless hash.key?('reports')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PayrollReportListEntity.new(result_type: result_type,
                              summaries: summaries,
                              reports: reports,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['result_type'] = 'resultType'
  @_hash['summaries'] = 'summaries'
  @_hash['reports'] = 'reports'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 35

def self.optionals
  %w[
    result_type
    summaries
    reports
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} result_type: #{@result_type.inspect}, summaries: #{@summaries.inspect},"\
  " reports: #{@reports.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/fdx_v660_api/models/payroll_report_list_entity.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} result_type: #{@result_type}, summaries: #{@summaries}, reports:"\
  " #{@reports}, additional_properties: #{@additional_properties}>"
end