Class: FdxV660Api::PaystubListEntity1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/paystub_list_entity1.rb

Overview

Array of PaystubList as a JSON response if not encrypted, or as the JSON payload which is encrypted for an application/jwt response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(page: SKIP, links: SKIP, paystubs: SKIP, additional_properties: nil) ⇒ PaystubListEntity1

Returns a new instance of PaystubListEntity1.



48
49
50
51
52
53
54
55
56
57
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 48

def initialize(page: SKIP, links: SKIP, paystubs: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @page = page unless page == SKIP
  @links = links unless links == SKIP
  @paystubs = paystubs unless paystubs == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

Resource URLs for navigating result sets

Returns:



19
20
21
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 19

def links
  @links
end

#pagePageMetadata

Page keys for navigating result sets

Returns:



15
16
17
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 15

def page
  @page
end

#paystubsArray[PaystubEntity]

Zero or more Paystubs found within the startTime to endTime range

Returns:



23
24
25
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 23

def paystubs
  @paystubs
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  page = PageMetadata.from_hash(hash['page']) if hash['page']
  links = PageMetadataLinks1.from_hash(hash['links']) if hash['links']
  # Parameter is an array, so we need to iterate through it
  paystubs = nil
  unless hash['paystubs'].nil?
    paystubs = []
    hash['paystubs'].each do |structure|
      paystubs << (PaystubEntity.from_hash(structure) if structure)
    end
  end

  paystubs = SKIP unless hash.key?('paystubs')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaystubListEntity1.new(page: page,
                         links: links,
                         paystubs: paystubs,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['page'] = 'page'
  @_hash['links'] = 'links'
  @_hash['paystubs'] = 'paystubs'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 35

def self.optionals
  %w[
    page
    links
    paystubs
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page.inspect}, links: #{@links.inspect}, paystubs:"\
  " #{@paystubs.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/fdx_v660_api/models/paystub_list_entity1.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page}, links: #{@links}, paystubs: #{@paystubs},"\
  " additional_properties: #{@additional_properties}>"
end