Class: FdxV660Api::ProprietaryAccountIdSchemeEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb

Overview

Proprietary account identification scheme, as per ISO 20022 v1.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(proprietary_name: SKIP, additional_properties: nil) ⇒ ProprietaryAccountIdSchemeEntity

Returns a new instance of ProprietaryAccountIdSchemeEntity.



36
37
38
39
40
41
42
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 36

def initialize(proprietary_name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @proprietary_name = proprietary_name unless proprietary_name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#proprietary_nameString

This property is related to the name of the identification scheme, in the proprietary system, as per ISO 20022 v1.

Returns:

  • (String)


15
16
17
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 15

def proprietary_name
  @proprietary_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  proprietary_name =
    hash.key?('proprietaryName') ? hash['proprietaryName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProprietaryAccountIdSchemeEntity.new(proprietary_name: proprietary_name,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['proprietary_name'] = 'proprietaryName'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 25

def self.optionals
  %w[
    proprietary_name
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



66
67
68
69
70
71
72
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 66

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} proprietary_name: #{@proprietary_name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/fdx_v660_api/models/proprietary_account_id_scheme_entity.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} proprietary_name: #{@proprietary_name}, additional_properties:"\
  " #{@additional_properties}>"
end