Class: FdxV660Api::RemittanceParty

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/remittance_party.rb

Overview

Identification of a party to the transaction

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, account_number: SKIP, additional_properties: nil) ⇒ RemittanceParty

Returns a new instance of RemittanceParty.



43
44
45
46
47
48
49
50
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 43

def initialize(name: SKIP, account_number: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @account_number =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_numberString

Full account number for the source or recipient account of the remittance debit or credit. If not masked this is sensitive data which should be encrypted in the response

Returns:

  • (String)


20
21
22
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 20

def 
  @account_number
end

#nameString

Company or individual name of the remittance debtor or creditor

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 14

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RemittanceParty.new(name: name,
                      account_number: ,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['account_number'] = 'accountNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 31

def self.optionals
  %w[
    name
    account_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, account_number: #{@account_number.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/fdx_v660_api/models/remittance_party.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, account_number: #{@account_number}, additional_properties:"\
  " #{@additional_properties}>"
end