Class: FdxV660Api::RemittanceParty3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/remittance_party3.rb

Overview

Identification of the debtor party to the transaction for the funds source, can include accountNumber which is sensitive data and should be encrypted

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, account_number: SKIP, additional_properties: nil) ⇒ RemittanceParty3

Returns a new instance of RemittanceParty3.



44
45
46
47
48
49
50
51
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 44

def initialize(name: SKIP, account_number: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @account_number =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_numberString

Full account number for the source or recipient account of the remittance debit or credit. If not masked this is sensitive data which should be encrypted in the response

Returns:

  • (String)


21
22
23
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 21

def 
  @account_number
end

#nameString

Company or individual name of the remittance debtor or creditor

Returns:

  • (String)


15
16
17
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 15

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RemittanceParty3.new(name: name,
                       account_number: ,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['account_number'] = 'accountNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 32

def self.optionals
  %w[
    name
    account_number
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



76
77
78
79
80
81
82
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 76

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, account_number: #{@account_number.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/fdx_v660_api/models/remittance_party3.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, account_number: #{@account_number}, additional_properties:"\
  " #{@additional_properties}>"
end