Class: FdxV660Api::RevocationRequestEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/revocation_request_entity.rb

Overview

Details of request to revoke consent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reason: SKIP, other_reason: SKIP, initiator: SKIP, additional_properties: nil) ⇒ RevocationRequestEntity

Returns a new instance of RevocationRequestEntity.



48
49
50
51
52
53
54
55
56
57
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 48

def initialize(reason: SKIP, other_reason: SKIP, initiator: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reason = reason unless reason == SKIP
  @other_reason = other_reason unless other_reason == SKIP
  @initiator = initiator unless initiator == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#initiatorPartyType2

The party initiating revocation

Returns:



23
24
25
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 23

def initiator
  @initiator
end

#other_reasonString

Text description of an OTHER reason

Returns:

  • (String)


19
20
21
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 19

def other_reason
  @other_reason
end

#reasonUpdateReason2

The reason for the revocation or status change, one of BUSINESS_RULE, SECURITY_EVENT, USER_ACTION or OTHER

Returns:



15
16
17
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 15

def reason
  @reason
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  other_reason = hash.key?('otherReason') ? hash['otherReason'] : SKIP
  initiator = hash.key?('initiator') ? hash['initiator'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RevocationRequestEntity.new(reason: reason,
                              other_reason: other_reason,
                              initiator: initiator,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reason'] = 'reason'
  @_hash['other_reason'] = 'otherReason'
  @_hash['initiator'] = 'initiator'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 35

def self.optionals
  %w[
    reason
    other_reason
    initiator
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason.inspect}, other_reason: #{@other_reason.inspect},"\
  " initiator: #{@initiator.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/fdx_v660_api/models/revocation_request_entity.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason}, other_reason: #{@other_reason}, initiator:"\
  " #{@initiator}, additional_properties: #{@additional_properties}>"
end