Class: FdxV660Api::RewardProgramsEntity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/reward_programs_entity.rb

Overview

An optionally paginated array of reward programs

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(page: SKIP, links: SKIP, reward_programs: SKIP, additional_properties: nil) ⇒ RewardProgramsEntity

Returns a new instance of RewardProgramsEntity.



47
48
49
50
51
52
53
54
55
56
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 47

def initialize(page: SKIP, links: SKIP, reward_programs: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @page = page unless page == SKIP
  @links = links unless links == SKIP
  @reward_programs = reward_programs unless reward_programs == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

Resource URLs for navigating result sets

Returns:



18
19
20
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 18

def links
  @links
end

#pagePageMetadata

Page keys for navigating result sets

Returns:



14
15
16
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 14

def page
  @page
end

#reward_programsArray[RewardProgramEntity]

Array of reward programs

Returns:



22
23
24
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 22

def reward_programs
  @reward_programs
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  page = PageMetadata.from_hash(hash['page']) if hash['page']
  links = PageMetadataLinks1.from_hash(hash['links']) if hash['links']
  # Parameter is an array, so we need to iterate through it
  reward_programs = nil
  unless hash['rewardPrograms'].nil?
    reward_programs = []
    hash['rewardPrograms'].each do |structure|
      reward_programs << (RewardProgramEntity.from_hash(structure) if structure)
    end
  end

  reward_programs = SKIP unless hash.key?('rewardPrograms')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RewardProgramsEntity.new(page: page,
                           links: links,
                           reward_programs: reward_programs,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['page'] = 'page'
  @_hash['links'] = 'links'
  @_hash['reward_programs'] = 'rewardPrograms'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 34

def self.optionals
  %w[
    page
    links
    reward_programs
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page.inspect}, links: #{@links.inspect}, reward_programs:"\
  " #{@reward_programs.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/fdx_v660_api/models/reward_programs_entity.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} page: #{@page}, links: #{@links}, reward_programs: #{@reward_programs},"\
  " additional_properties: #{@additional_properties}>"
end