Class: FdxV660Api::RoyaltyIncomeStatement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::RoyaltyIncomeStatement
- Defined in:
- lib/fdx_v660_api/models/royalty_income_statement.rb
Overview
Royalty Income Statement for IRS Form 1040 Schedule E
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#advertising ⇒ Float
Box 5, Advertising.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#auto ⇒ Float
Box 6, Auto and travel.
-
#capital_expenditures ⇒ Array[DateAndAmount]
Capital expenditures, for use in calculating Depreciation.
-
#cleaning ⇒ Float
Box 7, Cleaning and maintenance.
-
#commissions ⇒ Float
Box 8, Commissions.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#depletion_expense ⇒ Float
Box 18, Depletion.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#insurance ⇒ Float
Box 9, Insurance.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#legal ⇒ Float
Box 10, Legal and other professional fees.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#management_fees ⇒ Float
Box 11, Management fees.
-
#mortgage_interest ⇒ Float
Box 12, Mortgage interest paid to banks, etc.
-
#other_expenses ⇒ Array[DescriptionAndAmount]
Box 19, Other expenses.
-
#other_interest ⇒ Float
Box 13b, Other interest.
-
#property_address ⇒ TaxFormAddress1
Box 1a, Physical address of property (street, city, state, ZIP code).
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#repairs ⇒ Float
Box 14, Repairs.
-
#royalties ⇒ Float
Box 3, Royalties received.
-
#supplies ⇒ Float
Box 15, Supplies.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#taxes ⇒ Float
Box 16, Taxes.
-
#utilities ⇒ Float
Box 17, Utilities.
-
#vehicle_loan_interest ⇒ Float
Box 13a, Vehicle loan interest.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, property_address: SKIP, royalties: SKIP, advertising: SKIP, auto: SKIP, cleaning: SKIP, commissions: SKIP, insurance: SKIP, legal: SKIP, management_fees: SKIP, mortgage_interest: SKIP, vehicle_loan_interest: SKIP, other_interest: SKIP, repairs: SKIP, supplies: SKIP, taxes: SKIP, utilities: SKIP, depletion_expense: SKIP, other_expenses: SKIP, capital_expenditures: SKIP, additional_properties: nil) ⇒ RoyaltyIncomeStatement
constructor
A new instance of RoyaltyIncomeStatement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, property_address: SKIP, royalties: SKIP, advertising: SKIP, auto: SKIP, cleaning: SKIP, commissions: SKIP, insurance: SKIP, legal: SKIP, management_fees: SKIP, mortgage_interest: SKIP, vehicle_loan_interest: SKIP, other_interest: SKIP, repairs: SKIP, supplies: SKIP, taxes: SKIP, utilities: SKIP, depletion_expense: SKIP, other_expenses: SKIP, capital_expenditures: SKIP, additional_properties: nil) ⇒ RoyaltyIncomeStatement
Returns a new instance of RoyaltyIncomeStatement.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 228 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, property_address: SKIP, royalties: SKIP, advertising: SKIP, auto: SKIP, cleaning: SKIP, commissions: SKIP, insurance: SKIP, legal: SKIP, management_fees: SKIP, mortgage_interest: SKIP, vehicle_loan_interest: SKIP, other_interest: SKIP, repairs: SKIP, supplies: SKIP, taxes: SKIP, utilities: SKIP, depletion_expense: SKIP, other_expenses: SKIP, capital_expenditures: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @property_address = property_address unless property_address == SKIP @royalties = royalties unless royalties == SKIP @advertising = advertising unless advertising == SKIP @auto = auto unless auto == SKIP @cleaning = cleaning unless cleaning == SKIP @commissions = commissions unless commissions == SKIP @insurance = insurance unless insurance == SKIP @legal = legal unless legal == SKIP @management_fees = management_fees unless management_fees == SKIP @mortgage_interest = mortgage_interest unless mortgage_interest == SKIP @vehicle_loan_interest = vehicle_loan_interest unless vehicle_loan_interest == SKIP @other_interest = other_interest unless other_interest == SKIP @repairs = repairs unless repairs == SKIP @supplies = supplies unless supplies == SKIP @taxes = taxes unless taxes == SKIP @utilities = utilities unless utilities == SKIP @depletion_expense = depletion_expense unless depletion_expense == SKIP @other_expenses = other_expenses unless other_expenses == SKIP @capital_expenditures = capital_expenditures unless capital_expenditures == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 37 def additional_information @additional_information end |
#advertising ⇒ Float
Box 5, Advertising
83 84 85 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 83 def advertising @advertising end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 63 def attributes @attributes end |
#auto ⇒ Float
Box 6, Auto and travel
87 88 89 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 87 def auto @auto end |
#capital_expenditures ⇒ Array[DateAndAmount]
Capital expenditures, for use in calculating Depreciation
147 148 149 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 147 def capital_expenditures @capital_expenditures end |
#cleaning ⇒ Float
Box 7, Cleaning and maintenance
91 92 93 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 91 def cleaning @cleaning end |
#commissions ⇒ Float
Box 8, Commissions
95 96 97 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 95 def commissions @commissions end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 18 def corrected @corrected end |
#depletion_expense ⇒ Float
Box 18, Depletion
139 140 141 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 139 def depletion_expense @depletion_expense end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 67 def error @error end |
#insurance ⇒ Float
Box 9, Insurance
99 100 101 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 99 def insurance @insurance end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 47 def issuer @issuer end |
#legal ⇒ Float
Box 10, Legal and other professional fees
103 104 105 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 103 def legal @legal end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 71 def links @links end |
#management_fees ⇒ Float
Box 11, Management fees
107 108 109 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 107 def management_fees @management_fees end |
#mortgage_interest ⇒ Float
Box 12, Mortgage interest paid to banks, etc.
111 112 113 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 111 def mortgage_interest @mortgage_interest end |
#other_expenses ⇒ Array[DescriptionAndAmount]
Box 19, Other expenses
143 144 145 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 143 def other_expenses @other_expenses end |
#other_interest ⇒ Float
Box 13b, Other interest
119 120 121 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 119 def other_interest @other_interest end |
#property_address ⇒ TaxFormAddress1
Box 1a, Physical address of property (street, city, state, ZIP code)
75 76 77 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 75 def property_address @property_address end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 53 def recipient @recipient end |
#repairs ⇒ Float
Box 14, Repairs
123 124 125 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 123 def repairs @repairs end |
#royalties ⇒ Float
Box 3, Royalties received
79 80 81 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 79 def royalties @royalties end |
#supplies ⇒ Float
Box 15, Supplies
127 128 129 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 127 def supplies @supplies end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 14 def tax_year @tax_year end |
#taxes ⇒ Float
Box 16, Taxes
131 132 133 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 131 def taxes @taxes end |
#utilities ⇒ Float
Box 17, Utilities
135 136 137 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 135 def utilities @utilities end |
#vehicle_loan_interest ⇒ Float
Box 13a, Vehicle loan interest
115 116 117 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 115 def vehicle_loan_interest @vehicle_loan_interest end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 278 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') property_address = TaxFormAddress1.from_hash(hash['propertyAddress']) if hash['propertyAddress'] royalties = hash.key?('royalties') ? hash['royalties'] : SKIP advertising = hash.key?('advertising') ? hash['advertising'] : SKIP auto = hash.key?('auto') ? hash['auto'] : SKIP cleaning = hash.key?('cleaning') ? hash['cleaning'] : SKIP commissions = hash.key?('commissions') ? hash['commissions'] : SKIP insurance = hash.key?('insurance') ? hash['insurance'] : SKIP legal = hash.key?('legal') ? hash['legal'] : SKIP management_fees = hash.key?('managementFees') ? hash['managementFees'] : SKIP mortgage_interest = hash.key?('mortgageInterest') ? hash['mortgageInterest'] : SKIP vehicle_loan_interest = hash.key?('vehicleLoanInterest') ? hash['vehicleLoanInterest'] : SKIP other_interest = hash.key?('otherInterest') ? hash['otherInterest'] : SKIP repairs = hash.key?('repairs') ? hash['repairs'] : SKIP supplies = hash.key?('supplies') ? hash['supplies'] : SKIP taxes = hash.key?('taxes') ? hash['taxes'] : SKIP utilities = hash.key?('utilities') ? hash['utilities'] : SKIP depletion_expense = hash.key?('depletionExpense') ? hash['depletionExpense'] : SKIP # Parameter is an array, so we need to iterate through it other_expenses = nil unless hash['otherExpenses'].nil? other_expenses = [] hash['otherExpenses'].each do |structure| other_expenses << (DescriptionAndAmount.from_hash(structure) if structure) end end other_expenses = SKIP unless hash.key?('otherExpenses') # Parameter is an array, so we need to iterate through it capital_expenditures = nil unless hash['capitalExpenditures'].nil? capital_expenditures = [] hash['capitalExpenditures'].each do |structure| capital_expenditures << (DateAndAmount.from_hash(structure) if structure) end end capital_expenditures = SKIP unless hash.key?('capitalExpenditures') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RoyaltyIncomeStatement.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, property_address: property_address, royalties: royalties, advertising: advertising, auto: auto, cleaning: cleaning, commissions: commissions, insurance: insurance, legal: legal, management_fees: management_fees, mortgage_interest: mortgage_interest, vehicle_loan_interest: vehicle_loan_interest, other_interest: other_interest, repairs: repairs, supplies: supplies, taxes: taxes, utilities: utilities, depletion_expense: depletion_expense, other_expenses: other_expenses, capital_expenditures: capital_expenditures, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 150 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['property_address'] = 'propertyAddress' @_hash['royalties'] = 'royalties' @_hash['advertising'] = 'advertising' @_hash['auto'] = 'auto' @_hash['cleaning'] = 'cleaning' @_hash['commissions'] = 'commissions' @_hash['insurance'] = 'insurance' @_hash['legal'] = 'legal' @_hash['management_fees'] = 'managementFees' @_hash['mortgage_interest'] = 'mortgageInterest' @_hash['vehicle_loan_interest'] = 'vehicleLoanInterest' @_hash['other_interest'] = 'otherInterest' @_hash['repairs'] = 'repairs' @_hash['supplies'] = 'supplies' @_hash['taxes'] = 'taxes' @_hash['utilities'] = 'utilities' @_hash['depletion_expense'] = 'depletionExpense' @_hash['other_expenses'] = 'otherExpenses' @_hash['capital_expenditures'] = 'capitalExpenditures' @_hash end |
.nullables ⇒ Object
An array for nullable fields
224 225 226 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 224 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 187 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links property_address royalties advertising auto cleaning commissions insurance legal management_fees mortgage_interest vehicle_loan_interest other_interest repairs supplies taxes utilities depletion_expense other_expenses capital_expenditures ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 416 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, property_address: #{@property_address.inspect}, royalties:"\ " #{@royalties.inspect}, advertising: #{@advertising.inspect}, auto: #{@auto.inspect},"\ " cleaning: #{@cleaning.inspect}, commissions: #{@commissions.inspect}, insurance:"\ " #{@insurance.inspect}, legal: #{@legal.inspect}, management_fees:"\ " #{@management_fees.inspect}, mortgage_interest: #{@mortgage_interest.inspect},"\ " vehicle_loan_interest: #{@vehicle_loan_interest.inspect}, other_interest:"\ " #{@other_interest.inspect}, repairs: #{@repairs.inspect}, supplies: #{@supplies.inspect},"\ " taxes: #{@taxes.inspect}, utilities: #{@utilities.inspect}, depletion_expense:"\ " #{@depletion_expense.inspect}, other_expenses: #{@other_expenses.inspect},"\ " capital_expenditures: #{@capital_expenditures.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/fdx_v660_api/models/royalty_income_statement.rb', line 399 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, property_address: #{@property_address}, royalties:"\ " #{@royalties}, advertising: #{@advertising}, auto: #{@auto}, cleaning: #{@cleaning},"\ " commissions: #{@commissions}, insurance: #{@insurance}, legal: #{@legal}, management_fees:"\ " #{@management_fees}, mortgage_interest: #{@mortgage_interest}, vehicle_loan_interest:"\ " #{@vehicle_loan_interest}, other_interest: #{@other_interest}, repairs: #{@repairs},"\ " supplies: #{@supplies}, taxes: #{@taxes}, utilities: #{@utilities}, depletion_expense:"\ " #{@depletion_expense}, other_expenses: #{@other_expenses}, capital_expenditures:"\ " #{@capital_expenditures}, additional_properties: #{@additional_properties}>" end |