Class: FdxV660Api::StateTaxWithholding

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/state_tax_withholding.rb

Overview

Income in a state and its tax withholding

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(tax_withheld: SKIP, tax_id: SKIP, income: SKIP, additional_properties: nil) ⇒ StateTaxWithholding

Returns a new instance of StateTaxWithholding.



47
48
49
50
51
52
53
54
55
56
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 47

def initialize(tax_withheld: SKIP, tax_id: SKIP, income: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @tax_withheld = tax_withheld unless tax_withheld == SKIP
  @tax_id = tax_id unless tax_id == SKIP
  @income = income unless income == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#incomeFloat

Income amount for state tax purposes

Returns:

  • (Float)


22
23
24
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 22

def income
  @income
end

#tax_idString

Filer's state tax id

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 18

def tax_id
  @tax_id
end

#tax_withheldFloat

Amount of state income tax withheld

Returns:

  • (Float)


14
15
16
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 14

def tax_withheld
  @tax_withheld
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  tax_withheld = hash.key?('taxWithheld') ? hash['taxWithheld'] : SKIP
  tax_id = hash.key?('taxId') ? hash['taxId'] : SKIP
  income = hash.key?('income') ? hash['income'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StateTaxWithholding.new(tax_withheld: tax_withheld,
                          tax_id: tax_id,
                          income: income,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['tax_withheld'] = 'taxWithheld'
  @_hash['tax_id'] = 'taxId'
  @_hash['income'] = 'income'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 34

def self.optionals
  %w[
    tax_withheld
    tax_id
    income
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_withheld: #{@tax_withheld.inspect}, tax_id: #{@tax_id.inspect}, income:"\
  " #{@income.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/fdx_v660_api/models/state_tax_withholding.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} tax_withheld: #{@tax_withheld}, tax_id: #{@tax_id}, income: #{@income},"\
  " additional_properties: #{@additional_properties}>"
end