Class: FdxV660Api::TaxDataForQr
- Defined in:
- lib/fdx_v660_api/models/tax_data_for_qr.rb
Overview
Tax data container for QR Code purposes
Instance Attribute Summary collapse
-
#business_income_statement ⇒ BusinessIncomeStatement
Business Income Statement for IRS Form 1040 Schedule C.
-
#cryptocurrency_tax_statement ⇒ CryptocurrencyTaxStatementList1
Cryptocurrency Tax Statement list.
-
#farm_income_statement ⇒ FarmIncomeStatement
Farm Income Statement for IRS Form 1040 Schedule F.
-
#farm_rental_income_statement ⇒ FarmRentalIncomeStatement
Farm Rental Income Statement for IRS Form 4835.
-
#rental_income_statement ⇒ RentalIncomeStatement
Rental Income Statement for IRS Form 1040 Schedule E.
-
#royalty_income_statement ⇒ RoyaltyIncomeStatement
Royalty Income Statement for IRS Form 1040 Schedule E.
-
#software_id ⇒ String
The FDX registration ID of company or software generating this tax data.
-
#tax1041_k1 ⇒ Form1041ScheduleK11
Beneficiary's Share of Income, Deductions, Credits, etc.
-
#tax1042_s ⇒ Form1042S1
Foreign Person's U.S.
-
#tax1065_k1 ⇒ Form1065ScheduleK11
Partner's Share of Income, Deductions, Credits, etc.
-
#tax1065_k3 ⇒ Tax
Partner's Share of Income, Deductions, Credits, etc.
-
#tax1095_a ⇒ Form1095A1
Health Insurance Marketplace Statement.
-
#tax1095_b ⇒ Form1095B1
Health Coverage.
-
#tax1095_c ⇒ Form1095C1
Employer-Provided Health Insurance Offer and Coverage.
-
#tax1097_btc ⇒ Form1097Btc1
Bond Tax Credit.
-
#tax1098 ⇒ Form10981
Mortgage Interest Statement.
-
#tax1098_c ⇒ Form1098C1
Contributions of Motor Vehicles, Boats, and Airplanes.
-
#tax1098_e ⇒ Form1098E1
Student Loan Interest Statement.
-
#tax1098_ma ⇒ Form1098Ma1
Mortgage Assistance Payments.
-
#tax1098_q ⇒ Form1098Q1
Qualifying Longevity Annuity Contract Information.
-
#tax1098_t ⇒ Form1098T1
Tuition Statement.
-
#tax1098_vli ⇒ Form1098Vli1
Vehicle Loan Interest Statement.
-
#tax1099_a ⇒ Form1099A1
Acquisition or Abandonment of Secured Property.
-
#tax1099_b ⇒ Form1099B1
Proceeds From Broker and Barter Exchange Transactions.
-
#tax1099_c ⇒ Form1099C1
Cancellation of Debt.
-
#tax1099_cap ⇒ Form1099Cap1
Changes in Corporate Control and Capital Structure.
-
#tax1099_consolidated_statement ⇒ Form1099ConsolidatedStatement1
Consolidated Statement for combined IRS Form 1099s.
-
#tax1099_da ⇒ Form1099Da1
Digital Asset Proceeds From Broker Transactions.
-
#tax1099_div ⇒ Form1099Div1
Dividends and Distributions.
-
#tax1099_g ⇒ Form1099G1
Certain Government Payments.
-
#tax1099_h ⇒ Form1099H1
Health Coverage Tax Credit (HCTC) Advance Payments.
-
#tax1099_int ⇒ Form1099Int1
Interest Income.
-
#tax1099_k ⇒ Form1099K1
Merchant Card and Third-Party Network Payments.
-
#tax1099_lps ⇒ Form1099Lps1
Long-Term Care Premiums Paid Statement.
-
#tax1099_ls ⇒ Form1099Ls1
Reportable Life Insurance Sale.
-
#tax1099_ltc ⇒ Form1099Ltc1
Long-Term Care and Accelerated Death Benefits.
-
#tax1099_misc ⇒ Form1099Misc1
Miscellaneous Income.
-
#tax1099_nec ⇒ Form1099Nec1
Nonemployee Compensation.
-
#tax1099_oid ⇒ Form1099Oid1
Original Issue Discount.
-
#tax1099_patr ⇒ Form1099Patr1
Taxable Distributions Received From Cooperatives.
-
#tax1099_q ⇒ Form1099Q1
Payments From Qualified Education Programs.
-
#tax1099_qa ⇒ Form1099Qa1
Distributions From ABLE Accounts.
-
#tax1099_r ⇒ Form1099R1
Distributions from Pensions, Annuities, Retirement or Profit-Sharing Plans, IRAs, Insurance Contracts, etc.
-
#tax1099_s ⇒ Form1099S1
Proceeds From Real Estate Transactions.
-
#tax1099_sa ⇒ Form1099Sa1
Distributions From an HSA, Archer MSA, or Medicare Advantage MSA.
-
#tax1099_sb ⇒ Form1099Sb1
Seller's Investment in Life Insurance Contract.
-
#tax1120_sk1 ⇒ Form1120SScheduleK11
Shareholder's Share of Income, Deductions, Credits, etc.
-
#tax2439 ⇒ Form24391
Notice to Shareholder of Undistributed Long-Term Capital Gains.
-
#tax3921 ⇒ Form39211
Exercise of an Incentive Stock Option Under Section 422(b).
-
#tax3922 ⇒ Form39221
Transfer of Stock Acquired Through an Employee Stock Purchase Plan under Section 423(c).
-
#tax5227_k1 ⇒ Form1041ScheduleK1
Split-Interest Trust Beneficiary's schedule K-1.
-
#tax5498 ⇒ Form54981
IRA Contribution Information.
-
#tax5498_esa ⇒ Form5498Esa1
Coverdell ESA Contribution Information.
-
#tax5498_qa ⇒ Form5498Qa1
ABLE Account Contribution Information.
-
#tax5498_sa ⇒ Form5498Sa1
HSA, Archer MSA, or Medicare Advantage MSA Information.
-
#tax5498_ta ⇒ Form5498Ta1
Trump Account Contribution Information.
-
#tax_refund_direct_deposit ⇒ TaxRefundDirectDeposit2
Tax refund direct deposit information.
-
#tax_w2 ⇒ FormW24
Wage and Tax Statement.
-
#tax_w2_c ⇒ FormW2C2
IRS form W-2c, Corrected Wage and Tax Statement.
-
#tax_w2_g ⇒ FormW2G2
Certain Gambling Winnings.
-
#version ⇒ FdxVersion1
Financial Data Exchange (FDX) schema version number (e.g. "V5.0").
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(business_income_statement: SKIP, cryptocurrency_tax_statement: SKIP, farm_income_statement: SKIP, farm_rental_income_statement: SKIP, rental_income_statement: SKIP, royalty_income_statement: SKIP, tax1041_k1: SKIP, tax1042_s: SKIP, tax1065_k1: SKIP, tax1065_k3: SKIP, tax1095_a: SKIP, tax1095_b: SKIP, tax1095_c: SKIP, tax1097_btc: SKIP, tax1098: SKIP, tax1098_c: SKIP, tax1098_e: SKIP, tax1098_ma: SKIP, tax1098_q: SKIP, tax1098_t: SKIP, tax1098_vli: SKIP, tax1099_a: SKIP, tax1099_b: SKIP, tax1099_c: SKIP, tax1099_cap: SKIP, tax1099_consolidated_statement: SKIP, tax1099_da: SKIP, tax1099_div: SKIP, tax1099_g: SKIP, tax1099_h: SKIP, tax1099_int: SKIP, tax1099_k: SKIP, tax1099_lps: SKIP, tax1099_ls: SKIP, tax1099_ltc: SKIP, tax1099_misc: SKIP, tax1099_nec: SKIP, tax1099_oid: SKIP, tax1099_patr: SKIP, tax1099_q: SKIP, tax1099_qa: SKIP, tax1099_r: SKIP, tax1099_s: SKIP, tax1099_sa: SKIP, tax1099_sb: SKIP, tax1120_sk1: SKIP, tax2439: SKIP, tax3921: SKIP, tax3922: SKIP, tax5227_k1: SKIP, tax5498: SKIP, tax5498_esa: SKIP, tax5498_qa: SKIP, tax5498_sa: SKIP, tax5498_ta: SKIP, tax_w2: SKIP, tax_w2_c: SKIP, tax_w2_g: SKIP, tax_refund_direct_deposit: SKIP, version: SKIP, software_id: SKIP, additional_properties: nil) ⇒ TaxDataForQr
constructor
A new instance of TaxDataForQr.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(business_income_statement: SKIP, cryptocurrency_tax_statement: SKIP, farm_income_statement: SKIP, farm_rental_income_statement: SKIP, rental_income_statement: SKIP, royalty_income_statement: SKIP, tax1041_k1: SKIP, tax1042_s: SKIP, tax1065_k1: SKIP, tax1065_k3: SKIP, tax1095_a: SKIP, tax1095_b: SKIP, tax1095_c: SKIP, tax1097_btc: SKIP, tax1098: SKIP, tax1098_c: SKIP, tax1098_e: SKIP, tax1098_ma: SKIP, tax1098_q: SKIP, tax1098_t: SKIP, tax1098_vli: SKIP, tax1099_a: SKIP, tax1099_b: SKIP, tax1099_c: SKIP, tax1099_cap: SKIP, tax1099_consolidated_statement: SKIP, tax1099_da: SKIP, tax1099_div: SKIP, tax1099_g: SKIP, tax1099_h: SKIP, tax1099_int: SKIP, tax1099_k: SKIP, tax1099_lps: SKIP, tax1099_ls: SKIP, tax1099_ltc: SKIP, tax1099_misc: SKIP, tax1099_nec: SKIP, tax1099_oid: SKIP, tax1099_patr: SKIP, tax1099_q: SKIP, tax1099_qa: SKIP, tax1099_r: SKIP, tax1099_s: SKIP, tax1099_sa: SKIP, tax1099_sb: SKIP, tax1120_sk1: SKIP, tax2439: SKIP, tax3921: SKIP, tax3922: SKIP, tax5227_k1: SKIP, tax5498: SKIP, tax5498_esa: SKIP, tax5498_qa: SKIP, tax5498_sa: SKIP, tax5498_ta: SKIP, tax_w2: SKIP, tax_w2_c: SKIP, tax_w2_g: SKIP, tax_refund_direct_deposit: SKIP, version: SKIP, software_id: SKIP, additional_properties: nil) ⇒ TaxDataForQr
Returns a new instance of TaxDataForQr.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 400 def initialize(business_income_statement: SKIP, cryptocurrency_tax_statement: SKIP, farm_income_statement: SKIP, farm_rental_income_statement: SKIP, rental_income_statement: SKIP, royalty_income_statement: SKIP, tax1041_k1: SKIP, tax1042_s: SKIP, tax1065_k1: SKIP, tax1065_k3: SKIP, tax1095_a: SKIP, tax1095_b: SKIP, tax1095_c: SKIP, tax1097_btc: SKIP, tax1098: SKIP, tax1098_c: SKIP, tax1098_e: SKIP, tax1098_ma: SKIP, tax1098_q: SKIP, tax1098_t: SKIP, tax1098_vli: SKIP, tax1099_a: SKIP, tax1099_b: SKIP, tax1099_c: SKIP, tax1099_cap: SKIP, tax1099_consolidated_statement: SKIP, tax1099_da: SKIP, tax1099_div: SKIP, tax1099_g: SKIP, tax1099_h: SKIP, tax1099_int: SKIP, tax1099_k: SKIP, tax1099_lps: SKIP, tax1099_ls: SKIP, tax1099_ltc: SKIP, tax1099_misc: SKIP, tax1099_nec: SKIP, tax1099_oid: SKIP, tax1099_patr: SKIP, tax1099_q: SKIP, tax1099_qa: SKIP, tax1099_r: SKIP, tax1099_s: SKIP, tax1099_sa: SKIP, tax1099_sb: SKIP, tax1120_sk1: SKIP, tax2439: SKIP, tax3921: SKIP, tax3922: SKIP, tax5227_k1: SKIP, tax5498: SKIP, tax5498_esa: SKIP, tax5498_qa: SKIP, tax5498_sa: SKIP, tax5498_ta: SKIP, tax_w2: SKIP, tax_w2_c: SKIP, tax_w2_g: SKIP, tax_refund_direct_deposit: SKIP, version: SKIP, software_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless business_income_statement == SKIP @business_income_statement = business_income_statement end unless cryptocurrency_tax_statement == SKIP @cryptocurrency_tax_statement = cryptocurrency_tax_statement end @farm_income_statement = farm_income_statement unless farm_income_statement == SKIP unless farm_rental_income_statement == SKIP @farm_rental_income_statement = farm_rental_income_statement end @rental_income_statement = rental_income_statement unless rental_income_statement == SKIP @royalty_income_statement = royalty_income_statement unless royalty_income_statement == SKIP @tax1041_k1 = tax1041_k1 unless tax1041_k1 == SKIP @tax1042_s = tax1042_s unless tax1042_s == SKIP @tax1065_k1 = tax1065_k1 unless tax1065_k1 == SKIP @tax1065_k3 = tax1065_k3 unless tax1065_k3 == SKIP @tax1095_a = tax1095_a unless tax1095_a == SKIP @tax1095_b = tax1095_b unless tax1095_b == SKIP @tax1095_c = tax1095_c unless tax1095_c == SKIP @tax1097_btc = tax1097_btc unless tax1097_btc == SKIP @tax1098 = tax1098 unless tax1098 == SKIP @tax1098_c = tax1098_c unless tax1098_c == SKIP @tax1098_e = tax1098_e unless tax1098_e == SKIP @tax1098_ma = tax1098_ma unless tax1098_ma == SKIP @tax1098_q = tax1098_q unless tax1098_q == SKIP @tax1098_t = tax1098_t unless tax1098_t == SKIP @tax1098_vli = tax1098_vli unless tax1098_vli == SKIP @tax1099_a = tax1099_a unless tax1099_a == SKIP @tax1099_b = tax1099_b unless tax1099_b == SKIP @tax1099_c = tax1099_c unless tax1099_c == SKIP @tax1099_cap = tax1099_cap unless tax1099_cap == SKIP unless tax1099_consolidated_statement == SKIP @tax1099_consolidated_statement = tax1099_consolidated_statement end @tax1099_da = tax1099_da unless tax1099_da == SKIP @tax1099_div = tax1099_div unless tax1099_div == SKIP @tax1099_g = tax1099_g unless tax1099_g == SKIP @tax1099_h = tax1099_h unless tax1099_h == SKIP @tax1099_int = tax1099_int unless tax1099_int == SKIP @tax1099_k = tax1099_k unless tax1099_k == SKIP @tax1099_lps = tax1099_lps unless tax1099_lps == SKIP @tax1099_ls = tax1099_ls unless tax1099_ls == SKIP @tax1099_ltc = tax1099_ltc unless tax1099_ltc == SKIP @tax1099_misc = tax1099_misc unless tax1099_misc == SKIP @tax1099_nec = tax1099_nec unless tax1099_nec == SKIP @tax1099_oid = tax1099_oid unless tax1099_oid == SKIP @tax1099_patr = tax1099_patr unless tax1099_patr == SKIP @tax1099_q = tax1099_q unless tax1099_q == SKIP @tax1099_qa = tax1099_qa unless tax1099_qa == SKIP @tax1099_r = tax1099_r unless tax1099_r == SKIP @tax1099_s = tax1099_s unless tax1099_s == SKIP @tax1099_sa = tax1099_sa unless tax1099_sa == SKIP @tax1099_sb = tax1099_sb unless tax1099_sb == SKIP @tax1120_sk1 = tax1120_sk1 unless tax1120_sk1 == SKIP @tax2439 = tax2439 unless tax2439 == SKIP @tax3921 = tax3921 unless tax3921 == SKIP @tax3922 = tax3922 unless tax3922 == SKIP @tax5227_k1 = tax5227_k1 unless tax5227_k1 == SKIP @tax5498 = tax5498 unless tax5498 == SKIP @tax5498_esa = tax5498_esa unless tax5498_esa == SKIP @tax5498_qa = tax5498_qa unless tax5498_qa == SKIP @tax5498_sa = tax5498_sa unless tax5498_sa == SKIP @tax5498_ta = tax5498_ta unless tax5498_ta == SKIP @tax_w2 = tax_w2 unless tax_w2 == SKIP @tax_w2_c = tax_w2_c unless tax_w2_c == SKIP @tax_w2_g = tax_w2_g unless tax_w2_g == SKIP unless tax_refund_direct_deposit == SKIP @tax_refund_direct_deposit = tax_refund_direct_deposit end @version = version unless version == SKIP @software_id = software_id unless software_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#business_income_statement ⇒ BusinessIncomeStatement
Business Income Statement for IRS Form 1040 Schedule C
14 15 16 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 14 def business_income_statement @business_income_statement end |
#cryptocurrency_tax_statement ⇒ CryptocurrencyTaxStatementList1
Cryptocurrency Tax Statement list. Replaced summer of 2025 by Tax1099Da for IRS form 1099-DA
19 20 21 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 19 def cryptocurrency_tax_statement @cryptocurrency_tax_statement end |
#farm_income_statement ⇒ FarmIncomeStatement
Farm Income Statement for IRS Form 1040 Schedule F
23 24 25 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 23 def farm_income_statement @farm_income_statement end |
#farm_rental_income_statement ⇒ FarmRentalIncomeStatement
Farm Rental Income Statement for IRS Form 4835
27 28 29 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 27 def farm_rental_income_statement @farm_rental_income_statement end |
#rental_income_statement ⇒ RentalIncomeStatement
Rental Income Statement for IRS Form 1040 Schedule E
31 32 33 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 31 def rental_income_statement @rental_income_statement end |
#royalty_income_statement ⇒ RoyaltyIncomeStatement
Royalty Income Statement for IRS Form 1040 Schedule E
35 36 37 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 35 def royalty_income_statement @royalty_income_statement end |
#software_id ⇒ String
The FDX registration ID of company or software generating this tax data
258 259 260 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 258 def software_id @software_id end |
#tax1041_k1 ⇒ Form1041ScheduleK11
Beneficiary's Share of Income, Deductions, Credits, etc.
39 40 41 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 39 def tax1041_k1 @tax1041_k1 end |
#tax1042_s ⇒ Form1042S1
Foreign Person's U.S. Source Income Subject to Withholding
43 44 45 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 43 def tax1042_s @tax1042_s end |
#tax1065_k1 ⇒ Form1065ScheduleK11
Partner's Share of Income, Deductions, Credits, etc.
47 48 49 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 47 def tax1065_k1 @tax1065_k1 end |
#tax1065_k3 ⇒ Tax
Partner's Share of Income, Deductions, Credits, etc. - International
51 52 53 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 51 def tax1065_k3 @tax1065_k3 end |
#tax1095_a ⇒ Form1095A1
Health Insurance Marketplace Statement
55 56 57 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 55 def tax1095_a @tax1095_a end |
#tax1095_b ⇒ Form1095B1
Health Coverage
59 60 61 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 59 def tax1095_b @tax1095_b end |
#tax1095_c ⇒ Form1095C1
Employer-Provided Health Insurance Offer and Coverage
63 64 65 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 63 def tax1095_c @tax1095_c end |
#tax1097_btc ⇒ Form1097Btc1
Bond Tax Credit
67 68 69 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 67 def tax1097_btc @tax1097_btc end |
#tax1098 ⇒ Form10981
Mortgage Interest Statement
71 72 73 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 71 def tax1098 @tax1098 end |
#tax1098_c ⇒ Form1098C1
Contributions of Motor Vehicles, Boats, and Airplanes
75 76 77 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 75 def tax1098_c @tax1098_c end |
#tax1098_e ⇒ Form1098E1
Student Loan Interest Statement
79 80 81 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 79 def tax1098_e @tax1098_e end |
#tax1098_ma ⇒ Form1098Ma1
Mortgage Assistance Payments
83 84 85 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 83 def tax1098_ma @tax1098_ma end |
#tax1098_q ⇒ Form1098Q1
Qualifying Longevity Annuity Contract Information
87 88 89 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 87 def tax1098_q @tax1098_q end |
#tax1098_t ⇒ Form1098T1
Tuition Statement
91 92 93 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 91 def tax1098_t @tax1098_t end |
#tax1098_vli ⇒ Form1098Vli1
Vehicle Loan Interest Statement
95 96 97 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 95 def tax1098_vli @tax1098_vli end |
#tax1099_a ⇒ Form1099A1
Acquisition or Abandonment of Secured Property
99 100 101 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 99 def tax1099_a @tax1099_a end |
#tax1099_b ⇒ Form1099B1
Proceeds From Broker and Barter Exchange Transactions
103 104 105 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 103 def tax1099_b @tax1099_b end |
#tax1099_c ⇒ Form1099C1
Cancellation of Debt
107 108 109 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 107 def tax1099_c @tax1099_c end |
#tax1099_cap ⇒ Form1099Cap1
Changes in Corporate Control and Capital Structure
111 112 113 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 111 def tax1099_cap @tax1099_cap end |
#tax1099_consolidated_statement ⇒ Form1099ConsolidatedStatement1
Consolidated Statement for combined IRS Form 1099s
115 116 117 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 115 def tax1099_consolidated_statement @tax1099_consolidated_statement end |
#tax1099_da ⇒ Form1099Da1
Digital Asset Proceeds From Broker Transactions
119 120 121 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 119 def tax1099_da @tax1099_da end |
#tax1099_div ⇒ Form1099Div1
Dividends and Distributions
123 124 125 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 123 def tax1099_div @tax1099_div end |
#tax1099_g ⇒ Form1099G1
Certain Government Payments
127 128 129 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 127 def tax1099_g @tax1099_g end |
#tax1099_h ⇒ Form1099H1
Health Coverage Tax Credit (HCTC) Advance Payments
131 132 133 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 131 def tax1099_h @tax1099_h end |
#tax1099_int ⇒ Form1099Int1
Interest Income
135 136 137 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 135 def tax1099_int @tax1099_int end |
#tax1099_k ⇒ Form1099K1
Merchant Card and Third-Party Network Payments
139 140 141 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 139 def tax1099_k @tax1099_k end |
#tax1099_lps ⇒ Form1099Lps1
Long-Term Care Premiums Paid Statement
143 144 145 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 143 def tax1099_lps @tax1099_lps end |
#tax1099_ls ⇒ Form1099Ls1
Reportable Life Insurance Sale
147 148 149 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 147 def tax1099_ls @tax1099_ls end |
#tax1099_ltc ⇒ Form1099Ltc1
Long-Term Care and Accelerated Death Benefits
151 152 153 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 151 def tax1099_ltc @tax1099_ltc end |
#tax1099_misc ⇒ Form1099Misc1
Miscellaneous Income
155 156 157 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 155 def tax1099_misc @tax1099_misc end |
#tax1099_nec ⇒ Form1099Nec1
Nonemployee Compensation
159 160 161 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 159 def tax1099_nec @tax1099_nec end |
#tax1099_oid ⇒ Form1099Oid1
Original Issue Discount
163 164 165 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 163 def tax1099_oid @tax1099_oid end |
#tax1099_patr ⇒ Form1099Patr1
Taxable Distributions Received From Cooperatives
167 168 169 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 167 def tax1099_patr @tax1099_patr end |
#tax1099_q ⇒ Form1099Q1
Payments From Qualified Education Programs
171 172 173 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 171 def tax1099_q @tax1099_q end |
#tax1099_qa ⇒ Form1099Qa1
Distributions From ABLE Accounts
175 176 177 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 175 def tax1099_qa @tax1099_qa end |
#tax1099_r ⇒ Form1099R1
Distributions from Pensions, Annuities, Retirement or Profit-Sharing Plans, IRAs, Insurance Contracts, etc.
180 181 182 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 180 def tax1099_r @tax1099_r end |
#tax1099_s ⇒ Form1099S1
Proceeds From Real Estate Transactions
184 185 186 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 184 def tax1099_s @tax1099_s end |
#tax1099_sa ⇒ Form1099Sa1
Distributions From an HSA, Archer MSA, or Medicare Advantage MSA
188 189 190 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 188 def tax1099_sa @tax1099_sa end |
#tax1099_sb ⇒ Form1099Sb1
Seller's Investment in Life Insurance Contract
192 193 194 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 192 def tax1099_sb @tax1099_sb end |
#tax1120_sk1 ⇒ Form1120SScheduleK11
Shareholder's Share of Income, Deductions, Credits, etc.
196 197 198 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 196 def tax1120_sk1 @tax1120_sk1 end |
#tax2439 ⇒ Form24391
Notice to Shareholder of Undistributed Long-Term Capital Gains
200 201 202 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 200 def tax2439 @tax2439 end |
#tax3921 ⇒ Form39211
Exercise of an Incentive Stock Option Under Section 422(b)
204 205 206 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 204 def tax3921 @tax3921 end |
#tax3922 ⇒ Form39221
Transfer of Stock Acquired Through an Employee Stock Purchase Plan under Section 423(c)
209 210 211 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 209 def tax3922 @tax3922 end |
#tax5227_k1 ⇒ Form1041ScheduleK1
Split-Interest Trust Beneficiary's schedule K-1
213 214 215 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 213 def tax5227_k1 @tax5227_k1 end |
#tax5498 ⇒ Form54981
IRA Contribution Information
217 218 219 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 217 def tax5498 @tax5498 end |
#tax5498_esa ⇒ Form5498Esa1
Coverdell ESA Contribution Information
221 222 223 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 221 def tax5498_esa @tax5498_esa end |
#tax5498_qa ⇒ Form5498Qa1
ABLE Account Contribution Information
225 226 227 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 225 def tax5498_qa @tax5498_qa end |
#tax5498_sa ⇒ Form5498Sa1
HSA, Archer MSA, or Medicare Advantage MSA Information
229 230 231 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 229 def tax5498_sa @tax5498_sa end |
#tax5498_ta ⇒ Form5498Ta1
Trump Account Contribution Information
233 234 235 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 233 def tax5498_ta @tax5498_ta end |
#tax_refund_direct_deposit ⇒ TaxRefundDirectDeposit2
Tax refund direct deposit information
249 250 251 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 249 def tax_refund_direct_deposit @tax_refund_direct_deposit end |
#tax_w2 ⇒ FormW24
Wage and Tax Statement
237 238 239 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 237 def tax_w2 @tax_w2 end |
#tax_w2_c ⇒ FormW2C2
IRS form W-2c, Corrected Wage and Tax Statement
241 242 243 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 241 def tax_w2_c @tax_w2_c end |
#tax_w2_g ⇒ FormW2G2
Certain Gambling Winnings
245 246 247 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 245 def tax_w2_g @tax_w2_g end |
#version ⇒ FdxVersion1
Financial Data Exchange (FDX) schema version number (e.g. "V5.0").
254 255 256 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 254 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 508 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['businessIncomeStatement'] business_income_statement = BusinessIncomeStatement.from_hash(hash['businessIncomeStatement']) end if hash['cryptocurrencyTaxStatement'] cryptocurrency_tax_statement = CryptocurrencyTaxStatementList1.from_hash(hash['cryptocurrencyTaxStatement']) end farm_income_statement = FarmIncomeStatement.from_hash(hash['farmIncomeStatement']) if hash['farmIncomeStatement'] if hash['farmRentalIncomeStatement'] farm_rental_income_statement = FarmRentalIncomeStatement.from_hash(hash['farmRentalIncomeStatement']) end rental_income_statement = RentalIncomeStatement.from_hash(hash['rentalIncomeStatement']) if hash['rentalIncomeStatement'] royalty_income_statement = RoyaltyIncomeStatement.from_hash(hash['royaltyIncomeStatement']) if hash['royaltyIncomeStatement'] tax1041_k1 = Form1041ScheduleK11.from_hash(hash['tax1041K1']) if hash['tax1041K1'] tax1042_s = Form1042S1.from_hash(hash['tax1042S']) if hash['tax1042S'] tax1065_k1 = Form1065ScheduleK11.from_hash(hash['tax1065K1']) if hash['tax1065K1'] tax1065_k3 = Tax.from_hash(hash['tax1065K3']) if hash['tax1065K3'] tax1095_a = Form1095A1.from_hash(hash['tax1095A']) if hash['tax1095A'] tax1095_b = Form1095B1.from_hash(hash['tax1095B']) if hash['tax1095B'] tax1095_c = Form1095C1.from_hash(hash['tax1095C']) if hash['tax1095C'] tax1097_btc = Form1097Btc1.from_hash(hash['tax1097Btc']) if hash['tax1097Btc'] tax1098 = Form10981.from_hash(hash['tax1098']) if hash['tax1098'] tax1098_c = Form1098C1.from_hash(hash['tax1098C']) if hash['tax1098C'] tax1098_e = Form1098E1.from_hash(hash['tax1098E']) if hash['tax1098E'] tax1098_ma = Form1098Ma1.from_hash(hash['tax1098Ma']) if hash['tax1098Ma'] tax1098_q = Form1098Q1.from_hash(hash['tax1098Q']) if hash['tax1098Q'] tax1098_t = Form1098T1.from_hash(hash['tax1098T']) if hash['tax1098T'] tax1098_vli = Form1098Vli1.from_hash(hash['tax1098Vli']) if hash['tax1098Vli'] tax1099_a = Form1099A1.from_hash(hash['tax1099A']) if hash['tax1099A'] tax1099_b = Form1099B1.from_hash(hash['tax1099B']) if hash['tax1099B'] tax1099_c = Form1099C1.from_hash(hash['tax1099C']) if hash['tax1099C'] tax1099_cap = Form1099Cap1.from_hash(hash['tax1099Cap']) if hash['tax1099Cap'] if hash['tax1099ConsolidatedStatement'] tax1099_consolidated_statement = Form1099ConsolidatedStatement1.from_hash(hash['tax1099ConsolidatedStatement']) end tax1099_da = Form1099Da1.from_hash(hash['tax1099Da']) if hash['tax1099Da'] tax1099_div = Form1099Div1.from_hash(hash['tax1099Div']) if hash['tax1099Div'] tax1099_g = Form1099G1.from_hash(hash['tax1099G']) if hash['tax1099G'] tax1099_h = Form1099H1.from_hash(hash['tax1099H']) if hash['tax1099H'] tax1099_int = Form1099Int1.from_hash(hash['tax1099Int']) if hash['tax1099Int'] tax1099_k = Form1099K1.from_hash(hash['tax1099K']) if hash['tax1099K'] tax1099_lps = Form1099Lps1.from_hash(hash['tax1099Lps']) if hash['tax1099Lps'] tax1099_ls = Form1099Ls1.from_hash(hash['tax1099Ls']) if hash['tax1099Ls'] tax1099_ltc = Form1099Ltc1.from_hash(hash['tax1099Ltc']) if hash['tax1099Ltc'] tax1099_misc = Form1099Misc1.from_hash(hash['tax1099Misc']) if hash['tax1099Misc'] tax1099_nec = Form1099Nec1.from_hash(hash['tax1099Nec']) if hash['tax1099Nec'] tax1099_oid = Form1099Oid1.from_hash(hash['tax1099Oid']) if hash['tax1099Oid'] tax1099_patr = Form1099Patr1.from_hash(hash['tax1099Patr']) if hash['tax1099Patr'] tax1099_q = Form1099Q1.from_hash(hash['tax1099Q']) if hash['tax1099Q'] tax1099_qa = Form1099Qa1.from_hash(hash['tax1099Qa']) if hash['tax1099Qa'] tax1099_r = Form1099R1.from_hash(hash['tax1099R']) if hash['tax1099R'] tax1099_s = Form1099S1.from_hash(hash['tax1099S']) if hash['tax1099S'] tax1099_sa = Form1099Sa1.from_hash(hash['tax1099Sa']) if hash['tax1099Sa'] tax1099_sb = Form1099Sb1.from_hash(hash['tax1099Sb']) if hash['tax1099Sb'] tax1120_sk1 = Form1120SScheduleK11.from_hash(hash['tax1120SK1']) if hash['tax1120SK1'] tax2439 = Form24391.from_hash(hash['tax2439']) if hash['tax2439'] tax3921 = Form39211.from_hash(hash['tax3921']) if hash['tax3921'] tax3922 = Form39221.from_hash(hash['tax3922']) if hash['tax3922'] tax5227_k1 = Form1041ScheduleK1.from_hash(hash['tax5227K1']) if hash['tax5227K1'] tax5498 = Form54981.from_hash(hash['tax5498']) if hash['tax5498'] tax5498_esa = Form5498Esa1.from_hash(hash['tax5498Esa']) if hash['tax5498Esa'] tax5498_qa = Form5498Qa1.from_hash(hash['tax5498Qa']) if hash['tax5498Qa'] tax5498_sa = Form5498Sa1.from_hash(hash['tax5498Sa']) if hash['tax5498Sa'] tax5498_ta = Form5498Ta1.from_hash(hash['tax5498Ta']) if hash['tax5498Ta'] tax_w2 = FormW24.from_hash(hash['taxW2']) if hash['taxW2'] tax_w2_c = FormW2C2.from_hash(hash['taxW2C']) if hash['taxW2C'] tax_w2_g = FormW2G2.from_hash(hash['taxW2G']) if hash['taxW2G'] if hash['taxRefundDirectDeposit'] tax_refund_direct_deposit = TaxRefundDirectDeposit2.from_hash(hash['taxRefundDirectDeposit']) end version = hash.key?('version') ? hash['version'] : SKIP software_id = hash.key?('softwareId') ? hash['softwareId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxDataForQr.new(business_income_statement: business_income_statement, cryptocurrency_tax_statement: cryptocurrency_tax_statement, farm_income_statement: farm_income_statement, farm_rental_income_statement: farm_rental_income_statement, rental_income_statement: rental_income_statement, royalty_income_statement: royalty_income_statement, tax1041_k1: tax1041_k1, tax1042_s: tax1042_s, tax1065_k1: tax1065_k1, tax1065_k3: tax1065_k3, tax1095_a: tax1095_a, tax1095_b: tax1095_b, tax1095_c: tax1095_c, tax1097_btc: tax1097_btc, tax1098: tax1098, tax1098_c: tax1098_c, tax1098_e: tax1098_e, tax1098_ma: tax1098_ma, tax1098_q: tax1098_q, tax1098_t: tax1098_t, tax1098_vli: tax1098_vli, tax1099_a: tax1099_a, tax1099_b: tax1099_b, tax1099_c: tax1099_c, tax1099_cap: tax1099_cap, tax1099_consolidated_statement: tax1099_consolidated_statement, tax1099_da: tax1099_da, tax1099_div: tax1099_div, tax1099_g: tax1099_g, tax1099_h: tax1099_h, tax1099_int: tax1099_int, tax1099_k: tax1099_k, tax1099_lps: tax1099_lps, tax1099_ls: tax1099_ls, tax1099_ltc: tax1099_ltc, tax1099_misc: tax1099_misc, tax1099_nec: tax1099_nec, tax1099_oid: tax1099_oid, tax1099_patr: tax1099_patr, tax1099_q: tax1099_q, tax1099_qa: tax1099_qa, tax1099_r: tax1099_r, tax1099_s: tax1099_s, tax1099_sa: tax1099_sa, tax1099_sb: tax1099_sb, tax1120_sk1: tax1120_sk1, tax2439: tax2439, tax3921: tax3921, tax3922: tax3922, tax5227_k1: tax5227_k1, tax5498: tax5498, tax5498_esa: tax5498_esa, tax5498_qa: tax5498_qa, tax5498_sa: tax5498_sa, tax5498_ta: tax5498_ta, tax_w2: tax_w2, tax_w2_c: tax_w2_c, tax_w2_g: tax_w2_g, tax_refund_direct_deposit: tax_refund_direct_deposit, version: version, software_id: software_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 261 def self.names @_hash = {} if @_hash.nil? @_hash['business_income_statement'] = 'businessIncomeStatement' @_hash['cryptocurrency_tax_statement'] = 'cryptocurrencyTaxStatement' @_hash['farm_income_statement'] = 'farmIncomeStatement' @_hash['farm_rental_income_statement'] = 'farmRentalIncomeStatement' @_hash['rental_income_statement'] = 'rentalIncomeStatement' @_hash['royalty_income_statement'] = 'royaltyIncomeStatement' @_hash['tax1041_k1'] = 'tax1041K1' @_hash['tax1042_s'] = 'tax1042S' @_hash['tax1065_k1'] = 'tax1065K1' @_hash['tax1065_k3'] = 'tax1065K3' @_hash['tax1095_a'] = 'tax1095A' @_hash['tax1095_b'] = 'tax1095B' @_hash['tax1095_c'] = 'tax1095C' @_hash['tax1097_btc'] = 'tax1097Btc' @_hash['tax1098'] = 'tax1098' @_hash['tax1098_c'] = 'tax1098C' @_hash['tax1098_e'] = 'tax1098E' @_hash['tax1098_ma'] = 'tax1098Ma' @_hash['tax1098_q'] = 'tax1098Q' @_hash['tax1098_t'] = 'tax1098T' @_hash['tax1098_vli'] = 'tax1098Vli' @_hash['tax1099_a'] = 'tax1099A' @_hash['tax1099_b'] = 'tax1099B' @_hash['tax1099_c'] = 'tax1099C' @_hash['tax1099_cap'] = 'tax1099Cap' @_hash['tax1099_consolidated_statement'] = 'tax1099ConsolidatedStatement' @_hash['tax1099_da'] = 'tax1099Da' @_hash['tax1099_div'] = 'tax1099Div' @_hash['tax1099_g'] = 'tax1099G' @_hash['tax1099_h'] = 'tax1099H' @_hash['tax1099_int'] = 'tax1099Int' @_hash['tax1099_k'] = 'tax1099K' @_hash['tax1099_lps'] = 'tax1099Lps' @_hash['tax1099_ls'] = 'tax1099Ls' @_hash['tax1099_ltc'] = 'tax1099Ltc' @_hash['tax1099_misc'] = 'tax1099Misc' @_hash['tax1099_nec'] = 'tax1099Nec' @_hash['tax1099_oid'] = 'tax1099Oid' @_hash['tax1099_patr'] = 'tax1099Patr' @_hash['tax1099_q'] = 'tax1099Q' @_hash['tax1099_qa'] = 'tax1099Qa' @_hash['tax1099_r'] = 'tax1099R' @_hash['tax1099_s'] = 'tax1099S' @_hash['tax1099_sa'] = 'tax1099Sa' @_hash['tax1099_sb'] = 'tax1099Sb' @_hash['tax1120_sk1'] = 'tax1120SK1' @_hash['tax2439'] = 'tax2439' @_hash['tax3921'] = 'tax3921' @_hash['tax3922'] = 'tax3922' @_hash['tax5227_k1'] = 'tax5227K1' @_hash['tax5498'] = 'tax5498' @_hash['tax5498_esa'] = 'tax5498Esa' @_hash['tax5498_qa'] = 'tax5498Qa' @_hash['tax5498_sa'] = 'tax5498Sa' @_hash['tax5498_ta'] = 'tax5498Ta' @_hash['tax_w2'] = 'taxW2' @_hash['tax_w2_c'] = 'taxW2C' @_hash['tax_w2_g'] = 'taxW2G' @_hash['tax_refund_direct_deposit'] = 'taxRefundDirectDeposit' @_hash['version'] = 'version' @_hash['software_id'] = 'softwareId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
396 397 398 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 396 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 329 def self.optionals %w[ business_income_statement cryptocurrency_tax_statement farm_income_statement farm_rental_income_statement rental_income_statement royalty_income_statement tax1041_k1 tax1042_s tax1065_k1 tax1065_k3 tax1095_a tax1095_b tax1095_c tax1097_btc tax1098 tax1098_c tax1098_e tax1098_ma tax1098_q tax1098_t tax1098_vli tax1099_a tax1099_b tax1099_c tax1099_cap tax1099_consolidated_statement tax1099_da tax1099_div tax1099_g tax1099_h tax1099_int tax1099_k tax1099_lps tax1099_ls tax1099_ltc tax1099_misc tax1099_nec tax1099_oid tax1099_patr tax1099_q tax1099_qa tax1099_r tax1099_s tax1099_sa tax1099_sb tax1120_sk1 tax2439 tax3921 tax3922 tax5227_k1 tax5498 tax5498_esa tax5498_qa tax5498_sa tax5498_ta tax_w2 tax_w2_c tax_w2_g tax_refund_direct_deposit version software_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 689 def inspect class_name = self.class.name.split('::').last "<#{class_name} business_income_statement: #{@business_income_statement.inspect},"\ " cryptocurrency_tax_statement: #{@cryptocurrency_tax_statement.inspect},"\ " farm_income_statement: #{@farm_income_statement.inspect}, farm_rental_income_statement:"\ " #{@farm_rental_income_statement.inspect}, rental_income_statement:"\ " #{@rental_income_statement.inspect}, royalty_income_statement:"\ " #{@royalty_income_statement.inspect}, tax1041_k1: #{@tax1041_k1.inspect}, tax1042_s:"\ " #{@tax1042_s.inspect}, tax1065_k1: #{@tax1065_k1.inspect}, tax1065_k3:"\ " #{@tax1065_k3.inspect}, tax1095_a: #{@tax1095_a.inspect}, tax1095_b:"\ " #{@tax1095_b.inspect}, tax1095_c: #{@tax1095_c.inspect}, tax1097_btc:"\ " #{@tax1097_btc.inspect}, tax1098: #{@tax1098.inspect}, tax1098_c: #{@tax1098_c.inspect},"\ " tax1098_e: #{@tax1098_e.inspect}, tax1098_ma: #{@tax1098_ma.inspect}, tax1098_q:"\ " #{@tax1098_q.inspect}, tax1098_t: #{@tax1098_t.inspect}, tax1098_vli:"\ " #{@tax1098_vli.inspect}, tax1099_a: #{@tax1099_a.inspect}, tax1099_b:"\ " #{@tax1099_b.inspect}, tax1099_c: #{@tax1099_c.inspect}, tax1099_cap:"\ " #{@tax1099_cap.inspect}, tax1099_consolidated_statement:"\ " #{@tax1099_consolidated_statement.inspect}, tax1099_da: #{@tax1099_da.inspect},"\ " tax1099_div: #{@tax1099_div.inspect}, tax1099_g: #{@tax1099_g.inspect}, tax1099_h:"\ " #{@tax1099_h.inspect}, tax1099_int: #{@tax1099_int.inspect}, tax1099_k:"\ " #{@tax1099_k.inspect}, tax1099_lps: #{@tax1099_lps.inspect}, tax1099_ls:"\ " #{@tax1099_ls.inspect}, tax1099_ltc: #{@tax1099_ltc.inspect}, tax1099_misc:"\ " #{@tax1099_misc.inspect}, tax1099_nec: #{@tax1099_nec.inspect}, tax1099_oid:"\ " #{@tax1099_oid.inspect}, tax1099_patr: #{@tax1099_patr.inspect}, tax1099_q:"\ " #{@tax1099_q.inspect}, tax1099_qa: #{@tax1099_qa.inspect}, tax1099_r:"\ " #{@tax1099_r.inspect}, tax1099_s: #{@tax1099_s.inspect}, tax1099_sa:"\ " #{@tax1099_sa.inspect}, tax1099_sb: #{@tax1099_sb.inspect}, tax1120_sk1:"\ " #{@tax1120_sk1.inspect}, tax2439: #{@tax2439.inspect}, tax3921: #{@tax3921.inspect},"\ " tax3922: #{@tax3922.inspect}, tax5227_k1: #{@tax5227_k1.inspect}, tax5498:"\ " #{@tax5498.inspect}, tax5498_esa: #{@tax5498_esa.inspect}, tax5498_qa:"\ " #{@tax5498_qa.inspect}, tax5498_sa: #{@tax5498_sa.inspect}, tax5498_ta:"\ " #{@tax5498_ta.inspect}, tax_w2: #{@tax_w2.inspect}, tax_w2_c: #{@tax_w2_c.inspect},"\ " tax_w2_g: #{@tax_w2_g.inspect}, tax_refund_direct_deposit:"\ " #{@tax_refund_direct_deposit.inspect}, version: #{@version.inspect}, software_id:"\ " #{@software_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/fdx_v660_api/models/tax_data_for_qr.rb', line 660 def to_s class_name = self.class.name.split('::').last "<#{class_name} business_income_statement: #{@business_income_statement},"\ " cryptocurrency_tax_statement: #{@cryptocurrency_tax_statement}, farm_income_statement:"\ " #{@farm_income_statement}, farm_rental_income_statement: #{@farm_rental_income_statement},"\ " rental_income_statement: #{@rental_income_statement}, royalty_income_statement:"\ " #{@royalty_income_statement}, tax1041_k1: #{@tax1041_k1}, tax1042_s: #{@tax1042_s},"\ " tax1065_k1: #{@tax1065_k1}, tax1065_k3: #{@tax1065_k3}, tax1095_a: #{@tax1095_a},"\ " tax1095_b: #{@tax1095_b}, tax1095_c: #{@tax1095_c}, tax1097_btc: #{@tax1097_btc}, tax1098:"\ " #{@tax1098}, tax1098_c: #{@tax1098_c}, tax1098_e: #{@tax1098_e}, tax1098_ma:"\ " #{@tax1098_ma}, tax1098_q: #{@tax1098_q}, tax1098_t: #{@tax1098_t}, tax1098_vli:"\ " #{@tax1098_vli}, tax1099_a: #{@tax1099_a}, tax1099_b: #{@tax1099_b}, tax1099_c:"\ " #{@tax1099_c}, tax1099_cap: #{@tax1099_cap}, tax1099_consolidated_statement:"\ " #{@tax1099_consolidated_statement}, tax1099_da: #{@tax1099_da}, tax1099_div:"\ " #{@tax1099_div}, tax1099_g: #{@tax1099_g}, tax1099_h: #{@tax1099_h}, tax1099_int:"\ " #{@tax1099_int}, tax1099_k: #{@tax1099_k}, tax1099_lps: #{@tax1099_lps}, tax1099_ls:"\ " #{@tax1099_ls}, tax1099_ltc: #{@tax1099_ltc}, tax1099_misc: #{@tax1099_misc}, tax1099_nec:"\ " #{@tax1099_nec}, tax1099_oid: #{@tax1099_oid}, tax1099_patr: #{@tax1099_patr}, tax1099_q:"\ " #{@tax1099_q}, tax1099_qa: #{@tax1099_qa}, tax1099_r: #{@tax1099_r}, tax1099_s:"\ " #{@tax1099_s}, tax1099_sa: #{@tax1099_sa}, tax1099_sb: #{@tax1099_sb}, tax1120_sk1:"\ " #{@tax1120_sk1}, tax2439: #{@tax2439}, tax3921: #{@tax3921}, tax3922: #{@tax3922},"\ " tax5227_k1: #{@tax5227_k1}, tax5498: #{@tax5498}, tax5498_esa: #{@tax5498_esa},"\ " tax5498_qa: #{@tax5498_qa}, tax5498_sa: #{@tax5498_sa}, tax5498_ta: #{@tax5498_ta},"\ " tax_w2: #{@tax_w2}, tax_w2_c: #{@tax_w2_c}, tax_w2_g: #{@tax_w2_g},"\ " tax_refund_direct_deposit: #{@tax_refund_direct_deposit}, version: #{@version},"\ " software_id: #{@software_id}, additional_properties: #{@additional_properties}>" end |