Class: FdxV660Api::TaxFormAddress3
- Defined in:
- lib/fdx_v660_api/models/tax_form_address3.rb
Overview
Box 8, Address of property securing mortgage
Instance Attribute Summary collapse
-
#city ⇒ String
City.
-
#country ⇒ Iso3166CountryCode1
Country code.
-
#line1 ⇒ String
Address line 1.
-
#line2 ⇒ String
Address line 2.
-
#line3 ⇒ String
Address line 3.
-
#postal_code ⇒ String
Postal code.
-
#region ⇒ String
State, Province, Territory, Canton or Prefecture.
-
#unit_number ⇒ String
The number component of the address location's unit, can contain letters as appropriate.
-
#unit_type ⇒ String
Text name for type of unit, such as Suite, Apt./Apartment, Room, Floor, or Dept./Department.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, unit_type: SKIP, unit_number: SKIP, additional_properties: nil) ⇒ TaxFormAddress3
constructor
A new instance of TaxFormAddress3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, unit_type: SKIP, unit_number: SKIP, additional_properties: nil) ⇒ TaxFormAddress3
Returns a new instance of TaxFormAddress3.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 93 def initialize(line1: SKIP, line2: SKIP, line3: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, unit_type: SKIP, unit_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @line1 = line1 unless line1 == SKIP @line2 = line2 unless line2 == SKIP @line3 = line3 unless line3 == SKIP @city = city unless city == SKIP @region = region unless region == SKIP @postal_code = postal_code unless postal_code == SKIP @country = country unless country == SKIP @unit_type = unit_type unless unit_type == SKIP @unit_number = unit_number unless unit_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
City
26 27 28 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 26 def city @city end |
#country ⇒ Iso3166CountryCode1
Country code
45 46 47 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 45 def country @country end |
#line1 ⇒ String
Address line 1
14 15 16 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 14 def line1 @line1 end |
#line2 ⇒ String
Address line 2
18 19 20 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 18 def line2 @line2 end |
#line3 ⇒ String
Address line 3
22 23 24 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 22 def line3 @line3 end |
#postal_code ⇒ String
Postal code
41 42 43 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 41 def postal_code @postal_code end |
#region ⇒ String
State, Province, Territory, Canton or Prefecture. From [Universal Postal
Union](https://www.upu.int/en/Postal-Solutions/Programmes-Services/Address
ing-Solutions#addressing-s42-standard) as of 2-26-2020, [S42 International
Address
Standards](https://www.upu.int/UPU/media/upu/documents/PostCode/S42_Intern
ational-Addressing-Standards.pdf). For U.S. addresses can be a 2-character
code from StateCode. For Canadian addresses can be a 2-character code
from ProvinceTerritoryCode
37 38 39 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 37 def region @region end |
#unit_number ⇒ String
The number component of the address location's unit, can contain letters as appropriate
56 57 58 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 56 def unit_number @unit_number end |
#unit_type ⇒ String
Text name for type of unit, such as Suite, Apt./Apartment, Room, Floor, or Dept./Department. Does not appear on tax forms, for use in creating a postal address from a tax form recipient address
51 52 53 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 51 def unit_type @unit_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 113 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. line1 = hash.key?('line1') ? hash['line1'] : SKIP line2 = hash.key?('line2') ? hash['line2'] : SKIP line3 = hash.key?('line3') ? hash['line3'] : SKIP city = hash.key?('city') ? hash['city'] : SKIP region = hash.key?('region') ? hash['region'] : SKIP postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP unit_type = hash.key?('unitType') ? hash['unitType'] : SKIP unit_number = hash.key?('unitNumber') ? hash['unitNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxFormAddress3.new(line1: line1, line2: line2, line3: line3, city: city, region: region, postal_code: postal_code, country: country, unit_type: unit_type, unit_number: unit_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 59 def self.names @_hash = {} if @_hash.nil? @_hash['line1'] = 'line1' @_hash['line2'] = 'line2' @_hash['line3'] = 'line3' @_hash['city'] = 'city' @_hash['region'] = 'region' @_hash['postal_code'] = 'postalCode' @_hash['country'] = 'country' @_hash['unit_type'] = 'unitType' @_hash['unit_number'] = 'unitNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
89 90 91 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 89 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 74 def self.optionals %w[ line1 line2 line3 city region postal_code country unit_type unit_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
157 158 159 160 161 162 163 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 157 def inspect class_name = self.class.name.split('::').last "<#{class_name} line1: #{@line1.inspect}, line2: #{@line2.inspect}, line3:"\ " #{@line3.inspect}, city: #{@city.inspect}, region: #{@region.inspect}, postal_code:"\ " #{@postal_code.inspect}, country: #{@country.inspect}, unit_type: #{@unit_type.inspect},"\ " unit_number: #{@unit_number.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
148 149 150 151 152 153 154 |
# File 'lib/fdx_v660_api/models/tax_form_address3.rb', line 148 def to_s class_name = self.class.name.split('::').last "<#{class_name} line1: #{@line1}, line2: #{@line2}, line3: #{@line3}, city: #{@city},"\ " region: #{@region}, postal_code: #{@postal_code}, country: #{@country}, unit_type:"\ " #{@unit_type}, unit_number: #{@unit_number}, additional_properties:"\ " #{@additional_properties}>" end |