Class: FdxV660Api::TaxRefundDirectDeposit
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::TaxRefundDirectDeposit
- Defined in:
- lib/fdx_v660_api/models/tax_refund_direct_deposit.rb
Overview
IRS Form 8888 Direct Deposit Information
Instance Attribute Summary collapse
-
#account_nick_name ⇒ String
Account nickname.
-
#account_number ⇒ String
Account number.
-
#institution_name ⇒ String
Name of institution.
-
#rtn ⇒ String
Routing transit number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(institution_name: SKIP, rtn: SKIP, account_number: SKIP, account_nick_name: SKIP, additional_properties: nil) ⇒ TaxRefundDirectDeposit
constructor
A new instance of TaxRefundDirectDeposit.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(institution_name: SKIP, rtn: SKIP, account_number: SKIP, account_nick_name: SKIP, additional_properties: nil) ⇒ TaxRefundDirectDeposit
Returns a new instance of TaxRefundDirectDeposit.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 53 def initialize(institution_name: SKIP, rtn: SKIP, account_number: SKIP, account_nick_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @institution_name = institution_name unless institution_name == SKIP @rtn = rtn unless rtn == SKIP @account_number = account_number unless account_number == SKIP @account_nick_name = account_nick_name unless account_nick_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_nick_name ⇒ String
Account nickname
26 27 28 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 26 def account_nick_name @account_nick_name end |
#account_number ⇒ String
Account number
22 23 24 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 22 def account_number @account_number end |
#institution_name ⇒ String
Name of institution
14 15 16 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 14 def institution_name @institution_name end |
#rtn ⇒ String
Routing transit number
18 19 20 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 18 def rtn @rtn end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. institution_name = hash.key?('institutionName') ? hash['institutionName'] : SKIP rtn = hash.key?('rtn') ? hash['rtn'] : SKIP account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP account_nick_name = hash.key?('accountNickName') ? hash['accountNickName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxRefundDirectDeposit.new(institution_name: institution_name, rtn: rtn, account_number: account_number, account_nick_name: account_nick_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['institution_name'] = 'institutionName' @_hash['rtn'] = 'rtn' @_hash['account_number'] = 'accountNumber' @_hash['account_nick_name'] = 'accountNickName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 39 def self.optionals %w[ institution_name rtn account_number account_nick_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} institution_name: #{@institution_name.inspect}, rtn: #{@rtn.inspect},"\ " account_number: #{@account_number.inspect}, account_nick_name:"\ " #{@account_nick_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} institution_name: #{@institution_name}, rtn: #{@rtn}, account_number:"\ " #{@account_number}, account_nick_name: #{@account_nick_name}, additional_properties:"\ " #{@additional_properties}>" end |