Class: FdxV660Api::TaxRefundDirectDeposit2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb

Overview

Tax refund direct deposit information

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(institution_name: SKIP, rtn: SKIP, account_number: SKIP, account_nick_name: SKIP, additional_properties: nil) ⇒ TaxRefundDirectDeposit2

Returns a new instance of TaxRefundDirectDeposit2.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 53

def initialize(institution_name: SKIP, rtn: SKIP, account_number: SKIP,
               account_nick_name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @institution_name = institution_name unless institution_name == SKIP
  @rtn = rtn unless rtn == SKIP
  @account_number =  unless  == SKIP
  @account_nick_name =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_nick_nameString

Account nickname

Returns:

  • (String)


26
27
28
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 26

def 
  @account_nick_name
end

#account_numberString

Account number

Returns:

  • (String)


22
23
24
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 22

def 
  @account_number
end

#institution_nameString

Name of institution

Returns:

  • (String)


14
15
16
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 14

def institution_name
  @institution_name
end

#rtnString

Routing transit number

Returns:

  • (String)


18
19
20
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 18

def rtn
  @rtn
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  institution_name =
    hash.key?('institutionName') ? hash['institutionName'] : SKIP
  rtn = hash.key?('rtn') ? hash['rtn'] : SKIP
   = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP
   =
    hash.key?('accountNickName') ? hash['accountNickName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TaxRefundDirectDeposit2.new(institution_name: institution_name,
                              rtn: rtn,
                              account_number: ,
                              account_nick_name: ,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['institution_name'] = 'institutionName'
  @_hash['rtn'] = 'rtn'
  @_hash['account_number'] = 'accountNumber'
  @_hash['account_nick_name'] = 'accountNickName'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 39

def self.optionals
  %w[
    institution_name
    rtn
    account_number
    account_nick_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
106
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} institution_name: #{@institution_name.inspect}, rtn: #{@rtn.inspect},"\
  " account_number: #{@account_number.inspect}, account_nick_name:"\
  " #{@account_nick_name.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
98
# File 'lib/fdx_v660_api/models/tax_refund_direct_deposit2.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} institution_name: #{@institution_name}, rtn: #{@rtn}, account_number:"\
  " #{@account_number}, account_nick_name: #{@account_nick_name}, additional_properties:"\
  " #{@additional_properties}>"
end