Class: FdxV660Api::AccountContactEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::AccountContactEntity
- Defined in:
- lib/fdx_v660_api/models/account_contact_entity.rb
Overview
Contact information for the account
Instance Attribute Summary collapse
-
#addresses ⇒ Array[DeliveryAddress]
Array of the contact physical addresses.
-
#emails ⇒ Array[String]
Array of the contact email addresses.
-
#holders ⇒ Array[AccountHolderEntity]
Owners of the account.
-
#telephones ⇒ Array[TelephoneNumberPlusExtension]
Array of the contact telephone numbers, with extension if any.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(emails: SKIP, addresses: SKIP, telephones: SKIP, holders: SKIP, additional_properties: nil) ⇒ AccountContactEntity
constructor
A new instance of AccountContactEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(emails: SKIP, addresses: SKIP, telephones: SKIP, holders: SKIP, additional_properties: nil) ⇒ AccountContactEntity
Returns a new instance of AccountContactEntity.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 53 def initialize(emails: SKIP, addresses: SKIP, telephones: SKIP, holders: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @emails = emails unless emails == SKIP @addresses = addresses unless addresses == SKIP @telephones = telephones unless telephones == SKIP @holders = holders unless holders == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#addresses ⇒ Array[DeliveryAddress]
Array of the contact physical addresses
18 19 20 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 18 def addresses @addresses end |
#emails ⇒ Array[String]
Array of the contact email addresses
14 15 16 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 14 def emails @emails end |
#holders ⇒ Array[AccountHolderEntity]
Owners of the account
26 27 28 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 26 def holders @holders end |
#telephones ⇒ Array[TelephoneNumberPlusExtension]
Array of the contact telephone numbers, with extension if any
22 23 24 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 22 def telephones @telephones end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. emails = hash.key?('emails') ? hash['emails'] : SKIP # Parameter is an array, so we need to iterate through it addresses = nil unless hash['addresses'].nil? addresses = [] hash['addresses'].each do |structure| addresses << (DeliveryAddress.from_hash(structure) if structure) end end addresses = SKIP unless hash.key?('addresses') # Parameter is an array, so we need to iterate through it telephones = nil unless hash['telephones'].nil? telephones = [] hash['telephones'].each do |structure| telephones << (TelephoneNumberPlusExtension.from_hash(structure) if structure) end end telephones = SKIP unless hash.key?('telephones') # Parameter is an array, so we need to iterate through it holders = nil unless hash['holders'].nil? holders = [] hash['holders'].each do |structure| holders << (AccountHolderEntity.from_hash(structure) if structure) end end holders = SKIP unless hash.key?('holders') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountContactEntity.new(emails: emails, addresses: addresses, telephones: telephones, holders: holders, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['emails'] = 'emails' @_hash['addresses'] = 'addresses' @_hash['telephones'] = 'telephones' @_hash['holders'] = 'holders' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 39 def self.optionals %w[ emails addresses telephones holders ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
119 120 121 122 123 124 125 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 119 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
135 136 137 138 139 140 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 135 def inspect class_name = self.class.name.split('::').last "<#{class_name} emails: #{@emails.inspect}, addresses: #{@addresses.inspect}, telephones:"\ " #{@telephones.inspect}, holders: #{@holders.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
128 129 130 131 132 |
# File 'lib/fdx_v660_api/models/account_contact_entity.rb', line 128 def to_s class_name = self.class.name.split('::').last "<#{class_name} emails: #{@emails}, addresses: #{@addresses}, telephones: #{@telephones},"\ " holders: #{@holders}, additional_properties: #{@additional_properties}>" end |