Class: FdxV660Api::AccountEntity
- Inherits:
-
AccountDescriptorEntity
- Object
- CoreLibrary::BaseModel
- BaseModel
- AccountDescriptorEntity
- FdxV660Api::AccountEntity
- Defined in:
- lib/fdx_v660_api/models/account_entity.rb
Overview
An abstract account entity that concrete account entities extend
Direct Known Subclasses
AnnuityAccountEntity, BuyNowPayLaterAccountEntity, CommercialAccountEntity, DepositAccountEntity, DigitalWalletAccountEntity, InsuranceAccountEntity, InvestmentAccountEntity, LineOfCreditAccountEntity, LoanAccountEntity
Instance Attribute Summary collapse
-
#balance_type ⇒ BalanceType2
ASSET (positive transaction amount increases balance), LIABILITY (positive transaction amount decreases balance).
-
#bank_institution_id ⇒ String
The Canadian 3-digit Institution (FID) associated with the account number, including leading zeros.
-
#bank_transit_id ⇒ String
The Canadian 5-digit Transit number associated with the account number, including leading zeros.
-
#bill_pay_status ⇒ AccountBillPayStatus2
Defines account's ability to participate in bill payments.
-
#contact ⇒ AccountContactEntity
Contact information associated with this account.
-
#early_penalty_flag ⇒ TrueClass | FalseClass
Flag that indicates if there is an early penalty for withdrawal/payoff.
-
#interest_rate ⇒ Float
Interest Rate of Account Deprecated with v6.4 in favor of specific named rates on Account subtypes.
-
#interest_rate_as_of ⇒ DateTime
Date of account's interest rate Deprecated with v6.4 in favor of specific named rates on Account subtypes.
-
#interest_rate_index ⇒ String
Variable rate index name such as EONIA, EURIBOR, EURREPO, FEFUND, LIBOR, PRIME, SOFR, SONIA, etc.
-
#interest_rate_type ⇒ InterestRateType
FIXED or VARIABLE Deprecated with v6.4 in favor of specific named rates on Account subtypes.
-
#last_activity_date ⇒ Date
Date that last transaction occurred on account.
-
#line_of_business ⇒ String
The name of the line of business of this account, when type is OTHER.
-
#line_of_business_type ⇒ LineOfBusinessType2
The enumerated line of business of this account, one of COMMERCIAL, CONSUMER, SMALL_BUSINESS, OTHER.
-
#micr_number ⇒ String
Magnetic Ink Character Recognition (MICR) number for this account at the owning institution.
-
#prior_interest_rate ⇒ Float
Previous Interest Rate of Account Deprecated with v6.4 in favor of specific named rates on Account subtypes.
-
#reward_balances ⇒ Array[RewardBalanceEntity]
Array of reward balances on the account.
-
#reward_program_id ⇒ String
Long-term persistent identity of rewards program associated with this account.
-
#routing_transit_number ⇒ String
The routing transit number (RTN) associated with the account number at the owning institution.
-
#transactions_included ⇒ TrueClass | FalseClass
Default is false.
-
#transfer_in ⇒ TrueClass | FalseClass
Account is eligible for incoming transfers from accounts at the same institution.
-
#transfer_out ⇒ TrueClass | FalseClass
Account is eligible for outgoing transfers to accounts at the same institution.
Attributes inherited from AccountDescriptorEntity
#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases
Class Method Summary collapse
-
.discriminators ⇒ Object
Discriminators mapping.
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ AccountEntity
constructor
A new instance of AccountEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_interest_rate_as_of ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ AccountEntity
Returns a new instance of AccountEntity.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 209 def initialize(line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) @line_of_business = line_of_business unless line_of_business == SKIP @line_of_business_type = line_of_business_type unless line_of_business_type == SKIP @routing_transit_number = routing_transit_number unless routing_transit_number == SKIP @balance_type = balance_type unless balance_type == SKIP @contact = contact unless contact == SKIP @interest_rate = interest_rate unless interest_rate == SKIP @interest_rate_type = interest_rate_type unless interest_rate_type == SKIP @interest_rate_as_of = interest_rate_as_of unless interest_rate_as_of == SKIP @prior_interest_rate = prior_interest_rate unless prior_interest_rate == SKIP @interest_rate_index = interest_rate_index unless interest_rate_index == SKIP @early_penalty_flag = early_penalty_flag unless early_penalty_flag == SKIP @transfer_in = transfer_in unless transfer_in == SKIP @transfer_out = transfer_out unless transfer_out == SKIP @bill_pay_status = bill_pay_status unless bill_pay_status == SKIP @micr_number = micr_number unless micr_number == SKIP @last_activity_date = last_activity_date unless last_activity_date == SKIP @reward_program_id = reward_program_id unless reward_program_id == SKIP @reward_balances = reward_balances unless reward_balances == SKIP @transactions_included = transactions_included unless transactions_included == SKIP @bank_institution_id = bank_institution_id unless bank_institution_id == SKIP @bank_transit_id = bank_transit_id unless bank_transit_id == SKIP @additional_properties = additional_properties # Call the constructor of the base class super(account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
Instance Attribute Details
#balance_type ⇒ BalanceType2
ASSET (positive transaction amount increases balance), LIABILITY (positive transaction amount decreases balance)
35 36 37 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 35 def balance_type @balance_type end |
#bank_institution_id ⇒ String
The Canadian 3-digit Institution (FID) associated with the account number, including leading zeros
123 124 125 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 123 def bank_institution_id @bank_institution_id end |
#bank_transit_id ⇒ String
The Canadian 5-digit Transit number associated with the account number, including leading zeros
128 129 130 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 128 def bank_transit_id @bank_transit_id end |
#bill_pay_status ⇒ AccountBillPayStatus2
Defines account's ability to participate in bill payments
85 86 87 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 85 def bill_pay_status @bill_pay_status end |
#contact ⇒ AccountContactEntity
Contact information associated with this account. Deprecated in release V6.3.1 and will be removed in next major release. Provider should return contact in the getAccountContact operation
41 42 43 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 41 def contact @contact end |
#early_penalty_flag ⇒ TrueClass | FalseClass
Flag that indicates if there is an early penalty for withdrawal/payoff
71 72 73 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 71 def early_penalty_flag @early_penalty_flag end |
#interest_rate ⇒ Float
Interest Rate of Account Deprecated with v6.4 in favor of specific named rates on Account subtypes
46 47 48 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 46 def interest_rate @interest_rate end |
#interest_rate_as_of ⇒ DateTime
Date of account's interest rate Deprecated with v6.4 in favor of specific named rates on Account subtypes
56 57 58 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 56 def interest_rate_as_of @interest_rate_as_of end |
#interest_rate_index ⇒ String
Variable rate index name such as EONIA, EURIBOR, EURREPO, FEFUND, LIBOR, PRIME, SOFR, SONIA, etc. Deprecated with v6.4 in favor of specific named rates on Account subtypes
67 68 69 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 67 def interest_rate_index @interest_rate_index end |
#interest_rate_type ⇒ InterestRateType
FIXED or VARIABLE Deprecated with v6.4 in favor of specific named rates on Account subtypes
51 52 53 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 51 def interest_rate_type @interest_rate_type end |
#last_activity_date ⇒ Date
Date that last transaction occurred on account
102 103 104 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 102 def last_activity_date @last_activity_date end |
#line_of_business ⇒ String
The name of the line of business of this account, when type is OTHER
14 15 16 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 14 def line_of_business @line_of_business end |
#line_of_business_type ⇒ LineOfBusinessType2
The enumerated line of business of this account, one of COMMERCIAL,
CONSUMER, SMALL_BUSINESS, OTHER. For type OTHER, add your other line of
business name in property lineOfBusiness
20 21 22 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 20 def line_of_business_type @line_of_business_type end |
#micr_number ⇒ String
Magnetic Ink Character Recognition (MICR) number for this account at the owning institution. Typically printed on the bottom of checks in two of three parts as
- Routing number: First on the left, the nine-character number identifies the financial institution;
- Account number: In the middle, an account number linked to the specific customer account;
- Check number: The four-character check number on the right (omitted here at the account level). This is sensitive data which should only be exchanged if encrypted
98 99 100 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 98 def micr_number @micr_number end |
#prior_interest_rate ⇒ Float
Previous Interest Rate of Account Deprecated with v6.4 in favor of specific named rates on Account subtypes
61 62 63 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 61 def prior_interest_rate @prior_interest_rate end |
#reward_balances ⇒ Array[RewardBalanceEntity]
Array of reward balances on the account
111 112 113 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 111 def reward_balances @reward_balances end |
#reward_program_id ⇒ String
Long-term persistent identity of rewards program associated with this account
107 108 109 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 107 def reward_program_id @reward_program_id end |
#routing_transit_number ⇒ String
The routing transit number (RTN) associated with the account number at the
owning institution. FDX v6.3 adds separate bankInstitutionId and
bankTransitId properties and deprecates the prior approach to use this
field for concatenated Canadian institution IDs. Deprecated with FDX v6.4,
instead return through the getAccountPaymentNetworks operation as
bankId for U.S. institutions or bankInstitutionId and bankTransitId
for Canadian institutions
30 31 32 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 30 def routing_transit_number @routing_transit_number end |
#transactions_included ⇒ TrueClass | FalseClass
Default is false. The transactions field on each Account type was
deprecated in release V6.3.1 and will be removed in next major release.
Transactions are returned in the searchForAccountTransactions operation
response
118 119 120 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 118 def transactions_included @transactions_included end |
#transfer_in ⇒ TrueClass | FalseClass
Account is eligible for incoming transfers from accounts at the same institution
76 77 78 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 76 def transfer_in @transfer_in end |
#transfer_out ⇒ TrueClass | FalseClass
Account is eligible for outgoing transfers to accounts at the same institution
81 82 83 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 81 def transfer_out @transfer_out end |
Class Method Details
.discriminators ⇒ Object
Discriminators mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 131 def self.discriminators if @_discriminators.nil? @_discriminators = {} @_discriminators['Annuity Account entity'] = AnnuityAccountEntity @_discriminators['Buy Now Pay Later Account entity'] = BuyNowPayLaterAccountEntity @_discriminators['Commercial Account entity'] = CommercialAccountEntity @_discriminators['Deposit Account entity'] = DepositAccountEntity @_discriminators['Digital Wallet account entity'] = DigitalWalletAccountEntity @_discriminators['Insurance Account entity'] = InsuranceAccountEntity @_discriminators['Investment Account entity'] = InvestmentAccountEntity @_discriminators['Line of Credit Account entity'] = LineOfCreditAccountEntity @_discriminators['Loan Account entity'] = LoanAccountEntity end @_discriminators end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 275 def self.from_hash(hash) return nil unless hash # Delegate unboxing to another function if a discriminator # value for a child class is present. unboxer = discriminators[hash['accountCategory']] return unboxer.send(:from_hash, hash) if unboxer # Extract variables from the hash. line_of_business = hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP line_of_business_type = hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP routing_transit_number = hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact'] interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP interest_rate_type = hash.key?('interestRateType') ? hash['interestRateType'] : SKIP interest_rate_as_of = if hash.key?('interestRateAsOf') (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf']) else SKIP end prior_interest_rate = hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP interest_rate_index = hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP early_penalty_flag = hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP bill_pay_status = hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP last_activity_date = hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP reward_program_id = hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP # Parameter is an array, so we need to iterate through it reward_balances = nil unless hash['rewardBalances'].nil? reward_balances = [] hash['rewardBalances'].each do |structure| reward_balances << (RewardBalanceEntity.from_hash(structure) if structure) end end reward_balances = SKIP unless hash.key?('rewardBalances') transactions_included = hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP bank_institution_id = hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP bank_transit_id = hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP account_category = hash['accountCategory'] ||= 'Account entity' account_id = hash.key?('accountId') ? hash['accountId'] : SKIP parent_account_id = hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP error = Error3.from_hash(hash['error']) if hash['error'] account_type = hash.key?('accountType') ? hash['accountType'] : SKIP domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile'] account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP account_number_display = hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP product_id = hash.key?('productId') ? hash['productId'] : SKIP product_name = hash.key?('productName') ? hash['productName'] : SKIP nickname = hash.key?('nickname') ? hash['nickname'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP account_open_date = hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP account_close_date = hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency'] data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP transfer_out_use_cases = hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP # Parameter is an array, so we need to iterate through it fi_attributes = nil unless hash['fiAttributes'].nil? fi_attributes = [] hash['fiAttributes'].each do |structure| fi_attributes << (FiAttributeEntity.from_hash(structure) if structure) end end fi_attributes = SKIP unless hash.key?('fiAttributes') # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountEntity.new(line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 148 def self.names @_hash = {} if @_hash.nil? @_hash['line_of_business'] = 'lineOfBusiness' @_hash['line_of_business_type'] = 'lineOfBusinessType' @_hash['routing_transit_number'] = 'routingTransitNumber' @_hash['balance_type'] = 'balanceType' @_hash['contact'] = 'contact' @_hash['interest_rate'] = 'interestRate' @_hash['interest_rate_type'] = 'interestRateType' @_hash['interest_rate_as_of'] = 'interestRateAsOf' @_hash['prior_interest_rate'] = 'priorInterestRate' @_hash['interest_rate_index'] = 'interestRateIndex' @_hash['early_penalty_flag'] = 'earlyPenaltyFlag' @_hash['transfer_in'] = 'transferIn' @_hash['transfer_out'] = 'transferOut' @_hash['bill_pay_status'] = 'billPayStatus' @_hash['micr_number'] = 'micrNumber' @_hash['last_activity_date'] = 'lastActivityDate' @_hash['reward_program_id'] = 'rewardProgramId' @_hash['reward_balances'] = 'rewardBalances' @_hash['transactions_included'] = 'transactionsIncluded' @_hash['bank_institution_id'] = 'bankInstitutionId' @_hash['bank_transit_id'] = 'bankTransitId' @_hash = super().merge(@_hash) @_hash end |
.nullables ⇒ Object
An array for nullable fields
204 205 206 207 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 204 def self.nullables _arr = [] (_arr << super()).flatten! end |
.optionals ⇒ Object
An array for optional fields
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 176 def self.optionals _arr = %w[ line_of_business line_of_business_type routing_transit_number balance_type contact interest_rate interest_rate_type interest_rate_as_of prior_interest_rate interest_rate_index early_penalty_flag transfer_in transfer_out bill_pay_status micr_number last_activity_date reward_program_id reward_balances transactions_included bank_institution_id bank_transit_id ] (_arr << super()).flatten! end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 449 def inspect class_name = self.class.name.split('::').last super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, line_of_business: #{@line_of_business.inspect},"\ " line_of_business_type: #{@line_of_business_type.inspect}, routing_transit_number:"\ " #{@routing_transit_number.inspect}, balance_type: #{@balance_type.inspect}, contact:"\ " #{@contact.inspect}, interest_rate: #{@interest_rate.inspect}, interest_rate_type:"\ " #{@interest_rate_type.inspect}, interest_rate_as_of: #{@interest_rate_as_of.inspect},"\ " prior_interest_rate: #{@prior_interest_rate.inspect}, interest_rate_index:"\ " #{@interest_rate_index.inspect}, early_penalty_flag: #{@early_penalty_flag.inspect},"\ " transfer_in: #{@transfer_in.inspect}, transfer_out: #{@transfer_out.inspect},"\ " bill_pay_status: #{@bill_pay_status.inspect}, micr_number: #{@micr_number.inspect},"\ " last_activity_date: #{@last_activity_date.inspect}, reward_program_id:"\ " #{@reward_program_id.inspect}, reward_balances: #{@reward_balances.inspect},"\ " transactions_included: #{@transactions_included.inspect}, bank_institution_id:"\ " #{@bank_institution_id.inspect}, bank_transit_id: #{@bank_transit_id.inspect}>" end |
#to_custom_interest_rate_as_of ⇒ Object
427 428 429 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 427 def to_custom_interest_rate_as_of DateTimeHelper.to_rfc3339(interest_rate_as_of) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/fdx_v660_api/models/account_entity.rb', line 432 def to_s class_name = self.class.name.split('::').last super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, line_of_business: #{@line_of_business},"\ " line_of_business_type: #{@line_of_business_type}, routing_transit_number:"\ " #{@routing_transit_number}, balance_type: #{@balance_type}, contact: #{@contact},"\ " interest_rate: #{@interest_rate}, interest_rate_type: #{@interest_rate_type},"\ " interest_rate_as_of: #{@interest_rate_as_of}, prior_interest_rate:"\ " #{@prior_interest_rate}, interest_rate_index: #{@interest_rate_index}, early_penalty_flag:"\ " #{@early_penalty_flag}, transfer_in: #{@transfer_in}, transfer_out: #{@transfer_out},"\ " bill_pay_status: #{@bill_pay_status}, micr_number: #{@micr_number}, last_activity_date:"\ " #{@last_activity_date}, reward_program_id: #{@reward_program_id}, reward_balances:"\ " #{@reward_balances}, transactions_included: #{@transactions_included},"\ " bank_institution_id: #{@bank_institution_id}, bank_transit_id: #{@bank_transit_id}>" end |