Class: FdxV660Api::AccountInformationController
- Inherits:
-
BaseController
- Object
- BaseController
- FdxV660Api::AccountInformationController
- Defined in:
- lib/fdx_v660_api/controllers/account_information_controller.rb
Overview
AccountInformationController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#get_account(x_fapi_interaction_id, account_id, fdx_api_actor_type: nil, fdx_api_client_public_key: nil, fdx_api_data_provider_id: nil, fdx_api_data_recipient_id: nil) ⇒ ApiResponse
Retrieve full details about the account identified by
{accountId}parameter identifier for this interaction, as defined by [FAPI 2.0 Implementation Advice, 2.2.1 x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement ation_advice.html#name-x-fapi-interaction-id) whether the customer is present (USER) or it is a BATCH operation for data provider to encrypt sensitive response data financial institution responding to the request for the data recipient(s) on whose behalf the request is being made. -
#search_for_accounts(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_client_public_key: nil, fdx_api_data_provider_id: nil, fdx_api_data_recipient_id: nil, account_ids: nil, start_time: nil, end_time: nil, start_date: nil, end_date: nil, result_type: ResultType::LIGHTWEIGHT, offset: nil, page_key: nil, limit: nil) ⇒ ApiResponse
Return information for all of the customer's consented accounts or just those accounts identified in the
accountIdsrequest parameter.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from FdxV660Api::BaseController
Instance Method Details
#get_account(x_fapi_interaction_id, account_id, fdx_api_actor_type: nil, fdx_api_client_public_key: nil, fdx_api_data_provider_id: nil, fdx_api_data_recipient_id: nil) ⇒ ApiResponse
Retrieve full details about the account identified by {accountId}
parameter
identifier for this interaction, as defined by [FAPI 2.0 Implementation
Advice, 2.2.1
x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement
ation_advice.html#name-x-fapi-interaction-id)
whether the customer is present (USER) or it is a BATCH operation
for data provider to encrypt sensitive response data
financial institution responding to the request
for the data recipient(s) on whose behalf the request is being made
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/fdx_v660_api/controllers/account_information_controller.rb', line 135 def get_account(x_fapi_interaction_id, account_id, fdx_api_actor_type: nil, fdx_api_client_public_key: nil, fdx_api_data_provider_id: nil, fdx_api_data_recipient_id: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/accounts/{accountId}', Server::DEFAULT) .header_param(new_parameter(x_fapi_interaction_id, key: 'x-fapi-interaction-id') .is_required(true)) .template_param(new_parameter(account_id, key: 'accountId') .is_required(true) .should_encode(true)) .header_param(new_parameter(fdx_api_actor_type, key: 'FDX-API-Actor-Type')) .header_param(new_parameter(fdx_api_client_public_key, key: 'FDX-API-Client-Public-Key')) .header_param(new_parameter(fdx_api_data_provider_id, key: 'FDX-API-Data-Provider-Id')) .header_param(new_parameter(fdx_api_data_recipient_id, key: 'FDX-API-Data-Recipient-Id')) .header_param(new_parameter('application/json', key: 'accept'))) .response(new_response_handler .deserializer(proc do |response, should_symbolize| APIHelper.deserialize_union_type( UnionTypeLookUp.get(:AccountWithDetails), response, should_symbolize, true ) end) .is_api_response(true) .local_error('404', 'Account with id not found', ErrorException) .local_error('500', 'Catch-all exception where request was not processed due to an'\ ' internal outage/issue. Consider other more specific errors'\ ' before using this error', ErrorException) .local_error('501', 'Error when FdxVersion in Header is not one of those'\ ' implemented at backend', ErrorException) .local_error('503', 'System is down for maintenance', ErrorException)) .execute end |
#search_for_accounts(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_client_public_key: nil, fdx_api_data_provider_id: nil, fdx_api_data_recipient_id: nil, account_ids: nil, start_time: nil, end_time: nil, start_date: nil, end_date: nil, result_type: ResultType::LIGHTWEIGHT, offset: nil, page_key: nil, limit: nil) ⇒ ApiResponse
Return information for all of the customer's consented accounts or just
those accounts identified in the accountIds request parameter. Use
ResultTypeQuery parameter value of lightweight to retrieve minimal
descriptive information and the accountId for each account. The
accountId can then be used in the getAccount operation's path
/accounts/{accountId} to retrieve full details about each account
identifier for this interaction, as defined by [FAPI 2.0 Implementation
Advice, 2.2.1
x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement
ation_advice.html#name-x-fapi-interaction-id)
whether the customer is present (USER) or it is a BATCH operation
for data provider to encrypt sensitive response data
financial institution responding to the request
for the data recipient(s) on whose behalf the request is being made
list of account ids
retrieval of transactions. Deprecated in v6.5, transactions fields were
deprecated by RFCs 0309 and 0367
retrieval of transactions. Deprecated in v6.5, transactions fields were
deprecated by RFCs 0309 and 0367
retrieval of transactions. Deprecated in v6.5, transactions fields were
deprecated by RFCs 0309 and 0367
of transactions. Deprecated in v6.5, transactions fields were deprecated
by RFCs 0309 and 0367
you want a lightweight array of metadata (AccountDescriptor or Tax or
Operations) or full item details (Account or a Tax subclass or
Availability details). If set to 'lightweight', should only return the
fields associated with the metadata entity. This field is not required,
defaults to lightweight
provider to send the next set of records. Deprecated in favor of
PageKeyQuery, will be removed with a future major release
provider to send the next set of records. Pagination can be implemented
per provider's preference
consumer wishes to receive. Providers should implement reasonable
default/maximum/minimum values based on their internal architecture and
update their documentation accordingly
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/fdx_v660_api/controllers/account_information_controller.rb', line 59 def search_for_accounts(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_client_public_key: nil, fdx_api_data_provider_id: nil, fdx_api_data_recipient_id: nil, account_ids: nil, start_time: nil, end_time: nil, start_date: nil, end_date: nil, result_type: ResultType::LIGHTWEIGHT, offset: nil, page_key: nil, limit: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/accounts', Server::DEFAULT) .header_param(new_parameter(x_fapi_interaction_id, key: 'x-fapi-interaction-id') .is_required(true)) .header_param(new_parameter(fdx_api_actor_type, key: 'FDX-API-Actor-Type')) .header_param(new_parameter(fdx_api_client_public_key, key: 'FDX-API-Client-Public-Key')) .header_param(new_parameter(fdx_api_data_provider_id, key: 'FDX-API-Data-Provider-Id')) .header_param(new_parameter(fdx_api_data_recipient_id, key: 'FDX-API-Data-Recipient-Id')) .query_param(new_parameter(account_ids, key: 'accountIds')) .query_param(new_parameter(start_time, key: 'startTime')) .query_param(new_parameter(end_time, key: 'endTime')) .query_param(new_parameter(start_date, key: 'startDate')) .query_param(new_parameter(end_date, key: 'endDate')) .query_param(new_parameter(result_type, key: 'resultType')) .query_param(new_parameter(offset, key: 'offset')) .query_param(new_parameter(page_key, key: 'pageKey')) .query_param(new_parameter(limit, key: 'limit')) .header_param(new_parameter('application/json', key: 'accept'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(AccountsEntity.method(:from_hash)) .is_api_response(true) .local_error('400', 'Start or end date value is not in the ISO 8601 format', ErrorException) .local_error('404', 'Account with id not found', ErrorException) .local_error('500', 'Catch-all exception where request was not processed due to an'\ ' internal outage/issue. Consider other more specific errors'\ ' before using this error', ErrorException) .local_error('501', 'Error when FdxVersion in Header is not one of those'\ ' implemented at backend', ErrorException) .local_error('503', 'System is down for maintenance', ErrorException)) .execute end |