Class: FdxV660Api::BasePayrollRate1
- Defined in:
- lib/fdx_v660_api/models/base_payroll_rate1.rb
Overview
The employee's base payroll rate
Instance Attribute Summary collapse
-
#rate ⇒ MonetaryAmount6
The amount and currency of the base pay rate of employee.
-
#rate_type ⇒ PayrollRateType3
The unit for the worker's rate.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(rate:, rate_type:, additional_properties: nil) ⇒ BasePayrollRate1
constructor
A new instance of BasePayrollRate1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(rate:, rate_type:, additional_properties: nil) ⇒ BasePayrollRate1
Returns a new instance of BasePayrollRate1.
40 41 42 43 44 45 46 47 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 40 def initialize(rate:, rate_type:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @rate = rate @rate_type = rate_type @additional_properties = additional_properties end |
Instance Attribute Details
#rate ⇒ MonetaryAmount6
The amount and currency of the base pay rate of employee
14 15 16 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 14 def rate @rate end |
#rate_type ⇒ PayrollRateType3
The unit for the worker's rate. In time period length order, one of HOURLY, DAILY, WEEKLY, BI-WEEKLY, SEMI-MONTHLY, EVERY 2.6 WEEKS, EVERY 4 WEEKS, MONTHLY, EVERY 5.2 WEEKS, QUARTERLY, SEMI-ANNUALLY, ANNUAL, OTHER
20 21 22 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 20 def rate_type @rate_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. rate = MonetaryAmount6.from_hash(hash['rate']) if hash['rate'] rate_type = hash.key?('rateType') ? hash['rateType'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BasePayrollRate1.new(rate: rate, rate_type: rate_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['rate'] = 'rate' @_hash['rate_type'] = 'rateType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} rate: #{@rate.inspect}, rate_type: #{@rate_type.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/fdx_v660_api/models/base_payroll_rate1.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} rate: #{@rate}, rate_type: #{@rate_type}, additional_properties:"\ " #{@additional_properties}>" end |