Class: FdxV660Api::BasicAuthCredentials1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::BasicAuthCredentials1
- Defined in:
- lib/fdx_v660_api/models/basic_auth_credentials1.rb
Overview
The Basic Authentication credentials to retrieve a tax form
Instance Attribute Summary collapse
-
#id ⇒ String
Confidential and unique identifier of the tax form.
-
#passcode ⇒ String
Unique, randomized and restricted password for this document.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, tax_form_type: SKIP, id: SKIP, passcode: SKIP, additional_properties: nil) ⇒ BasicAuthCredentials1
constructor
A new instance of BasicAuthCredentials1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, tax_form_type: SKIP, id: SKIP, passcode: SKIP, additional_properties: nil) ⇒ BasicAuthCredentials1
Returns a new instance of BasicAuthCredentials1.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 53 def initialize(tax_year: SKIP, tax_form_type: SKIP, id: SKIP, passcode: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @id = id unless id == SKIP @passcode = passcode unless passcode == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Confidential and unique identifier of the tax form
22 23 24 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 22 def id @id end |
#passcode ⇒ String
Unique, randomized and restricted password for this document
26 27 28 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 26 def passcode @passcode end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
18 19 20 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 18 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 14 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP passcode = hash.key?('passcode') ? hash['passcode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BasicAuthCredentials1.new(tax_year: tax_year, tax_form_type: tax_form_type, id: id, passcode: passcode, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['tax_form_type'] = 'taxFormType' @_hash['id'] = 'id' @_hash['passcode'] = 'passcode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 39 def self.optionals %w[ tax_year tax_form_type id passcode ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, tax_form_type: #{@tax_form_type.inspect},"\ " id: #{@id.inspect}, passcode: #{@passcode.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/fdx_v660_api/models/basic_auth_credentials1.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, tax_form_type: #{@tax_form_type}, id: #{@id},"\ " passcode: #{@passcode}, additional_properties: #{@additional_properties}>" end |