Class: FdxV660Api::BusinessIncomeStatement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::BusinessIncomeStatement
- Defined in:
- lib/fdx_v660_api/models/business_income_statement.rb
Overview
Business Income Statement for IRS Form 1040 Schedule C
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#advertising ⇒ Float
Box 8, Advertising.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#beginning_inventory ⇒ Float
Box 35, Inventory at beginning of year.
-
#business_name ⇒ String
Box C, Business name.
-
#capital_expenditures ⇒ Array[DateAndAmount]
Capital expenditures, for use in calculating Depreciation.
-
#car_and_truck ⇒ Float
Box 9, Car and truck expenses.
-
#commissions ⇒ Float
Box 10, Commissions and fees.
-
#contract_labor ⇒ Float
Box 11, Contract labor.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#cost_of_labor ⇒ Float
Box 37, Cost of labor.
-
#depletion ⇒ Float
Box 12, Depletion.
-
#depreciation ⇒ Float
Box 13, Depreciation.
-
#employee_benefits ⇒ Float
Box 14, Employee benefit programs.
-
#ending_inventory ⇒ Float
Box 41, Inventory at end of year.
-
#equipment_rent ⇒ Float
Box 20a, Equipment rent.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#insurance ⇒ Float
Box 15, Insurance.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#legal ⇒ Float
Box 17, Legal and professional services.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#materials ⇒ Float
Box 38, Materials and supplies.
-
#meals ⇒ Float
Box 24b, Deductible meals.
-
#mortgage_interest ⇒ Float
Box 16a, Mortgage interest.
-
#office ⇒ Float
Box 18, Office expense.
-
#other_costs ⇒ Array[DescriptionAndAmount]
Box 39, Other costs.
-
#other_expenses ⇒ Array[DescriptionAndAmount]
Box 27, Other expenses.
-
#other_income ⇒ Array[DescriptionAndAmount]
Box 6, Other income, including federal and state gasoline or fuel tax credit or refund.
-
#other_interest ⇒ Float
Box 16c, Other interest.
-
#other_rent ⇒ Float
Box 20b, Other rent.
-
#pension ⇒ Float
Box 19, Pension and profit-sharing plans.
-
#purchases ⇒ Float
Box 36, Purchases.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#repairs ⇒ Float
Box 21, Repairs and maintenance.
-
#returns ⇒ Float
Box 2, Returns and allowances.
-
#sales ⇒ Float
Box 1, Gross receipts or sales.
-
#supplies ⇒ Float
Box 22, Supplies.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#taxes ⇒ Float
Box 23, Taxes and licenses.
-
#travel ⇒ Float
Box 24a, Travel.
-
#utilities ⇒ Float
Box 25, Utilities.
-
#vehicle_loan_interest ⇒ Float
Box 16b, Vehicle loan interest.
-
#wages ⇒ Float
Box 26, Wages.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, business_name: SKIP, sales: SKIP, returns: SKIP, other_income: SKIP, advertising: SKIP, car_and_truck: SKIP, commissions: SKIP, contract_labor: SKIP, depletion: SKIP, depreciation: SKIP, employee_benefits: SKIP, insurance: SKIP, mortgage_interest: SKIP, vehicle_loan_interest: SKIP, other_interest: SKIP, legal: SKIP, office: SKIP, pension: SKIP, equipment_rent: SKIP, other_rent: SKIP, repairs: SKIP, supplies: SKIP, taxes: SKIP, travel: SKIP, meals: SKIP, utilities: SKIP, wages: SKIP, other_expenses: SKIP, beginning_inventory: SKIP, purchases: SKIP, cost_of_labor: SKIP, materials: SKIP, other_costs: SKIP, ending_inventory: SKIP, capital_expenditures: SKIP, additional_properties: nil) ⇒ BusinessIncomeStatement
constructor
A new instance of BusinessIncomeStatement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, business_name: SKIP, sales: SKIP, returns: SKIP, other_income: SKIP, advertising: SKIP, car_and_truck: SKIP, commissions: SKIP, contract_labor: SKIP, depletion: SKIP, depreciation: SKIP, employee_benefits: SKIP, insurance: SKIP, mortgage_interest: SKIP, vehicle_loan_interest: SKIP, other_interest: SKIP, legal: SKIP, office: SKIP, pension: SKIP, equipment_rent: SKIP, other_rent: SKIP, repairs: SKIP, supplies: SKIP, taxes: SKIP, travel: SKIP, meals: SKIP, utilities: SKIP, wages: SKIP, other_expenses: SKIP, beginning_inventory: SKIP, purchases: SKIP, cost_of_labor: SKIP, materials: SKIP, other_costs: SKIP, ending_inventory: SKIP, capital_expenditures: SKIP, additional_properties: nil) ⇒ BusinessIncomeStatement
Returns a new instance of BusinessIncomeStatement.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 325 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, business_name: SKIP, sales: SKIP, returns: SKIP, other_income: SKIP, advertising: SKIP, car_and_truck: SKIP, commissions: SKIP, contract_labor: SKIP, depletion: SKIP, depreciation: SKIP, employee_benefits: SKIP, insurance: SKIP, mortgage_interest: SKIP, vehicle_loan_interest: SKIP, other_interest: SKIP, legal: SKIP, office: SKIP, pension: SKIP, equipment_rent: SKIP, other_rent: SKIP, repairs: SKIP, supplies: SKIP, taxes: SKIP, travel: SKIP, meals: SKIP, utilities: SKIP, wages: SKIP, other_expenses: SKIP, beginning_inventory: SKIP, purchases: SKIP, cost_of_labor: SKIP, materials: SKIP, other_costs: SKIP, ending_inventory: SKIP, capital_expenditures: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @business_name = business_name unless business_name == SKIP @sales = sales unless sales == SKIP @returns = returns unless returns == SKIP @other_income = other_income unless other_income == SKIP @advertising = advertising unless advertising == SKIP @car_and_truck = car_and_truck unless car_and_truck == SKIP @commissions = commissions unless commissions == SKIP @contract_labor = contract_labor unless contract_labor == SKIP @depletion = depletion unless depletion == SKIP @depreciation = depreciation unless depreciation == SKIP @employee_benefits = employee_benefits unless employee_benefits == SKIP @insurance = insurance unless insurance == SKIP @mortgage_interest = mortgage_interest unless mortgage_interest == SKIP @vehicle_loan_interest = vehicle_loan_interest unless vehicle_loan_interest == SKIP @other_interest = other_interest unless other_interest == SKIP @legal = legal unless legal == SKIP @office = office unless office == SKIP @pension = pension unless pension == SKIP @equipment_rent = equipment_rent unless equipment_rent == SKIP @other_rent = other_rent unless other_rent == SKIP @repairs = repairs unless repairs == SKIP @supplies = supplies unless supplies == SKIP @taxes = taxes unless taxes == SKIP @travel = travel unless travel == SKIP @meals = meals unless meals == SKIP @utilities = utilities unless utilities == SKIP @wages = wages unless wages == SKIP @other_expenses = other_expenses unless other_expenses == SKIP @beginning_inventory = beginning_inventory unless beginning_inventory == SKIP @purchases = purchases unless purchases == SKIP @cost_of_labor = cost_of_labor unless cost_of_labor == SKIP @materials = materials unless materials == SKIP @other_costs = other_costs unless other_costs == SKIP @ending_inventory = ending_inventory unless ending_inventory == SKIP @capital_expenditures = capital_expenditures unless capital_expenditures == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 37 def additional_information @additional_information end |
#advertising ⇒ Float
Box 8, Advertising
92 93 94 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 92 def advertising @advertising end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 63 def attributes @attributes end |
#beginning_inventory ⇒ Float
Box 35, Inventory at beginning of year
188 189 190 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 188 def beginning_inventory @beginning_inventory end |
#business_name ⇒ String
Box C, Business name
75 76 77 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 75 def business_name @business_name end |
#capital_expenditures ⇒ Array[DateAndAmount]
Capital expenditures, for use in calculating Depreciation
212 213 214 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 212 def capital_expenditures @capital_expenditures end |
#car_and_truck ⇒ Float
Box 9, Car and truck expenses
96 97 98 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 96 def car_and_truck @car_and_truck end |
#commissions ⇒ Float
Box 10, Commissions and fees
100 101 102 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 100 def commissions @commissions end |
#contract_labor ⇒ Float
Box 11, Contract labor
104 105 106 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 104 def contract_labor @contract_labor end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 18 def corrected @corrected end |
#cost_of_labor ⇒ Float
Box 37, Cost of labor
196 197 198 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 196 def cost_of_labor @cost_of_labor end |
#depletion ⇒ Float
Box 12, Depletion
108 109 110 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 108 def depletion @depletion end |
#depreciation ⇒ Float
Box 13, Depreciation
112 113 114 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 112 def depreciation @depreciation end |
#employee_benefits ⇒ Float
Box 14, Employee benefit programs
116 117 118 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 116 def employee_benefits @employee_benefits end |
#ending_inventory ⇒ Float
Box 41, Inventory at end of year
208 209 210 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 208 def ending_inventory @ending_inventory end |
#equipment_rent ⇒ Float
Box 20a, Equipment rent
148 149 150 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 148 def equipment_rent @equipment_rent end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 67 def error @error end |
#insurance ⇒ Float
Box 15, Insurance
120 121 122 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 120 def insurance @insurance end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 47 def issuer @issuer end |
#legal ⇒ Float
Box 17, Legal and professional services
136 137 138 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 136 def legal @legal end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 71 def links @links end |
#materials ⇒ Float
Box 38, Materials and supplies
200 201 202 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 200 def materials @materials end |
#meals ⇒ Float
Box 24b, Deductible meals
172 173 174 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 172 def meals @meals end |
#mortgage_interest ⇒ Float
Box 16a, Mortgage interest
124 125 126 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 124 def mortgage_interest @mortgage_interest end |
#office ⇒ Float
Box 18, Office expense
140 141 142 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 140 def office @office end |
#other_costs ⇒ Array[DescriptionAndAmount]
Box 39, Other costs
204 205 206 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 204 def other_costs @other_costs end |
#other_expenses ⇒ Array[DescriptionAndAmount]
Box 27, Other expenses
184 185 186 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 184 def other_expenses @other_expenses end |
#other_income ⇒ Array[DescriptionAndAmount]
Box 6, Other income, including federal and state gasoline or fuel tax credit or refund
88 89 90 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 88 def other_income @other_income end |
#other_interest ⇒ Float
Box 16c, Other interest
132 133 134 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 132 def other_interest @other_interest end |
#other_rent ⇒ Float
Box 20b, Other rent
152 153 154 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 152 def other_rent @other_rent end |
#pension ⇒ Float
Box 19, Pension and profit-sharing plans
144 145 146 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 144 def pension @pension end |
#purchases ⇒ Float
Box 36, Purchases
192 193 194 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 192 def purchases @purchases end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 53 def recipient @recipient end |
#repairs ⇒ Float
Box 21, Repairs and maintenance
156 157 158 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 156 def repairs @repairs end |
#returns ⇒ Float
Box 2, Returns and allowances
83 84 85 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 83 def returns @returns end |
#sales ⇒ Float
Box 1, Gross receipts or sales
79 80 81 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 79 def sales @sales end |
#supplies ⇒ Float
Box 22, Supplies
160 161 162 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 160 def supplies @supplies end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 14 def tax_year @tax_year end |
#taxes ⇒ Float
Box 23, Taxes and licenses
164 165 166 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 164 def taxes @taxes end |
#travel ⇒ Float
Box 24a, Travel
168 169 170 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 168 def travel @travel end |
#utilities ⇒ Float
Box 25, Utilities
176 177 178 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 176 def utilities @utilities end |
#vehicle_loan_interest ⇒ Float
Box 16b, Vehicle loan interest
128 129 130 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 128 def vehicle_loan_interest @vehicle_loan_interest end |
#wages ⇒ Float
Box 26, Wages
180 181 182 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 180 def wages @wages end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 396 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') business_name = hash.key?('businessName') ? hash['businessName'] : SKIP sales = hash.key?('sales') ? hash['sales'] : SKIP returns = hash.key?('returns') ? hash['returns'] : SKIP # Parameter is an array, so we need to iterate through it other_income = nil unless hash['otherIncome'].nil? other_income = [] hash['otherIncome'].each do |structure| other_income << (DescriptionAndAmount.from_hash(structure) if structure) end end other_income = SKIP unless hash.key?('otherIncome') advertising = hash.key?('advertising') ? hash['advertising'] : SKIP car_and_truck = hash.key?('carAndTruck') ? hash['carAndTruck'] : SKIP commissions = hash.key?('commissions') ? hash['commissions'] : SKIP contract_labor = hash.key?('contractLabor') ? hash['contractLabor'] : SKIP depletion = hash.key?('depletion') ? hash['depletion'] : SKIP depreciation = hash.key?('depreciation') ? hash['depreciation'] : SKIP employee_benefits = hash.key?('employeeBenefits') ? hash['employeeBenefits'] : SKIP insurance = hash.key?('insurance') ? hash['insurance'] : SKIP mortgage_interest = hash.key?('mortgageInterest') ? hash['mortgageInterest'] : SKIP vehicle_loan_interest = hash.key?('vehicleLoanInterest') ? hash['vehicleLoanInterest'] : SKIP other_interest = hash.key?('otherInterest') ? hash['otherInterest'] : SKIP legal = hash.key?('legal') ? hash['legal'] : SKIP office = hash.key?('office') ? hash['office'] : SKIP pension = hash.key?('pension') ? hash['pension'] : SKIP equipment_rent = hash.key?('equipmentRent') ? hash['equipmentRent'] : SKIP other_rent = hash.key?('otherRent') ? hash['otherRent'] : SKIP repairs = hash.key?('repairs') ? hash['repairs'] : SKIP supplies = hash.key?('supplies') ? hash['supplies'] : SKIP taxes = hash.key?('taxes') ? hash['taxes'] : SKIP travel = hash.key?('travel') ? hash['travel'] : SKIP meals = hash.key?('meals') ? hash['meals'] : SKIP utilities = hash.key?('utilities') ? hash['utilities'] : SKIP wages = hash.key?('wages') ? hash['wages'] : SKIP # Parameter is an array, so we need to iterate through it other_expenses = nil unless hash['otherExpenses'].nil? other_expenses = [] hash['otherExpenses'].each do |structure| other_expenses << (DescriptionAndAmount.from_hash(structure) if structure) end end other_expenses = SKIP unless hash.key?('otherExpenses') beginning_inventory = hash.key?('beginningInventory') ? hash['beginningInventory'] : SKIP purchases = hash.key?('purchases') ? hash['purchases'] : SKIP cost_of_labor = hash.key?('costOfLabor') ? hash['costOfLabor'] : SKIP materials = hash.key?('materials') ? hash['materials'] : SKIP # Parameter is an array, so we need to iterate through it other_costs = nil unless hash['otherCosts'].nil? other_costs = [] hash['otherCosts'].each do |structure| other_costs << (DescriptionAndAmount.from_hash(structure) if structure) end end other_costs = SKIP unless hash.key?('otherCosts') ending_inventory = hash.key?('endingInventory') ? hash['endingInventory'] : SKIP # Parameter is an array, so we need to iterate through it capital_expenditures = nil unless hash['capitalExpenditures'].nil? capital_expenditures = [] hash['capitalExpenditures'].each do |structure| capital_expenditures << (DateAndAmount.from_hash(structure) if structure) end end capital_expenditures = SKIP unless hash.key?('capitalExpenditures') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BusinessIncomeStatement.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, business_name: business_name, sales: sales, returns: returns, other_income: other_income, advertising: advertising, car_and_truck: car_and_truck, commissions: commissions, contract_labor: contract_labor, depletion: depletion, depreciation: depreciation, employee_benefits: employee_benefits, insurance: insurance, mortgage_interest: mortgage_interest, vehicle_loan_interest: vehicle_loan_interest, other_interest: other_interest, legal: legal, office: office, pension: pension, equipment_rent: equipment_rent, other_rent: other_rent, repairs: repairs, supplies: supplies, taxes: taxes, travel: travel, meals: meals, utilities: utilities, wages: wages, other_expenses: other_expenses, beginning_inventory: beginning_inventory, purchases: purchases, cost_of_labor: cost_of_labor, materials: materials, other_costs: other_costs, ending_inventory: ending_inventory, capital_expenditures: capital_expenditures, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 215 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['business_name'] = 'businessName' @_hash['sales'] = 'sales' @_hash['returns'] = 'returns' @_hash['other_income'] = 'otherIncome' @_hash['advertising'] = 'advertising' @_hash['car_and_truck'] = 'carAndTruck' @_hash['commissions'] = 'commissions' @_hash['contract_labor'] = 'contractLabor' @_hash['depletion'] = 'depletion' @_hash['depreciation'] = 'depreciation' @_hash['employee_benefits'] = 'employeeBenefits' @_hash['insurance'] = 'insurance' @_hash['mortgage_interest'] = 'mortgageInterest' @_hash['vehicle_loan_interest'] = 'vehicleLoanInterest' @_hash['other_interest'] = 'otherInterest' @_hash['legal'] = 'legal' @_hash['office'] = 'office' @_hash['pension'] = 'pension' @_hash['equipment_rent'] = 'equipmentRent' @_hash['other_rent'] = 'otherRent' @_hash['repairs'] = 'repairs' @_hash['supplies'] = 'supplies' @_hash['taxes'] = 'taxes' @_hash['travel'] = 'travel' @_hash['meals'] = 'meals' @_hash['utilities'] = 'utilities' @_hash['wages'] = 'wages' @_hash['other_expenses'] = 'otherExpenses' @_hash['beginning_inventory'] = 'beginningInventory' @_hash['purchases'] = 'purchases' @_hash['cost_of_labor'] = 'costOfLabor' @_hash['materials'] = 'materials' @_hash['other_costs'] = 'otherCosts' @_hash['ending_inventory'] = 'endingInventory' @_hash['capital_expenditures'] = 'capitalExpenditures' @_hash end |
.nullables ⇒ Object
An array for nullable fields
321 322 323 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 321 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 268 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links business_name sales returns other_income advertising car_and_truck commissions contract_labor depletion depreciation employee_benefits insurance mortgage_interest vehicle_loan_interest other_interest legal office pension equipment_rent other_rent repairs supplies taxes travel meals utilities wages other_expenses beginning_inventory purchases cost_of_labor materials other_costs ending_inventory capital_expenditures ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 590 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, business_name: #{@business_name.inspect}, sales:"\ " #{@sales.inspect}, returns: #{@returns.inspect}, other_income: #{@other_income.inspect},"\ " advertising: #{@advertising.inspect}, car_and_truck: #{@car_and_truck.inspect},"\ " commissions: #{@commissions.inspect}, contract_labor: #{@contract_labor.inspect},"\ " depletion: #{@depletion.inspect}, depreciation: #{@depreciation.inspect},"\ " employee_benefits: #{@employee_benefits.inspect}, insurance: #{@insurance.inspect},"\ " mortgage_interest: #{@mortgage_interest.inspect}, vehicle_loan_interest:"\ " #{@vehicle_loan_interest.inspect}, other_interest: #{@other_interest.inspect}, legal:"\ " #{@legal.inspect}, office: #{@office.inspect}, pension: #{@pension.inspect},"\ " equipment_rent: #{@equipment_rent.inspect}, other_rent: #{@other_rent.inspect}, repairs:"\ " #{@repairs.inspect}, supplies: #{@supplies.inspect}, taxes: #{@taxes.inspect}, travel:"\ " #{@travel.inspect}, meals: #{@meals.inspect}, utilities: #{@utilities.inspect}, wages:"\ " #{@wages.inspect}, other_expenses: #{@other_expenses.inspect}, beginning_inventory:"\ " #{@beginning_inventory.inspect}, purchases: #{@purchases.inspect}, cost_of_labor:"\ " #{@cost_of_labor.inspect}, materials: #{@materials.inspect}, other_costs:"\ " #{@other_costs.inspect}, ending_inventory: #{@ending_inventory.inspect},"\ " capital_expenditures: #{@capital_expenditures.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/fdx_v660_api/models/business_income_statement.rb', line 567 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, business_name: #{@business_name}, sales: #{@sales}, returns:"\ " #{@returns}, other_income: #{@other_income}, advertising: #{@advertising}, car_and_truck:"\ " #{@car_and_truck}, commissions: #{@commissions}, contract_labor: #{@contract_labor},"\ " depletion: #{@depletion}, depreciation: #{@depreciation}, employee_benefits:"\ " #{@employee_benefits}, insurance: #{@insurance}, mortgage_interest: #{@mortgage_interest},"\ " vehicle_loan_interest: #{@vehicle_loan_interest}, other_interest: #{@other_interest},"\ " legal: #{@legal}, office: #{@office}, pension: #{@pension}, equipment_rent:"\ " #{@equipment_rent}, other_rent: #{@other_rent}, repairs: #{@repairs}, supplies:"\ " #{@supplies}, taxes: #{@taxes}, travel: #{@travel}, meals: #{@meals}, utilities:"\ " #{@utilities}, wages: #{@wages}, other_expenses: #{@other_expenses}, beginning_inventory:"\ " #{@beginning_inventory}, purchases: #{@purchases}, cost_of_labor: #{@cost_of_labor},"\ " materials: #{@materials}, other_costs: #{@other_costs}, ending_inventory:"\ " #{@ending_inventory}, capital_expenditures: #{@capital_expenditures},"\ " additional_properties: #{@additional_properties}>" end |