Class: FdxV660Api::BusinessName5
- Defined in:
- lib/fdx_v660_api/models/business_name5.rb
Overview
Name when payee is a merchant, typically a business from which goods or services are rendered
Instance Attribute Summary collapse
-
#name1 ⇒ String
Name line 1.
-
#name2 ⇒ String
Name line 2.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name1: SKIP, name2: SKIP, additional_properties: nil) ⇒ BusinessName5
constructor
A new instance of BusinessName5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name1: SKIP, name2: SKIP, additional_properties: nil) ⇒ BusinessName5
Returns a new instance of BusinessName5.
42 43 44 45 46 47 48 49 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 42 def initialize(name1: SKIP, name2: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name1 = name1 unless name1 == SKIP @name2 = name2 unless name2 == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#name1 ⇒ String
Name line 1
15 16 17 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 15 def name1 @name1 end |
#name2 ⇒ String
Name line 2
19 20 21 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 19 def name2 @name2 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name1 = hash.key?('name1') ? hash['name1'] : SKIP name2 = hash.key?('name2') ? hash['name2'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BusinessName5.new(name1: name1, name2: name2, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['name1'] = 'name1' @_hash['name2'] = 'name2' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 30 def self.optionals %w[ name1 name2 ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
74 75 76 77 78 79 80 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 74 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} name1: #{@name1.inspect}, name2: #{@name2.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/fdx_v660_api/models/business_name5.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} name1: #{@name1}, name2: #{@name2}, additional_properties:"\ " #{@additional_properties}>" end |