Class: FdxV660Api::CommercialAccountEntity
- Inherits:
-
AccountEntity
- Object
- CoreLibrary::BaseModel
- BaseModel
- AccountDescriptorEntity
- AccountEntity
- FdxV660Api::CommercialAccountEntity
- Defined in:
- lib/fdx_v660_api/models/commercial_account_entity.rb
Overview
Information for a commercial account type
Instance Attribute Summary collapse
-
#balance_as_of ⇒ DateTime
As-of date of balances.
-
#closing_available_balance ⇒ Float
Closing available balance.
-
#closing_ledger_balance ⇒ Float
Closing ledger balance.
-
#commercial_balances ⇒ Array[CommercialBalanceEntity]
A list of specific treasury management defined balances.
-
#current_available_balance ⇒ Float
Current available balance.
-
#current_ledger_balance ⇒ Float
Current ledger balance.
-
#earned_interest ⇒ InterestRateEntity1
The periodic (usually monthly) interest rate earned on account balances.
-
#next_day_available_balance ⇒ Float
Next day's available balance.
-
#number_of_outstanding_credits ⇒ Integer
Number of outstanding credit transactions.
-
#number_of_outstanding_debits ⇒ Integer
Number of outstanding debit transactions.
-
#opening_available_balance ⇒ Float
Opening available balance.
-
#opening_ledger_balance ⇒ Float
Opening ledger balance.
-
#outstanding_credits_amount ⇒ Float
Total amount of outstanding credits.
-
#outstanding_debits_amount ⇒ Float
Total amount of outstanding debits.
-
#transactions ⇒ Array[CommercialTransactionEntity]
Transactions on the commercial account.
-
#two_days_plus_available_balance ⇒ Float
Two days out's available balance.
Attributes inherited from AccountEntity
#balance_type, #bank_institution_id, #bank_transit_id, #bill_pay_status, #contact, #early_penalty_flag, #interest_rate, #interest_rate_as_of, #interest_rate_index, #interest_rate_type, #last_activity_date, #line_of_business, #line_of_business_type, #micr_number, #prior_interest_rate, #reward_balances, #reward_program_id, #routing_transit_number, #transactions_included, #transfer_in, #transfer_out
Attributes inherited from AccountDescriptorEntity
#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(earned_interest: SKIP, balance_as_of: SKIP, opening_ledger_balance: SKIP, closing_ledger_balance: SKIP, current_ledger_balance: SKIP, opening_available_balance: SKIP, current_available_balance: SKIP, closing_available_balance: SKIP, next_day_available_balance: SKIP, two_days_plus_available_balance: SKIP, number_of_outstanding_credits: SKIP, outstanding_credits_amount: SKIP, number_of_outstanding_debits: SKIP, outstanding_debits_amount: SKIP, transactions: SKIP, commercial_balances: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Commercial Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ CommercialAccountEntity
constructor
A new instance of CommercialAccountEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_balance_as_of ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from AccountEntity
discriminators, #to_custom_interest_rate_as_of
Methods inherited from AccountDescriptorEntity
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(earned_interest: SKIP, balance_as_of: SKIP, opening_ledger_balance: SKIP, closing_ledger_balance: SKIP, current_ledger_balance: SKIP, opening_available_balance: SKIP, current_available_balance: SKIP, closing_available_balance: SKIP, next_day_available_balance: SKIP, two_days_plus_available_balance: SKIP, number_of_outstanding_credits: SKIP, outstanding_credits_amount: SKIP, number_of_outstanding_debits: SKIP, outstanding_debits_amount: SKIP, transactions: SKIP, commercial_balances: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Commercial Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ CommercialAccountEntity
Returns a new instance of CommercialAccountEntity.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 131 def initialize(earned_interest: SKIP, balance_as_of: SKIP, opening_ledger_balance: SKIP, closing_ledger_balance: SKIP, current_ledger_balance: SKIP, opening_available_balance: SKIP, current_available_balance: SKIP, closing_available_balance: SKIP, next_day_available_balance: SKIP, two_days_plus_available_balance: SKIP, number_of_outstanding_credits: SKIP, outstanding_credits_amount: SKIP, number_of_outstanding_debits: SKIP, outstanding_debits_amount: SKIP, transactions: SKIP, commercial_balances: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Commercial Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) @earned_interest = earned_interest unless earned_interest == SKIP @balance_as_of = balance_as_of unless balance_as_of == SKIP @opening_ledger_balance = opening_ledger_balance unless opening_ledger_balance == SKIP @closing_ledger_balance = closing_ledger_balance unless closing_ledger_balance == SKIP @current_ledger_balance = current_ledger_balance unless current_ledger_balance == SKIP unless opening_available_balance == SKIP @opening_available_balance = opening_available_balance end unless current_available_balance == SKIP @current_available_balance = current_available_balance end unless closing_available_balance == SKIP @closing_available_balance = closing_available_balance end unless next_day_available_balance == SKIP @next_day_available_balance = next_day_available_balance end unless two_days_plus_available_balance == SKIP @two_days_plus_available_balance = two_days_plus_available_balance end unless number_of_outstanding_credits == SKIP @number_of_outstanding_credits = number_of_outstanding_credits end unless outstanding_credits_amount == SKIP @outstanding_credits_amount = outstanding_credits_amount end unless number_of_outstanding_debits == SKIP @number_of_outstanding_debits = number_of_outstanding_debits end unless outstanding_debits_amount == SKIP @outstanding_debits_amount = outstanding_debits_amount end @transactions = transactions unless transactions == SKIP @commercial_balances = commercial_balances unless commercial_balances == SKIP @additional_properties = additional_properties # Call the constructor of the base class super(line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
Instance Attribute Details
#balance_as_of ⇒ DateTime
As-of date of balances
18 19 20 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 18 def balance_as_of @balance_as_of end |
#closing_available_balance ⇒ Float
Closing available balance
42 43 44 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 42 def closing_available_balance @closing_available_balance end |
#closing_ledger_balance ⇒ Float
Closing ledger balance
26 27 28 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 26 def closing_ledger_balance @closing_ledger_balance end |
#commercial_balances ⇒ Array[CommercialBalanceEntity]
A list of specific treasury management defined balances
76 77 78 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 76 def commercial_balances @commercial_balances end |
#current_available_balance ⇒ Float
Current available balance
38 39 40 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 38 def current_available_balance @current_available_balance end |
#current_ledger_balance ⇒ Float
Current ledger balance
30 31 32 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 30 def current_ledger_balance @current_ledger_balance end |
#earned_interest ⇒ InterestRateEntity1
The periodic (usually monthly) interest rate earned on account balances
14 15 16 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 14 def earned_interest @earned_interest end |
#next_day_available_balance ⇒ Float
Next day's available balance
46 47 48 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 46 def next_day_available_balance @next_day_available_balance end |
#number_of_outstanding_credits ⇒ Integer
Number of outstanding credit transactions
54 55 56 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 54 def number_of_outstanding_credits @number_of_outstanding_credits end |
#number_of_outstanding_debits ⇒ Integer
Number of outstanding debit transactions
62 63 64 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 62 def number_of_outstanding_debits @number_of_outstanding_debits end |
#opening_available_balance ⇒ Float
Opening available balance
34 35 36 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 34 def opening_available_balance @opening_available_balance end |
#opening_ledger_balance ⇒ Float
Opening ledger balance
22 23 24 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 22 def opening_ledger_balance @opening_ledger_balance end |
#outstanding_credits_amount ⇒ Float
Total amount of outstanding credits
58 59 60 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 58 def outstanding_credits_amount @outstanding_credits_amount end |
#outstanding_debits_amount ⇒ Float
Total amount of outstanding debits
66 67 68 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 66 def outstanding_debits_amount @outstanding_debits_amount end |
#transactions ⇒ Array[CommercialTransactionEntity]
Transactions on the commercial account. Deprecated in release V6.3.1 and
will be removed in next major release. Transactions are returned in the
searchForAccountTransactions operation response
72 73 74 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 72 def transactions @transactions end |
#two_days_plus_available_balance ⇒ Float
Two days out's available balance
50 51 52 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 50 def two_days_plus_available_balance @two_days_plus_available_balance end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 253 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. earned_interest = InterestRateEntity1.from_hash(hash['earnedInterest']) if hash['earnedInterest'] balance_as_of = if hash.key?('balanceAsOf') (DateTimeHelper.from_rfc3339(hash['balanceAsOf']) if hash['balanceAsOf']) else SKIP end opening_ledger_balance = hash.key?('openingLedgerBalance') ? hash['openingLedgerBalance'] : SKIP closing_ledger_balance = hash.key?('closingLedgerBalance') ? hash['closingLedgerBalance'] : SKIP current_ledger_balance = hash.key?('currentLedgerBalance') ? hash['currentLedgerBalance'] : SKIP opening_available_balance = hash.key?('openingAvailableBalance') ? hash['openingAvailableBalance'] : SKIP current_available_balance = hash.key?('currentAvailableBalance') ? hash['currentAvailableBalance'] : SKIP closing_available_balance = hash.key?('closingAvailableBalance') ? hash['closingAvailableBalance'] : SKIP next_day_available_balance = hash.key?('nextDayAvailableBalance') ? hash['nextDayAvailableBalance'] : SKIP two_days_plus_available_balance = hash.key?('twoDaysPlusAvailableBalance') ? hash['twoDaysPlusAvailableBalance'] : SKIP number_of_outstanding_credits = hash.key?('numberOfOutstandingCredits') ? hash['numberOfOutstandingCredits'] : SKIP outstanding_credits_amount = hash.key?('outstandingCreditsAmount') ? hash['outstandingCreditsAmount'] : SKIP number_of_outstanding_debits = hash.key?('numberOfOutstandingDebits') ? hash['numberOfOutstandingDebits'] : SKIP outstanding_debits_amount = hash.key?('outstandingDebitsAmount') ? hash['outstandingDebitsAmount'] : SKIP # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (CommercialTransactionEntity.from_hash(structure) if structure) end end transactions = SKIP unless hash.key?('transactions') # Parameter is an array, so we need to iterate through it commercial_balances = nil unless hash['commercialBalances'].nil? commercial_balances = [] hash['commercialBalances'].each do |structure| commercial_balances << (CommercialBalanceEntity.from_hash(structure) if structure) end end commercial_balances = SKIP unless hash.key?('commercialBalances') line_of_business = hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP line_of_business_type = hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP routing_transit_number = hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact'] interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP interest_rate_type = hash.key?('interestRateType') ? hash['interestRateType'] : SKIP interest_rate_as_of = if hash.key?('interestRateAsOf') (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf']) else SKIP end prior_interest_rate = hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP interest_rate_index = hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP early_penalty_flag = hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP bill_pay_status = hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP last_activity_date = hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP reward_program_id = hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP # Parameter is an array, so we need to iterate through it reward_balances = nil unless hash['rewardBalances'].nil? reward_balances = [] hash['rewardBalances'].each do |structure| reward_balances << (RewardBalanceEntity.from_hash(structure) if structure) end end reward_balances = SKIP unless hash.key?('rewardBalances') transactions_included = hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP bank_institution_id = hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP bank_transit_id = hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP account_category = hash['accountCategory'] ||= 'Commercial Account entity' account_id = hash.key?('accountId') ? hash['accountId'] : SKIP parent_account_id = hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP error = Error3.from_hash(hash['error']) if hash['error'] account_type = hash.key?('accountType') ? hash['accountType'] : SKIP domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile'] account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP account_number_display = hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP product_id = hash.key?('productId') ? hash['productId'] : SKIP product_name = hash.key?('productName') ? hash['productName'] : SKIP nickname = hash.key?('nickname') ? hash['nickname'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP account_open_date = hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP account_close_date = hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency'] data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP transfer_out_use_cases = hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP # Parameter is an array, so we need to iterate through it fi_attributes = nil unless hash['fiAttributes'].nil? fi_attributes = [] hash['fiAttributes'].each do |structure| fi_attributes << (FiAttributeEntity.from_hash(structure) if structure) end end fi_attributes = SKIP unless hash.key?('fiAttributes') # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CommercialAccountEntity.new(earned_interest: earned_interest, balance_as_of: balance_as_of, opening_ledger_balance: opening_ledger_balance, closing_ledger_balance: closing_ledger_balance, current_ledger_balance: current_ledger_balance, opening_available_balance: opening_available_balance, current_available_balance: current_available_balance, closing_available_balance: closing_available_balance, next_day_available_balance: next_day_available_balance, two_days_plus_available_balance: two_days_plus_available_balance, number_of_outstanding_credits: number_of_outstanding_credits, outstanding_credits_amount: outstanding_credits_amount, number_of_outstanding_debits: number_of_outstanding_debits, outstanding_debits_amount: outstanding_debits_amount, transactions: transactions, commercial_balances: commercial_balances, line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 79 def self.names @_hash = {} if @_hash.nil? @_hash['earned_interest'] = 'earnedInterest' @_hash['balance_as_of'] = 'balanceAsOf' @_hash['opening_ledger_balance'] = 'openingLedgerBalance' @_hash['closing_ledger_balance'] = 'closingLedgerBalance' @_hash['current_ledger_balance'] = 'currentLedgerBalance' @_hash['opening_available_balance'] = 'openingAvailableBalance' @_hash['current_available_balance'] = 'currentAvailableBalance' @_hash['closing_available_balance'] = 'closingAvailableBalance' @_hash['next_day_available_balance'] = 'nextDayAvailableBalance' @_hash['two_days_plus_available_balance'] = 'twoDaysPlusAvailableBalance' @_hash['number_of_outstanding_credits'] = 'numberOfOutstandingCredits' @_hash['outstanding_credits_amount'] = 'outstandingCreditsAmount' @_hash['number_of_outstanding_debits'] = 'numberOfOutstandingDebits' @_hash['outstanding_debits_amount'] = 'outstandingDebitsAmount' @_hash['transactions'] = 'transactions' @_hash['commercial_balances'] = 'commercialBalances' @_hash = super().merge(@_hash) @_hash end |
.nullables ⇒ Object
An array for nullable fields
126 127 128 129 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 126 def self.nullables _arr = [] (_arr << super()).flatten! end |
.optionals ⇒ Object
An array for optional fields
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 103 def self.optionals _arr = %w[ earned_interest balance_as_of opening_ledger_balance closing_ledger_balance current_ledger_balance opening_available_balance current_available_balance closing_available_balance next_day_available_balance two_days_plus_available_balance number_of_outstanding_credits outstanding_credits_amount number_of_outstanding_debits outstanding_debits_amount transactions commercial_balances ] (_arr << super()).flatten! end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
473 474 475 476 477 478 479 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 473 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 500 def inspect class_name = self.class.name.split('::').last super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, earned_interest: #{@earned_interest.inspect},"\ " balance_as_of: #{@balance_as_of.inspect}, opening_ledger_balance:"\ " #{@opening_ledger_balance.inspect}, closing_ledger_balance:"\ " #{@closing_ledger_balance.inspect}, current_ledger_balance:"\ " #{@current_ledger_balance.inspect}, opening_available_balance:"\ " #{@opening_available_balance.inspect}, current_available_balance:"\ " #{@current_available_balance.inspect}, closing_available_balance:"\ " #{@closing_available_balance.inspect}, next_day_available_balance:"\ " #{@next_day_available_balance.inspect}, two_days_plus_available_balance:"\ " #{@two_days_plus_available_balance.inspect}, number_of_outstanding_credits:"\ " #{@number_of_outstanding_credits.inspect}, outstanding_credits_amount:"\ " #{@outstanding_credits_amount.inspect}, number_of_outstanding_debits:"\ " #{@number_of_outstanding_debits.inspect}, outstanding_debits_amount:"\ " #{@outstanding_debits_amount.inspect}, transactions: #{@transactions.inspect},"\ " commercial_balances: #{@commercial_balances.inspect}>" end |
#to_custom_balance_as_of ⇒ Object
467 468 469 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 467 def to_custom_balance_as_of DateTimeHelper.to_rfc3339(balance_as_of) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/fdx_v660_api/models/commercial_account_entity.rb', line 482 def to_s class_name = self.class.name.split('::').last super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, earned_interest: #{@earned_interest}, balance_as_of:"\ " #{@balance_as_of}, opening_ledger_balance: #{@opening_ledger_balance},"\ " closing_ledger_balance: #{@closing_ledger_balance}, current_ledger_balance:"\ " #{@current_ledger_balance}, opening_available_balance: #{@opening_available_balance},"\ " current_available_balance: #{@current_available_balance}, closing_available_balance:"\ " #{@closing_available_balance}, next_day_available_balance: #{@next_day_available_balance},"\ " two_days_plus_available_balance: #{@two_days_plus_available_balance},"\ " number_of_outstanding_credits: #{@number_of_outstanding_credits},"\ " outstanding_credits_amount: #{@outstanding_credits_amount}, number_of_outstanding_debits:"\ " #{@number_of_outstanding_debits}, outstanding_debits_amount:"\ " #{@outstanding_debits_amount}, transactions: #{@transactions}, commercial_balances:"\ " #{@commercial_balances}>" end |