Class: FdxV660Api::CommercialBalanceEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::CommercialBalanceEntity
- Defined in:
- lib/fdx_v660_api/models/commercial_balance_entity.rb
Overview
A specific treasury management defined balance
Instance Attribute Summary collapse
-
#amount ⇒ Float
The treasury management balance amount.
-
#commercial_code ⇒ CommercialCodeEntity1
The code for a specific treasury management defined field.
-
#memo ⇒ String
Memo field for the treasury management balance amount.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(commercial_code: SKIP, amount: SKIP, memo: SKIP, additional_properties: nil) ⇒ CommercialBalanceEntity
constructor
A new instance of CommercialBalanceEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(commercial_code: SKIP, amount: SKIP, memo: SKIP, additional_properties: nil) ⇒ CommercialBalanceEntity
Returns a new instance of CommercialBalanceEntity.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 47 def initialize(commercial_code: SKIP, amount: SKIP, memo: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @commercial_code = commercial_code unless commercial_code == SKIP @amount = amount unless amount == SKIP @memo = memo unless memo == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
The treasury management balance amount
18 19 20 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 18 def amount @amount end |
#commercial_code ⇒ CommercialCodeEntity1
The code for a specific treasury management defined field
14 15 16 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 14 def commercial_code @commercial_code end |
#memo ⇒ String
Memo field for the treasury management balance amount
22 23 24 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 22 def memo @memo end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. commercial_code = CommercialCodeEntity1.from_hash(hash['commercialCode']) if hash['commercialCode'] amount = hash.key?('amount') ? hash['amount'] : SKIP memo = hash.key?('memo') ? hash['memo'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CommercialBalanceEntity.new(commercial_code: commercial_code, amount: amount, memo: memo, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['commercial_code'] = 'commercialCode' @_hash['amount'] = 'amount' @_hash['memo'] = 'memo' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 34 def self.optionals %w[ commercial_code amount memo ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 84 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} commercial_code: #{@commercial_code.inspect}, amount: #{@amount.inspect},"\ " memo: #{@memo.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/fdx_v660_api/models/commercial_balance_entity.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} commercial_code: #{@commercial_code}, amount: #{@amount}, memo: #{@memo},"\ " additional_properties: #{@additional_properties}>" end |