Class: FdxV660Api::CurrencyEntity2
- Defined in:
- lib/fdx_v660_api/models/currency_entity2.rb
Overview
Currency if different from that of account
Instance Attribute Summary collapse
-
#currency_code ⇒ Iso4217CurrencyCode5
ISO 4217 currency code.
-
#currency_rate ⇒ Float
Currency rate between original and converted currency.
-
#original_currency_code ⇒ Iso4217CurrencyCode1
Original ISO 4217 currency code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(currency_rate: SKIP, currency_code: SKIP, original_currency_code: SKIP, additional_properties: nil) ⇒ CurrencyEntity2
constructor
A new instance of CurrencyEntity2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency_rate: SKIP, currency_code: SKIP, original_currency_code: SKIP, additional_properties: nil) ⇒ CurrencyEntity2
Returns a new instance of CurrencyEntity2.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 47 def initialize(currency_rate: SKIP, currency_code: SKIP, original_currency_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency_rate = currency_rate unless currency_rate == SKIP @currency_code = currency_code unless currency_code == SKIP @original_currency_code = original_currency_code unless original_currency_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#currency_code ⇒ Iso4217CurrencyCode5
ISO 4217 currency code
18 19 20 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 18 def currency_code @currency_code end |
#currency_rate ⇒ Float
Currency rate between original and converted currency
14 15 16 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 14 def currency_rate @currency_rate end |
#original_currency_code ⇒ Iso4217CurrencyCode1
Original ISO 4217 currency code
22 23 24 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 22 def original_currency_code @original_currency_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency_rate = hash.key?('currencyRate') ? hash['currencyRate'] : SKIP currency_code = hash.key?('currencyCode') ? hash['currencyCode'] : SKIP original_currency_code = hash.key?('originalCurrencyCode') ? hash['originalCurrencyCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CurrencyEntity2.new(currency_rate: currency_rate, currency_code: currency_code, original_currency_code: original_currency_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['currency_rate'] = 'currencyRate' @_hash['currency_code'] = 'currencyCode' @_hash['original_currency_code'] = 'originalCurrencyCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 34 def self.optionals %w[ currency_rate currency_code original_currency_code ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 84 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency_rate: #{@currency_rate.inspect}, currency_code:"\ " #{@currency_code.inspect}, original_currency_code: #{@original_currency_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/fdx_v660_api/models/currency_entity2.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency_rate: #{@currency_rate}, currency_code: #{@currency_code},"\ " original_currency_code: #{@original_currency_code}, additional_properties:"\ " #{@additional_properties}>" end |