Class: FdxV660Api::DepositAccountEntity
- Inherits:
-
AccountEntity
- Object
- CoreLibrary::BaseModel
- BaseModel
- AccountDescriptorEntity
- AccountEntity
- FdxV660Api::DepositAccountEntity
- Defined in:
- lib/fdx_v660_api/models/deposit_account_entity.rb
Overview
Information for a deposit account type
Instance Attribute Summary collapse
-
#annual_percentage_yield ⇒ Float
Annual Percentage Yield.
-
#available_balance ⇒ Float
Balance of funds available for use.
-
#balance_as_of ⇒ DateTime
As-of date of balances.
-
#current_balance ⇒ Float
Balance of funds in account.
-
#earned_interest ⇒ InterestRateEntity1
The periodic (usually monthly) interest rate earned on account balances.
-
#interest_ytd ⇒ Float
YTD Interest.
-
#maturity_date ⇒ Date
Maturity date for CDs.
-
#opening_day_balance ⇒ Float
Day's opening fund balance.
-
#overdraft_funding_sources ⇒ Array[FundingSource]
List of the customer's alternate funding sources from which FI can transfer funds to cover transactions if customer has overdraft protection from a consented account.
-
#overdraft_opt_in ⇒ TrueClass | FalseClass
Whether customer has opted-in to coverage for FI to allow transactions which overdraw their account balance due to a debit card payment or ATM withdrawal.
-
#overdraft_protection_funded ⇒ TrueClass | FalseClass
Whether customer has arranged alternate funding source(s) for FI to authorize and pay transactions on their account which might otherwise be declined or cause an overdraft on the account.
-
#overdrafted ⇒ TrueClass | FalseClass
Whether account currently has a negative or overdrafted account balance.
-
#term ⇒ Integer
Term of CD in months.
-
#transactions ⇒ Array[DepositTransactionEntity]
Transactions on the deposit account.
-
#under_arbitration ⇒ TrueClass | FalseClass
If
true, the account is currently under arbitration.
Attributes inherited from AccountEntity
#balance_type, #bank_institution_id, #bank_transit_id, #bill_pay_status, #contact, #early_penalty_flag, #interest_rate, #interest_rate_as_of, #interest_rate_index, #interest_rate_type, #last_activity_date, #line_of_business, #line_of_business_type, #micr_number, #prior_interest_rate, #reward_balances, #reward_program_id, #routing_transit_number, #transactions_included, #transfer_in, #transfer_out
Attributes inherited from AccountDescriptorEntity
#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(balance_as_of: SKIP, earned_interest: SKIP, current_balance: SKIP, opening_day_balance: SKIP, available_balance: SKIP, annual_percentage_yield: SKIP, interest_ytd: SKIP, term: SKIP, maturity_date: SKIP, under_arbitration: SKIP, overdraft_opt_in: SKIP, overdrafted: SKIP, overdraft_protection_funded: SKIP, overdraft_funding_sources: SKIP, transactions: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Deposit Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ DepositAccountEntity
constructor
A new instance of DepositAccountEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_balance_as_of ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from AccountEntity
discriminators, #to_custom_interest_rate_as_of
Methods inherited from AccountDescriptorEntity
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(balance_as_of: SKIP, earned_interest: SKIP, current_balance: SKIP, opening_day_balance: SKIP, available_balance: SKIP, annual_percentage_yield: SKIP, interest_ytd: SKIP, term: SKIP, maturity_date: SKIP, under_arbitration: SKIP, overdraft_opt_in: SKIP, overdrafted: SKIP, overdraft_protection_funded: SKIP, overdraft_funding_sources: SKIP, transactions: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Deposit Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ DepositAccountEntity
Returns a new instance of DepositAccountEntity.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 133 def initialize(balance_as_of: SKIP, earned_interest: SKIP, current_balance: SKIP, opening_day_balance: SKIP, available_balance: SKIP, annual_percentage_yield: SKIP, interest_ytd: SKIP, term: SKIP, maturity_date: SKIP, under_arbitration: SKIP, overdraft_opt_in: SKIP, overdrafted: SKIP, overdraft_protection_funded: SKIP, overdraft_funding_sources: SKIP, transactions: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Deposit Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) @balance_as_of = balance_as_of unless balance_as_of == SKIP @earned_interest = earned_interest unless earned_interest == SKIP @current_balance = current_balance unless current_balance == SKIP @opening_day_balance = opening_day_balance unless opening_day_balance == SKIP @available_balance = available_balance unless available_balance == SKIP @annual_percentage_yield = annual_percentage_yield unless annual_percentage_yield == SKIP @interest_ytd = interest_ytd unless interest_ytd == SKIP @term = term unless term == SKIP @maturity_date = maturity_date unless maturity_date == SKIP @under_arbitration = under_arbitration unless under_arbitration == SKIP @overdraft_opt_in = overdraft_opt_in unless overdraft_opt_in == SKIP @overdrafted = overdrafted unless overdrafted == SKIP unless overdraft_protection_funded == SKIP @overdraft_protection_funded = overdraft_protection_funded end unless overdraft_funding_sources == SKIP @overdraft_funding_sources = overdraft_funding_sources end @transactions = transactions unless transactions == SKIP @additional_properties = additional_properties # Call the constructor of the base class super(line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
Instance Attribute Details
#annual_percentage_yield ⇒ Float
Annual Percentage Yield
34 35 36 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 34 def annual_percentage_yield @annual_percentage_yield end |
#available_balance ⇒ Float
Balance of funds available for use
30 31 32 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 30 def available_balance @available_balance end |
#balance_as_of ⇒ DateTime
As-of date of balances
14 15 16 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 14 def balance_as_of @balance_as_of end |
#current_balance ⇒ Float
Balance of funds in account
22 23 24 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 22 def current_balance @current_balance end |
#earned_interest ⇒ InterestRateEntity1
The periodic (usually monthly) interest rate earned on account balances
18 19 20 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 18 def earned_interest @earned_interest end |
#interest_ytd ⇒ Float
YTD Interest
38 39 40 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 38 def interest_ytd @interest_ytd end |
#maturity_date ⇒ Date
Maturity date for CDs
46 47 48 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 46 def maturity_date @maturity_date end |
#opening_day_balance ⇒ Float
Day's opening fund balance
26 27 28 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 26 def opening_day_balance @opening_day_balance end |
#overdraft_funding_sources ⇒ Array[FundingSource]
List of the customer's alternate funding sources from which FI can transfer funds to cover transactions if customer has overdraft protection from a consented account. In the order of which accounts will be attempted to transfer the coverage amount needed. Contains masked or truncated account number or nickname, account type and/or institution name for full clarity on an internal or external funding source
75 76 77 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 75 def overdraft_funding_sources @overdraft_funding_sources end |
#overdraft_opt_in ⇒ TrueClass | FalseClass
Whether customer has opted-in to coverage for FI to allow transactions which overdraw their account balance due to a debit card payment or ATM withdrawal
56 57 58 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 56 def overdraft_opt_in @overdraft_opt_in end |
#overdraft_protection_funded ⇒ TrueClass | FalseClass
Whether customer has arranged alternate funding source(s) for FI to authorize and pay transactions on their account which might otherwise be declined or cause an overdraft on the account
66 67 68 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 66 def overdraft_protection_funded @overdraft_protection_funded end |
#overdrafted ⇒ TrueClass | FalseClass
Whether account currently has a negative or overdrafted account balance
60 61 62 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 60 def overdrafted @overdrafted end |
#term ⇒ Integer
Term of CD in months
42 43 44 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 42 def term @term end |
#transactions ⇒ Array[DepositTransactionEntity]
Transactions on the deposit account. Deprecated in release V6.3.1 and will
be removed in next major release. Transactions are returned in the
searchForAccountTransactions operation response.
81 82 83 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 81 def transactions @transactions end |
#under_arbitration ⇒ TrueClass | FalseClass
If true, the account is currently under arbitration
50 51 52 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 50 def under_arbitration @under_arbitration end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 228 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. balance_as_of = if hash.key?('balanceAsOf') (DateTimeHelper.from_rfc3339(hash['balanceAsOf']) if hash['balanceAsOf']) else SKIP end earned_interest = InterestRateEntity1.from_hash(hash['earnedInterest']) if hash['earnedInterest'] current_balance = hash.key?('currentBalance') ? hash['currentBalance'] : SKIP opening_day_balance = hash.key?('openingDayBalance') ? hash['openingDayBalance'] : SKIP available_balance = hash.key?('availableBalance') ? hash['availableBalance'] : SKIP annual_percentage_yield = hash.key?('annualPercentageYield') ? hash['annualPercentageYield'] : SKIP interest_ytd = hash.key?('interestYtd') ? hash['interestYtd'] : SKIP term = hash.key?('term') ? hash['term'] : SKIP maturity_date = hash.key?('maturityDate') ? hash['maturityDate'] : SKIP under_arbitration = hash.key?('underArbitration') ? hash['underArbitration'] : SKIP overdraft_opt_in = hash.key?('overdraftOptIn') ? hash['overdraftOptIn'] : SKIP overdrafted = hash.key?('overdrafted') ? hash['overdrafted'] : SKIP overdraft_protection_funded = hash.key?('overdraftProtectionFunded') ? hash['overdraftProtectionFunded'] : SKIP # Parameter is an array, so we need to iterate through it overdraft_funding_sources = nil unless hash['overdraftFundingSources'].nil? overdraft_funding_sources = [] hash['overdraftFundingSources'].each do |structure| overdraft_funding_sources << (FundingSource.from_hash(structure) if structure) end end overdraft_funding_sources = SKIP unless hash.key?('overdraftFundingSources') # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (DepositTransactionEntity.from_hash(structure) if structure) end end transactions = SKIP unless hash.key?('transactions') line_of_business = hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP line_of_business_type = hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP routing_transit_number = hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact'] interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP interest_rate_type = hash.key?('interestRateType') ? hash['interestRateType'] : SKIP interest_rate_as_of = if hash.key?('interestRateAsOf') (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf']) else SKIP end prior_interest_rate = hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP interest_rate_index = hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP early_penalty_flag = hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP bill_pay_status = hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP last_activity_date = hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP reward_program_id = hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP # Parameter is an array, so we need to iterate through it reward_balances = nil unless hash['rewardBalances'].nil? reward_balances = [] hash['rewardBalances'].each do |structure| reward_balances << (RewardBalanceEntity.from_hash(structure) if structure) end end reward_balances = SKIP unless hash.key?('rewardBalances') transactions_included = hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP bank_institution_id = hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP bank_transit_id = hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP account_category = hash['accountCategory'] ||= 'Deposit Account entity' account_id = hash.key?('accountId') ? hash['accountId'] : SKIP parent_account_id = hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP error = Error3.from_hash(hash['error']) if hash['error'] account_type = hash.key?('accountType') ? hash['accountType'] : SKIP domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile'] account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP account_number_display = hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP product_id = hash.key?('productId') ? hash['productId'] : SKIP product_name = hash.key?('productName') ? hash['productName'] : SKIP nickname = hash.key?('nickname') ? hash['nickname'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP account_open_date = hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP account_close_date = hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency'] data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP transfer_out_use_cases = hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP # Parameter is an array, so we need to iterate through it fi_attributes = nil unless hash['fiAttributes'].nil? fi_attributes = [] hash['fiAttributes'].each do |structure| fi_attributes << (FiAttributeEntity.from_hash(structure) if structure) end end fi_attributes = SKIP unless hash.key?('fiAttributes') # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DepositAccountEntity.new(balance_as_of: balance_as_of, earned_interest: earned_interest, current_balance: current_balance, opening_day_balance: opening_day_balance, available_balance: available_balance, annual_percentage_yield: annual_percentage_yield, interest_ytd: interest_ytd, term: term, maturity_date: maturity_date, under_arbitration: under_arbitration, overdraft_opt_in: overdraft_opt_in, overdrafted: overdrafted, overdraft_protection_funded: overdraft_protection_funded, overdraft_funding_sources: overdraft_funding_sources, transactions: transactions, line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 84 def self.names @_hash = {} if @_hash.nil? @_hash['balance_as_of'] = 'balanceAsOf' @_hash['earned_interest'] = 'earnedInterest' @_hash['current_balance'] = 'currentBalance' @_hash['opening_day_balance'] = 'openingDayBalance' @_hash['available_balance'] = 'availableBalance' @_hash['annual_percentage_yield'] = 'annualPercentageYield' @_hash['interest_ytd'] = 'interestYtd' @_hash['term'] = 'term' @_hash['maturity_date'] = 'maturityDate' @_hash['under_arbitration'] = 'underArbitration' @_hash['overdraft_opt_in'] = 'overdraftOptIn' @_hash['overdrafted'] = 'overdrafted' @_hash['overdraft_protection_funded'] = 'overdraftProtectionFunded' @_hash['overdraft_funding_sources'] = 'overdraftFundingSources' @_hash['transactions'] = 'transactions' @_hash = super().merge(@_hash) @_hash end |
.nullables ⇒ Object
An array for nullable fields
128 129 130 131 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 128 def self.nullables _arr = [] (_arr << super()).flatten! end |
.optionals ⇒ Object
An array for optional fields
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 106 def self.optionals _arr = %w[ balance_as_of earned_interest current_balance opening_day_balance available_balance annual_percentage_yield interest_ytd term maturity_date under_arbitration overdraft_opt_in overdrafted overdraft_protection_funded overdraft_funding_sources transactions ] (_arr << super()).flatten! end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
441 442 443 444 445 446 447 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 441 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 464 def inspect class_name = self.class.name.split('::').last super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, balance_as_of: #{@balance_as_of.inspect}, earned_interest:"\ " #{@earned_interest.inspect}, current_balance: #{@current_balance.inspect},"\ " opening_day_balance: #{@opening_day_balance.inspect}, available_balance:"\ " #{@available_balance.inspect}, annual_percentage_yield:"\ " #{@annual_percentage_yield.inspect}, interest_ytd: #{@interest_ytd.inspect}, term:"\ " #{@term.inspect}, maturity_date: #{@maturity_date.inspect}, under_arbitration:"\ " #{@under_arbitration.inspect}, overdraft_opt_in: #{@overdraft_opt_in.inspect},"\ " overdrafted: #{@overdrafted.inspect}, overdraft_protection_funded:"\ " #{@overdraft_protection_funded.inspect}, overdraft_funding_sources:"\ " #{@overdraft_funding_sources.inspect}, transactions: #{@transactions.inspect}>" end |
#to_custom_balance_as_of ⇒ Object
435 436 437 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 435 def to_custom_balance_as_of DateTimeHelper.to_rfc3339(balance_as_of) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/fdx_v660_api/models/deposit_account_entity.rb', line 450 def to_s class_name = self.class.name.split('::').last super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, balance_as_of: #{@balance_as_of}, earned_interest:"\ " #{@earned_interest}, current_balance: #{@current_balance}, opening_day_balance:"\ " #{@opening_day_balance}, available_balance: #{@available_balance},"\ " annual_percentage_yield: #{@annual_percentage_yield}, interest_ytd: #{@interest_ytd},"\ " term: #{@term}, maturity_date: #{@maturity_date}, under_arbitration:"\ " #{@under_arbitration}, overdraft_opt_in: #{@overdraft_opt_in}, overdrafted:"\ " #{@overdrafted}, overdraft_protection_funded: #{@overdraft_protection_funded},"\ " overdraft_funding_sources: #{@overdraft_funding_sources}, transactions: #{@transactions}>" end |