Class: FdxV660Api::Form1095A
- Defined in:
- lib/fdx_v660_api/models/form1095_a.rb
Overview
Health Insurance Marketplace Statement, to Recipient (boxes 4-5, 12-15)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#coverages ⇒ Array[HealthInsuranceCoverage]
Boxes 21-33, Coverage Information.
-
#covered_individuals ⇒ Array[HealthInsuranceMarketplaceCoveredIndividual]
Boxes 16+, Covered Individuals.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#marketplace_id ⇒ String
Box 1, Marketplace identifier.
-
#marketplace_policy_number ⇒ String
Box 2, Marketplace-assigned policy number.
-
#policy_issuer_name ⇒ String
Box 3, Policy issuer's name.
-
#policy_start_date ⇒ Date
Box 10, Policy start date.
-
#policy_termination_date ⇒ Date
Box 11, Policy termination date.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#recipient_date_of_birth ⇒ Date
Box 6, Recipient's date of birth.
-
#spouse_date_of_birth ⇒ Date
Box 9, Recipient's spouse's date of birth.
-
#spouse_name ⇒ String
Box 7, Recipient's spouse's name.
-
#spouse_tin ⇒ String
Box 8, Recipient's spouse's SSN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, marketplace_id: SKIP, marketplace_policy_number: SKIP, policy_issuer_name: SKIP, recipient_date_of_birth: SKIP, spouse_name: SKIP, spouse_tin: SKIP, spouse_date_of_birth: SKIP, policy_start_date: SKIP, policy_termination_date: SKIP, covered_individuals: SKIP, coverages: SKIP, additional_properties: nil) ⇒ Form1095A
constructor
A new instance of Form1095A.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, marketplace_id: SKIP, marketplace_policy_number: SKIP, policy_issuer_name: SKIP, recipient_date_of_birth: SKIP, spouse_name: SKIP, spouse_tin: SKIP, spouse_date_of_birth: SKIP, policy_start_date: SKIP, policy_termination_date: SKIP, covered_individuals: SKIP, coverages: SKIP, additional_properties: nil) ⇒ Form1095A
Returns a new instance of Form1095A.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 180 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, marketplace_id: SKIP, marketplace_policy_number: SKIP, policy_issuer_name: SKIP, recipient_date_of_birth: SKIP, spouse_name: SKIP, spouse_tin: SKIP, spouse_date_of_birth: SKIP, policy_start_date: SKIP, policy_termination_date: SKIP, covered_individuals: SKIP, coverages: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @marketplace_id = marketplace_id unless marketplace_id == SKIP unless marketplace_policy_number == SKIP @marketplace_policy_number = marketplace_policy_number end @policy_issuer_name = policy_issuer_name unless policy_issuer_name == SKIP @recipient_date_of_birth = recipient_date_of_birth unless recipient_date_of_birth == SKIP @spouse_name = spouse_name unless spouse_name == SKIP @spouse_tin = spouse_tin unless spouse_tin == SKIP @spouse_date_of_birth = spouse_date_of_birth unless spouse_date_of_birth == SKIP @policy_start_date = policy_start_date unless policy_start_date == SKIP @policy_termination_date = policy_termination_date unless policy_termination_date == SKIP @covered_individuals = covered_individuals unless covered_individuals == SKIP @coverages = coverages unless coverages == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 23 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 37 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 63 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 18 def corrected @corrected end |
#coverages ⇒ Array[HealthInsuranceCoverage]
Boxes 21-33, Coverage Information
115 116 117 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 115 def coverages @coverages end |
#covered_individuals ⇒ Array[HealthInsuranceMarketplaceCoveredIndividual]
Boxes 16+, Covered Individuals
111 112 113 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 111 def covered_individuals @covered_individuals end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 67 def error @error end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 71 def links @links end |
#marketplace_id ⇒ String
Box 1, Marketplace identifier
75 76 77 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 75 def marketplace_id @marketplace_id end |
#marketplace_policy_number ⇒ String
Box 2, Marketplace-assigned policy number
79 80 81 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 79 def marketplace_policy_number @marketplace_policy_number end |
#policy_issuer_name ⇒ String
Box 3, Policy issuer's name
83 84 85 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 83 def policy_issuer_name @policy_issuer_name end |
#policy_start_date ⇒ Date
Box 10, Policy start date
103 104 105 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 103 def policy_start_date @policy_start_date end |
#policy_termination_date ⇒ Date
Box 11, Policy termination date
107 108 109 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 107 def policy_termination_date @policy_termination_date end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 53 def recipient @recipient end |
#recipient_date_of_birth ⇒ Date
Box 6, Recipient's date of birth
87 88 89 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 87 def recipient_date_of_birth @recipient_date_of_birth end |
#spouse_date_of_birth ⇒ Date
Box 9, Recipient's spouse's date of birth
99 100 101 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 99 def spouse_date_of_birth @spouse_date_of_birth end |
#spouse_name ⇒ String
Box 7, Recipient's spouse's name
91 92 93 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 91 def spouse_name @spouse_name end |
#spouse_tin ⇒ String
Box 8, Recipient's spouse's SSN
95 96 97 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 95 def spouse_tin @spouse_tin end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 14 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 224 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') marketplace_id = hash.key?('marketplaceId') ? hash['marketplaceId'] : SKIP marketplace_policy_number = hash.key?('marketplacePolicyNumber') ? hash['marketplacePolicyNumber'] : SKIP policy_issuer_name = hash.key?('policyIssuerName') ? hash['policyIssuerName'] : SKIP recipient_date_of_birth = hash.key?('recipientDateOfBirth') ? hash['recipientDateOfBirth'] : SKIP spouse_name = hash.key?('spouseName') ? hash['spouseName'] : SKIP spouse_tin = hash.key?('spouseTin') ? hash['spouseTin'] : SKIP spouse_date_of_birth = hash.key?('spouseDateOfBirth') ? hash['spouseDateOfBirth'] : SKIP policy_start_date = hash.key?('policyStartDate') ? hash['policyStartDate'] : SKIP policy_termination_date = hash.key?('policyTerminationDate') ? hash['policyTerminationDate'] : SKIP # Parameter is an array, so we need to iterate through it covered_individuals = nil unless hash['coveredIndividuals'].nil? covered_individuals = [] hash['coveredIndividuals'].each do |structure| covered_individuals << (HealthInsuranceMarketplaceCoveredIndividual.from_hash(structure) if structure) end end covered_individuals = SKIP unless hash.key?('coveredIndividuals') # Parameter is an array, so we need to iterate through it coverages = nil unless hash['coverages'].nil? coverages = [] hash['coverages'].each do |structure| coverages << (HealthInsuranceCoverage.from_hash(structure) if structure) end end coverages = SKIP unless hash.key?('coverages') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1095A.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, marketplace_id: marketplace_id, marketplace_policy_number: marketplace_policy_number, policy_issuer_name: policy_issuer_name, recipient_date_of_birth: recipient_date_of_birth, spouse_name: spouse_name, spouse_tin: spouse_tin, spouse_date_of_birth: spouse_date_of_birth, policy_start_date: policy_start_date, policy_termination_date: policy_termination_date, covered_individuals: covered_individuals, coverages: coverages, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 118 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['marketplace_id'] = 'marketplaceId' @_hash['marketplace_policy_number'] = 'marketplacePolicyNumber' @_hash['policy_issuer_name'] = 'policyIssuerName' @_hash['recipient_date_of_birth'] = 'recipientDateOfBirth' @_hash['spouse_name'] = 'spouseName' @_hash['spouse_tin'] = 'spouseTin' @_hash['spouse_date_of_birth'] = 'spouseDateOfBirth' @_hash['policy_start_date'] = 'policyStartDate' @_hash['policy_termination_date'] = 'policyTerminationDate' @_hash['covered_individuals'] = 'coveredIndividuals' @_hash['coverages'] = 'coverages' @_hash end |
.nullables ⇒ Object
An array for nullable fields
176 177 178 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 176 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 147 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links marketplace_id marketplace_policy_number policy_issuer_name recipient_date_of_birth spouse_name spouse_tin spouse_date_of_birth policy_start_date policy_termination_date covered_individuals coverages ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 347 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, marketplace_id: #{@marketplace_id.inspect},"\ " marketplace_policy_number: #{@marketplace_policy_number.inspect}, policy_issuer_name:"\ " #{@policy_issuer_name.inspect}, recipient_date_of_birth:"\ " #{@recipient_date_of_birth.inspect}, spouse_name: #{@spouse_name.inspect}, spouse_tin:"\ " #{@spouse_tin.inspect}, spouse_date_of_birth: #{@spouse_date_of_birth.inspect},"\ " policy_start_date: #{@policy_start_date.inspect}, policy_termination_date:"\ " #{@policy_termination_date.inspect}, covered_individuals: #{@covered_individuals.inspect},"\ " coverages: #{@coverages.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/fdx_v660_api/models/form1095_a.rb', line 330 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, marketplace_id: #{@marketplace_id},"\ " marketplace_policy_number: #{@marketplace_policy_number}, policy_issuer_name:"\ " #{@policy_issuer_name}, recipient_date_of_birth: #{@recipient_date_of_birth}, spouse_name:"\ " #{@spouse_name}, spouse_tin: #{@spouse_tin}, spouse_date_of_birth:"\ " #{@spouse_date_of_birth}, policy_start_date: #{@policy_start_date},"\ " policy_termination_date: #{@policy_termination_date}, covered_individuals:"\ " #{@covered_individuals}, coverages: #{@coverages}, additional_properties:"\ " #{@additional_properties}>" end |