Class: FdxV660Api::Form1098Q1
- Defined in:
- lib/fdx_v660_api/models/form1098_q1.rb
Overview
Qualifying Longevity Annuity Contract Information
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#annuity_amount ⇒ Float
Box 1a, Annuity amount on start date.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#can_be_accelerated ⇒ TrueClass | FalseClass
Box 2, Start date may be accelerated.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#fair_market_value ⇒ Float
Box 4, Fair market value of qualifying longevity annuity contract (FMV of QLAC).
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#plan_name ⇒ String
Plan name.
-
#plan_number ⇒ String
Plan number.
-
#plan_sponsor_id ⇒ String
Plan sponsor's EIN.
-
#premiums ⇒ Array[DateAndAmount]
Box 5, Total monthly premiums paid for the contract and date of the last payment in the month.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#start_date ⇒ Date
Box 1b, Annuity start date.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#total_premiums ⇒ Float
Box 3, Total premiums.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, plan_number: SKIP, plan_name: SKIP, plan_sponsor_id: SKIP, annuity_amount: SKIP, start_date: SKIP, can_be_accelerated: SKIP, total_premiums: SKIP, fair_market_value: SKIP, premiums: SKIP, additional_properties: nil) ⇒ Form1098Q1
constructor
A new instance of Form1098Q1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, plan_number: SKIP, plan_name: SKIP, plan_sponsor_id: SKIP, annuity_amount: SKIP, start_date: SKIP, can_be_accelerated: SKIP, total_premiums: SKIP, fair_market_value: SKIP, premiums: SKIP, additional_properties: nil) ⇒ Form1098Q1
Returns a new instance of Form1098Q1.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 176 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, plan_number: SKIP, plan_name: SKIP, plan_sponsor_id: SKIP, annuity_amount: SKIP, start_date: SKIP, can_be_accelerated: SKIP, total_premiums: SKIP, fair_market_value: SKIP, premiums: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @plan_number = plan_number unless plan_number == SKIP @plan_name = plan_name unless plan_name == SKIP @plan_sponsor_id = plan_sponsor_id unless plan_sponsor_id == SKIP @annuity_amount = annuity_amount unless annuity_amount == SKIP @start_date = start_date unless start_date == SKIP @can_be_accelerated = can_be_accelerated unless can_be_accelerated == SKIP @total_premiums = total_premiums unless total_premiums == SKIP @fair_market_value = fair_market_value unless fair_market_value == SKIP @premiums = premiums unless premiums == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 23 def account_id @account_id end |
#account_number ⇒ String
Account number
75 76 77 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 75 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 37 def additional_information @additional_information end |
#annuity_amount ⇒ Float
Box 1a, Annuity amount on start date
91 92 93 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 91 def annuity_amount @annuity_amount end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 63 def attributes @attributes end |
#can_be_accelerated ⇒ TrueClass | FalseClass
Box 2, Start date may be accelerated
99 100 101 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 99 def can_be_accelerated @can_be_accelerated end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 18 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 67 def error @error end |
#fair_market_value ⇒ Float
Box 4, Fair market value of qualifying longevity annuity contract (FMV of QLAC)
108 109 110 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 108 def fair_market_value @fair_market_value end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 71 def links @links end |
#plan_name ⇒ String
Plan name
83 84 85 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 83 def plan_name @plan_name end |
#plan_number ⇒ String
Plan number
79 80 81 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 79 def plan_number @plan_number end |
#plan_sponsor_id ⇒ String
Plan sponsor's EIN
87 88 89 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 87 def plan_sponsor_id @plan_sponsor_id end |
#premiums ⇒ Array[DateAndAmount]
Box 5, Total monthly premiums paid for the contract and date of the last payment in the month
113 114 115 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 113 def premiums @premiums end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 53 def recipient @recipient end |
#start_date ⇒ Date
Box 1b, Annuity start date
95 96 97 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 95 def start_date @start_date end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 14 def tax_year @tax_year end |
#total_premiums ⇒ Float
Box 3, Total premiums
103 104 105 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 103 def total_premiums @total_premiums end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 214 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP plan_number = hash.key?('planNumber') ? hash['planNumber'] : SKIP plan_name = hash.key?('planName') ? hash['planName'] : SKIP plan_sponsor_id = hash.key?('planSponsorId') ? hash['planSponsorId'] : SKIP annuity_amount = hash.key?('annuityAmount') ? hash['annuityAmount'] : SKIP start_date = hash.key?('startDate') ? hash['startDate'] : SKIP can_be_accelerated = hash.key?('canBeAccelerated') ? hash['canBeAccelerated'] : SKIP total_premiums = hash.key?('totalPremiums') ? hash['totalPremiums'] : SKIP fair_market_value = hash.key?('fairMarketValue') ? hash['fairMarketValue'] : SKIP # Parameter is an array, so we need to iterate through it premiums = nil unless hash['premiums'].nil? premiums = [] hash['premiums'].each do |structure| premiums << (DateAndAmount.from_hash(structure) if structure) end end premiums = SKIP unless hash.key?('premiums') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1098Q1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, plan_number: plan_number, plan_name: plan_name, plan_sponsor_id: plan_sponsor_id, annuity_amount: annuity_amount, start_date: start_date, can_be_accelerated: can_be_accelerated, total_premiums: total_premiums, fair_market_value: fair_market_value, premiums: premiums, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 116 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['plan_number'] = 'planNumber' @_hash['plan_name'] = 'planName' @_hash['plan_sponsor_id'] = 'planSponsorId' @_hash['annuity_amount'] = 'annuityAmount' @_hash['start_date'] = 'startDate' @_hash['can_be_accelerated'] = 'canBeAccelerated' @_hash['total_premiums'] = 'totalPremiums' @_hash['fair_market_value'] = 'fairMarketValue' @_hash['premiums'] = 'premiums' @_hash end |
.nullables ⇒ Object
An array for nullable fields
172 173 174 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 172 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 144 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number plan_number plan_name plan_sponsor_id annuity_amount start_date can_be_accelerated total_premiums fair_market_value premiums ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 321 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, plan_number:"\ " #{@plan_number.inspect}, plan_name: #{@plan_name.inspect}, plan_sponsor_id:"\ " #{@plan_sponsor_id.inspect}, annuity_amount: #{@annuity_amount.inspect}, start_date:"\ " #{@start_date.inspect}, can_be_accelerated: #{@can_be_accelerated.inspect},"\ " total_premiums: #{@total_premiums.inspect}, fair_market_value:"\ " #{@fair_market_value.inspect}, premiums: #{@premiums.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/fdx_v660_api/models/form1098_q1.rb', line 306 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, plan_number:"\ " #{@plan_number}, plan_name: #{@plan_name}, plan_sponsor_id: #{@plan_sponsor_id},"\ " annuity_amount: #{@annuity_amount}, start_date: #{@start_date}, can_be_accelerated:"\ " #{@can_be_accelerated}, total_premiums: #{@total_premiums}, fair_market_value:"\ " #{@fair_market_value}, premiums: #{@premiums}, additional_properties:"\ " #{@additional_properties}>" end |