Class: FdxV660Api::Form1098T1
- Defined in:
- lib/fdx_v660_api/models/form1098_t1.rb
Overview
Tuition Statement
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#adjust_scholarship ⇒ Float
Box 6, Adjustments to scholarships or grants for a prior year.
-
#adjustment_prior_year ⇒ Float
Box 4, Adjustments made for a prior year.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#graduate ⇒ TrueClass | FalseClass
Box 9, Check if graduate student.
-
#half_time ⇒ TrueClass | FalseClass
Box 8, Check if at least half-time student.
-
#include_jan_mar ⇒ TrueClass | FalseClass
Box 7, Check if the amount in box 1 or box 2 includes amounts for an academic period beginning January - March of next year.
-
#insurance_refund ⇒ Float
Box 10, Insurance contract reimbursement / refund.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#qualified_tuition_fees ⇒ Float
Box 1, Payments received for qualified tuition and related expenses.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#scholarship ⇒ Float
Box 5, Scholarships or grants.
-
#student_tin_certification ⇒ TrueClass | FalseClass
By checking the box in STUDENT'S TIN, filer is making a true and accurate certification under penalty of perjury that they have complied with standards promulgated by the Secretary for obtaining such individual's TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, student_tin_certification: SKIP, account_number: SKIP, half_time: SKIP, qualified_tuition_fees: SKIP, adjustment_prior_year: SKIP, scholarship: SKIP, adjust_scholarship: SKIP, include_jan_mar: SKIP, graduate: SKIP, insurance_refund: SKIP, additional_properties: nil) ⇒ Form1098T1
constructor
A new instance of Form1098T1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, student_tin_certification: SKIP, account_number: SKIP, half_time: SKIP, qualified_tuition_fees: SKIP, adjustment_prior_year: SKIP, scholarship: SKIP, adjust_scholarship: SKIP, include_jan_mar: SKIP, graduate: SKIP, insurance_refund: SKIP, additional_properties: nil) ⇒ Form1098T1
Returns a new instance of Form1098T1.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 177 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, student_tin_certification: SKIP, account_number: SKIP, half_time: SKIP, qualified_tuition_fees: SKIP, adjustment_prior_year: SKIP, scholarship: SKIP, adjust_scholarship: SKIP, include_jan_mar: SKIP, graduate: SKIP, insurance_refund: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP unless student_tin_certification == SKIP @student_tin_certification = student_tin_certification end @account_number = account_number unless account_number == SKIP @half_time = half_time unless half_time == SKIP @qualified_tuition_fees = qualified_tuition_fees unless qualified_tuition_fees == SKIP @adjustment_prior_year = adjustment_prior_year unless adjustment_prior_year == SKIP @scholarship = scholarship unless scholarship == SKIP @adjust_scholarship = adjust_scholarship unless adjust_scholarship == SKIP @include_jan_mar = include_jan_mar unless include_jan_mar == SKIP @graduate = graduate unless graduate == SKIP @insurance_refund = insurance_refund unless insurance_refund == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 23 def account_id @account_id end |
#account_number ⇒ String
Account number
81 82 83 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 81 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 37 def additional_information @additional_information end |
#adjust_scholarship ⇒ Float
Box 6, Adjustments to scholarships or grants for a prior year
101 102 103 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 101 def adjust_scholarship @adjust_scholarship end |
#adjustment_prior_year ⇒ Float
Box 4, Adjustments made for a prior year
93 94 95 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 93 def adjustment_prior_year @adjustment_prior_year end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 63 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 18 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 67 def error @error end |
#graduate ⇒ TrueClass | FalseClass
Box 9, Check if graduate student
110 111 112 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 110 def graduate @graduate end |
#half_time ⇒ TrueClass | FalseClass
Box 8, Check if at least half-time student
85 86 87 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 85 def half_time @half_time end |
#include_jan_mar ⇒ TrueClass | FalseClass
Box 7, Check if the amount in box 1 or box 2 includes amounts for an academic period beginning January - March of next year
106 107 108 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 106 def include_jan_mar @include_jan_mar end |
#insurance_refund ⇒ Float
Box 10, Insurance contract reimbursement / refund
114 115 116 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 114 def insurance_refund @insurance_refund end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 71 def links @links end |
#qualified_tuition_fees ⇒ Float
Box 1, Payments received for qualified tuition and related expenses
89 90 91 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 89 def qualified_tuition_fees @qualified_tuition_fees end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 53 def recipient @recipient end |
#scholarship ⇒ Float
Box 5, Scholarships or grants
97 98 99 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 97 def scholarship @scholarship end |
#student_tin_certification ⇒ TrueClass | FalseClass
By checking the box in STUDENT'S TIN, filer is making a true and accurate certification under penalty of perjury that they have complied with standards promulgated by the Secretary for obtaining such individual's TIN
77 78 79 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 77 def student_tin_certification @student_tin_certification end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 14 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 219 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') student_tin_certification = hash.key?('studentTinCertification') ? hash['studentTinCertification'] : SKIP account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP half_time = hash.key?('halfTime') ? hash['halfTime'] : SKIP qualified_tuition_fees = hash.key?('qualifiedTuitionFees') ? hash['qualifiedTuitionFees'] : SKIP adjustment_prior_year = hash.key?('adjustmentPriorYear') ? hash['adjustmentPriorYear'] : SKIP scholarship = hash.key?('scholarship') ? hash['scholarship'] : SKIP adjust_scholarship = hash.key?('adjustScholarship') ? hash['adjustScholarship'] : SKIP include_jan_mar = hash.key?('includeJanMar') ? hash['includeJanMar'] : SKIP graduate = hash.key?('graduate') ? hash['graduate'] : SKIP insurance_refund = hash.key?('insuranceRefund') ? hash['insuranceRefund'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1098T1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, student_tin_certification: student_tin_certification, account_number: account_number, half_time: half_time, qualified_tuition_fees: qualified_tuition_fees, adjustment_prior_year: adjustment_prior_year, scholarship: scholarship, adjust_scholarship: adjust_scholarship, include_jan_mar: include_jan_mar, graduate: graduate, insurance_refund: insurance_refund, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 117 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['student_tin_certification'] = 'studentTinCertification' @_hash['account_number'] = 'accountNumber' @_hash['half_time'] = 'halfTime' @_hash['qualified_tuition_fees'] = 'qualifiedTuitionFees' @_hash['adjustment_prior_year'] = 'adjustmentPriorYear' @_hash['scholarship'] = 'scholarship' @_hash['adjust_scholarship'] = 'adjustScholarship' @_hash['include_jan_mar'] = 'includeJanMar' @_hash['graduate'] = 'graduate' @_hash['insurance_refund'] = 'insuranceRefund' @_hash end |
.nullables ⇒ Object
An array for nullable fields
173 174 175 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 173 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 145 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links student_tin_certification account_number half_time qualified_tuition_fees adjustment_prior_year scholarship adjust_scholarship include_jan_mar graduate insurance_refund ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 320 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, student_tin_certification:"\ " #{@student_tin_certification.inspect}, account_number: #{@account_number.inspect},"\ " half_time: #{@half_time.inspect}, qualified_tuition_fees:"\ " #{@qualified_tuition_fees.inspect}, adjustment_prior_year:"\ " #{@adjustment_prior_year.inspect}, scholarship: #{@scholarship.inspect},"\ " adjust_scholarship: #{@adjust_scholarship.inspect}, include_jan_mar:"\ " #{@include_jan_mar.inspect}, graduate: #{@graduate.inspect}, insurance_refund:"\ " #{@insurance_refund.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/fdx_v660_api/models/form1098_t1.rb', line 305 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, student_tin_certification: #{@student_tin_certification},"\ " account_number: #{@account_number}, half_time: #{@half_time}, qualified_tuition_fees:"\ " #{@qualified_tuition_fees}, adjustment_prior_year: #{@adjustment_prior_year}, scholarship:"\ " #{@scholarship}, adjust_scholarship: #{@adjust_scholarship}, include_jan_mar:"\ " #{@include_jan_mar}, graduate: #{@graduate}, insurance_refund: #{@insurance_refund},"\ " additional_properties: #{@additional_properties}>" end |