Class: FdxV660Api::Form1099Misc
- Defined in:
- lib/fdx_v660_api/models/form1099_misc.rb
Overview
Miscellaneous Income, from PAYER (1st-9th boxes as issuer) to RECIPIENT (10th-17th boxes)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#crop_insurance ⇒ Float
Box 9, Crop insurance proceeds.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#excess_golden ⇒ Float
Excess golden parachute payments.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#fish_purchased ⇒ Float
Box 11, Fish purchased for resale.
-
#fishing_boat_proceeds ⇒ Float
Box 5, Fishing boat proceeds.
-
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
FATCA filing requirement.
-
#gross_attorney ⇒ Float
Box 10, Gross proceeds paid to an attorney.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#medical_health_payment ⇒ Float
Box 6, Medical and health care payments.
-
#non_qualified_deferred_compensation ⇒ Float
Box 15, Nonqualified Deferred Compensation.
-
#occupation_codes ⇒ Array[String]
Box 13b, Treasury Tipped Occupation Codes (TTOC).
-
#other_income ⇒ Float
Box 3, Other income.
-
#overtime ⇒ Float
Box 14, Overtime compensation.
-
#payer_direct_sales ⇒ TrueClass | FalseClass
Box 7, Payer made direct sales of $5,000 or more of consumer products to a buyer (recipient) for resale.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#rents ⇒ Float
Box 1, Rents.
-
#royalties ⇒ Float
Box 2, Royalties.
-
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice.
-
#section409_a_deferrals ⇒ Float
Box 12, Section 409A deferrals.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 16-18, State and Local tax withholding.
-
#substitute_payments ⇒ Float
Box 8, Substitute payments in lieu of dividends or interest.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#tips ⇒ Float
Box 13a, Cash tips.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, rents: SKIP, royalties: SKIP, other_income: SKIP, federal_tax_withheld: SKIP, fishing_boat_proceeds: SKIP, medical_health_payment: SKIP, payer_direct_sales: SKIP, substitute_payments: SKIP, crop_insurance: SKIP, second_tin_notice: SKIP, gross_attorney: SKIP, fish_purchased: SKIP, section409_a_deferrals: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, foreign_account_tax_compliance: SKIP, excess_golden: SKIP, non_qualified_deferred_compensation: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099Misc
constructor
A new instance of Form1099Misc.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, rents: SKIP, royalties: SKIP, other_income: SKIP, federal_tax_withheld: SKIP, fishing_boat_proceeds: SKIP, medical_health_payment: SKIP, payer_direct_sales: SKIP, substitute_payments: SKIP, crop_insurance: SKIP, second_tin_notice: SKIP, gross_attorney: SKIP, fish_purchased: SKIP, section409_a_deferrals: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, foreign_account_tax_compliance: SKIP, excess_golden: SKIP, non_qualified_deferred_compensation: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099Misc
Returns a new instance of Form1099Misc.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 244 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, rents: SKIP, royalties: SKIP, other_income: SKIP, federal_tax_withheld: SKIP, fishing_boat_proceeds: SKIP, medical_health_payment: SKIP, payer_direct_sales: SKIP, substitute_payments: SKIP, crop_insurance: SKIP, second_tin_notice: SKIP, gross_attorney: SKIP, fish_purchased: SKIP, section409_a_deferrals: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, foreign_account_tax_compliance: SKIP, excess_golden: SKIP, non_qualified_deferred_compensation: SKIP, state_and_local: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @rents = rents unless rents == SKIP @royalties = royalties unless royalties == SKIP @other_income = other_income unless other_income == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @fishing_boat_proceeds = fishing_boat_proceeds unless fishing_boat_proceeds == SKIP @medical_health_payment = medical_health_payment unless medical_health_payment == SKIP @payer_direct_sales = payer_direct_sales unless payer_direct_sales == SKIP @substitute_payments = substitute_payments unless substitute_payments == SKIP @crop_insurance = crop_insurance unless crop_insurance == SKIP @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP @gross_attorney = gross_attorney unless gross_attorney == SKIP @fish_purchased = fish_purchased unless fish_purchased == SKIP @section409_a_deferrals = section409_a_deferrals unless section409_a_deferrals == SKIP @tips = tips unless tips == SKIP @occupation_codes = occupation_codes unless occupation_codes == SKIP @overtime = overtime unless overtime == SKIP unless foreign_account_tax_compliance == SKIP @foreign_account_tax_compliance = foreign_account_tax_compliance end @excess_golden = excess_golden unless excess_golden == SKIP unless non_qualified_deferred_compensation == SKIP @non_qualified_deferred_compensation = non_qualified_deferred_compensation end @state_and_local = state_and_local unless state_and_local == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 19 def corrected @corrected end |
#crop_insurance ⇒ Float
Box 9, Crop insurance proceeds
113 114 115 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 113 def crop_insurance @crop_insurance end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 68 def error @error end |
#excess_golden ⇒ Float
Excess golden parachute payments. Moved to 1099-NEC Box 3 for tax year 2025
150 151 152 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 150 def excess_golden @excess_golden end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 92 def federal_tax_withheld @federal_tax_withheld end |
#fish_purchased ⇒ Float
Box 11, Fish purchased for resale
125 126 127 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 125 def fish_purchased @fish_purchased end |
#fishing_boat_proceeds ⇒ Float
Box 5, Fishing boat proceeds
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 96 def fishing_boat_proceeds @fishing_boat_proceeds end |
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
FATCA filing requirement
145 146 147 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 145 def foreign_account_tax_compliance @foreign_account_tax_compliance end |
#gross_attorney ⇒ Float
Box 10, Gross proceeds paid to an attorney
121 122 123 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 121 def gross_attorney @gross_attorney end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 72 def links @links end |
#medical_health_payment ⇒ Float
Box 6, Medical and health care payments
100 101 102 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 100 def medical_health_payment @medical_health_payment end |
#non_qualified_deferred_compensation ⇒ Float
Box 15, Nonqualified Deferred Compensation
154 155 156 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 154 def non_qualified_deferred_compensation @non_qualified_deferred_compensation end |
#occupation_codes ⇒ Array[String]
Box 13b, Treasury Tipped Occupation Codes (TTOC)
137 138 139 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 137 def occupation_codes @occupation_codes end |
#other_income ⇒ Float
Box 3, Other income
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 88 def other_income @other_income end |
#overtime ⇒ Float
Box 14, Overtime compensation
141 142 143 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 141 def overtime @overtime end |
#payer_direct_sales ⇒ TrueClass | FalseClass
Box 7, Payer made direct sales of $5,000 or more of consumer products to a buyer (recipient) for resale
105 106 107 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 105 def payer_direct_sales @payer_direct_sales end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 54 def recipient @recipient end |
#rents ⇒ Float
Box 1, Rents
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 80 def rents @rents end |
#royalties ⇒ Float
Box 2, Royalties
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 84 def royalties @royalties end |
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice
117 118 119 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 117 def second_tin_notice @second_tin_notice end |
#section409_a_deferrals ⇒ Float
Box 12, Section 409A deferrals
129 130 131 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 129 def section409_a_deferrals @section409_a_deferrals end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 16-18, State and Local tax withholding
158 159 160 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 158 def state_and_local @state_and_local end |
#substitute_payments ⇒ Float
Box 8, Substitute payments in lieu of dividends or interest
109 110 111 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 109 def substitute_payments @substitute_payments end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 15 def tax_year @tax_year end |
#tips ⇒ Float
Box 13a, Cash tips
133 134 135 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 133 def tips @tips end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 305 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP rents = hash.key?('rents') ? hash['rents'] : SKIP royalties = hash.key?('royalties') ? hash['royalties'] : SKIP other_income = hash.key?('otherIncome') ? hash['otherIncome'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP fishing_boat_proceeds = hash.key?('fishingBoatProceeds') ? hash['fishingBoatProceeds'] : SKIP medical_health_payment = hash.key?('medicalHealthPayment') ? hash['medicalHealthPayment'] : SKIP payer_direct_sales = hash.key?('payerDirectSales') ? hash['payerDirectSales'] : SKIP substitute_payments = hash.key?('substitutePayments') ? hash['substitutePayments'] : SKIP crop_insurance = hash.key?('cropInsurance') ? hash['cropInsurance'] : SKIP second_tin_notice = hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP gross_attorney = hash.key?('grossAttorney') ? hash['grossAttorney'] : SKIP fish_purchased = hash.key?('fishPurchased') ? hash['fishPurchased'] : SKIP section409_a_deferrals = hash.key?('section409ADeferrals') ? hash['section409ADeferrals'] : SKIP tips = hash.key?('tips') ? hash['tips'] : SKIP occupation_codes = hash.key?('occupationCodes') ? hash['occupationCodes'] : SKIP overtime = hash.key?('overtime') ? hash['overtime'] : SKIP foreign_account_tax_compliance = hash.key?('foreignAccountTaxCompliance') ? hash['foreignAccountTaxCompliance'] : SKIP excess_golden = hash.key?('excessGolden') ? hash['excessGolden'] : SKIP non_qualified_deferred_compensation = hash.key?('nonQualifiedDeferredCompensation') ? hash['nonQualifiedDeferredCompensation'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099Misc.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, rents: rents, royalties: royalties, other_income: other_income, federal_tax_withheld: federal_tax_withheld, fishing_boat_proceeds: fishing_boat_proceeds, medical_health_payment: medical_health_payment, payer_direct_sales: payer_direct_sales, substitute_payments: substitute_payments, crop_insurance: crop_insurance, second_tin_notice: second_tin_notice, gross_attorney: gross_attorney, fish_purchased: fish_purchased, section409_a_deferrals: section409_a_deferrals, tips: tips, occupation_codes: occupation_codes, overtime: overtime, foreign_account_tax_compliance: foreign_account_tax_compliance, excess_golden: excess_golden, non_qualified_deferred_compensation: non_qualified_deferred_compensation, state_and_local: state_and_local, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 161 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['rents'] = 'rents' @_hash['royalties'] = 'royalties' @_hash['other_income'] = 'otherIncome' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['fishing_boat_proceeds'] = 'fishingBoatProceeds' @_hash['medical_health_payment'] = 'medicalHealthPayment' @_hash['payer_direct_sales'] = 'payerDirectSales' @_hash['substitute_payments'] = 'substitutePayments' @_hash['crop_insurance'] = 'cropInsurance' @_hash['second_tin_notice'] = 'secondTinNotice' @_hash['gross_attorney'] = 'grossAttorney' @_hash['fish_purchased'] = 'fishPurchased' @_hash['section409_a_deferrals'] = 'section409ADeferrals' @_hash['tips'] = 'tips' @_hash['occupation_codes'] = 'occupationCodes' @_hash['overtime'] = 'overtime' @_hash['foreign_account_tax_compliance'] = 'foreignAccountTaxCompliance' @_hash['excess_golden'] = 'excessGolden' @_hash['non_qualified_deferred_compensation'] = 'nonQualifiedDeferredCompensation' @_hash['state_and_local'] = 'stateAndLocal' @_hash end |
.nullables ⇒ Object
An array for nullable fields
240 241 242 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 240 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 201 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number rents royalties other_income federal_tax_withheld fishing_boat_proceeds medical_health_payment payer_direct_sales substitute_payments crop_insurance second_tin_notice gross_attorney fish_purchased section409_a_deferrals tips occupation_codes overtime foreign_account_tax_compliance excess_golden non_qualified_deferred_compensation state_and_local ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 447 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, rents:"\ " #{@rents.inspect}, royalties: #{@royalties.inspect}, other_income:"\ " #{@other_income.inspect}, federal_tax_withheld: #{@federal_tax_withheld.inspect},"\ " fishing_boat_proceeds: #{@fishing_boat_proceeds.inspect}, medical_health_payment:"\ " #{@medical_health_payment.inspect}, payer_direct_sales: #{@payer_direct_sales.inspect},"\ " substitute_payments: #{@substitute_payments.inspect}, crop_insurance:"\ " #{@crop_insurance.inspect}, second_tin_notice: #{@second_tin_notice.inspect},"\ " gross_attorney: #{@gross_attorney.inspect}, fish_purchased: #{@fish_purchased.inspect},"\ " section409_a_deferrals: #{@section409_a_deferrals.inspect}, tips: #{@tips.inspect},"\ " occupation_codes: #{@occupation_codes.inspect}, overtime: #{@overtime.inspect},"\ " foreign_account_tax_compliance: #{@foreign_account_tax_compliance.inspect}, excess_golden:"\ " #{@excess_golden.inspect}, non_qualified_deferred_compensation:"\ " #{@non_qualified_deferred_compensation.inspect}, state_and_local:"\ " #{@state_and_local.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/fdx_v660_api/models/form1099_misc.rb', line 426 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, rents: #{@rents},"\ " royalties: #{@royalties}, other_income: #{@other_income}, federal_tax_withheld:"\ " #{@federal_tax_withheld}, fishing_boat_proceeds: #{@fishing_boat_proceeds},"\ " medical_health_payment: #{@medical_health_payment}, payer_direct_sales:"\ " #{@payer_direct_sales}, substitute_payments: #{@substitute_payments}, crop_insurance:"\ " #{@crop_insurance}, second_tin_notice: #{@second_tin_notice}, gross_attorney:"\ " #{@gross_attorney}, fish_purchased: #{@fish_purchased}, section409_a_deferrals:"\ " #{@section409_a_deferrals}, tips: #{@tips}, occupation_codes: #{@occupation_codes},"\ " overtime: #{@overtime}, foreign_account_tax_compliance:"\ " #{@foreign_account_tax_compliance}, excess_golden: #{@excess_golden},"\ " non_qualified_deferred_compensation: #{@non_qualified_deferred_compensation},"\ " state_and_local: #{@state_and_local}, additional_properties: #{@additional_properties}>" end |