Class: FdxV660Api::Form1099Nec
- Defined in:
- lib/fdx_v660_api/models/form1099_nec.rb
Overview
Non-Employee Compensation, from PAYER (1st-9th boxes as issuer) to RECIPIENT (10th-17th boxes)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#excess_golden ⇒ Float
Box 3, Excess golden parachute payments, added for tax year 2025.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#non_employee_compensation ⇒ Float
Box 1a, Nonemployee compensation.
-
#occupation_codes ⇒ Array[String]
Box 1c, Treasury Tipped Occupation Codes (TTOC).
-
#overtime ⇒ Float
Box 1d, Overtime compensation.
-
#payer_direct_sales ⇒ TrueClass | FalseClass
Box 2, Payer made direct sales of $5,000 or more of consumer products to a buyer (recipient) for resale.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 5-7, State and Local tax withholding.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#tips ⇒ Float
Box 1b, Cash tips.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, second_tin_notice: SKIP, non_employee_compensation: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, payer_direct_sales: SKIP, excess_golden: SKIP, federal_tax_withheld: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099Nec
constructor
A new instance of Form1099Nec.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, second_tin_notice: SKIP, non_employee_compensation: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, payer_direct_sales: SKIP, excess_golden: SKIP, federal_tax_withheld: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099Nec
Returns a new instance of Form1099Nec.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 176 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, second_tin_notice: SKIP, non_employee_compensation: SKIP, tips: SKIP, occupation_codes: SKIP, overtime: SKIP, payer_direct_sales: SKIP, excess_golden: SKIP, federal_tax_withheld: SKIP, state_and_local: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP unless non_employee_compensation == SKIP @non_employee_compensation = non_employee_compensation end @tips = tips unless tips == SKIP @occupation_codes = occupation_codes unless occupation_codes == SKIP @overtime = overtime unless overtime == SKIP @payer_direct_sales = payer_direct_sales unless payer_direct_sales == SKIP @excess_golden = excess_golden unless excess_golden == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 19 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 68 def error @error end |
#excess_golden ⇒ Float
Box 3, Excess golden parachute payments, added for tax year 2025
105 106 107 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 105 def excess_golden @excess_golden end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
109 110 111 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 109 def federal_tax_withheld @federal_tax_withheld end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 72 def links @links end |
#non_employee_compensation ⇒ Float
Box 1a, Nonemployee compensation
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 84 def non_employee_compensation @non_employee_compensation end |
#occupation_codes ⇒ Array[String]
Box 1c, Treasury Tipped Occupation Codes (TTOC)
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 92 def occupation_codes @occupation_codes end |
#overtime ⇒ Float
Box 1d, Overtime compensation
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 96 def overtime @overtime end |
#payer_direct_sales ⇒ TrueClass | FalseClass
Box 2, Payer made direct sales of $5,000 or more of consumer products to a buyer (recipient) for resale
101 102 103 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 101 def payer_direct_sales @payer_direct_sales end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 54 def recipient @recipient end |
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 80 def second_tin_notice @second_tin_notice end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 5-7, State and Local tax withholding
113 114 115 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 113 def state_and_local @state_and_local end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 15 def tax_year @tax_year end |
#tips ⇒ Float
Box 1b, Cash tips
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 88 def tips @tips end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 218 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP second_tin_notice = hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP non_employee_compensation = hash.key?('nonEmployeeCompensation') ? hash['nonEmployeeCompensation'] : SKIP tips = hash.key?('tips') ? hash['tips'] : SKIP occupation_codes = hash.key?('occupationCodes') ? hash['occupationCodes'] : SKIP overtime = hash.key?('overtime') ? hash['overtime'] : SKIP payer_direct_sales = hash.key?('payerDirectSales') ? hash['payerDirectSales'] : SKIP excess_golden = hash.key?('excessGolden') ? hash['excessGolden'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099Nec.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, second_tin_notice: second_tin_notice, non_employee_compensation: non_employee_compensation, tips: tips, occupation_codes: occupation_codes, overtime: overtime, payer_direct_sales: payer_direct_sales, excess_golden: excess_golden, federal_tax_withheld: federal_tax_withheld, state_and_local: state_and_local, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 116 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['second_tin_notice'] = 'secondTinNotice' @_hash['non_employee_compensation'] = 'nonEmployeeCompensation' @_hash['tips'] = 'tips' @_hash['occupation_codes'] = 'occupationCodes' @_hash['overtime'] = 'overtime' @_hash['payer_direct_sales'] = 'payerDirectSales' @_hash['excess_golden'] = 'excessGolden' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['state_and_local'] = 'stateAndLocal' @_hash end |
.nullables ⇒ Object
An array for nullable fields
172 173 174 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 172 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 144 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number second_tin_notice non_employee_compensation tips occupation_codes overtime payer_direct_sales excess_golden federal_tax_withheld state_and_local ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 327 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, second_tin_notice:"\ " #{@second_tin_notice.inspect}, non_employee_compensation:"\ " #{@non_employee_compensation.inspect}, tips: #{@tips.inspect}, occupation_codes:"\ " #{@occupation_codes.inspect}, overtime: #{@overtime.inspect}, payer_direct_sales:"\ " #{@payer_direct_sales.inspect}, excess_golden: #{@excess_golden.inspect},"\ " federal_tax_withheld: #{@federal_tax_withheld.inspect}, state_and_local:"\ " #{@state_and_local.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/fdx_v660_api/models/form1099_nec.rb', line 312 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, second_tin_notice:"\ " #{@second_tin_notice}, non_employee_compensation: #{@non_employee_compensation}, tips:"\ " #{@tips}, occupation_codes: #{@occupation_codes}, overtime: #{@overtime},"\ " payer_direct_sales: #{@payer_direct_sales}, excess_golden: #{@excess_golden},"\ " federal_tax_withheld: #{@federal_tax_withheld}, state_and_local: #{@state_and_local},"\ " additional_properties: #{@additional_properties}>" end |