Class: FdxV660Api::Form1099Oid
- Defined in:
- lib/fdx_v660_api/models/form1099_oid.rb
Overview
Original Issue Discount, from PAYER (1st-2nd boxes as issuer) to RECIPIENT (3rd-4th boxes)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#acquisition_premium ⇒ Float
Box 6, Acquisition premium.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#bond_premium ⇒ Float
Box 10, Bond premium.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#discount_on_treasury_obligations ⇒ Float
Box 8, Original issue discount on U.S.
-
#early_withdrawal_penalty ⇒ Float
Box 3, Early withdrawal penalty.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
FATCA filing requirement.
-
#investment_expenses ⇒ Float
Box 9, Investment expenses.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#market_discount ⇒ Float
Box 5, Market discount.
-
#oid_description ⇒ String
Box 7, Description.
-
#original_issue_discount ⇒ Float
Box 1, Original issue discount.
-
#other_periodic_interest ⇒ Float
Box 2, Other periodic interest.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 12-14, State and Local tax withheld.
-
#state_exempt_oid ⇒ Array[DescriptionAndAmount]
Supplemental: State name and tax-exempt OID by state.
-
#tax_exempt_oid ⇒ Float
Box 11, Tax-exempt OID.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, foreign_account_tax_compliance: SKIP, account_number: SKIP, original_issue_discount: SKIP, other_periodic_interest: SKIP, early_withdrawal_penalty: SKIP, federal_tax_withheld: SKIP, market_discount: SKIP, acquisition_premium: SKIP, oid_description: SKIP, discount_on_treasury_obligations: SKIP, investment_expenses: SKIP, bond_premium: SKIP, tax_exempt_oid: SKIP, state_and_local: SKIP, state_exempt_oid: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099Oid
constructor
A new instance of Form1099Oid.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, foreign_account_tax_compliance: SKIP, account_number: SKIP, original_issue_discount: SKIP, other_periodic_interest: SKIP, early_withdrawal_penalty: SKIP, federal_tax_withheld: SKIP, market_discount: SKIP, acquisition_premium: SKIP, oid_description: SKIP, discount_on_treasury_obligations: SKIP, investment_expenses: SKIP, bond_premium: SKIP, tax_exempt_oid: SKIP, state_and_local: SKIP, state_exempt_oid: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099Oid
Returns a new instance of Form1099Oid.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 212 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, foreign_account_tax_compliance: SKIP, account_number: SKIP, original_issue_discount: SKIP, other_periodic_interest: SKIP, early_withdrawal_penalty: SKIP, federal_tax_withheld: SKIP, market_discount: SKIP, acquisition_premium: SKIP, oid_description: SKIP, discount_on_treasury_obligations: SKIP, investment_expenses: SKIP, bond_premium: SKIP, tax_exempt_oid: SKIP, state_and_local: SKIP, state_exempt_oid: SKIP, second_tin_notice: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP unless foreign_account_tax_compliance == SKIP @foreign_account_tax_compliance = foreign_account_tax_compliance end @account_number = account_number unless account_number == SKIP @original_issue_discount = original_issue_discount unless original_issue_discount == SKIP @other_periodic_interest = other_periodic_interest unless other_periodic_interest == SKIP @early_withdrawal_penalty = early_withdrawal_penalty unless early_withdrawal_penalty == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @market_discount = market_discount unless market_discount == SKIP @acquisition_premium = acquisition_premium unless acquisition_premium == SKIP @oid_description = oid_description unless oid_description == SKIP unless discount_on_treasury_obligations == SKIP @discount_on_treasury_obligations = discount_on_treasury_obligations end @investment_expenses = investment_expenses unless investment_expenses == SKIP @bond_premium = bond_premium unless bond_premium == SKIP @tax_exempt_oid = tax_exempt_oid unless tax_exempt_oid == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @state_exempt_oid = state_exempt_oid unless state_exempt_oid == SKIP @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 80 def account_number @account_number end |
#acquisition_premium ⇒ Float
Box 6, Acquisition premium
104 105 106 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 104 def acquisition_premium @acquisition_premium end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 64 def attributes @attributes end |
#bond_premium ⇒ Float
Box 10, Bond premium
120 121 122 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 120 def bond_premium @bond_premium end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 19 def corrected @corrected end |
#discount_on_treasury_obligations ⇒ Float
Box 8, Original issue discount on U.S. Treasury obligations
112 113 114 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 112 def discount_on_treasury_obligations @discount_on_treasury_obligations end |
#early_withdrawal_penalty ⇒ Float
Box 3, Early withdrawal penalty
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 92 def early_withdrawal_penalty @early_withdrawal_penalty end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 68 def error @error end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 96 def federal_tax_withheld @federal_tax_withheld end |
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
FATCA filing requirement
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 76 def foreign_account_tax_compliance @foreign_account_tax_compliance end |
#investment_expenses ⇒ Float
Box 9, Investment expenses
116 117 118 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 116 def investment_expenses @investment_expenses end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 72 def links @links end |
#market_discount ⇒ Float
Box 5, Market discount
100 101 102 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 100 def market_discount @market_discount end |
#oid_description ⇒ String
Box 7, Description
108 109 110 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 108 def oid_description @oid_description end |
#original_issue_discount ⇒ Float
Box 1, Original issue discount
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 84 def original_issue_discount @original_issue_discount end |
#other_periodic_interest ⇒ Float
Box 2, Other periodic interest
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 88 def other_periodic_interest @other_periodic_interest end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 54 def recipient @recipient end |
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice
136 137 138 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 136 def second_tin_notice @second_tin_notice end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 12-14, State and Local tax withheld
128 129 130 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 128 def state_and_local @state_and_local end |
#state_exempt_oid ⇒ Array[DescriptionAndAmount]
Supplemental: State name and tax-exempt OID by state
132 133 134 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 132 def state_exempt_oid @state_exempt_oid end |
#tax_exempt_oid ⇒ Float
Box 11, Tax-exempt OID
124 125 126 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 124 def tax_exempt_oid @tax_exempt_oid end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 15 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 268 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') foreign_account_tax_compliance = hash.key?('foreignAccountTaxCompliance') ? hash['foreignAccountTaxCompliance'] : SKIP account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP original_issue_discount = hash.key?('originalIssueDiscount') ? hash['originalIssueDiscount'] : SKIP other_periodic_interest = hash.key?('otherPeriodicInterest') ? hash['otherPeriodicInterest'] : SKIP early_withdrawal_penalty = hash.key?('earlyWithdrawalPenalty') ? hash['earlyWithdrawalPenalty'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP market_discount = hash.key?('marketDiscount') ? hash['marketDiscount'] : SKIP acquisition_premium = hash.key?('acquisitionPremium') ? hash['acquisitionPremium'] : SKIP oid_description = hash.key?('oidDescription') ? hash['oidDescription'] : SKIP discount_on_treasury_obligations = hash.key?('discountOnTreasuryObligations') ? hash['discountOnTreasuryObligations'] : SKIP investment_expenses = hash.key?('investmentExpenses') ? hash['investmentExpenses'] : SKIP bond_premium = hash.key?('bondPremium') ? hash['bondPremium'] : SKIP tax_exempt_oid = hash.key?('taxExemptOid') ? hash['taxExemptOid'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') # Parameter is an array, so we need to iterate through it state_exempt_oid = nil unless hash['stateExemptOid'].nil? state_exempt_oid = [] hash['stateExemptOid'].each do |structure| state_exempt_oid << (DescriptionAndAmount.from_hash(structure) if structure) end end state_exempt_oid = SKIP unless hash.key?('stateExemptOid') second_tin_notice = hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099Oid.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, foreign_account_tax_compliance: foreign_account_tax_compliance, account_number: account_number, original_issue_discount: original_issue_discount, other_periodic_interest: other_periodic_interest, early_withdrawal_penalty: early_withdrawal_penalty, federal_tax_withheld: federal_tax_withheld, market_discount: market_discount, acquisition_premium: acquisition_premium, oid_description: oid_description, discount_on_treasury_obligations: discount_on_treasury_obligations, investment_expenses: investment_expenses, bond_premium: bond_premium, tax_exempt_oid: tax_exempt_oid, state_and_local: state_and_local, state_exempt_oid: state_exempt_oid, second_tin_notice: second_tin_notice, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 139 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['foreign_account_tax_compliance'] = 'foreignAccountTaxCompliance' @_hash['account_number'] = 'accountNumber' @_hash['original_issue_discount'] = 'originalIssueDiscount' @_hash['other_periodic_interest'] = 'otherPeriodicInterest' @_hash['early_withdrawal_penalty'] = 'earlyWithdrawalPenalty' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['market_discount'] = 'marketDiscount' @_hash['acquisition_premium'] = 'acquisitionPremium' @_hash['oid_description'] = 'oidDescription' @_hash['discount_on_treasury_obligations'] = 'discountOnTreasuryObligations' @_hash['investment_expenses'] = 'investmentExpenses' @_hash['bond_premium'] = 'bondPremium' @_hash['tax_exempt_oid'] = 'taxExemptOid' @_hash['state_and_local'] = 'stateAndLocal' @_hash['state_exempt_oid'] = 'stateExemptOid' @_hash['second_tin_notice'] = 'secondTinNotice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
208 209 210 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 208 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 174 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links foreign_account_tax_compliance account_number original_issue_discount other_periodic_interest early_withdrawal_penalty federal_tax_withheld market_discount acquisition_premium oid_description discount_on_treasury_obligations investment_expenses bond_premium tax_exempt_oid state_and_local state_exempt_oid second_tin_notice ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 409 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, foreign_account_tax_compliance:"\ " #{@foreign_account_tax_compliance.inspect}, account_number: #{@account_number.inspect},"\ " original_issue_discount: #{@original_issue_discount.inspect}, other_periodic_interest:"\ " #{@other_periodic_interest.inspect}, early_withdrawal_penalty:"\ " #{@early_withdrawal_penalty.inspect}, federal_tax_withheld:"\ " #{@federal_tax_withheld.inspect}, market_discount: #{@market_discount.inspect},"\ " acquisition_premium: #{@acquisition_premium.inspect}, oid_description:"\ " #{@oid_description.inspect}, discount_on_treasury_obligations:"\ " #{@discount_on_treasury_obligations.inspect}, investment_expenses:"\ " #{@investment_expenses.inspect}, bond_premium: #{@bond_premium.inspect}, tax_exempt_oid:"\ " #{@tax_exempt_oid.inspect}, state_and_local: #{@state_and_local.inspect},"\ " state_exempt_oid: #{@state_exempt_oid.inspect}, second_tin_notice:"\ " #{@second_tin_notice.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/fdx_v660_api/models/form1099_oid.rb', line 389 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, foreign_account_tax_compliance:"\ " #{@foreign_account_tax_compliance}, account_number: #{@account_number},"\ " original_issue_discount: #{@original_issue_discount}, other_periodic_interest:"\ " #{@other_periodic_interest}, early_withdrawal_penalty: #{@early_withdrawal_penalty},"\ " federal_tax_withheld: #{@federal_tax_withheld}, market_discount: #{@market_discount},"\ " acquisition_premium: #{@acquisition_premium}, oid_description: #{@oid_description},"\ " discount_on_treasury_obligations: #{@discount_on_treasury_obligations},"\ " investment_expenses: #{@investment_expenses}, bond_premium: #{@bond_premium},"\ " tax_exempt_oid: #{@tax_exempt_oid}, state_and_local: #{@state_and_local},"\ " state_exempt_oid: #{@state_exempt_oid}, second_tin_notice: #{@second_tin_notice},"\ " additional_properties: #{@additional_properties}>" end |