Class: FdxV660Api::Form1099Patr
- Defined in:
- lib/fdx_v660_api/models/form1099_patr.rb
Overview
Taxable Distributions Received From Cooperatives, from PAYER (1st-2nd boxes as issuer) to RECIPIENT (3rd-4th boxes)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#form8844_credit ⇒ Float
Box 12 - Empowerment Zone Credit (Form 8844).
-
#form8864_credit ⇒ Float
Box 12 - Biodiesel and Renewable Diesel Fuels Credit (Form 8864).
-
#form8896_credit ⇒ Float
Box 12 - Low Sulfur Diesel Fuel Production Credit (Form 8896).
-
#form8932_credit ⇒ Float
Box 12 - Credit for Employer Differential Wage Payments (Form 8932).
-
#form8941_credit ⇒ Float
Box 12 - Credit for Small Employer Health Insurance Premiums (Form 8941).
-
#investment_credit ⇒ Float
Box 10, Investment credit.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#nonpatronage_distributions ⇒ Float
Box 2, Nonpatronage distributions.
-
#other_credits_and_deductions ⇒ Float
Box 12, Other credits and deductions.
-
#patronage_dividends ⇒ Float
Box 1, Patronage dividends.
-
#per_unit_retain_allocations ⇒ Float
Box 3, Per-unit retain allocations.
-
#qualified_payments ⇒ Float
Box 7, Qualified payments.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#redemption ⇒ Float
Box 5, Redemption of nonqualified notices and retain allocations.
-
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice.
-
#section199_deduction ⇒ Float
Box 6, Section 199A(g) deduction.
-
#section199_qualified_items ⇒ Float
Box 8, Section 199A(a) qualified items.
-
#section199_sstb_items ⇒ Float
Box 9, Section 199A(a) SSTB (Specified Service Trade or Business) items.
-
#specified_coop ⇒ TrueClass | FalseClass
Box 13, Specified Cooperative.
-
#state_and_local ⇒ StateAndLocalTaxWithholding2
State and Local tax withholding, from IRS's IRIS schema.
-
#sulfur_deduction ⇒ Float
Box 12 - EPA Sulfur Regulations Deduction Amount.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#work_opportunity_credit ⇒ Float
Box 11, Work opportunity credit.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, patronage_dividends: SKIP, nonpatronage_distributions: SKIP, per_unit_retain_allocations: SKIP, federal_tax_withheld: SKIP, redemption: SKIP, section199_deduction: SKIP, qualified_payments: SKIP, section199_qualified_items: SKIP, section199_sstb_items: SKIP, investment_credit: SKIP, work_opportunity_credit: SKIP, other_credits_and_deductions: SKIP, form8844_credit: SKIP, form8864_credit: SKIP, form8896_credit: SKIP, form8932_credit: SKIP, sulfur_deduction: SKIP, form8941_credit: SKIP, specified_coop: SKIP, state_and_local: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099Patr
constructor
A new instance of Form1099Patr.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, patronage_dividends: SKIP, nonpatronage_distributions: SKIP, per_unit_retain_allocations: SKIP, federal_tax_withheld: SKIP, redemption: SKIP, section199_deduction: SKIP, qualified_payments: SKIP, section199_qualified_items: SKIP, section199_sstb_items: SKIP, investment_credit: SKIP, work_opportunity_credit: SKIP, other_credits_and_deductions: SKIP, form8844_credit: SKIP, form8864_credit: SKIP, form8896_credit: SKIP, form8932_credit: SKIP, sulfur_deduction: SKIP, form8941_credit: SKIP, specified_coop: SKIP, state_and_local: SKIP, second_tin_notice: SKIP, additional_properties: nil) ⇒ Form1099Patr
Returns a new instance of Form1099Patr.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 247 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, patronage_dividends: SKIP, nonpatronage_distributions: SKIP, per_unit_retain_allocations: SKIP, federal_tax_withheld: SKIP, redemption: SKIP, section199_deduction: SKIP, qualified_payments: SKIP, section199_qualified_items: SKIP, section199_sstb_items: SKIP, investment_credit: SKIP, work_opportunity_credit: SKIP, other_credits_and_deductions: SKIP, form8844_credit: SKIP, form8864_credit: SKIP, form8896_credit: SKIP, form8932_credit: SKIP, sulfur_deduction: SKIP, form8941_credit: SKIP, specified_coop: SKIP, state_and_local: SKIP, second_tin_notice: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @patronage_dividends = patronage_dividends unless patronage_dividends == SKIP unless nonpatronage_distributions == SKIP @nonpatronage_distributions = nonpatronage_distributions end unless per_unit_retain_allocations == SKIP @per_unit_retain_allocations = per_unit_retain_allocations end @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @redemption = redemption unless redemption == SKIP @section199_deduction = section199_deduction unless section199_deduction == SKIP @qualified_payments = qualified_payments unless qualified_payments == SKIP unless section199_qualified_items == SKIP @section199_qualified_items = section199_qualified_items end @section199_sstb_items = section199_sstb_items unless section199_sstb_items == SKIP @investment_credit = investment_credit unless investment_credit == SKIP @work_opportunity_credit = work_opportunity_credit unless work_opportunity_credit == SKIP unless other_credits_and_deductions == SKIP @other_credits_and_deductions = other_credits_and_deductions end @form8844_credit = form8844_credit unless form8844_credit == SKIP @form8864_credit = form8864_credit unless form8864_credit == SKIP @form8896_credit = form8896_credit unless form8896_credit == SKIP @form8932_credit = form8932_credit unless form8932_credit == SKIP @sulfur_deduction = sulfur_deduction unless sulfur_deduction == SKIP @form8941_credit = form8941_credit unless form8941_credit == SKIP @specified_coop = specified_coop unless specified_coop == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @second_tin_notice = second_tin_notice unless second_tin_notice == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 19 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 68 def error @error end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 92 def federal_tax_withheld @federal_tax_withheld end |
#form8844_credit ⇒ Float
Box 12 - Empowerment Zone Credit (Form 8844)
128 129 130 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 128 def form8844_credit @form8844_credit end |
#form8864_credit ⇒ Float
Box 12 - Biodiesel and Renewable Diesel Fuels Credit (Form 8864)
132 133 134 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 132 def form8864_credit @form8864_credit end |
#form8896_credit ⇒ Float
Box 12 - Low Sulfur Diesel Fuel Production Credit (Form 8896)
136 137 138 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 136 def form8896_credit @form8896_credit end |
#form8932_credit ⇒ Float
Box 12 - Credit for Employer Differential Wage Payments (Form 8932)
140 141 142 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 140 def form8932_credit @form8932_credit end |
#form8941_credit ⇒ Float
Box 12 - Credit for Small Employer Health Insurance Premiums (Form 8941)
148 149 150 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 148 def form8941_credit @form8941_credit end |
#investment_credit ⇒ Float
Box 10, Investment credit
116 117 118 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 116 def investment_credit @investment_credit end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 72 def links @links end |
#nonpatronage_distributions ⇒ Float
Box 2, Nonpatronage distributions
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 84 def nonpatronage_distributions @nonpatronage_distributions end |
#other_credits_and_deductions ⇒ Float
Box 12, Other credits and deductions
124 125 126 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 124 def other_credits_and_deductions @other_credits_and_deductions end |
#patronage_dividends ⇒ Float
Box 1, Patronage dividends
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 80 def patronage_dividends @patronage_dividends end |
#per_unit_retain_allocations ⇒ Float
Box 3, Per-unit retain allocations
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 88 def per_unit_retain_allocations @per_unit_retain_allocations end |
#qualified_payments ⇒ Float
Box 7, Qualified payments
104 105 106 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 104 def qualified_payments @qualified_payments end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 54 def recipient @recipient end |
#redemption ⇒ Float
Box 5, Redemption of nonqualified notices and retain allocations
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 96 def redemption @redemption end |
#second_tin_notice ⇒ TrueClass | FalseClass
Second TIN Notice
160 161 162 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 160 def second_tin_notice @second_tin_notice end |
#section199_deduction ⇒ Float
Box 6, Section 199A(g) deduction
100 101 102 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 100 def section199_deduction @section199_deduction end |
#section199_qualified_items ⇒ Float
Box 8, Section 199A(a) qualified items
108 109 110 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 108 def section199_qualified_items @section199_qualified_items end |
#section199_sstb_items ⇒ Float
Box 9, Section 199A(a) SSTB (Specified Service Trade or Business) items
112 113 114 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 112 def section199_sstb_items @section199_sstb_items end |
#specified_coop ⇒ TrueClass | FalseClass
Box 13, Specified Cooperative
152 153 154 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 152 def specified_coop @specified_coop end |
#state_and_local ⇒ StateAndLocalTaxWithholding2
State and Local tax withholding, from IRS's IRIS schema
156 157 158 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 156 def state_and_local @state_and_local end |
#sulfur_deduction ⇒ Float
Box 12 - EPA Sulfur Regulations Deduction Amount
144 145 146 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 144 def sulfur_deduction @sulfur_deduction end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 15 def tax_year @tax_year end |
#work_opportunity_credit ⇒ Float
Box 11, Work opportunity credit
120 121 122 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 120 def work_opportunity_credit @work_opportunity_credit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 318 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP patronage_dividends = hash.key?('patronageDividends') ? hash['patronageDividends'] : SKIP nonpatronage_distributions = hash.key?('nonpatronageDistributions') ? hash['nonpatronageDistributions'] : SKIP per_unit_retain_allocations = hash.key?('perUnitRetainAllocations') ? hash['perUnitRetainAllocations'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP redemption = hash.key?('redemption') ? hash['redemption'] : SKIP section199_deduction = hash.key?('section199Deduction') ? hash['section199Deduction'] : SKIP qualified_payments = hash.key?('qualifiedPayments') ? hash['qualifiedPayments'] : SKIP section199_qualified_items = hash.key?('section199QualifiedItems') ? hash['section199QualifiedItems'] : SKIP section199_sstb_items = hash.key?('section199SstbItems') ? hash['section199SstbItems'] : SKIP investment_credit = hash.key?('investmentCredit') ? hash['investmentCredit'] : SKIP work_opportunity_credit = hash.key?('workOpportunityCredit') ? hash['workOpportunityCredit'] : SKIP other_credits_and_deductions = hash.key?('otherCreditsAndDeductions') ? hash['otherCreditsAndDeductions'] : SKIP form8844_credit = hash.key?('form8844Credit') ? hash['form8844Credit'] : SKIP form8864_credit = hash.key?('form8864Credit') ? hash['form8864Credit'] : SKIP form8896_credit = hash.key?('form8896Credit') ? hash['form8896Credit'] : SKIP form8932_credit = hash.key?('form8932Credit') ? hash['form8932Credit'] : SKIP sulfur_deduction = hash.key?('sulfurDeduction') ? hash['sulfurDeduction'] : SKIP form8941_credit = hash.key?('form8941Credit') ? hash['form8941Credit'] : SKIP specified_coop = hash.key?('specifiedCoop') ? hash['specifiedCoop'] : SKIP state_and_local = StateAndLocalTaxWithholding2.from_hash(hash['stateAndLocal']) if hash['stateAndLocal'] second_tin_notice = hash.key?('secondTinNotice') ? hash['secondTinNotice'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099Patr.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, patronage_dividends: patronage_dividends, nonpatronage_distributions: nonpatronage_distributions, per_unit_retain_allocations: per_unit_retain_allocations, federal_tax_withheld: federal_tax_withheld, redemption: redemption, section199_deduction: section199_deduction, qualified_payments: qualified_payments, section199_qualified_items: section199_qualified_items, section199_sstb_items: section199_sstb_items, investment_credit: investment_credit, work_opportunity_credit: work_opportunity_credit, other_credits_and_deductions: other_credits_and_deductions, form8844_credit: form8844_credit, form8864_credit: form8864_credit, form8896_credit: form8896_credit, form8932_credit: form8932_credit, sulfur_deduction: sulfur_deduction, form8941_credit: form8941_credit, specified_coop: specified_coop, state_and_local: state_and_local, second_tin_notice: second_tin_notice, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 163 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['patronage_dividends'] = 'patronageDividends' @_hash['nonpatronage_distributions'] = 'nonpatronageDistributions' @_hash['per_unit_retain_allocations'] = 'perUnitRetainAllocations' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['redemption'] = 'redemption' @_hash['section199_deduction'] = 'section199Deduction' @_hash['qualified_payments'] = 'qualifiedPayments' @_hash['section199_qualified_items'] = 'section199QualifiedItems' @_hash['section199_sstb_items'] = 'section199SstbItems' @_hash['investment_credit'] = 'investmentCredit' @_hash['work_opportunity_credit'] = 'workOpportunityCredit' @_hash['other_credits_and_deductions'] = 'otherCreditsAndDeductions' @_hash['form8844_credit'] = 'form8844Credit' @_hash['form8864_credit'] = 'form8864Credit' @_hash['form8896_credit'] = 'form8896Credit' @_hash['form8932_credit'] = 'form8932Credit' @_hash['sulfur_deduction'] = 'sulfurDeduction' @_hash['form8941_credit'] = 'form8941Credit' @_hash['specified_coop'] = 'specifiedCoop' @_hash['state_and_local'] = 'stateAndLocal' @_hash['second_tin_notice'] = 'secondTinNotice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
243 244 245 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 243 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 203 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number patronage_dividends nonpatronage_distributions per_unit_retain_allocations federal_tax_withheld redemption section199_deduction qualified_payments section199_qualified_items section199_sstb_items investment_credit work_opportunity_credit other_credits_and_deductions form8844_credit form8864_credit form8896_credit form8932_credit sulfur_deduction form8941_credit specified_coop state_and_local second_tin_notice ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 464 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, patronage_dividends:"\ " #{@patronage_dividends.inspect}, nonpatronage_distributions:"\ " #{@nonpatronage_distributions.inspect}, per_unit_retain_allocations:"\ " #{@per_unit_retain_allocations.inspect}, federal_tax_withheld:"\ " #{@federal_tax_withheld.inspect}, redemption: #{@redemption.inspect},"\ " section199_deduction: #{@section199_deduction.inspect}, qualified_payments:"\ " #{@qualified_payments.inspect}, section199_qualified_items:"\ " #{@section199_qualified_items.inspect}, section199_sstb_items:"\ " #{@section199_sstb_items.inspect}, investment_credit: #{@investment_credit.inspect},"\ " work_opportunity_credit: #{@work_opportunity_credit.inspect},"\ " other_credits_and_deductions: #{@other_credits_and_deductions.inspect}, form8844_credit:"\ " #{@form8844_credit.inspect}, form8864_credit: #{@form8864_credit.inspect},"\ " form8896_credit: #{@form8896_credit.inspect}, form8932_credit:"\ " #{@form8932_credit.inspect}, sulfur_deduction: #{@sulfur_deduction.inspect},"\ " form8941_credit: #{@form8941_credit.inspect}, specified_coop: #{@specified_coop.inspect},"\ " state_and_local: #{@state_and_local.inspect}, second_tin_notice:"\ " #{@second_tin_notice.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/fdx_v660_api/models/form1099_patr.rb', line 441 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, patronage_dividends:"\ " #{@patronage_dividends}, nonpatronage_distributions: #{@nonpatronage_distributions},"\ " per_unit_retain_allocations: #{@per_unit_retain_allocations}, federal_tax_withheld:"\ " #{@federal_tax_withheld}, redemption: #{@redemption}, section199_deduction:"\ " #{@section199_deduction}, qualified_payments: #{@qualified_payments},"\ " section199_qualified_items: #{@section199_qualified_items}, section199_sstb_items:"\ " #{@section199_sstb_items}, investment_credit: #{@investment_credit},"\ " work_opportunity_credit: #{@work_opportunity_credit}, other_credits_and_deductions:"\ " #{@other_credits_and_deductions}, form8844_credit: #{@form8844_credit}, form8864_credit:"\ " #{@form8864_credit}, form8896_credit: #{@form8896_credit}, form8932_credit:"\ " #{@form8932_credit}, sulfur_deduction: #{@sulfur_deduction}, form8941_credit:"\ " #{@form8941_credit}, specified_coop: #{@specified_coop}, state_and_local:"\ " #{@state_and_local}, second_tin_notice: #{@second_tin_notice}, additional_properties:"\ " #{@additional_properties}>" end |