Class: FdxV660Api::Form1099Q
- Defined in:
- lib/fdx_v660_api/models/form1099_q.rb
Overview
Payments From Qualified Education Programs, from PAYER/TRUSTEE (1st-2nd boxes as issuer) to RECIPIENT (3rd-4th boxes)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#basis ⇒ Float
Box 3, Basis.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#coverdell_esa ⇒ TrueClass | FalseClass
Box 5c, Coverdell ESA.
-
#earnings ⇒ Float
Box 2, Earnings.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#fair_market_value ⇒ Float
If fair market value (FMV) is included, see Pub.
-
#gross_distribution ⇒ Float
Box 1, Gross distribution.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#qtp_to_roth_ira ⇒ TrueClass | FalseClass
Box 4b, Qualified Tuition Program (QTP) to Roth IRA transfer.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#recipient_is_not_beneficiary ⇒ TrueClass | FalseClass
Box 6, If this box is checked, the recipient is not the designated beneficiary.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#trustee_to_trustee ⇒ TrueClass | FalseClass
Box 4a, Trustee-to-trustee transfer.
-
#tuition_plan_private ⇒ TrueClass | FalseClass
Box 5a, Private Qualified Tuition Program (QTP).
-
#tuition_plan_public ⇒ TrueClass | FalseClass
Box 5b, State Qualified Tuition Program (QTP).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, gross_distribution: SKIP, earnings: SKIP, basis: SKIP, trustee_to_trustee: SKIP, qtp_to_roth_ira: SKIP, tuition_plan_private: SKIP, tuition_plan_public: SKIP, coverdell_esa: SKIP, recipient_is_not_beneficiary: SKIP, fair_market_value: SKIP, additional_properties: nil) ⇒ Form1099Q
constructor
A new instance of Form1099Q.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, gross_distribution: SKIP, earnings: SKIP, basis: SKIP, trustee_to_trustee: SKIP, qtp_to_roth_ira: SKIP, tuition_plan_private: SKIP, tuition_plan_public: SKIP, coverdell_esa: SKIP, recipient_is_not_beneficiary: SKIP, fair_market_value: SKIP, additional_properties: nil) ⇒ Form1099Q
Returns a new instance of Form1099Q.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 184 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, gross_distribution: SKIP, earnings: SKIP, basis: SKIP, trustee_to_trustee: SKIP, qtp_to_roth_ira: SKIP, tuition_plan_private: SKIP, tuition_plan_public: SKIP, coverdell_esa: SKIP, recipient_is_not_beneficiary: SKIP, fair_market_value: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @gross_distribution = gross_distribution unless gross_distribution == SKIP @earnings = earnings unless earnings == SKIP @basis = basis unless basis == SKIP @trustee_to_trustee = trustee_to_trustee unless trustee_to_trustee == SKIP @qtp_to_roth_ira = qtp_to_roth_ira unless qtp_to_roth_ira == SKIP @tuition_plan_private = tuition_plan_private unless tuition_plan_private == SKIP @tuition_plan_public = tuition_plan_public unless tuition_plan_public == SKIP @coverdell_esa = coverdell_esa unless coverdell_esa == SKIP unless recipient_is_not_beneficiary == SKIP @recipient_is_not_beneficiary = recipient_is_not_beneficiary end @fair_market_value = fair_market_value unless fair_market_value == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 64 def attributes @attributes end |
#basis ⇒ Float
Box 3, Basis
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 88 def basis @basis end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 19 def corrected @corrected end |
#coverdell_esa ⇒ TrueClass | FalseClass
Box 5c, Coverdell ESA
109 110 111 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 109 def coverdell_esa @coverdell_esa end |
#earnings ⇒ Float
Box 2, Earnings
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 84 def earnings @earnings end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 68 def error @error end |
#fair_market_value ⇒ Float
If fair market value (FMV) is included, see Pub. 970, Tax Benefits for Education, for how to figure earnings
119 120 121 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 119 def fair_market_value @fair_market_value end |
#gross_distribution ⇒ Float
Box 1, Gross distribution
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 80 def gross_distribution @gross_distribution end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 72 def links @links end |
#qtp_to_roth_ira ⇒ TrueClass | FalseClass
Box 4b, Qualified Tuition Program (QTP) to Roth IRA transfer
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 96 def qtp_to_roth_ira @qtp_to_roth_ira end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 54 def recipient @recipient end |
#recipient_is_not_beneficiary ⇒ TrueClass | FalseClass
Box 6, If this box is checked, the recipient is not the designated beneficiary
114 115 116 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 114 def recipient_is_not_beneficiary @recipient_is_not_beneficiary end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 15 def tax_year @tax_year end |
#trustee_to_trustee ⇒ TrueClass | FalseClass
Box 4a, Trustee-to-trustee transfer
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 92 def trustee_to_trustee @trustee_to_trustee end |
#tuition_plan_private ⇒ TrueClass | FalseClass
Box 5a, Private Qualified Tuition Program (QTP)
100 101 102 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 100 def tuition_plan_private @tuition_plan_private end |
#tuition_plan_public ⇒ TrueClass | FalseClass
Box 5b, State Qualified Tuition Program (QTP). IRS repurposed field, was Qualified tuition plan - Public
105 106 107 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 105 def tuition_plan_public @tuition_plan_public end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 227 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP gross_distribution = hash.key?('grossDistribution') ? hash['grossDistribution'] : SKIP earnings = hash.key?('earnings') ? hash['earnings'] : SKIP basis = hash.key?('basis') ? hash['basis'] : SKIP trustee_to_trustee = hash.key?('trusteeToTrustee') ? hash['trusteeToTrustee'] : SKIP qtp_to_roth_ira = hash.key?('qtpToRothIRA') ? hash['qtpToRothIRA'] : SKIP tuition_plan_private = hash.key?('tuitionPlanPrivate') ? hash['tuitionPlanPrivate'] : SKIP tuition_plan_public = hash.key?('tuitionPlanPublic') ? hash['tuitionPlanPublic'] : SKIP coverdell_esa = hash.key?('coverdellEsa') ? hash['coverdellEsa'] : SKIP recipient_is_not_beneficiary = hash.key?('recipientIsNotBeneficiary') ? hash['recipientIsNotBeneficiary'] : SKIP fair_market_value = hash.key?('fairMarketValue') ? hash['fairMarketValue'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099Q.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, gross_distribution: gross_distribution, earnings: earnings, basis: basis, trustee_to_trustee: trustee_to_trustee, qtp_to_roth_ira: qtp_to_roth_ira, tuition_plan_private: tuition_plan_private, tuition_plan_public: tuition_plan_public, coverdell_esa: coverdell_esa, recipient_is_not_beneficiary: recipient_is_not_beneficiary, fair_market_value: fair_market_value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 122 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['gross_distribution'] = 'grossDistribution' @_hash['earnings'] = 'earnings' @_hash['basis'] = 'basis' @_hash['trustee_to_trustee'] = 'trusteeToTrustee' @_hash['qtp_to_roth_ira'] = 'qtpToRothIRA' @_hash['tuition_plan_private'] = 'tuitionPlanPrivate' @_hash['tuition_plan_public'] = 'tuitionPlanPublic' @_hash['coverdell_esa'] = 'coverdellEsa' @_hash['recipient_is_not_beneficiary'] = 'recipientIsNotBeneficiary' @_hash['fair_market_value'] = 'fairMarketValue' @_hash end |
.nullables ⇒ Object
An array for nullable fields
180 181 182 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 180 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 151 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number gross_distribution earnings basis trustee_to_trustee qtp_to_roth_ira tuition_plan_private tuition_plan_public coverdell_esa recipient_is_not_beneficiary fair_market_value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 331 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, gross_distribution:"\ " #{@gross_distribution.inspect}, earnings: #{@earnings.inspect}, basis: #{@basis.inspect},"\ " trustee_to_trustee: #{@trustee_to_trustee.inspect}, qtp_to_roth_ira:"\ " #{@qtp_to_roth_ira.inspect}, tuition_plan_private: #{@tuition_plan_private.inspect},"\ " tuition_plan_public: #{@tuition_plan_public.inspect}, coverdell_esa:"\ " #{@coverdell_esa.inspect}, recipient_is_not_beneficiary:"\ " #{@recipient_is_not_beneficiary.inspect}, fair_market_value:"\ " #{@fair_market_value.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/fdx_v660_api/models/form1099_q.rb', line 315 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, gross_distribution:"\ " #{@gross_distribution}, earnings: #{@earnings}, basis: #{@basis}, trustee_to_trustee:"\ " #{@trustee_to_trustee}, qtp_to_roth_ira: #{@qtp_to_roth_ira}, tuition_plan_private:"\ " #{@tuition_plan_private}, tuition_plan_public: #{@tuition_plan_public}, coverdell_esa:"\ " #{@coverdell_esa}, recipient_is_not_beneficiary: #{@recipient_is_not_beneficiary},"\ " fair_market_value: #{@fair_market_value}, additional_properties:"\ " #{@additional_properties}>" end |