Class: FdxV660Api::Form1099R1
- Defined in:
- lib/fdx_v660_api/models/form1099_r1.rb
Overview
Distributions from Pensions, Annuities, Retirement or Profit-Sharing Plans, IRAs, Insurance Contracts, etc.
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#allocable_to_irr ⇒ Float
Box 10, Amount allocable to IRR within 5 years.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#capital_gain ⇒ Float
Box 3, Capital gain (included in box 2a).
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#date_of_payment ⇒ Date
Box 13, Date of payment.
-
#distribution_codes ⇒ Array[String]
Box 7a, Distribution codes.
-
#earnings ⇒ Float
Box 7d, Earnings on excess contributions.
-
#employee_contributions ⇒ Float
Box 5, Employee contributions / designated Roth contribution or insurance premiums.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#first_year_of_roth ⇒ Integer
Box 11, First year of designated Roth contributions.
-
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
Box 12, FATCA filing requirement.
-
#gross_distribution ⇒ Float
Box 1, Gross distribution.
-
#ira_sep_simple ⇒ TrueClass | FalseClass
Box 7b, IRA/SEP/SIMPLE.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#net_unrealized_appreciation ⇒ Float
Box 6, Net unrealized appreciation (NUA) in employer's securities.
-
#other_amount ⇒ Float
Box 8a, Other.
-
#other_percent ⇒ Float
Box 8b, Percentage of annuity contract.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#recipient_account_number ⇒ String
Account number.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 14-19, State and Local tax withholding.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#taxable_amount ⇒ Float
Box 2a, Taxable amount.
-
#taxable_amount_not_determined ⇒ TrueClass | FalseClass
Box 2b, Taxable amount not determined.
-
#total_distribution ⇒ TrueClass | FalseClass
Box 2b, Total distribution.
-
#total_employee_contributions ⇒ Float
Box 9b, Total employee contributions.
-
#trump_account ⇒ TrueClass | FalseClass
Box 7c, Trump account.
-
#your_percent_of_total ⇒ Float
Box 9a, Your percent of total distribution.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, recipient_account_number: SKIP, gross_distribution: SKIP, taxable_amount: SKIP, taxable_amount_not_determined: SKIP, total_distribution: SKIP, capital_gain: SKIP, federal_tax_withheld: SKIP, employee_contributions: SKIP, net_unrealized_appreciation: SKIP, distribution_codes: SKIP, ira_sep_simple: SKIP, trump_account: SKIP, earnings: SKIP, other_amount: SKIP, other_percent: SKIP, your_percent_of_total: SKIP, total_employee_contributions: SKIP, allocable_to_irr: SKIP, first_year_of_roth: SKIP, foreign_account_tax_compliance: SKIP, date_of_payment: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099R1
constructor
A new instance of Form1099R1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, recipient_account_number: SKIP, gross_distribution: SKIP, taxable_amount: SKIP, taxable_amount_not_determined: SKIP, total_distribution: SKIP, capital_gain: SKIP, federal_tax_withheld: SKIP, employee_contributions: SKIP, net_unrealized_appreciation: SKIP, distribution_codes: SKIP, ira_sep_simple: SKIP, trump_account: SKIP, earnings: SKIP, other_amount: SKIP, other_percent: SKIP, your_percent_of_total: SKIP, total_employee_contributions: SKIP, allocable_to_irr: SKIP, first_year_of_roth: SKIP, foreign_account_tax_compliance: SKIP, date_of_payment: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ Form1099R1
Returns a new instance of Form1099R1.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 250 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, recipient_account_number: SKIP, gross_distribution: SKIP, taxable_amount: SKIP, taxable_amount_not_determined: SKIP, total_distribution: SKIP, capital_gain: SKIP, federal_tax_withheld: SKIP, employee_contributions: SKIP, net_unrealized_appreciation: SKIP, distribution_codes: SKIP, ira_sep_simple: SKIP, trump_account: SKIP, earnings: SKIP, other_amount: SKIP, other_percent: SKIP, your_percent_of_total: SKIP, total_employee_contributions: SKIP, allocable_to_irr: SKIP, first_year_of_roth: SKIP, foreign_account_tax_compliance: SKIP, date_of_payment: SKIP, state_and_local: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @recipient_account_number = recipient_account_number unless recipient_account_number == SKIP @gross_distribution = gross_distribution unless gross_distribution == SKIP @taxable_amount = taxable_amount unless taxable_amount == SKIP unless taxable_amount_not_determined == SKIP @taxable_amount_not_determined = taxable_amount_not_determined end @total_distribution = total_distribution unless total_distribution == SKIP @capital_gain = capital_gain unless capital_gain == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @employee_contributions = employee_contributions unless employee_contributions == SKIP unless net_unrealized_appreciation == SKIP @net_unrealized_appreciation = net_unrealized_appreciation end @distribution_codes = distribution_codes unless distribution_codes == SKIP @ira_sep_simple = ira_sep_simple unless ira_sep_simple == SKIP @trump_account = trump_account unless trump_account == SKIP @earnings = earnings unless earnings == SKIP @other_amount = other_amount unless other_amount == SKIP @other_percent = other_percent unless other_percent == SKIP @your_percent_of_total = your_percent_of_total unless your_percent_of_total == SKIP unless total_employee_contributions == SKIP @total_employee_contributions = total_employee_contributions end @allocable_to_irr = allocable_to_irr unless allocable_to_irr == SKIP @first_year_of_roth = first_year_of_roth unless first_year_of_roth == SKIP unless foreign_account_tax_compliance == SKIP @foreign_account_tax_compliance = foreign_account_tax_compliance end @date_of_payment = date_of_payment unless date_of_payment == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 24 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 38 def additional_information @additional_information end |
#allocable_to_irr ⇒ Float
Box 10, Amount allocable to IRR within 5 years
145 146 147 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 145 def allocable_to_irr @allocable_to_irr end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 64 def attributes @attributes end |
#capital_gain ⇒ Float
Box 3, Capital gain (included in box 2a)
96 97 98 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 96 def capital_gain @capital_gain end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 19 def corrected @corrected end |
#date_of_payment ⇒ Date
Box 13, Date of payment
159 160 161 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 159 def date_of_payment @date_of_payment end |
#distribution_codes ⇒ Array[String]
Box 7a, Distribution codes
113 114 115 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 113 def distribution_codes @distribution_codes end |
#earnings ⇒ Float
Box 7d, Earnings on excess contributions
125 126 127 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 125 def earnings @earnings end |
#employee_contributions ⇒ Float
Box 5, Employee contributions / designated Roth contribution or insurance premiums
105 106 107 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 105 def employee_contributions @employee_contributions end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 68 def error @error end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
100 101 102 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 100 def federal_tax_withheld @federal_tax_withheld end |
#first_year_of_roth ⇒ Integer
Box 11, First year of designated Roth contributions. A four-digit year.
(Like TaxYear definition, but lower minimum since first year of Roth
IRAs was 1997)
151 152 153 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 151 def first_year_of_roth @first_year_of_roth end |
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
Box 12, FATCA filing requirement
155 156 157 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 155 def foreign_account_tax_compliance @foreign_account_tax_compliance end |
#gross_distribution ⇒ Float
Box 1, Gross distribution
80 81 82 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 80 def gross_distribution @gross_distribution end |
#ira_sep_simple ⇒ TrueClass | FalseClass
Box 7b, IRA/SEP/SIMPLE
117 118 119 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 117 def ira_sep_simple @ira_sep_simple end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 72 def links @links end |
#net_unrealized_appreciation ⇒ Float
Box 6, Net unrealized appreciation (NUA) in employer's securities
109 110 111 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 109 def net_unrealized_appreciation @net_unrealized_appreciation end |
#other_amount ⇒ Float
Box 8a, Other
129 130 131 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 129 def other_amount @other_amount end |
#other_percent ⇒ Float
Box 8b, Percentage of annuity contract
133 134 135 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 133 def other_percent @other_percent end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 54 def recipient @recipient end |
#recipient_account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 76 def recipient_account_number @recipient_account_number end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 14-19, State and Local tax withholding
163 164 165 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 163 def state_and_local @state_and_local end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 15 def tax_year @tax_year end |
#taxable_amount ⇒ Float
Box 2a, Taxable amount
84 85 86 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 84 def taxable_amount @taxable_amount end |
#taxable_amount_not_determined ⇒ TrueClass | FalseClass
Box 2b, Taxable amount not determined
88 89 90 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 88 def taxable_amount_not_determined @taxable_amount_not_determined end |
#total_distribution ⇒ TrueClass | FalseClass
Box 2b, Total distribution
92 93 94 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 92 def total_distribution @total_distribution end |
#total_employee_contributions ⇒ Float
Box 9b, Total employee contributions
141 142 143 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 141 def total_employee_contributions @total_employee_contributions end |
#trump_account ⇒ TrueClass | FalseClass
Box 7c, Trump account
121 122 123 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 121 def trump_account @trump_account end |
#your_percent_of_total ⇒ Float
Box 9a, Your percent of total distribution
137 138 139 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 137 def your_percent_of_total @your_percent_of_total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 320 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') recipient_account_number = hash.key?('recipientAccountNumber') ? hash['recipientAccountNumber'] : SKIP gross_distribution = hash.key?('grossDistribution') ? hash['grossDistribution'] : SKIP taxable_amount = hash.key?('taxableAmount') ? hash['taxableAmount'] : SKIP taxable_amount_not_determined = hash.key?('taxableAmountNotDetermined') ? hash['taxableAmountNotDetermined'] : SKIP total_distribution = hash.key?('totalDistribution') ? hash['totalDistribution'] : SKIP capital_gain = hash.key?('capitalGain') ? hash['capitalGain'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP employee_contributions = hash.key?('employeeContributions') ? hash['employeeContributions'] : SKIP net_unrealized_appreciation = hash.key?('netUnrealizedAppreciation') ? hash['netUnrealizedAppreciation'] : SKIP distribution_codes = hash.key?('distributionCodes') ? hash['distributionCodes'] : SKIP ira_sep_simple = hash.key?('iraSepSimple') ? hash['iraSepSimple'] : SKIP trump_account = hash.key?('trumpAccount') ? hash['trumpAccount'] : SKIP earnings = hash.key?('earnings') ? hash['earnings'] : SKIP other_amount = hash.key?('otherAmount') ? hash['otherAmount'] : SKIP other_percent = hash.key?('otherPercent') ? hash['otherPercent'] : SKIP your_percent_of_total = hash.key?('yourPercentOfTotal') ? hash['yourPercentOfTotal'] : SKIP total_employee_contributions = hash.key?('totalEmployeeContributions') ? hash['totalEmployeeContributions'] : SKIP allocable_to_irr = hash.key?('allocableToIRR') ? hash['allocableToIRR'] : SKIP first_year_of_roth = hash.key?('firstYearOfRoth') ? hash['firstYearOfRoth'] : SKIP foreign_account_tax_compliance = hash.key?('foreignAccountTaxCompliance') ? hash['foreignAccountTaxCompliance'] : SKIP date_of_payment = hash.key?('dateOfPayment') ? hash['dateOfPayment'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form1099R1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, recipient_account_number: recipient_account_number, gross_distribution: gross_distribution, taxable_amount: taxable_amount, taxable_amount_not_determined: taxable_amount_not_determined, total_distribution: total_distribution, capital_gain: capital_gain, federal_tax_withheld: federal_tax_withheld, employee_contributions: employee_contributions, net_unrealized_appreciation: net_unrealized_appreciation, distribution_codes: distribution_codes, ira_sep_simple: ira_sep_simple, trump_account: trump_account, earnings: earnings, other_amount: other_amount, other_percent: other_percent, your_percent_of_total: your_percent_of_total, total_employee_contributions: total_employee_contributions, allocable_to_irr: allocable_to_irr, first_year_of_roth: first_year_of_roth, foreign_account_tax_compliance: foreign_account_tax_compliance, date_of_payment: date_of_payment, state_and_local: state_and_local, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 166 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['recipient_account_number'] = 'recipientAccountNumber' @_hash['gross_distribution'] = 'grossDistribution' @_hash['taxable_amount'] = 'taxableAmount' @_hash['taxable_amount_not_determined'] = 'taxableAmountNotDetermined' @_hash['total_distribution'] = 'totalDistribution' @_hash['capital_gain'] = 'capitalGain' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['employee_contributions'] = 'employeeContributions' @_hash['net_unrealized_appreciation'] = 'netUnrealizedAppreciation' @_hash['distribution_codes'] = 'distributionCodes' @_hash['ira_sep_simple'] = 'iraSepSimple' @_hash['trump_account'] = 'trumpAccount' @_hash['earnings'] = 'earnings' @_hash['other_amount'] = 'otherAmount' @_hash['other_percent'] = 'otherPercent' @_hash['your_percent_of_total'] = 'yourPercentOfTotal' @_hash['total_employee_contributions'] = 'totalEmployeeContributions' @_hash['allocable_to_irr'] = 'allocableToIRR' @_hash['first_year_of_roth'] = 'firstYearOfRoth' @_hash['foreign_account_tax_compliance'] = 'foreignAccountTaxCompliance' @_hash['date_of_payment'] = 'dateOfPayment' @_hash['state_and_local'] = 'stateAndLocal' @_hash end |
.nullables ⇒ Object
An array for nullable fields
246 247 248 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 246 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 206 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links recipient_account_number gross_distribution taxable_amount taxable_amount_not_determined total_distribution capital_gain federal_tax_withheld employee_contributions net_unrealized_appreciation distribution_codes ira_sep_simple trump_account earnings other_amount other_percent your_percent_of_total total_employee_contributions allocable_to_irr first_year_of_roth foreign_account_tax_compliance date_of_payment state_and_local ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 470 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, recipient_account_number: #{@recipient_account_number.inspect},"\ " gross_distribution: #{@gross_distribution.inspect}, taxable_amount:"\ " #{@taxable_amount.inspect}, taxable_amount_not_determined:"\ " #{@taxable_amount_not_determined.inspect}, total_distribution:"\ " #{@total_distribution.inspect}, capital_gain: #{@capital_gain.inspect},"\ " federal_tax_withheld: #{@federal_tax_withheld.inspect}, employee_contributions:"\ " #{@employee_contributions.inspect}, net_unrealized_appreciation:"\ " #{@net_unrealized_appreciation.inspect}, distribution_codes:"\ " #{@distribution_codes.inspect}, ira_sep_simple: #{@ira_sep_simple.inspect}, trump_account:"\ " #{@trump_account.inspect}, earnings: #{@earnings.inspect}, other_amount:"\ " #{@other_amount.inspect}, other_percent: #{@other_percent.inspect}, your_percent_of_total:"\ " #{@your_percent_of_total.inspect}, total_employee_contributions:"\ " #{@total_employee_contributions.inspect}, allocable_to_irr: #{@allocable_to_irr.inspect},"\ " first_year_of_roth: #{@first_year_of_roth.inspect}, foreign_account_tax_compliance:"\ " #{@foreign_account_tax_compliance.inspect}, date_of_payment: #{@date_of_payment.inspect},"\ " state_and_local: #{@state_and_local.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/fdx_v660_api/models/form1099_r1.rb', line 447 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, recipient_account_number: #{@recipient_account_number},"\ " gross_distribution: #{@gross_distribution}, taxable_amount: #{@taxable_amount},"\ " taxable_amount_not_determined: #{@taxable_amount_not_determined}, total_distribution:"\ " #{@total_distribution}, capital_gain: #{@capital_gain}, federal_tax_withheld:"\ " #{@federal_tax_withheld}, employee_contributions: #{@employee_contributions},"\ " net_unrealized_appreciation: #{@net_unrealized_appreciation}, distribution_codes:"\ " #{@distribution_codes}, ira_sep_simple: #{@ira_sep_simple}, trump_account:"\ " #{@trump_account}, earnings: #{@earnings}, other_amount: #{@other_amount}, other_percent:"\ " #{@other_percent}, your_percent_of_total: #{@your_percent_of_total},"\ " total_employee_contributions: #{@total_employee_contributions}, allocable_to_irr:"\ " #{@allocable_to_irr}, first_year_of_roth: #{@first_year_of_roth},"\ " foreign_account_tax_compliance: #{@foreign_account_tax_compliance}, date_of_payment:"\ " #{@date_of_payment}, state_and_local: #{@state_and_local}, additional_properties:"\ " #{@additional_properties}>" end |