Class: FdxV660Api::Form5498
- Defined in:
- lib/fdx_v660_api/models/form5498.rb
Overview
IRA Contribution Information, from TRUSTEE/ISSUER (1st-8th boxes as issuer) to PARTICIPANT (9th-16th boxes as recipient)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#fair_market_value ⇒ Float
Box 5, Fair market value of account.
-
#fmv_specified_assets ⇒ Float
Box 15a, FMV of certain specified assets.
-
#ira ⇒ TrueClass | FalseClass
Box 7a, IRA.
-
#ira_contributions ⇒ Float
Box 1, IRA contributions.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#life_insurance_cost ⇒ Float
Box 6, Life insurance cost included in box 1.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#postponed_code ⇒ String
Box 13c, Code.
-
#postponed_contribution ⇒ Float
Box 13a, Postponed contribution.
-
#postponed_year ⇒ Integer
Box 13b, Year.
-
#recharacterized_contributions ⇒ Float
Box 4, Recharacterized contributions.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#repay_code ⇒ String
Box 14b, Code.
-
#repayments ⇒ Float
Box 14a, Repayments.
-
#rmd_amount ⇒ Float
Box 12b, RMD amount.
-
#rmd_date ⇒ Date
Box 12a, RMD date.
-
#rmd_next_year ⇒ TrueClass | FalseClass
Box 11, If checked, required minimum distribution for next year.
-
#rollover_contributions ⇒ Float
Box 2, Rollover contributions.
-
#roth_ira ⇒ TrueClass | FalseClass
Box 7d, Roth IRA.
-
#roth_ira_contributions ⇒ Float
Box 10, Roth IRA contributions.
-
#roth_ira_conversion ⇒ Float
Box 3, Roth IRA conversion amount.
-
#sep ⇒ TrueClass | FalseClass
Box 7b, SEP.
-
#sep_contributions ⇒ Float
Box 8, SEP contributions.
-
#simple ⇒ TrueClass | FalseClass
Box 7c, SIMPLE.
-
#simple_contributions ⇒ Float
Box 9, SIMPLE contributions.
-
#specified_codes ⇒ String
Box 15b, Code(s).
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ira_contributions: SKIP, rollover_contributions: SKIP, roth_ira_conversion: SKIP, recharacterized_contributions: SKIP, fair_market_value: SKIP, life_insurance_cost: SKIP, ira: SKIP, sep: SKIP, simple: SKIP, roth_ira: SKIP, sep_contributions: SKIP, simple_contributions: SKIP, roth_ira_contributions: SKIP, rmd_next_year: SKIP, rmd_date: SKIP, rmd_amount: SKIP, postponed_contribution: SKIP, postponed_year: SKIP, postponed_code: SKIP, repayments: SKIP, repay_code: SKIP, fmv_specified_assets: SKIP, specified_codes: SKIP, additional_properties: nil) ⇒ Form5498
constructor
A new instance of Form5498.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ira_contributions: SKIP, rollover_contributions: SKIP, roth_ira_conversion: SKIP, recharacterized_contributions: SKIP, fair_market_value: SKIP, life_insurance_cost: SKIP, ira: SKIP, sep: SKIP, simple: SKIP, roth_ira: SKIP, sep_contributions: SKIP, simple_contributions: SKIP, roth_ira_contributions: SKIP, rmd_next_year: SKIP, rmd_date: SKIP, rmd_amount: SKIP, postponed_contribution: SKIP, postponed_year: SKIP, postponed_code: SKIP, repayments: SKIP, repay_code: SKIP, fmv_specified_assets: SKIP, specified_codes: SKIP, additional_properties: nil) ⇒ Form5498
Returns a new instance of Form5498.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 259 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, ira_contributions: SKIP, rollover_contributions: SKIP, roth_ira_conversion: SKIP, recharacterized_contributions: SKIP, fair_market_value: SKIP, life_insurance_cost: SKIP, ira: SKIP, sep: SKIP, simple: SKIP, roth_ira: SKIP, sep_contributions: SKIP, simple_contributions: SKIP, roth_ira_contributions: SKIP, rmd_next_year: SKIP, rmd_date: SKIP, rmd_amount: SKIP, postponed_contribution: SKIP, postponed_year: SKIP, postponed_code: SKIP, repayments: SKIP, repay_code: SKIP, fmv_specified_assets: SKIP, specified_codes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @ira_contributions = ira_contributions unless ira_contributions == SKIP @rollover_contributions = rollover_contributions unless rollover_contributions == SKIP @roth_ira_conversion = roth_ira_conversion unless roth_ira_conversion == SKIP unless recharacterized_contributions == SKIP @recharacterized_contributions = recharacterized_contributions end @fair_market_value = fair_market_value unless fair_market_value == SKIP @life_insurance_cost = life_insurance_cost unless life_insurance_cost == SKIP @ira = ira unless ira == SKIP @sep = sep unless sep == SKIP @simple = simple unless simple == SKIP @roth_ira = roth_ira unless roth_ira == SKIP @sep_contributions = sep_contributions unless sep_contributions == SKIP @simple_contributions = simple_contributions unless simple_contributions == SKIP @roth_ira_contributions = roth_ira_contributions unless roth_ira_contributions == SKIP @rmd_next_year = rmd_next_year unless rmd_next_year == SKIP @rmd_date = rmd_date unless rmd_date == SKIP @rmd_amount = rmd_amount unless rmd_amount == SKIP @postponed_contribution = postponed_contribution unless postponed_contribution == SKIP @postponed_year = postponed_year unless postponed_year == SKIP @postponed_code = postponed_code unless postponed_code == SKIP @repayments = repayments unless repayments == SKIP @repay_code = repay_code unless repay_code == SKIP @fmv_specified_assets = fmv_specified_assets unless fmv_specified_assets == SKIP @specified_codes = specified_codes unless specified_codes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 24 def account_id @account_id end |
#account_number ⇒ String
Account number
76 77 78 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 76 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 19 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 68 def error @error end |
#fair_market_value ⇒ Float
Box 5, Fair market value of account
96 97 98 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 96 def fair_market_value @fair_market_value end |
#fmv_specified_assets ⇒ Float
Box 15a, FMV of certain specified assets
164 165 166 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 164 def fmv_specified_assets @fmv_specified_assets end |
#ira ⇒ TrueClass | FalseClass
Box 7a, IRA
104 105 106 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 104 def ira @ira end |
#ira_contributions ⇒ Float
Box 1, IRA contributions
80 81 82 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 80 def ira_contributions @ira_contributions end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 48 def issuer @issuer end |
#life_insurance_cost ⇒ Float
Box 6, Life insurance cost included in box 1
100 101 102 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 100 def life_insurance_cost @life_insurance_cost end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 72 def links @links end |
#postponed_code ⇒ String
Box 13c, Code
152 153 154 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 152 def postponed_code @postponed_code end |
#postponed_contribution ⇒ Float
Box 13a, Postponed contribution
144 145 146 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 144 def postponed_contribution @postponed_contribution end |
#postponed_year ⇒ Integer
Box 13b, Year
148 149 150 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 148 def postponed_year @postponed_year end |
#recharacterized_contributions ⇒ Float
Box 4, Recharacterized contributions
92 93 94 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 92 def recharacterized_contributions @recharacterized_contributions end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 54 def recipient @recipient end |
#repay_code ⇒ String
Box 14b, Code
160 161 162 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 160 def repay_code @repay_code end |
#repayments ⇒ Float
Box 14a, Repayments
156 157 158 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 156 def repayments @repayments end |
#rmd_amount ⇒ Float
Box 12b, RMD amount
140 141 142 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 140 def rmd_amount @rmd_amount end |
#rmd_date ⇒ Date
Box 12a, RMD date
136 137 138 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 136 def rmd_date @rmd_date end |
#rmd_next_year ⇒ TrueClass | FalseClass
Box 11, If checked, required minimum distribution for next year
132 133 134 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 132 def rmd_next_year @rmd_next_year end |
#rollover_contributions ⇒ Float
Box 2, Rollover contributions
84 85 86 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 84 def rollover_contributions @rollover_contributions end |
#roth_ira ⇒ TrueClass | FalseClass
Box 7d, Roth IRA
116 117 118 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 116 def roth_ira @roth_ira end |
#roth_ira_contributions ⇒ Float
Box 10, Roth IRA contributions
128 129 130 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 128 def roth_ira_contributions @roth_ira_contributions end |
#roth_ira_conversion ⇒ Float
Box 3, Roth IRA conversion amount
88 89 90 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 88 def roth_ira_conversion @roth_ira_conversion end |
#sep ⇒ TrueClass | FalseClass
Box 7b, SEP
108 109 110 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 108 def sep @sep end |
#sep_contributions ⇒ Float
Box 8, SEP contributions
120 121 122 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 120 def sep_contributions @sep_contributions end |
#simple ⇒ TrueClass | FalseClass
Box 7c, SIMPLE
112 113 114 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 112 def simple @simple end |
#simple_contributions ⇒ Float
Box 9, SIMPLE contributions
124 125 126 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 124 def simple_contributions @simple_contributions end |
#specified_codes ⇒ String
Box 15b, Code(s)
168 169 170 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 168 def specified_codes @specified_codes end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 15 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 320 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP ira_contributions = hash.key?('iraContributions') ? hash['iraContributions'] : SKIP rollover_contributions = hash.key?('rolloverContributions') ? hash['rolloverContributions'] : SKIP roth_ira_conversion = hash.key?('rothIraConversion') ? hash['rothIraConversion'] : SKIP recharacterized_contributions = hash.key?('recharacterizedContributions') ? hash['recharacterizedContributions'] : SKIP fair_market_value = hash.key?('fairMarketValue') ? hash['fairMarketValue'] : SKIP life_insurance_cost = hash.key?('lifeInsuranceCost') ? hash['lifeInsuranceCost'] : SKIP ira = hash.key?('ira') ? hash['ira'] : SKIP sep = hash.key?('sep') ? hash['sep'] : SKIP simple = hash.key?('simple') ? hash['simple'] : SKIP roth_ira = hash.key?('rothIra') ? hash['rothIra'] : SKIP sep_contributions = hash.key?('sepContributions') ? hash['sepContributions'] : SKIP simple_contributions = hash.key?('simpleContributions') ? hash['simpleContributions'] : SKIP roth_ira_contributions = hash.key?('rothIraContributions') ? hash['rothIraContributions'] : SKIP rmd_next_year = hash.key?('rmdNextYear') ? hash['rmdNextYear'] : SKIP rmd_date = hash.key?('rmdDate') ? hash['rmdDate'] : SKIP rmd_amount = hash.key?('rmdAmount') ? hash['rmdAmount'] : SKIP postponed_contribution = hash.key?('postponedContribution') ? hash['postponedContribution'] : SKIP postponed_year = hash.key?('postponedYear') ? hash['postponedYear'] : SKIP postponed_code = hash.key?('postponedCode') ? hash['postponedCode'] : SKIP repayments = hash.key?('repayments') ? hash['repayments'] : SKIP repay_code = hash.key?('repayCode') ? hash['repayCode'] : SKIP fmv_specified_assets = hash.key?('fmvSpecifiedAssets') ? hash['fmvSpecifiedAssets'] : SKIP specified_codes = hash.key?('specifiedCodes') ? hash['specifiedCodes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form5498.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, ira_contributions: ira_contributions, rollover_contributions: rollover_contributions, roth_ira_conversion: roth_ira_conversion, recharacterized_contributions: recharacterized_contributions, fair_market_value: fair_market_value, life_insurance_cost: life_insurance_cost, ira: ira, sep: sep, simple: simple, roth_ira: roth_ira, sep_contributions: sep_contributions, simple_contributions: simple_contributions, roth_ira_contributions: roth_ira_contributions, rmd_next_year: rmd_next_year, rmd_date: rmd_date, rmd_amount: rmd_amount, postponed_contribution: postponed_contribution, postponed_year: postponed_year, postponed_code: postponed_code, repayments: repayments, repay_code: repay_code, fmv_specified_assets: fmv_specified_assets, specified_codes: specified_codes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 171 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['ira_contributions'] = 'iraContributions' @_hash['rollover_contributions'] = 'rolloverContributions' @_hash['roth_ira_conversion'] = 'rothIraConversion' @_hash['recharacterized_contributions'] = 'recharacterizedContributions' @_hash['fair_market_value'] = 'fairMarketValue' @_hash['life_insurance_cost'] = 'lifeInsuranceCost' @_hash['ira'] = 'ira' @_hash['sep'] = 'sep' @_hash['simple'] = 'simple' @_hash['roth_ira'] = 'rothIra' @_hash['sep_contributions'] = 'sepContributions' @_hash['simple_contributions'] = 'simpleContributions' @_hash['roth_ira_contributions'] = 'rothIraContributions' @_hash['rmd_next_year'] = 'rmdNextYear' @_hash['rmd_date'] = 'rmdDate' @_hash['rmd_amount'] = 'rmdAmount' @_hash['postponed_contribution'] = 'postponedContribution' @_hash['postponed_year'] = 'postponedYear' @_hash['postponed_code'] = 'postponedCode' @_hash['repayments'] = 'repayments' @_hash['repay_code'] = 'repayCode' @_hash['fmv_specified_assets'] = 'fmvSpecifiedAssets' @_hash['specified_codes'] = 'specifiedCodes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
255 256 257 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 255 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 213 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number ira_contributions rollover_contributions roth_ira_conversion recharacterized_contributions fair_market_value life_insurance_cost ira sep simple roth_ira sep_contributions simple_contributions roth_ira_contributions rmd_next_year rmd_date rmd_amount postponed_contribution postponed_year postponed_code repayments repay_code fmv_specified_assets specified_codes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 462 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, ira_contributions:"\ " #{@ira_contributions.inspect}, rollover_contributions: #{@rollover_contributions.inspect},"\ " roth_ira_conversion: #{@roth_ira_conversion.inspect}, recharacterized_contributions:"\ " #{@recharacterized_contributions.inspect}, fair_market_value:"\ " #{@fair_market_value.inspect}, life_insurance_cost: #{@life_insurance_cost.inspect}, ira:"\ " #{@ira.inspect}, sep: #{@sep.inspect}, simple: #{@simple.inspect}, roth_ira:"\ " #{@roth_ira.inspect}, sep_contributions: #{@sep_contributions.inspect},"\ " simple_contributions: #{@simple_contributions.inspect}, roth_ira_contributions:"\ " #{@roth_ira_contributions.inspect}, rmd_next_year: #{@rmd_next_year.inspect}, rmd_date:"\ " #{@rmd_date.inspect}, rmd_amount: #{@rmd_amount.inspect}, postponed_contribution:"\ " #{@postponed_contribution.inspect}, postponed_year: #{@postponed_year.inspect},"\ " postponed_code: #{@postponed_code.inspect}, repayments: #{@repayments.inspect},"\ " repay_code: #{@repay_code.inspect}, fmv_specified_assets:"\ " #{@fmv_specified_assets.inspect}, specified_codes: #{@specified_codes.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/fdx_v660_api/models/form5498.rb', line 440 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, ira_contributions:"\ " #{@ira_contributions}, rollover_contributions: #{@rollover_contributions},"\ " roth_ira_conversion: #{@roth_ira_conversion}, recharacterized_contributions:"\ " #{@recharacterized_contributions}, fair_market_value: #{@fair_market_value},"\ " life_insurance_cost: #{@life_insurance_cost}, ira: #{@ira}, sep: #{@sep}, simple:"\ " #{@simple}, roth_ira: #{@roth_ira}, sep_contributions: #{@sep_contributions},"\ " simple_contributions: #{@simple_contributions}, roth_ira_contributions:"\ " #{@roth_ira_contributions}, rmd_next_year: #{@rmd_next_year}, rmd_date: #{@rmd_date},"\ " rmd_amount: #{@rmd_amount}, postponed_contribution: #{@postponed_contribution},"\ " postponed_year: #{@postponed_year}, postponed_code: #{@postponed_code}, repayments:"\ " #{@repayments}, repay_code: #{@repay_code}, fmv_specified_assets:"\ " #{@fmv_specified_assets}, specified_codes: #{@specified_codes}, additional_properties:"\ " #{@additional_properties}>" end |