Class: FdxV660Api::Form5498Sa1
- Defined in:
- lib/fdx_v660_api/models/form5498_sa1.rb
Overview
HSA, Archer MSA, or Medicare Advantage MSA Information
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#account_number ⇒ String
Account number.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#archer ⇒ TrueClass | FalseClass
Box 6b, Archer MSA.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#fair_market_value ⇒ Float
Box 5, Fair market value of HSA, Archer MSA, or Medicare Advantage (MA) MSA.
-
#hsa ⇒ TrueClass | FalseClass
Box 6a, HSA.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#ma_msa ⇒ TrueClass | FalseClass
Box 6c, Medicare Advantage (MA) MSA.
-
#msa_contributions ⇒ Float
Box 1, Employee or self-employed person's Archer MSA contributions made in current and following years for current year.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#rollover_contributions ⇒ Float
Box 4, Rollover contributions.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#total_contributions ⇒ Float
Box 2, Total contributions made in current year.
-
#total_post_year_end ⇒ Float
Box 3, Total HSA or Archer MSA contributions made in following year for current year.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, msa_contributions: SKIP, total_contributions: SKIP, total_post_year_end: SKIP, rollover_contributions: SKIP, fair_market_value: SKIP, hsa: SKIP, archer: SKIP, ma_msa: SKIP, additional_properties: nil) ⇒ Form5498Sa1
constructor
A new instance of Form5498Sa1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, msa_contributions: SKIP, total_contributions: SKIP, total_post_year_end: SKIP, rollover_contributions: SKIP, fair_market_value: SKIP, hsa: SKIP, archer: SKIP, ma_msa: SKIP, additional_properties: nil) ⇒ Form5498Sa1
Returns a new instance of Form5498Sa1.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 171 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, account_number: SKIP, msa_contributions: SKIP, total_contributions: SKIP, total_post_year_end: SKIP, rollover_contributions: SKIP, fair_market_value: SKIP, hsa: SKIP, archer: SKIP, ma_msa: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @account_number = account_number unless account_number == SKIP @msa_contributions = msa_contributions unless msa_contributions == SKIP @total_contributions = total_contributions unless total_contributions == SKIP @total_post_year_end = total_post_year_end unless total_post_year_end == SKIP @rollover_contributions = rollover_contributions unless rollover_contributions == SKIP @fair_market_value = fair_market_value unless fair_market_value == SKIP @hsa = hsa unless hsa == SKIP @archer = archer unless archer == SKIP @ma_msa = ma_msa unless ma_msa == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
23 24 25 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 23 def account_id @account_id end |
#account_number ⇒ String
Account number
75 76 77 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 75 def account_number @account_number end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
37 38 39 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 37 def additional_information @additional_information end |
#archer ⇒ TrueClass | FalseClass
Box 6b, Archer MSA
106 107 108 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 106 def archer @archer end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
63 64 65 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 63 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
18 19 20 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 18 def corrected @corrected end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
67 68 69 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 67 def error @error end |
#fair_market_value ⇒ Float
Box 5, Fair market value of HSA, Archer MSA, or Medicare Advantage (MA) MSA
98 99 100 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 98 def fair_market_value @fair_market_value end |
#hsa ⇒ TrueClass | FalseClass
Box 6a, HSA
102 103 104 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 102 def hsa @hsa end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
47 48 49 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 47 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
71 72 73 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 71 def links @links end |
#ma_msa ⇒ TrueClass | FalseClass
Box 6c, Medicare Advantage (MA) MSA
110 111 112 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 110 def ma_msa @ma_msa end |
#msa_contributions ⇒ Float
Box 1, Employee or self-employed person's Archer MSA contributions made in current and following years for current year
80 81 82 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 80 def msa_contributions @msa_contributions end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
53 54 55 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 53 def recipient @recipient end |
#rollover_contributions ⇒ Float
Box 4, Rollover contributions
93 94 95 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 93 def rollover_contributions @rollover_contributions end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
33 34 35 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 33 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
29 30 31 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 29 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
41 42 43 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 41 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
14 15 16 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 14 def tax_year @tax_year end |
#total_contributions ⇒ Float
Box 2, Total contributions made in current year
84 85 86 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 84 def total_contributions @total_contributions end |
#total_post_year_end ⇒ Float
Box 3, Total HSA or Archer MSA contributions made in following year for current year
89 90 91 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 89 def total_post_year_end @total_post_year_end end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 208 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP msa_contributions = hash.key?('msaContributions') ? hash['msaContributions'] : SKIP total_contributions = hash.key?('totalContributions') ? hash['totalContributions'] : SKIP total_post_year_end = hash.key?('totalPostYearEnd') ? hash['totalPostYearEnd'] : SKIP rollover_contributions = hash.key?('rolloverContributions') ? hash['rolloverContributions'] : SKIP fair_market_value = hash.key?('fairMarketValue') ? hash['fairMarketValue'] : SKIP hsa = hash.key?('hsa') ? hash['hsa'] : SKIP archer = hash.key?('archer') ? hash['archer'] : SKIP ma_msa = hash.key?('maMsa') ? hash['maMsa'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Form5498Sa1.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, account_number: account_number, msa_contributions: msa_contributions, total_contributions: total_contributions, total_post_year_end: total_post_year_end, rollover_contributions: rollover_contributions, fair_market_value: fair_market_value, hsa: hsa, archer: archer, ma_msa: ma_msa, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 113 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['account_number'] = 'accountNumber' @_hash['msa_contributions'] = 'msaContributions' @_hash['total_contributions'] = 'totalContributions' @_hash['total_post_year_end'] = 'totalPostYearEnd' @_hash['rollover_contributions'] = 'rolloverContributions' @_hash['fair_market_value'] = 'fairMarketValue' @_hash['hsa'] = 'hsa' @_hash['archer'] = 'archer' @_hash['ma_msa'] = 'maMsa' @_hash end |
.nullables ⇒ Object
An array for nullable fields
167 168 169 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 167 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 140 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links account_number msa_contributions total_contributions total_post_year_end rollover_contributions fair_market_value hsa archer ma_msa ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 305 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, account_number: #{@account_number.inspect}, msa_contributions:"\ " #{@msa_contributions.inspect}, total_contributions: #{@total_contributions.inspect},"\ " total_post_year_end: #{@total_post_year_end.inspect}, rollover_contributions:"\ " #{@rollover_contributions.inspect}, fair_market_value: #{@fair_market_value.inspect}, hsa:"\ " #{@hsa.inspect}, archer: #{@archer.inspect}, ma_msa: #{@ma_msa.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/fdx_v660_api/models/form5498_sa1.rb', line 291 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, account_number: #{@account_number}, msa_contributions:"\ " #{@msa_contributions}, total_contributions: #{@total_contributions}, total_post_year_end:"\ " #{@total_post_year_end}, rollover_contributions: #{@rollover_contributions},"\ " fair_market_value: #{@fair_market_value}, hsa: #{@hsa}, archer: #{@archer}, ma_msa:"\ " #{@ma_msa}, additional_properties: #{@additional_properties}>" end |