Class: FdxV660Api::FormW2C
- Defined in:
- lib/fdx_v660_api/models/form_w2_c.rb
Overview
IRS form W-2c, Corrected Wage and Tax Statement, from Employer (boxes a-b as issuer) to Employee (boxes d, f-i as recipient)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#corrected_tin_or_name ⇒ TrueClass | FalseClass
Box e, Corrected SSN and/or name.
-
#corrected_w2 ⇒ FormW22
Boxes 1-20 of Correct information Wage and Tax Statement.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#original_w2 ⇒ FormW21
Boxes 1-20 of Previously reported Wage and Tax Statement.
-
#previous_employee_name ⇒ IndividualName6
Box g, Employee's previously reported name.
-
#previous_employee_tin ⇒ String
Box f, Employee's previously reported SSN.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, corrected_tin_or_name: SKIP, previous_employee_tin: SKIP, previous_employee_name: SKIP, original_w2: SKIP, corrected_w2: SKIP, additional_properties: nil) ⇒ FormW2C
constructor
A new instance of FormW2C.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, corrected_tin_or_name: SKIP, previous_employee_tin: SKIP, previous_employee_name: SKIP, original_w2: SKIP, corrected_w2: SKIP, additional_properties: nil) ⇒ FormW2C
Returns a new instance of FormW2C.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 145 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, corrected_tin_or_name: SKIP, previous_employee_tin: SKIP, previous_employee_name: SKIP, original_w2: SKIP, corrected_w2: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @corrected_tin_or_name = corrected_tin_or_name unless corrected_tin_or_name == SKIP @previous_employee_tin = previous_employee_tin unless previous_employee_tin == SKIP @previous_employee_name = previous_employee_name unless previous_employee_name == SKIP @original_w2 = original_w2 unless original_w2 == SKIP @corrected_w2 = corrected_w2 unless corrected_w2 == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 24 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 64 def attributes @attributes end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 19 def corrected @corrected end |
#corrected_tin_or_name ⇒ TrueClass | FalseClass
Box e, Corrected SSN and/or name
76 77 78 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 76 def corrected_tin_or_name @corrected_tin_or_name end |
#corrected_w2 ⇒ FormW22
Boxes 1-20 of Correct information Wage and Tax Statement
92 93 94 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 92 def corrected_w2 @corrected_w2 end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 68 def error @error end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 72 def links @links end |
#original_w2 ⇒ FormW21
Boxes 1-20 of Previously reported Wage and Tax Statement
88 89 90 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 88 def original_w2 @original_w2 end |
#previous_employee_name ⇒ IndividualName6
Box g, Employee's previously reported name
84 85 86 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 84 def previous_employee_name @previous_employee_name end |
#previous_employee_tin ⇒ String
Box f, Employee's previously reported SSN
80 81 82 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 80 def previous_employee_tin @previous_employee_tin end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 54 def recipient @recipient end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 15 def tax_year @tax_year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 177 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') corrected_tin_or_name = hash.key?('correctedTinOrName') ? hash['correctedTinOrName'] : SKIP previous_employee_tin = hash.key?('previousEmployeeTin') ? hash['previousEmployeeTin'] : SKIP previous_employee_name = IndividualName6.from_hash(hash['previousEmployeeName']) if hash['previousEmployeeName'] original_w2 = FormW21.from_hash(hash['originalW2']) if hash['originalW2'] corrected_w2 = FormW22.from_hash(hash['correctedW2']) if hash['correctedW2'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FormW2C.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, corrected_tin_or_name: corrected_tin_or_name, previous_employee_tin: previous_employee_tin, previous_employee_name: previous_employee_name, original_w2: original_w2, corrected_w2: corrected_w2, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 95 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['corrected_tin_or_name'] = 'correctedTinOrName' @_hash['previous_employee_tin'] = 'previousEmployeeTin' @_hash['previous_employee_name'] = 'previousEmployeeName' @_hash['original_w2'] = 'originalW2' @_hash['corrected_w2'] = 'correctedW2' @_hash end |
.nullables ⇒ Object
An array for nullable fields
141 142 143 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 141 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 118 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links corrected_tin_or_name previous_employee_tin previous_employee_name original_w2 corrected_w2 ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 263 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, corrected_tin_or_name: #{@corrected_tin_or_name.inspect},"\ " previous_employee_tin: #{@previous_employee_tin.inspect}, previous_employee_name:"\ " #{@previous_employee_name.inspect}, original_w2: #{@original_w2.inspect}, corrected_w2:"\ " #{@corrected_w2.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/fdx_v660_api/models/form_w2_c.rb', line 250 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, corrected_tin_or_name: #{@corrected_tin_or_name},"\ " previous_employee_tin: #{@previous_employee_tin}, previous_employee_name:"\ " #{@previous_employee_name}, original_w2: #{@original_w2}, corrected_w2: #{@corrected_w2},"\ " additional_properties: #{@additional_properties}>" end |