Class: FdxV660Api::FormW2G
- Defined in:
- lib/fdx_v660_api/models/form_w2_g.rb
Overview
Certain Gambling Winnings, from PAYER (1st-9th boxes as issuer) to WINNER (10th-16th boxes and Box 9 as recipient)
Instance Attribute Summary collapse
-
#account_id ⇒ String
Long-term persistent identity of the source account.
-
#additional_information ⇒ String
Additional explanation text or content about this tax form.
-
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available.
-
#cashier ⇒ String
Box 8, Cashier.
-
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form.
-
#date_won ⇒ Date
Box 2, Date won.
-
#error ⇒ Error2
Present if an error was encountered while retrieving this form.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#first_id ⇒ String
Box 11, First I.D.
-
#identical_winnings ⇒ Float
Box 7, Winnings from identical wagers.
-
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN.
-
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs.
-
#race ⇒ String
Box 6, Race.
-
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN.
-
#second_id ⇒ String
Box 12, Second I.D.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 13-18, State and Local tax withholding, use income fields for state (box 14) and local (box 16) winnings amounts.
-
#tax_form_date ⇒ Date
Date of production or delivery of the tax form.
-
#tax_form_id ⇒ String
Long-term persistent id for this tax form.
-
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g.
-
#tax_year ⇒ Integer
Year for which taxes are being paid.
-
#transaction ⇒ String
Box 5, Transaction.
-
#type_of_wager ⇒ String
Box 3, Type of wager.
-
#window ⇒ String
Box 10, Window.
-
#winnings ⇒ Float
Box 1, Reportable winnings.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, winnings: SKIP, date_won: SKIP, type_of_wager: SKIP, federal_tax_withheld: SKIP, transaction: SKIP, race: SKIP, identical_winnings: SKIP, cashier: SKIP, window: SKIP, first_id: SKIP, second_id: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ FormW2G
constructor
A new instance of FormW2G.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, winnings: SKIP, date_won: SKIP, type_of_wager: SKIP, federal_tax_withheld: SKIP, transaction: SKIP, race: SKIP, identical_winnings: SKIP, cashier: SKIP, window: SKIP, first_id: SKIP, second_id: SKIP, state_and_local: SKIP, additional_properties: nil) ⇒ FormW2G
Returns a new instance of FormW2G.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 188 def initialize(tax_year: SKIP, corrected: SKIP, account_id: SKIP, tax_form_id: SKIP, tax_form_date: SKIP, additional_information: SKIP, tax_form_type: SKIP, issuer: SKIP, recipient: SKIP, attributes: SKIP, error: SKIP, links: SKIP, winnings: SKIP, date_won: SKIP, type_of_wager: SKIP, federal_tax_withheld: SKIP, transaction: SKIP, race: SKIP, identical_winnings: SKIP, cashier: SKIP, window: SKIP, first_id: SKIP, second_id: SKIP, state_and_local: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tax_year = tax_year unless tax_year == SKIP @corrected = corrected unless corrected == SKIP @account_id = account_id unless account_id == SKIP @tax_form_id = tax_form_id unless tax_form_id == SKIP @tax_form_date = tax_form_date unless tax_form_date == SKIP @additional_information = additional_information unless additional_information == SKIP @tax_form_type = tax_form_type unless tax_form_type == SKIP @issuer = issuer unless issuer == SKIP @recipient = recipient unless recipient == SKIP @attributes = attributes unless attributes == SKIP @error = error unless error == SKIP @links = links unless links == SKIP @winnings = winnings unless winnings == SKIP @date_won = date_won unless date_won == SKIP @type_of_wager = type_of_wager unless type_of_wager == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @transaction = transaction unless transaction == SKIP @race = race unless race == SKIP @identical_winnings = identical_winnings unless identical_winnings == SKIP @cashier = cashier unless cashier == SKIP @window = window unless window == SKIP @first_id = first_id unless first_id == SKIP @second_id = second_id unless second_id == SKIP @state_and_local = state_and_local unless state_and_local == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
Long-term persistent identity of the source account. Not the account number
24 25 26 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 24 def account_id @account_id end |
#additional_information ⇒ String
Additional explanation text or content about this tax form
38 39 40 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 38 def additional_information @additional_information end |
#attributes ⇒ Array[TaxFormAttribute]
Additional attributes for this tax form when defined fields are not available. Some specific additional attributes already defined by providers: Fields required by [IRS FIRE](https://www.irs.gov/e-file-providers/filing-information-returns-elec tronically-fire): Name Control, Type of Identification Number (EIN, SSN, ITIN, ATIN). (ATIN is tax ID number for pending adoptions.) Tax form provider field for taxpayer notification: Recipient Email Address.
64 65 66 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 64 def attributes @attributes end |
#cashier ⇒ String
Box 8, Cashier
104 105 106 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 104 def cashier @cashier end |
#corrected ⇒ TrueClass | FalseClass
True to indicate this is a corrected tax form
19 20 21 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 19 def corrected @corrected end |
#date_won ⇒ Date
Box 2, Date won
80 81 82 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 80 def date_won @date_won end |
#error ⇒ Error2
Present if an error was encountered while retrieving this form
68 69 70 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 68 def error @error end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
88 89 90 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 88 def federal_tax_withheld @federal_tax_withheld end |
#first_id ⇒ String
Box 11, First I.D.
112 113 114 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 112 def first_id @first_id end |
#identical_winnings ⇒ Float
Box 7, Winnings from identical wagers
100 101 102 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 100 def identical_winnings @identical_winnings end |
#issuer ⇒ TaxParty8
Issuer's name, address, phone, and TIN. Issuer data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
48 49 50 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 48 def issuer @issuer end |
#links ⇒ Array[HateoasLink]
Links to retrieve this form as data or image, or to invoke other APIs
72 73 74 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 72 def links @links end |
#race ⇒ String
Box 6, Race
96 97 98 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 96 def race @race end |
#recipient ⇒ TaxParty1
Recipient's name, address, phone, and TIN. Recipient data need only be transmitted on enclosing TaxStatement, if it is the same on all its included tax forms.
54 55 56 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 54 def recipient @recipient end |
#second_id ⇒ String
Box 12, Second I.D.
116 117 118 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 116 def second_id @second_id end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 13-18, State and Local tax withholding, use income fields for state (box 14) and local (box 16) winnings amounts
121 122 123 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 121 def state_and_local @state_and_local end |
#tax_form_date ⇒ Date
Date of production or delivery of the tax form
34 35 36 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 34 def tax_form_date @tax_form_date end |
#tax_form_id ⇒ String
Long-term persistent id for this tax form. Depending upon the data provider, this may be the same id as the enclosing tax statement id, or this may be a different id, or this id may be omitted.
30 31 32 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 30 def tax_form_id @tax_form_id end |
#tax_form_type ⇒ TypeFormType1
Enumerated name of the tax form entity e.g. "TaxW2"
42 43 44 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 42 def tax_form_type @tax_form_type end |
#tax_year ⇒ Integer
Year for which taxes are being paid
15 16 17 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 15 def tax_year @tax_year end |
#transaction ⇒ String
Box 5, Transaction
92 93 94 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 92 def transaction @transaction end |
#type_of_wager ⇒ String
Box 3, Type of wager
84 85 86 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 84 def type_of_wager @type_of_wager end |
#window ⇒ String
Box 10, Window
108 109 110 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 108 def window @window end |
#winnings ⇒ Float
Box 1, Reportable winnings
76 77 78 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 76 def winnings @winnings end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 228 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_year = hash.key?('taxYear') ? hash['taxYear'] : SKIP corrected = hash.key?('corrected') ? hash['corrected'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP tax_form_id = hash.key?('taxFormId') ? hash['taxFormId'] : SKIP tax_form_date = hash.key?('taxFormDate') ? hash['taxFormDate'] : SKIP additional_information = hash.key?('additionalInformation') ? hash['additionalInformation'] : SKIP tax_form_type = hash.key?('taxFormType') ? hash['taxFormType'] : SKIP issuer = TaxParty8.from_hash(hash['issuer']) if hash['issuer'] recipient = TaxParty1.from_hash(hash['recipient']) if hash['recipient'] # Parameter is an array, so we need to iterate through it attributes = nil unless hash['attributes'].nil? attributes = [] hash['attributes'].each do |structure| attributes << (TaxFormAttribute.from_hash(structure) if structure) end end attributes = SKIP unless hash.key?('attributes') error = Error2.from_hash(hash['error']) if hash['error'] # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') winnings = hash.key?('winnings') ? hash['winnings'] : SKIP date_won = hash.key?('dateWon') ? hash['dateWon'] : SKIP type_of_wager = hash.key?('typeOfWager') ? hash['typeOfWager'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP transaction = hash.key?('transaction') ? hash['transaction'] : SKIP race = hash.key?('race') ? hash['race'] : SKIP identical_winnings = hash.key?('identicalWinnings') ? hash['identicalWinnings'] : SKIP cashier = hash.key?('cashier') ? hash['cashier'] : SKIP window = hash.key?('window') ? hash['window'] : SKIP first_id = hash.key?('firstId') ? hash['firstId'] : SKIP second_id = hash.key?('secondId') ? hash['secondId'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FormW2G.new(tax_year: tax_year, corrected: corrected, account_id: account_id, tax_form_id: tax_form_id, tax_form_date: tax_form_date, additional_information: additional_information, tax_form_type: tax_form_type, issuer: issuer, recipient: recipient, attributes: attributes, error: error, links: links, winnings: winnings, date_won: date_won, type_of_wager: type_of_wager, federal_tax_withheld: federal_tax_withheld, transaction: transaction, race: race, identical_winnings: identical_winnings, cashier: cashier, window: window, first_id: first_id, second_id: second_id, state_and_local: state_and_local, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 124 def self.names @_hash = {} if @_hash.nil? @_hash['tax_year'] = 'taxYear' @_hash['corrected'] = 'corrected' @_hash['account_id'] = 'accountId' @_hash['tax_form_id'] = 'taxFormId' @_hash['tax_form_date'] = 'taxFormDate' @_hash['additional_information'] = 'additionalInformation' @_hash['tax_form_type'] = 'taxFormType' @_hash['issuer'] = 'issuer' @_hash['recipient'] = 'recipient' @_hash['attributes'] = 'attributes' @_hash['error'] = 'error' @_hash['links'] = 'links' @_hash['winnings'] = 'winnings' @_hash['date_won'] = 'dateWon' @_hash['type_of_wager'] = 'typeOfWager' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['transaction'] = 'transaction' @_hash['race'] = 'race' @_hash['identical_winnings'] = 'identicalWinnings' @_hash['cashier'] = 'cashier' @_hash['window'] = 'window' @_hash['first_id'] = 'firstId' @_hash['second_id'] = 'secondId' @_hash['state_and_local'] = 'stateAndLocal' @_hash end |
.nullables ⇒ Object
An array for nullable fields
184 185 186 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 184 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 154 def self.optionals %w[ tax_year corrected account_id tax_form_id tax_form_date additional_information tax_form_type issuer recipient attributes error links winnings date_won type_of_wager federal_tax_withheld transaction race identical_winnings cashier window first_id second_id state_and_local ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 338 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year.inspect}, corrected: #{@corrected.inspect},"\ " account_id: #{@account_id.inspect}, tax_form_id: #{@tax_form_id.inspect}, tax_form_date:"\ " #{@tax_form_date.inspect}, additional_information: #{@additional_information.inspect},"\ " tax_form_type: #{@tax_form_type.inspect}, issuer: #{@issuer.inspect}, recipient:"\ " #{@recipient.inspect}, attributes: #{@attributes.inspect}, error: #{@error.inspect},"\ " links: #{@links.inspect}, winnings: #{@winnings.inspect}, date_won: #{@date_won.inspect},"\ " type_of_wager: #{@type_of_wager.inspect}, federal_tax_withheld:"\ " #{@federal_tax_withheld.inspect}, transaction: #{@transaction.inspect}, race:"\ " #{@race.inspect}, identical_winnings: #{@identical_winnings.inspect}, cashier:"\ " #{@cashier.inspect}, window: #{@window.inspect}, first_id: #{@first_id.inspect},"\ " second_id: #{@second_id.inspect}, state_and_local: #{@state_and_local.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/fdx_v660_api/models/form_w2_g.rb', line 323 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_year: #{@tax_year}, corrected: #{@corrected}, account_id:"\ " #{@account_id}, tax_form_id: #{@tax_form_id}, tax_form_date: #{@tax_form_date},"\ " additional_information: #{@additional_information}, tax_form_type: #{@tax_form_type},"\ " issuer: #{@issuer}, recipient: #{@recipient}, attributes: #{@attributes}, error:"\ " #{@error}, links: #{@links}, winnings: #{@winnings}, date_won: #{@date_won},"\ " type_of_wager: #{@type_of_wager}, federal_tax_withheld: #{@federal_tax_withheld},"\ " transaction: #{@transaction}, race: #{@race}, identical_winnings: #{@identical_winnings},"\ " cashier: #{@cashier}, window: #{@window}, first_id: #{@first_id}, second_id:"\ " #{@second_id}, state_and_local: #{@state_and_local}, additional_properties:"\ " #{@additional_properties}>" end |