Class: FdxV660Api::InsuranceAccountEntity
- Inherits:
-
AccountEntity
- Object
- CoreLibrary::BaseModel
- BaseModel
- AccountDescriptorEntity
- AccountEntity
- FdxV660Api::InsuranceAccountEntity
- Defined in:
- lib/fdx_v660_api/models/insurance_account_entity.rb
Overview
An insurance account type and properties such as category, premium, and payment term information
Instance Attribute Summary collapse
-
#bills ⇒ Array[BillEntity]
Payments due on the insurance account.
-
#earned_interest ⇒ InterestRateEntity3
The periodic (usually monthly) interest rate earned on account cash balances.
-
#policy_coverage_amount ⇒ Float
Total amount of money the user is insured for.
-
#policy_end_date ⇒ Date
The premium end date.
-
#policy_premium ⇒ Float
The amount of the user's premium.
-
#policy_premium_term ⇒ PolicyPremiumTermType2
The payment term for the premium.
-
#policy_start_date ⇒ Date
The premium start date.
-
#policy_status ⇒ PolicyStatus2
The status of an insurance policy account.
-
#transactions ⇒ Array[InsuranceTransactionEntity]
Transactions on the insurance account.
Attributes inherited from AccountEntity
#balance_type, #bank_institution_id, #bank_transit_id, #bill_pay_status, #contact, #early_penalty_flag, #interest_rate, #interest_rate_as_of, #interest_rate_index, #interest_rate_type, #last_activity_date, #line_of_business, #line_of_business_type, #micr_number, #prior_interest_rate, #reward_balances, #reward_program_id, #routing_transit_number, #transactions_included, #transfer_in, #transfer_out
Attributes inherited from AccountDescriptorEntity
#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(earned_interest: SKIP, policy_premium: SKIP, policy_premium_term: SKIP, policy_start_date: SKIP, policy_status: SKIP, policy_end_date: SKIP, policy_coverage_amount: SKIP, transactions: SKIP, bills: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Insurance Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ InsuranceAccountEntity
constructor
A new instance of InsuranceAccountEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from AccountEntity
discriminators, #to_custom_interest_rate_as_of
Methods inherited from AccountDescriptorEntity
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(earned_interest: SKIP, policy_premium: SKIP, policy_premium_term: SKIP, policy_start_date: SKIP, policy_status: SKIP, policy_end_date: SKIP, policy_coverage_amount: SKIP, transactions: SKIP, bills: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Insurance Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ InsuranceAccountEntity
Returns a new instance of InsuranceAccountEntity.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 90 def initialize(earned_interest: SKIP, policy_premium: SKIP, policy_premium_term: SKIP, policy_start_date: SKIP, policy_status: SKIP, policy_end_date: SKIP, policy_coverage_amount: SKIP, transactions: SKIP, bills: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Insurance Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) @earned_interest = earned_interest unless earned_interest == SKIP @policy_premium = policy_premium unless policy_premium == SKIP @policy_premium_term = policy_premium_term unless policy_premium_term == SKIP @policy_start_date = policy_start_date unless policy_start_date == SKIP @policy_status = policy_status unless policy_status == SKIP @policy_end_date = policy_end_date unless policy_end_date == SKIP @policy_coverage_amount = policy_coverage_amount unless policy_coverage_amount == SKIP @transactions = transactions unless transactions == SKIP @bills = bills unless bills == SKIP @additional_properties = additional_properties # Call the constructor of the base class super(line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
Instance Attribute Details
#bills ⇒ Array[BillEntity]
Payments due on the insurance account
50 51 52 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 50 def bills @bills end |
#earned_interest ⇒ InterestRateEntity3
The periodic (usually monthly) interest rate earned on account cash balances
16 17 18 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 16 def earned_interest @earned_interest end |
#policy_coverage_amount ⇒ Float
Total amount of money the user is insured for
40 41 42 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 40 def policy_coverage_amount @policy_coverage_amount end |
#policy_end_date ⇒ Date
The premium end date
36 37 38 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 36 def policy_end_date @policy_end_date end |
#policy_premium ⇒ Float
The amount of the user's premium
20 21 22 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 20 def policy_premium @policy_premium end |
#policy_premium_term ⇒ PolicyPremiumTermType2
The payment term for the premium
24 25 26 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 24 def policy_premium_term @policy_premium_term end |
#policy_start_date ⇒ Date
The premium start date
28 29 30 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 28 def policy_start_date @policy_start_date end |
#policy_status ⇒ PolicyStatus2
The status of an insurance policy account
32 33 34 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 32 def policy_status @policy_status end |
#transactions ⇒ Array[InsuranceTransactionEntity]
Transactions on the insurance account. Deprecated in release V6.3.1 and
will be removed in next major release. Transactions are returned in the
searchForAccountTransactions operation response.
46 47 48 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 46 def transactions @transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 170 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. earned_interest = InterestRateEntity3.from_hash(hash['earnedInterest']) if hash['earnedInterest'] policy_premium = hash.key?('policyPremium') ? hash['policyPremium'] : SKIP policy_premium_term = hash.key?('policyPremiumTerm') ? hash['policyPremiumTerm'] : SKIP policy_start_date = hash.key?('policyStartDate') ? hash['policyStartDate'] : SKIP policy_status = hash.key?('policyStatus') ? hash['policyStatus'] : SKIP policy_end_date = hash.key?('policyEndDate') ? hash['policyEndDate'] : SKIP policy_coverage_amount = hash.key?('policyCoverageAmount') ? hash['policyCoverageAmount'] : SKIP # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (InsuranceTransactionEntity.from_hash(structure) if structure) end end transactions = SKIP unless hash.key?('transactions') # Parameter is an array, so we need to iterate through it bills = nil unless hash['bills'].nil? bills = [] hash['bills'].each do |structure| bills << (BillEntity.from_hash(structure) if structure) end end bills = SKIP unless hash.key?('bills') line_of_business = hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP line_of_business_type = hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP routing_transit_number = hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact'] interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP interest_rate_type = hash.key?('interestRateType') ? hash['interestRateType'] : SKIP interest_rate_as_of = if hash.key?('interestRateAsOf') (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf']) else SKIP end prior_interest_rate = hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP interest_rate_index = hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP early_penalty_flag = hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP bill_pay_status = hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP last_activity_date = hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP reward_program_id = hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP # Parameter is an array, so we need to iterate through it reward_balances = nil unless hash['rewardBalances'].nil? reward_balances = [] hash['rewardBalances'].each do |structure| reward_balances << (RewardBalanceEntity.from_hash(structure) if structure) end end reward_balances = SKIP unless hash.key?('rewardBalances') transactions_included = hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP bank_institution_id = hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP bank_transit_id = hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP account_category = hash['accountCategory'] ||= 'Insurance Account entity' account_id = hash.key?('accountId') ? hash['accountId'] : SKIP parent_account_id = hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP error = Error3.from_hash(hash['error']) if hash['error'] account_type = hash.key?('accountType') ? hash['accountType'] : SKIP domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile'] account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP account_number_display = hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP product_id = hash.key?('productId') ? hash['productId'] : SKIP product_name = hash.key?('productName') ? hash['productName'] : SKIP nickname = hash.key?('nickname') ? hash['nickname'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP account_open_date = hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP account_close_date = hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency'] data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP transfer_out_use_cases = hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP # Parameter is an array, so we need to iterate through it fi_attributes = nil unless hash['fiAttributes'].nil? fi_attributes = [] hash['fiAttributes'].each do |structure| fi_attributes << (FiAttributeEntity.from_hash(structure) if structure) end end fi_attributes = SKIP unless hash.key?('fiAttributes') # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InsuranceAccountEntity.new(earned_interest: earned_interest, policy_premium: policy_premium, policy_premium_term: policy_premium_term, policy_start_date: policy_start_date, policy_status: policy_status, policy_end_date: policy_end_date, policy_coverage_amount: policy_coverage_amount, transactions: transactions, bills: bills, line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['earned_interest'] = 'earnedInterest' @_hash['policy_premium'] = 'policyPremium' @_hash['policy_premium_term'] = 'policyPremiumTerm' @_hash['policy_start_date'] = 'policyStartDate' @_hash['policy_status'] = 'policyStatus' @_hash['policy_end_date'] = 'policyEndDate' @_hash['policy_coverage_amount'] = 'policyCoverageAmount' @_hash['transactions'] = 'transactions' @_hash['bills'] = 'bills' @_hash = super().merge(@_hash) @_hash end |
.nullables ⇒ Object
An array for nullable fields
85 86 87 88 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 85 def self.nullables _arr = [] (_arr << super()).flatten! end |
.optionals ⇒ Object
An array for optional fields
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 69 def self.optionals _arr = %w[ earned_interest policy_premium policy_premium_term policy_start_date policy_status policy_end_date policy_coverage_amount transactions bills ] (_arr << super()).flatten! end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
360 361 362 363 364 365 366 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 360 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
380 381 382 383 384 385 386 387 388 389 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 380 def inspect class_name = self.class.name.split('::').last super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, earned_interest: #{@earned_interest.inspect},"\ " policy_premium: #{@policy_premium.inspect}, policy_premium_term:"\ " #{@policy_premium_term.inspect}, policy_start_date: #{@policy_start_date.inspect},"\ " policy_status: #{@policy_status.inspect}, policy_end_date: #{@policy_end_date.inspect},"\ " policy_coverage_amount: #{@policy_coverage_amount.inspect}, transactions:"\ " #{@transactions.inspect}, bills: #{@bills.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
369 370 371 372 373 374 375 376 377 |
# File 'lib/fdx_v660_api/models/insurance_account_entity.rb', line 369 def to_s class_name = self.class.name.split('::').last super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, earned_interest: #{@earned_interest}, policy_premium:"\ " #{@policy_premium}, policy_premium_term: #{@policy_premium_term}, policy_start_date:"\ " #{@policy_start_date}, policy_status: #{@policy_status}, policy_end_date:"\ " #{@policy_end_date}, policy_coverage_amount: #{@policy_coverage_amount}, transactions:"\ " #{@transactions}, bills: #{@bills}>" end |