Class: FdxV660Api::InvestmentAssetType
- Inherits:
-
Object
- Object
- FdxV660Api::InvestmentAssetType
- Defined in:
- lib/fdx_v660_api/models/investment_asset_type.rb
Overview
The type of an investment account asset. | Value | Description | |-----|-----| | ANNUITY | Financial product that pays out a fixed stream of payments | | BOND | Debt security as a loan to a government, agency or company, repaid with interest | | CD | Certificate of Deposit, a savings account with a fixed rate and term | | DEBT | Any type of security that must be paid back in full along with interest | | DIGITALASSET | Digital representation of an asset or right that is stored and transferred on a digital network such as the internet or a blockchain | | MUTUALFUND | Pooled collection of assets invested in stocks, bonds, and other securities | | OPTION | The right to buy a specific number of stock shares at a pre-set price | | OTHER | Another type of investment account asset not listed here | | STOCK | A share in the ownership of a company | | SWEEP | Interest-earning account used to collect low- or non-interest-earning cash at close of day |
Constant Summary collapse
- INVESTMENT_ASSET_TYPE =
[ # TODO: Write general description for ANNUITY ANNUITY = 'ANNUITY'.freeze, # TODO: Write general description for BOND BOND = 'BOND'.freeze, # TODO: Write general description for CD CD = 'CD'.freeze, # TODO: Write general description for DEBT DEBT = 'DEBT'.freeze, # TODO: Write general description for DIGITALASSET DIGITALASSET = 'DIGITALASSET'.freeze, # TODO: Write general description for MUTUALFUND MUTUALFUND = 'MUTUALFUND'.freeze, # TODO: Write general description for OPTION OPTION = 'OPTION'.freeze, # TODO: Write general description for OTHER OTHER = 'OTHER'.freeze, # TODO: Write general description for STOCK STOCK = 'STOCK'.freeze, # TODO: Write general description for SWEEP SWEEP = 'SWEEP'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = ANNUITY) ⇒ Object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/fdx_v660_api/models/investment_asset_type.rb', line 60 def self.from_value(value, default_value = ANNUITY) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'annuity' then ANNUITY when 'bond' then BOND when 'cd' then CD when 'debt' then DEBT when 'digitalasset' then DIGITALASSET when 'mutualfund' then MUTUALFUND when 'option' then OPTION when 'other' then OTHER when 'stock' then STOCK when 'sweep' then SWEEP else default_value end end |
.validate(value) ⇒ Object
54 55 56 57 58 |
# File 'lib/fdx_v660_api/models/investment_asset_type.rb', line 54 def self.validate(value) return false if value.nil? true end |