Class: FdxV660Api::LoanAccountEntity
- Inherits:
-
AccountEntity
- Object
- CoreLibrary::BaseModel
- BaseModel
- AccountDescriptorEntity
- AccountEntity
- FdxV660Api::LoanAccountEntity
- Defined in:
- lib/fdx_v660_api/models/loan_account_entity.rb
Overview
A loan account type
Instance Attribute Summary collapse
-
#annual_percentage_rate ⇒ Float
The Annual Percentage Rate on the loan.
-
#balance_as_of ⇒ DateTime
As-of date for balances.
-
#charged_interest ⇒ InterestRateEntity7
The periodic interest rate on the loan.
-
#compounding_period ⇒ CompoundingPeriod1
DAILY, WEEKLY, BIWEEKLY, SEMIMONTHLY, MONTHLY, SEMIANNUALLY, ANNUALLY.
-
#current_school ⇒ String
Current school the student loan is connected to.
-
#escrow_balance ⇒ Float
Escrow balance of loan.
-
#interest_paid_year_to_date ⇒ Float
Interest paid year to date.
-
#last_payment_amount ⇒ Float
Last payment amount.
-
#last_payment_date ⇒ Date
Last payment date.
-
#loan_provider_name ⇒ String
Name of the institution providing the loan.
-
#loan_term ⇒ Integer
Term of loan in months.
-
#maturity_date ⇒ Date
Maturity date.
-
#next_payment_amount ⇒ Float
Amount of next payment.
-
#next_payment_date ⇒ Date
Date of next payment.
-
#original_principal ⇒ Float
Original principal of loan.
-
#originating_date ⇒ Date
Loan origination date.
-
#pay_off_amount ⇒ Float
Payoff amount.
-
#payment_frequency ⇒ EventFrequency2
Defines how often the loan payment repeats.
-
#principal_balance ⇒ Float
Principal balance of loan.
-
#total_number_of_payments ⇒ Integer
Total number of payments.
-
#transactions ⇒ Array[LoanTransactionEntity]
Transactions on the loan account.
Attributes inherited from AccountEntity
#balance_type, #bank_institution_id, #bank_transit_id, #bill_pay_status, #contact, #early_penalty_flag, #interest_rate, #interest_rate_as_of, #interest_rate_index, #interest_rate_type, #last_activity_date, #line_of_business, #line_of_business_type, #micr_number, #prior_interest_rate, #reward_balances, #reward_program_id, #routing_transit_number, #transactions_included, #transfer_in, #transfer_out
Attributes inherited from AccountDescriptorEntity
#account_category, #account_close_date, #account_id, #account_number, #account_number_display, #account_open_date, #account_type, #currency, #data_clusters, #description, #domicile, #error, #fi_attributes, #links, #nickname, #parent_account_id, #product_id, #product_name, #status, #transfer_out_use_cases
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(charged_interest: SKIP, annual_percentage_rate: SKIP, balance_as_of: SKIP, principal_balance: SKIP, escrow_balance: SKIP, original_principal: SKIP, originating_date: SKIP, loan_term: SKIP, total_number_of_payments: SKIP, next_payment_amount: SKIP, next_payment_date: SKIP, payment_frequency: SKIP, compounding_period: SKIP, pay_off_amount: SKIP, last_payment_amount: SKIP, last_payment_date: SKIP, maturity_date: SKIP, interest_paid_year_to_date: SKIP, current_school: SKIP, loan_provider_name: SKIP, transactions: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Loan Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ LoanAccountEntity
constructor
A new instance of LoanAccountEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_balance_as_of ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from AccountEntity
discriminators, #to_custom_interest_rate_as_of
Methods inherited from AccountDescriptorEntity
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(charged_interest: SKIP, annual_percentage_rate: SKIP, balance_as_of: SKIP, principal_balance: SKIP, escrow_balance: SKIP, original_principal: SKIP, originating_date: SKIP, loan_term: SKIP, total_number_of_payments: SKIP, next_payment_amount: SKIP, next_payment_date: SKIP, payment_frequency: SKIP, compounding_period: SKIP, pay_off_amount: SKIP, last_payment_amount: SKIP, last_payment_date: SKIP, maturity_date: SKIP, interest_paid_year_to_date: SKIP, current_school: SKIP, loan_provider_name: SKIP, transactions: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Loan Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) ⇒ LoanAccountEntity
Returns a new instance of LoanAccountEntity.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 160 def initialize(charged_interest: SKIP, annual_percentage_rate: SKIP, balance_as_of: SKIP, principal_balance: SKIP, escrow_balance: SKIP, original_principal: SKIP, originating_date: SKIP, loan_term: SKIP, total_number_of_payments: SKIP, next_payment_amount: SKIP, next_payment_date: SKIP, payment_frequency: SKIP, compounding_period: SKIP, pay_off_amount: SKIP, last_payment_amount: SKIP, last_payment_date: SKIP, maturity_date: SKIP, interest_paid_year_to_date: SKIP, current_school: SKIP, loan_provider_name: SKIP, transactions: SKIP, line_of_business: SKIP, line_of_business_type: SKIP, routing_transit_number: SKIP, balance_type: SKIP, contact: SKIP, interest_rate: SKIP, interest_rate_type: SKIP, interest_rate_as_of: SKIP, prior_interest_rate: SKIP, interest_rate_index: SKIP, early_penalty_flag: SKIP, transfer_in: SKIP, transfer_out: SKIP, bill_pay_status: SKIP, micr_number: SKIP, last_activity_date: SKIP, reward_program_id: SKIP, reward_balances: SKIP, transactions_included: SKIP, bank_institution_id: SKIP, bank_transit_id: SKIP, account_category: 'Loan Account entity', account_id: SKIP, parent_account_id: SKIP, error: SKIP, account_type: SKIP, domicile: SKIP, account_number: SKIP, account_number_display: SKIP, product_id: SKIP, product_name: SKIP, nickname: SKIP, status: SKIP, description: SKIP, account_open_date: SKIP, account_close_date: SKIP, currency: SKIP, data_clusters: SKIP, transfer_out_use_cases: SKIP, fi_attributes: SKIP, links: SKIP, additional_properties: nil) @charged_interest = charged_interest unless charged_interest == SKIP @annual_percentage_rate = annual_percentage_rate unless annual_percentage_rate == SKIP @balance_as_of = balance_as_of unless balance_as_of == SKIP @principal_balance = principal_balance unless principal_balance == SKIP @escrow_balance = escrow_balance unless escrow_balance == SKIP @original_principal = original_principal unless original_principal == SKIP @originating_date = originating_date unless originating_date == SKIP @loan_term = loan_term unless loan_term == SKIP @total_number_of_payments = total_number_of_payments unless total_number_of_payments == SKIP @next_payment_amount = next_payment_amount unless next_payment_amount == SKIP @next_payment_date = next_payment_date unless next_payment_date == SKIP @payment_frequency = payment_frequency unless payment_frequency == SKIP @compounding_period = compounding_period unless compounding_period == SKIP @pay_off_amount = pay_off_amount unless pay_off_amount == SKIP @last_payment_amount = last_payment_amount unless last_payment_amount == SKIP @last_payment_date = last_payment_date unless last_payment_date == SKIP @maturity_date = maturity_date unless maturity_date == SKIP unless interest_paid_year_to_date == SKIP @interest_paid_year_to_date = interest_paid_year_to_date end @current_school = current_school unless current_school == SKIP @loan_provider_name = loan_provider_name unless loan_provider_name == SKIP @transactions = transactions unless transactions == SKIP @additional_properties = additional_properties # Call the constructor of the base class super(line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
Instance Attribute Details
#annual_percentage_rate ⇒ Float
The Annual Percentage Rate on the loan
18 19 20 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 18 def annual_percentage_rate @annual_percentage_rate end |
#balance_as_of ⇒ DateTime
As-of date for balances
22 23 24 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 22 def balance_as_of @balance_as_of end |
#charged_interest ⇒ InterestRateEntity7
The periodic interest rate on the loan
14 15 16 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 14 def charged_interest @charged_interest end |
#compounding_period ⇒ CompoundingPeriod1
DAILY, WEEKLY, BIWEEKLY, SEMIMONTHLY, MONTHLY, SEMIANNUALLY, ANNUALLY
62 63 64 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 62 def compounding_period @compounding_period end |
#current_school ⇒ String
Current school the student loan is connected to
86 87 88 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 86 def current_school @current_school end |
#escrow_balance ⇒ Float
Escrow balance of loan
30 31 32 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 30 def escrow_balance @escrow_balance end |
#interest_paid_year_to_date ⇒ Float
Interest paid year to date
82 83 84 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 82 def interest_paid_year_to_date @interest_paid_year_to_date end |
#last_payment_amount ⇒ Float
Last payment amount
70 71 72 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 70 def last_payment_amount @last_payment_amount end |
#last_payment_date ⇒ Date
Last payment date
74 75 76 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 74 def last_payment_date @last_payment_date end |
#loan_provider_name ⇒ String
Name of the institution providing the loan
90 91 92 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 90 def loan_provider_name @loan_provider_name end |
#loan_term ⇒ Integer
Term of loan in months
42 43 44 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 42 def loan_term @loan_term end |
#maturity_date ⇒ Date
Maturity date
78 79 80 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 78 def maturity_date @maturity_date end |
#next_payment_amount ⇒ Float
Amount of next payment
50 51 52 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 50 def next_payment_amount @next_payment_amount end |
#next_payment_date ⇒ Date
Date of next payment
54 55 56 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 54 def next_payment_date @next_payment_date end |
#original_principal ⇒ Float
Original principal of loan
34 35 36 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 34 def original_principal @original_principal end |
#originating_date ⇒ Date
Loan origination date
38 39 40 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 38 def originating_date @originating_date end |
#pay_off_amount ⇒ Float
Payoff amount
66 67 68 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 66 def pay_off_amount @pay_off_amount end |
#payment_frequency ⇒ EventFrequency2
Defines how often the loan payment repeats
58 59 60 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 58 def payment_frequency @payment_frequency end |
#principal_balance ⇒ Float
Principal balance of loan
26 27 28 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 26 def principal_balance @principal_balance end |
#total_number_of_payments ⇒ Integer
Total number of payments
46 47 48 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 46 def total_number_of_payments @total_number_of_payments end |
#transactions ⇒ Array[LoanTransactionEntity]
Transactions on the loan account. Deprecated in release V6.3.1 and will be
removed in next major release. Transactions are returned in the
searchForAccountTransactions operation response.
96 97 98 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 96 def transactions @transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 261 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. charged_interest = InterestRateEntity7.from_hash(hash['chargedInterest']) if hash['chargedInterest'] annual_percentage_rate = hash.key?('annualPercentageRate') ? hash['annualPercentageRate'] : SKIP balance_as_of = if hash.key?('balanceAsOf') (DateTimeHelper.from_rfc3339(hash['balanceAsOf']) if hash['balanceAsOf']) else SKIP end principal_balance = hash.key?('principalBalance') ? hash['principalBalance'] : SKIP escrow_balance = hash.key?('escrowBalance') ? hash['escrowBalance'] : SKIP original_principal = hash.key?('originalPrincipal') ? hash['originalPrincipal'] : SKIP originating_date = hash.key?('originatingDate') ? hash['originatingDate'] : SKIP loan_term = hash.key?('loanTerm') ? hash['loanTerm'] : SKIP total_number_of_payments = hash.key?('totalNumberOfPayments') ? hash['totalNumberOfPayments'] : SKIP next_payment_amount = hash.key?('nextPaymentAmount') ? hash['nextPaymentAmount'] : SKIP next_payment_date = hash.key?('nextPaymentDate') ? hash['nextPaymentDate'] : SKIP payment_frequency = hash.key?('paymentFrequency') ? hash['paymentFrequency'] : SKIP compounding_period = hash.key?('compoundingPeriod') ? hash['compoundingPeriod'] : SKIP pay_off_amount = hash.key?('payOffAmount') ? hash['payOffAmount'] : SKIP last_payment_amount = hash.key?('lastPaymentAmount') ? hash['lastPaymentAmount'] : SKIP last_payment_date = hash.key?('lastPaymentDate') ? hash['lastPaymentDate'] : SKIP maturity_date = hash.key?('maturityDate') ? hash['maturityDate'] : SKIP interest_paid_year_to_date = hash.key?('interestPaidYearToDate') ? hash['interestPaidYearToDate'] : SKIP current_school = hash.key?('currentSchool') ? hash['currentSchool'] : SKIP loan_provider_name = hash.key?('loanProviderName') ? hash['loanProviderName'] : SKIP # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (LoanTransactionEntity.from_hash(structure) if structure) end end transactions = SKIP unless hash.key?('transactions') line_of_business = hash.key?('lineOfBusiness') ? hash['lineOfBusiness'] : SKIP line_of_business_type = hash.key?('lineOfBusinessType') ? hash['lineOfBusinessType'] : SKIP routing_transit_number = hash.key?('routingTransitNumber') ? hash['routingTransitNumber'] : SKIP balance_type = hash.key?('balanceType') ? hash['balanceType'] : SKIP contact = AccountContactEntity.from_hash(hash['contact']) if hash['contact'] interest_rate = hash.key?('interestRate') ? hash['interestRate'] : SKIP interest_rate_type = hash.key?('interestRateType') ? hash['interestRateType'] : SKIP interest_rate_as_of = if hash.key?('interestRateAsOf') (DateTimeHelper.from_rfc3339(hash['interestRateAsOf']) if hash['interestRateAsOf']) else SKIP end prior_interest_rate = hash.key?('priorInterestRate') ? hash['priorInterestRate'] : SKIP interest_rate_index = hash.key?('interestRateIndex') ? hash['interestRateIndex'] : SKIP early_penalty_flag = hash.key?('earlyPenaltyFlag') ? hash['earlyPenaltyFlag'] : SKIP transfer_in = hash.key?('transferIn') ? hash['transferIn'] : SKIP transfer_out = hash.key?('transferOut') ? hash['transferOut'] : SKIP bill_pay_status = hash.key?('billPayStatus') ? hash['billPayStatus'] : SKIP micr_number = hash.key?('micrNumber') ? hash['micrNumber'] : SKIP last_activity_date = hash.key?('lastActivityDate') ? hash['lastActivityDate'] : SKIP reward_program_id = hash.key?('rewardProgramId') ? hash['rewardProgramId'] : SKIP # Parameter is an array, so we need to iterate through it reward_balances = nil unless hash['rewardBalances'].nil? reward_balances = [] hash['rewardBalances'].each do |structure| reward_balances << (RewardBalanceEntity.from_hash(structure) if structure) end end reward_balances = SKIP unless hash.key?('rewardBalances') transactions_included = hash.key?('transactionsIncluded') ? hash['transactionsIncluded'] : SKIP bank_institution_id = hash.key?('bankInstitutionId') ? hash['bankInstitutionId'] : SKIP bank_transit_id = hash.key?('bankTransitId') ? hash['bankTransitId'] : SKIP account_category = hash['accountCategory'] ||= 'Loan Account entity' account_id = hash.key?('accountId') ? hash['accountId'] : SKIP parent_account_id = hash.key?('parentAccountId') ? hash['parentAccountId'] : SKIP error = Error3.from_hash(hash['error']) if hash['error'] account_type = hash.key?('accountType') ? hash['accountType'] : SKIP domicile = DomicileEntity3.from_hash(hash['domicile']) if hash['domicile'] account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP account_number_display = hash.key?('accountNumberDisplay') ? hash['accountNumberDisplay'] : SKIP product_id = hash.key?('productId') ? hash['productId'] : SKIP product_name = hash.key?('productName') ? hash['productName'] : SKIP nickname = hash.key?('nickname') ? hash['nickname'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP account_open_date = hash.key?('accountOpenDate') ? hash['accountOpenDate'] : SKIP account_close_date = hash.key?('accountCloseDate') ? hash['accountCloseDate'] : SKIP currency = CurrencyEntity4.from_hash(hash['currency']) if hash['currency'] data_clusters = hash.key?('dataClusters') ? hash['dataClusters'] : SKIP transfer_out_use_cases = hash.key?('transferOutUseCases') ? hash['transferOutUseCases'] : SKIP # Parameter is an array, so we need to iterate through it fi_attributes = nil unless hash['fiAttributes'].nil? fi_attributes = [] hash['fiAttributes'].each do |structure| fi_attributes << (FiAttributeEntity.from_hash(structure) if structure) end end fi_attributes = SKIP unless hash.key?('fiAttributes') # Parameter is an array, so we need to iterate through it links = nil unless hash['links'].nil? links = [] hash['links'].each do |structure| links << (HateoasLink.from_hash(structure) if structure) end end links = SKIP unless hash.key?('links') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LoanAccountEntity.new(charged_interest: charged_interest, annual_percentage_rate: annual_percentage_rate, balance_as_of: balance_as_of, principal_balance: principal_balance, escrow_balance: escrow_balance, original_principal: original_principal, originating_date: originating_date, loan_term: loan_term, total_number_of_payments: total_number_of_payments, next_payment_amount: next_payment_amount, next_payment_date: next_payment_date, payment_frequency: payment_frequency, compounding_period: compounding_period, pay_off_amount: pay_off_amount, last_payment_amount: last_payment_amount, last_payment_date: last_payment_date, maturity_date: maturity_date, interest_paid_year_to_date: interest_paid_year_to_date, current_school: current_school, loan_provider_name: loan_provider_name, transactions: transactions, line_of_business: line_of_business, line_of_business_type: line_of_business_type, routing_transit_number: routing_transit_number, balance_type: balance_type, contact: contact, interest_rate: interest_rate, interest_rate_type: interest_rate_type, interest_rate_as_of: interest_rate_as_of, prior_interest_rate: prior_interest_rate, interest_rate_index: interest_rate_index, early_penalty_flag: early_penalty_flag, transfer_in: transfer_in, transfer_out: transfer_out, bill_pay_status: bill_pay_status, micr_number: micr_number, last_activity_date: last_activity_date, reward_program_id: reward_program_id, reward_balances: reward_balances, transactions_included: transactions_included, bank_institution_id: bank_institution_id, bank_transit_id: bank_transit_id, account_category: account_category, account_id: account_id, parent_account_id: parent_account_id, error: error, account_type: account_type, domicile: domicile, account_number: account_number, account_number_display: account_number_display, product_id: product_id, product_name: product_name, nickname: nickname, status: status, description: description, account_open_date: account_open_date, account_close_date: account_close_date, currency: currency, data_clusters: data_clusters, transfer_out_use_cases: transfer_out_use_cases, fi_attributes: fi_attributes, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 99 def self.names @_hash = {} if @_hash.nil? @_hash['charged_interest'] = 'chargedInterest' @_hash['annual_percentage_rate'] = 'annualPercentageRate' @_hash['balance_as_of'] = 'balanceAsOf' @_hash['principal_balance'] = 'principalBalance' @_hash['escrow_balance'] = 'escrowBalance' @_hash['original_principal'] = 'originalPrincipal' @_hash['originating_date'] = 'originatingDate' @_hash['loan_term'] = 'loanTerm' @_hash['total_number_of_payments'] = 'totalNumberOfPayments' @_hash['next_payment_amount'] = 'nextPaymentAmount' @_hash['next_payment_date'] = 'nextPaymentDate' @_hash['payment_frequency'] = 'paymentFrequency' @_hash['compounding_period'] = 'compoundingPeriod' @_hash['pay_off_amount'] = 'payOffAmount' @_hash['last_payment_amount'] = 'lastPaymentAmount' @_hash['last_payment_date'] = 'lastPaymentDate' @_hash['maturity_date'] = 'maturityDate' @_hash['interest_paid_year_to_date'] = 'interestPaidYearToDate' @_hash['current_school'] = 'currentSchool' @_hash['loan_provider_name'] = 'loanProviderName' @_hash['transactions'] = 'transactions' @_hash = super().merge(@_hash) @_hash end |
.nullables ⇒ Object
An array for nullable fields
155 156 157 158 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 155 def self.nullables _arr = [] (_arr << super()).flatten! end |
.optionals ⇒ Object
An array for optional fields
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 127 def self.optionals _arr = %w[ charged_interest annual_percentage_rate balance_as_of principal_balance escrow_balance original_principal originating_date loan_term total_number_of_payments next_payment_amount next_payment_date payment_frequency compounding_period pay_off_amount last_payment_amount last_payment_date maturity_date interest_paid_year_to_date current_school loan_provider_name transactions ] (_arr << super()).flatten! end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
483 484 485 486 487 488 489 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 483 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 510 def inspect class_name = self.class.name.split('::').last super_string = super().inspect.sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, charged_interest: #{@charged_interest.inspect},"\ " annual_percentage_rate: #{@annual_percentage_rate.inspect}, balance_as_of:"\ " #{@balance_as_of.inspect}, principal_balance: #{@principal_balance.inspect},"\ " escrow_balance: #{@escrow_balance.inspect}, original_principal:"\ " #{@original_principal.inspect}, originating_date: #{@originating_date.inspect}, loan_term:"\ " #{@loan_term.inspect}, total_number_of_payments: #{@total_number_of_payments.inspect},"\ " next_payment_amount: #{@next_payment_amount.inspect}, next_payment_date:"\ " #{@next_payment_date.inspect}, payment_frequency: #{@payment_frequency.inspect},"\ " compounding_period: #{@compounding_period.inspect}, pay_off_amount:"\ " #{@pay_off_amount.inspect}, last_payment_amount: #{@last_payment_amount.inspect},"\ " last_payment_date: #{@last_payment_date.inspect}, maturity_date:"\ " #{@maturity_date.inspect}, interest_paid_year_to_date:"\ " #{@interest_paid_year_to_date.inspect}, current_school: #{@current_school.inspect},"\ " loan_provider_name: #{@loan_provider_name.inspect}, transactions:"\ " #{@transactions.inspect}>" end |
#to_custom_balance_as_of ⇒ Object
477 478 479 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 477 def to_custom_balance_as_of DateTimeHelper.to_rfc3339(balance_as_of) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/fdx_v660_api/models/loan_account_entity.rb', line 492 def to_s class_name = self.class.name.split('::').last super_string = super().sub(/^<[^ ]+ /, '').sub(/>$/, '') "<#{class_name} #{super_string}, charged_interest: #{@charged_interest},"\ " annual_percentage_rate: #{@annual_percentage_rate}, balance_as_of: #{@balance_as_of},"\ " principal_balance: #{@principal_balance}, escrow_balance: #{@escrow_balance},"\ " original_principal: #{@original_principal}, originating_date: #{@originating_date},"\ " loan_term: #{@loan_term}, total_number_of_payments: #{@total_number_of_payments},"\ " next_payment_amount: #{@next_payment_amount}, next_payment_date: #{@next_payment_date},"\ " payment_frequency: #{@payment_frequency}, compounding_period: #{@compounding_period},"\ " pay_off_amount: #{@pay_off_amount}, last_payment_amount: #{@last_payment_amount},"\ " last_payment_date: #{@last_payment_date}, maturity_date: #{@maturity_date},"\ " interest_paid_year_to_date: #{@interest_paid_year_to_date}, current_school:"\ " #{@current_school}, loan_provider_name: #{@loan_provider_name}, transactions:"\ " #{@transactions}>" end |