Class: FdxV660Api::MetaController
- Inherits:
-
BaseController
- Object
- BaseController
- FdxV660Api::MetaController
- Defined in:
- lib/fdx_v660_api/controllers/meta_controller.rb
Overview
MetaController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#get_availability(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil) ⇒ ApiResponse
Get information about this API's availability identifier for this interaction, as defined by [FAPI 2.0 Implementation Advice, 2.2.1 x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement ation_advice.html#name-x-fapi-interaction-id) whether the customer is present (USER) or it is a BATCH operation financial institution responding to the request operationId for which to get the metrics.
-
#get_capability(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil, fdx_version: nil, fdx_api_version: nil, result_type: ResultType::LIGHTWEIGHT) ⇒ ApiResponse
Get information about this API's capability identifier for this interaction, as defined by [FAPI 2.0 Implementation Advice, 2.2.1 x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement ation_advice.html#name-x-fapi-interaction-id) whether the customer is present (USER) or it is a BATCH operation financial institution responding to the request operationId for which to get the metrics.
-
#get_certification_metrics(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil) ⇒ ApiResponse
Get certification performance metrics for this implementer's APIs identifier for this interaction, as defined by [FAPI 2.0 Implementation Advice, 2.2.1 x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement ation_advice.html#name-x-fapi-interaction-id) whether the customer is present (USER) or it is a BATCH operation financial institution responding to the request operationId for which to get the metrics.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from FdxV660Api::BaseController
Instance Method Details
#get_availability(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil) ⇒ ApiResponse
Get information about this API's availability identifier for this interaction, as defined by [FAPI 2.0 Implementation Advice, 2.2.1 x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement ation_advice.html#name-x-fapi-interaction-id) whether the customer is present (USER) or it is a BATCH operation financial institution responding to the request operationId for which to get the metrics. Optional
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/fdx_v660_api/controllers/meta_controller.rb', line 22 def get_availability(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/availability', Server::DEFAULT) .header_param(new_parameter(x_fapi_interaction_id, key: 'x-fapi-interaction-id') .is_required(true)) .header_param(new_parameter(fdx_api_actor_type, key: 'FDX-API-Actor-Type')) .header_param(new_parameter(fdx_api_data_provider_id, key: 'FDX-API-Data-Provider-Id')) .query_param(new_parameter(operation_id, key: 'operationId')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('OAuthFapi1Baseline'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(AvailabilityListEntity.method(:from_hash)) .is_api_response(true)) .execute end |
#get_capability(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil, fdx_version: nil, fdx_api_version: nil, result_type: ResultType::LIGHTWEIGHT) ⇒ ApiResponse
Get information about this API's capability
identifier for this interaction, as defined by [FAPI 2.0 Implementation
Advice, 2.2.1
x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement
ation_advice.html#name-x-fapi-interaction-id)
whether the customer is present (USER) or it is a BATCH operation
financial institution responding to the request
operationId for which to get the metrics. Optional
for which to get the capability. Optional. Deprecated in v6.5 and replaced
with FdxApiVersionQuery in components
version for which to request the API response. Optional
you want a lightweight array of metadata (AccountDescriptor or Tax or
Operations) or full item details (Account or a Tax subclass or
Availability details). If set to 'lightweight', should only return the
fields associated with the metadata entity. This field is not required,
defaults to lightweight
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/fdx_v660_api/controllers/meta_controller.rb', line 68 def get_capability(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil, fdx_version: nil, fdx_api_version: nil, result_type: ResultType::LIGHTWEIGHT) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/capability', Server::DEFAULT) .header_param(new_parameter(x_fapi_interaction_id, key: 'x-fapi-interaction-id') .is_required(true)) .header_param(new_parameter(fdx_api_actor_type, key: 'FDX-API-Actor-Type')) .header_param(new_parameter(fdx_api_data_provider_id, key: 'FDX-API-Data-Provider-Id')) .query_param(new_parameter(operation_id, key: 'operationId')) .query_param(new_parameter(fdx_version, key: 'fdxVersion')) .query_param(new_parameter(fdx_api_version, key: 'FDX-API-Version')) .query_param(new_parameter(result_type, key: 'resultType')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('OAuthFapi1Baseline'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CapabilityEntity.method(:from_hash)) .is_api_response(true)) .execute end |
#get_certification_metrics(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil) ⇒ ApiResponse
Get certification performance metrics for this implementer's APIs identifier for this interaction, as defined by [FAPI 2.0 Implementation Advice, 2.2.1 x-fapi-interaction-id](https://openid.bitbucket.io/fapi/fapi-2_0-implement ation_advice.html#name-x-fapi-interaction-id) whether the customer is present (USER) or it is a BATCH operation financial institution responding to the request operationId for which to get the metrics. Optional
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/fdx_v660_api/controllers/meta_controller.rb', line 109 def get_certification_metrics(x_fapi_interaction_id, fdx_api_actor_type: nil, fdx_api_data_provider_id: nil, operation_id: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/certification-metrics', Server::DEFAULT) .header_param(new_parameter(x_fapi_interaction_id, key: 'x-fapi-interaction-id') .is_required(true)) .header_param(new_parameter(fdx_api_actor_type, key: 'FDX-API-Actor-Type')) .header_param(new_parameter(fdx_api_data_provider_id, key: 'FDX-API-Data-Provider-Id')) .query_param(new_parameter(operation_id, key: 'operationId')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('OAuthFapi1Baseline'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CertificationMetricsEntity.method(:from_hash)) .is_api_response(true)) .execute end |