Class: FdxV660Api::OccurrenceBasedLimitsForAPaymentNetwork2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::OccurrenceBasedLimitsForAPaymentNetwork2
- Defined in:
- lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb
Overview
The transfer limits taking effect from all the timeframe limits
Instance Attribute Summary collapse
-
#transfer_max_amount ⇒ Float
Maximum limit of funds that can be transferred to/from the account using the timeframe limits.
-
#transfer_remaining_amount ⇒ Float
Remaining value of the maximum limit of funds that can be transferred to/from the account using the timeframe limits.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transfer_max_amount: SKIP, transfer_remaining_amount: SKIP, additional_properties: nil) ⇒ OccurrenceBasedLimitsForAPaymentNetwork2
constructor
A new instance of OccurrenceBasedLimitsForAPaymentNetwork2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transfer_max_amount: SKIP, transfer_remaining_amount: SKIP, additional_properties: nil) ⇒ OccurrenceBasedLimitsForAPaymentNetwork2
Returns a new instance of OccurrenceBasedLimitsForAPaymentNetwork2.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 43 def initialize(transfer_max_amount: SKIP, transfer_remaining_amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transfer_max_amount = transfer_max_amount unless transfer_max_amount == SKIP unless transfer_remaining_amount == SKIP @transfer_remaining_amount = transfer_remaining_amount end @additional_properties = additional_properties end |
Instance Attribute Details
#transfer_max_amount ⇒ Float
Maximum limit of funds that can be transferred to/from the account using the timeframe limits
15 16 17 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 15 def transfer_max_amount @transfer_max_amount end |
#transfer_remaining_amount ⇒ Float
Remaining value of the maximum limit of funds that can be transferred to/from the account using the timeframe limits
20 21 22 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 20 def transfer_remaining_amount @transfer_remaining_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transfer_max_amount = hash.key?('transferMaxAmount') ? hash['transferMaxAmount'] : SKIP transfer_remaining_amount = hash.key?('transferRemainingAmount') ? hash['transferRemainingAmount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OccurrenceBasedLimitsForAPaymentNetwork2.new(transfer_max_amount: transfer_max_amount, transfer_remaining_amount: transfer_remaining_amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['transfer_max_amount'] = 'transferMaxAmount' @_hash['transfer_remaining_amount'] = 'transferRemainingAmount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 31 def self.optionals %w[ transfer_max_amount transfer_remaining_amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} transfer_max_amount: #{@transfer_max_amount.inspect},"\ " transfer_remaining_amount: #{@transfer_remaining_amount.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/fdx_v660_api/models/occurrence_based_limits_for_a_payment_network2.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} transfer_max_amount: #{@transfer_max_amount}, transfer_remaining_amount:"\ " #{@transfer_remaining_amount}, additional_properties: #{@additional_properties}>" end |