Class: FdxV660Api::PaymentInitiationPartyCreateResponseEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::PaymentInitiationPartyCreateResponseEntity
- Defined in:
- lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb
Overview
Entity that stores FI payment initiation party details. Each payment initiation party will have a separate entry per FI customer, e.g. we might have multiple payment initiation parties that represent the same physical person, nevertheless since they are registered for separate customers then they will have separate entries.
Instance Attribute Summary collapse
-
#payment_initiation_party_id ⇒ String
Unique identifier of a payment initiation party.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_initiation_party_id: SKIP, additional_properties: nil) ⇒ PaymentInitiationPartyCreateResponseEntity
constructor
A new instance of PaymentInitiationPartyCreateResponseEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_initiation_party_id: SKIP, additional_properties: nil) ⇒ PaymentInitiationPartyCreateResponseEntity
Returns a new instance of PaymentInitiationPartyCreateResponseEntity.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 39 def initialize(payment_initiation_party_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless payment_initiation_party_id == SKIP @payment_initiation_party_id = payment_initiation_party_id end @additional_properties = additional_properties end |
Instance Attribute Details
#payment_initiation_party_id ⇒ String
Unique identifier of a payment initiation party
18 19 20 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 18 def payment_initiation_party_id @payment_initiation_party_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_initiation_party_id = hash.key?('paymentInitiationPartyId') ? hash['paymentInitiationPartyId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInitiationPartyCreateResponseEntity.new(payment_initiation_party_id: payment_initiation_party_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['payment_initiation_party_id'] = 'paymentInitiationPartyId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 28 def self.optionals %w[ payment_initiation_party_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_initiation_party_id: #{@payment_initiation_party_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/fdx_v660_api/models/payment_initiation_party_create_response_entity.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_initiation_party_id: #{@payment_initiation_party_id},"\ " additional_properties: #{@additional_properties}>" end |