Class: FdxV660Api::PaymentMethodId
- Defined in:
- lib/fdx_v660_api/models/payment_method_id.rb
Overview
FI's unique identifier for the method of payment
Instance Attribute Summary collapse
-
#external_local_instrument1_code ⇒ String
Unique identifier code of the payment method rail as documented internally to the FI.
-
#payment_method_id ⇒ String
Unique identifier of the payment method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_method_id: SKIP, external_local_instrument1_code: SKIP, additional_properties: nil) ⇒ PaymentMethodId
constructor
A new instance of PaymentMethodId.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_method_id: SKIP, external_local_instrument1_code: SKIP, additional_properties: nil) ⇒ PaymentMethodId
Returns a new instance of PaymentMethodId.
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 44 def initialize(payment_method_id: SKIP, external_local_instrument1_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_method_id = payment_method_id unless payment_method_id == SKIP unless external_local_instrument1_code == SKIP @external_local_instrument1_code = external_local_instrument1_code end @additional_properties = additional_properties end |
Instance Attribute Details
#external_local_instrument1_code ⇒ String
Unique identifier code of the payment method rail as documented internally to the FI. This is aligned with ISO 20022 pain.001, transaction level
20 21 22 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 20 def external_local_instrument1_code @external_local_instrument1_code end |
#payment_method_id ⇒ String
Unique identifier of the payment method
14 15 16 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 14 def payment_method_id @payment_method_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_method_id = hash.key?('paymentMethodId') ? hash['paymentMethodId'] : SKIP external_local_instrument1_code = hash.key?('externalLocalInstrument1Code') ? hash['externalLocalInstrument1Code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentMethodId.new(payment_method_id: payment_method_id, external_local_instrument1_code: external_local_instrument1_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 29 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['payment_method_id'] = 'paymentMethodId' @_hash['external_local_instrument1_code'] = 'externalLocalInstrument1Code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 32 def self.optionals %w[ payment_method_id external_local_instrument1_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_method_id: #{@payment_method_id.inspect},"\ " external_local_instrument1_code: #{@external_local_instrument1_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/fdx_v660_api/models/payment_method_id.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_method_id: #{@payment_method_id}, external_local_instrument1_code:"\ " #{@external_local_instrument1_code}, additional_properties: #{@additional_properties}>" end |