Class: FdxV660Api::PaymentMethodSystemCode
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::PaymentMethodSystemCode
- Defined in:
- lib/fdx_v660_api/models/payment_method_system_code.rb
Overview
Unique identifier code of the external clearing system. Aligned with ISO 20022 pacs.008 group level
Instance Attribute Summary collapse
-
#external_clearing_system_identification1_code ⇒ String
Unique identifier code of the external clearing system.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(external_clearing_system_identification1_code: SKIP, additional_properties: nil) ⇒ PaymentMethodSystemCode
constructor
A new instance of PaymentMethodSystemCode.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_clearing_system_identification1_code: SKIP, additional_properties: nil) ⇒ PaymentMethodSystemCode
Returns a new instance of PaymentMethodSystemCode.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 42 def initialize(external_clearing_system_identification1_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless external_clearing_system_identification1_code == SKIP @external_clearing_system_identification1_code = external_clearing_system_identification1_code end @additional_properties = additional_properties end |
Instance Attribute Details
#external_clearing_system_identification1_code ⇒ String
Unique identifier code of the external clearing system. This is aligned with ISO 20022 pacs.008 group level. It can be used to send the payment rail for the payment. ISO has already listed codes in the fields which indicates the payment rail like "ACH" for ACH, "ACS" for EFT Payments, "LVT" for Canada LVTS, "LYX" for Lynx Canada, etc.
20 21 22 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 20 def external_clearing_system_identification1_code @external_clearing_system_identification1_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_clearing_system_identification1_code = hash.key?('externalClearingSystemIdentification1Code') ? hash['externalClearingSystemIdentification1Code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentMethodSystemCode.new(external_clearing_system_identification1_code: external_clearing_system_identification1_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['external_clearing_system_identification1_code'] = 'externalClearingSystemIdentification1Code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 31 def self.optionals %w[ external_clearing_system_identification1_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_clearing_system_identification1_code:"\ " #{@external_clearing_system_identification1_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 80 |
# File 'lib/fdx_v660_api/models/payment_method_system_code.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_clearing_system_identification1_code:"\ " #{@external_clearing_system_identification1_code}, additional_properties:"\ " #{@additional_properties}>" end |