Class: FdxV660Api::PaymentNetworkLifecycleEventsEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::PaymentNetworkLifecycleEventsEntity
- Defined in:
- lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb
Overview
List of lifecycle change events on a payment network pair of bankId and
account identifier identified by the paymentNetworkId
Instance Attribute Summary collapse
-
#events ⇒ Array[PaymentNetworkLifecycleEventEntity]
The list of payment network lifecycle events such as revocation requests.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(events: SKIP, additional_properties: nil) ⇒ PaymentNetworkLifecycleEventsEntity
constructor
A new instance of PaymentNetworkLifecycleEventsEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(events: SKIP, additional_properties: nil) ⇒ PaymentNetworkLifecycleEventsEntity
Returns a new instance of PaymentNetworkLifecycleEventsEntity.
36 37 38 39 40 41 42 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 36 def initialize(events: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @events = events unless events == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#events ⇒ Array[PaymentNetworkLifecycleEventEntity]
The list of payment network lifecycle events such as revocation requests
15 16 17 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 15 def events @events end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it events = nil unless hash['events'].nil? events = [] hash['events'].each do |structure| events << (PaymentNetworkLifecycleEventEntity.from_hash(structure) if structure) end end events = SKIP unless hash.key?('events') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentNetworkLifecycleEventsEntity.new(events: events, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['events'] = 'events' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 25 def self.optionals %w[ events ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} events: #{@events.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 |
# File 'lib/fdx_v660_api/models/payment_network_lifecycle_events_entity.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} events: #{@events}, additional_properties: #{@additional_properties}>" end |