Class: FdxV660Api::PayrollReportListEntity1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::PayrollReportListEntity1
- Defined in:
- lib/fdx_v660_api/models/payroll_report_list_entity1.rb
Overview
Array of PayrollReportList as a JSON response if not encrypted, or as the JSON payload which is encrypted for an application/jwt response
Instance Attribute Summary collapse
-
#reports ⇒ Array[PayrollReportEntity]
Zero or more PayrollReports, for details response.
-
#result_type ⇒ ResultType1
Indicates whether response array of
lightweightpayroll report summaries or ofdetailfull payroll reports is being returned. -
#summaries ⇒ Array[PayrollReportSummaryEntity]
Zero or more PayrollReportSummaries for lightweight response.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(result_type: ResultType1::LIGHTWEIGHT, summaries: SKIP, reports: SKIP, additional_properties: nil) ⇒ PayrollReportListEntity1
constructor
A new instance of PayrollReportListEntity1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(result_type: ResultType1::LIGHTWEIGHT, summaries: SKIP, reports: SKIP, additional_properties: nil) ⇒ PayrollReportListEntity1
Returns a new instance of PayrollReportListEntity1.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 49 def initialize(result_type: ResultType1::LIGHTWEIGHT, summaries: SKIP, reports: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @result_type = result_type unless result_type == SKIP @summaries = summaries unless summaries == SKIP @reports = reports unless reports == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#reports ⇒ Array[PayrollReportEntity]
Zero or more PayrollReports, for details response
24 25 26 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 24 def reports @reports end |
#result_type ⇒ ResultType1
Indicates whether response array of lightweight payroll report summaries
or of detail full payroll reports is being returned
16 17 18 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 16 def result_type @result_type end |
#summaries ⇒ Array[PayrollReportSummaryEntity]
Zero or more PayrollReportSummaries for lightweight response
20 21 22 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 20 def summaries @summaries end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. result_type = hash['resultType'] ||= ResultType1::LIGHTWEIGHT # Parameter is an array, so we need to iterate through it summaries = nil unless hash['summaries'].nil? summaries = [] hash['summaries'].each do |structure| summaries << (PayrollReportSummaryEntity.from_hash(structure) if structure) end end summaries = SKIP unless hash.key?('summaries') # Parameter is an array, so we need to iterate through it reports = nil unless hash['reports'].nil? reports = [] hash['reports'].each do |structure| reports << (PayrollReportEntity.from_hash(structure) if structure) end end reports = SKIP unless hash.key?('reports') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayrollReportListEntity1.new(result_type: result_type, summaries: summaries, reports: reports, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['result_type'] = 'resultType' @_hash['summaries'] = 'summaries' @_hash['reports'] = 'reports' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 42 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 36 def self.optionals %w[ result_type summaries reports ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
109 110 111 112 113 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 109 def inspect class_name = self.class.name.split('::').last "<#{class_name} result_type: #{@result_type.inspect}, summaries: #{@summaries.inspect},"\ " reports: #{@reports.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 |
# File 'lib/fdx_v660_api/models/payroll_report_list_entity1.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} result_type: #{@result_type}, summaries: #{@summaries}, reports:"\ " #{@reports}, additional_properties: #{@additional_properties}>" end |