Class: FdxV660Api::PlannedAvailabilityEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::PlannedAvailabilityEntity
- Defined in:
- lib/fdx_v660_api/models/planned_availability_entity.rb
Overview
Provider's plan for API availability
Instance Attribute Summary collapse
-
#description ⇒ String
Description of API availability status.
-
#end_time ⇒ DateTime
End time for this status period.
-
#start_time ⇒ DateTime
Start time for this status period.
-
#status ⇒ AvailabilityStatus1
API availability status for this time period.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status: SKIP, description: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ PlannedAvailabilityEntity
constructor
A new instance of PlannedAvailabilityEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_end_time ⇒ Object
- #to_custom_start_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status: SKIP, description: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ PlannedAvailabilityEntity
Returns a new instance of PlannedAvailabilityEntity.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 54 def initialize(status: SKIP, description: SKIP, start_time: SKIP, end_time: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status unless status == SKIP @description = description unless description == SKIP @start_time = start_time unless start_time == SKIP @end_time = end_time unless end_time == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#description ⇒ String
Description of API availability status
19 20 21 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 19 def description @description end |
#end_time ⇒ DateTime
End time for this status period
27 28 29 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 27 def end_time @end_time end |
#start_time ⇒ DateTime
Start time for this status period
23 24 25 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 23 def start_time @start_time end |
#status ⇒ AvailabilityStatus1
API availability status for this time period
15 16 17 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 15 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP start_time = if hash.key?('startTime') (DateTimeHelper.from_rfc3339(hash['startTime']) if hash['startTime']) else SKIP end end_time = if hash.key?('endTime') (DateTimeHelper.from_rfc3339(hash['endTime']) if hash['endTime']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PlannedAvailabilityEntity.new(status: status, description: description, start_time: start_time, end_time: end_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['description'] = 'description' @_hash['start_time'] = 'startTime' @_hash['end_time'] = 'endTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 46 47 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 40 def self.optionals %w[ status description start_time end_time ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, description: #{@description.inspect},"\ " start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_end_time ⇒ Object
103 104 105 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 103 def to_custom_end_time DateTimeHelper.to_rfc3339(end_time) end |
#to_custom_start_time ⇒ Object
99 100 101 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 99 def to_custom_start_time DateTimeHelper.to_rfc3339(start_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/fdx_v660_api/models/planned_availability_entity.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, description: #{@description}, start_time:"\ " #{@start_time}, end_time: #{@end_time}, additional_properties: #{@additional_properties}>" end |