Class: FdxV660Api::PortionEntity
- Defined in:
- lib/fdx_v660_api/models/portion_entity.rb
Overview
An asset allocation with class and percentage
Instance Attribute Summary collapse
-
#asset_class ⇒ AssetClass2
The asset class for this allocation.
-
#percent ⇒ Float
The percentage of this allocation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(asset_class: SKIP, percent: SKIP, additional_properties: nil) ⇒ PortionEntity
constructor
A new instance of PortionEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(asset_class: SKIP, percent: SKIP, additional_properties: nil) ⇒ PortionEntity
Returns a new instance of PortionEntity.
41 42 43 44 45 46 47 48 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 41 def initialize(asset_class: SKIP, percent: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @asset_class = asset_class unless asset_class == SKIP @percent = percent unless percent == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#asset_class ⇒ AssetClass2
The asset class for this allocation
14 15 16 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 14 def asset_class @asset_class end |
#percent ⇒ Float
The percentage of this allocation
18 19 20 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 18 def percent @percent end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. asset_class = hash.key?('assetClass') ? hash['assetClass'] : SKIP percent = hash.key?('percent') ? hash['percent'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PortionEntity.new(asset_class: asset_class, percent: percent, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['asset_class'] = 'assetClass' @_hash['percent'] = 'percent' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 29 def self.optionals %w[ asset_class percent ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
73 74 75 76 77 78 79 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 73 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} asset_class: #{@asset_class.inspect}, percent: #{@percent.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/fdx_v660_api/models/portion_entity.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} asset_class: #{@asset_class}, percent: #{@percent}, additional_properties:"\ " #{@additional_properties}>" end |