Class: FdxV660Api::RemittanceParty1
- Defined in:
- lib/fdx_v660_api/models/remittance_party1.rb
Overview
Identification of the creditor party to the transaction for the funds
received, can include accountNumber which is sensitive data and should be
encrypted
Instance Attribute Summary collapse
-
#account_number ⇒ String
Full account number for the source or recipient account of the remittance debit or credit.
-
#name ⇒ String
Company or individual name of the remittance debtor or creditor.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name: SKIP, account_number: SKIP, additional_properties: nil) ⇒ RemittanceParty1
constructor
A new instance of RemittanceParty1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, account_number: SKIP, additional_properties: nil) ⇒ RemittanceParty1
Returns a new instance of RemittanceParty1.
45 46 47 48 49 50 51 52 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 45 def initialize(name: SKIP, account_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @account_number = account_number unless account_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_number ⇒ String
Full account number for the source or recipient account of the remittance debit or credit. If not masked this is sensitive data which should be encrypted in the response
22 23 24 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 22 def account_number @account_number end |
#name ⇒ String
Company or individual name of the remittance debtor or creditor
16 17 18 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 16 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP account_number = hash.key?('accountNumber') ? hash['accountNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RemittanceParty1.new(name: name, account_number: account_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['account_number'] = 'accountNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 33 def self.optionals %w[ name account_number ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
77 78 79 80 81 82 83 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 77 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, account_number: #{@account_number.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/fdx_v660_api/models/remittance_party1.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, account_number: #{@account_number}, additional_properties:"\ " #{@additional_properties}>" end |