Class: FdxV660Api::ResultType1
- Inherits:
-
Object
- Object
- FdxV660Api::ResultType1
- Defined in:
- lib/fdx_v660_api/models/result_type1.rb
Overview
Indicates whether response array of lightweight payroll report summaries
or of detail full payroll reports is being returned
Constant Summary collapse
- RESULT_TYPE1 =
[ # TODO: Write general description for DETAILS DETAILS = 'details'.freeze, # TODO: Write general description for LIGHTWEIGHT LIGHTWEIGHT = 'lightweight'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = DETAILS) ⇒ Object
24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/fdx_v660_api/models/result_type1.rb', line 24 def self.from_value(value, default_value = DETAILS) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'details' then DETAILS when 'lightweight' then LIGHTWEIGHT else default_value end end |
.validate(value) ⇒ Object
18 19 20 21 22 |
# File 'lib/fdx_v660_api/models/result_type1.rb', line 18 def self.validate(value) return false if value.nil? true end |