Class: FdxV660Api::RewardTransactionsEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::RewardTransactionsEntity
- Defined in:
- lib/fdx_v660_api/models/reward_transactions_entity.rb
Overview
Optionally paginated array of account transaction summaries with rewards
Instance Attribute Summary collapse
-
#links ⇒ PageMetadataLinks1
Resource URLs for navigating result sets.
-
#page ⇒ PageMetadata
Page keys for navigating result sets.
-
#reward_transactions ⇒ Array[TransactionSummary]
An array of transaction summaries on which the account has earned rewards or adjustments.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(page: SKIP, links: SKIP, reward_transactions: SKIP, additional_properties: nil) ⇒ RewardTransactionsEntity
constructor
A new instance of RewardTransactionsEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(page: SKIP, links: SKIP, reward_transactions: SKIP, additional_properties: nil) ⇒ RewardTransactionsEntity
Returns a new instance of RewardTransactionsEntity.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 48 def initialize(page: SKIP, links: SKIP, reward_transactions: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @page = page unless page == SKIP @links = links unless links == SKIP @reward_transactions = reward_transactions unless reward_transactions == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#links ⇒ PageMetadataLinks1
Resource URLs for navigating result sets
18 19 20 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 18 def links @links end |
#page ⇒ PageMetadata
Page keys for navigating result sets
14 15 16 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 14 def page @page end |
#reward_transactions ⇒ Array[TransactionSummary]
An array of transaction summaries on which the account has earned rewards or adjustments
23 24 25 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 23 def reward_transactions @reward_transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. page = PageMetadata.from_hash(hash['page']) if hash['page'] links = PageMetadataLinks1.from_hash(hash['links']) if hash['links'] # Parameter is an array, so we need to iterate through it reward_transactions = nil unless hash['rewardTransactions'].nil? reward_transactions = [] hash['rewardTransactions'].each do |structure| reward_transactions << (TransactionSummary.from_hash(structure) if structure) end end reward_transactions = SKIP unless hash.key?('rewardTransactions') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RewardTransactionsEntity.new(page: page, links: links, reward_transactions: reward_transactions, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['page'] = 'page' @_hash['links'] = 'links' @_hash['reward_transactions'] = 'rewardTransactions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 35 def self.optionals %w[ page links reward_transactions ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} page: #{@page.inspect}, links: #{@links.inspect}, reward_transactions:"\ " #{@reward_transactions.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/fdx_v660_api/models/reward_transactions_entity.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} page: #{@page}, links: #{@links}, reward_transactions:"\ " #{@reward_transactions}, additional_properties: #{@additional_properties}>" end |