Class: FdxV660Api::SecurityDetailIrsForm1099B
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::SecurityDetailIrsForm1099B
- Defined in:
- lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb
Overview
Tax information for a single security transaction. If reported on Form 1099-DA, use Tax1099Da and DigitalAssetDetail instead
Instance Attribute Summary collapse
-
#accrued_market_discount ⇒ Float
Box 1f, Accrued market discount.
-
#adjustment_codes ⇒ Array[CodeAndAmount]
Other adjustments (code and amount).
-
#basis_reported ⇒ TrueClass | FalseClass
Box 12, Basis reported to IRS.
-
#checkbox_on_form8949 ⇒ String
Applicable checkbox on Form 8949.
-
#collectible ⇒ TrueClass | FalseClass
Box 3, Collectibles.
-
#corrected_cost_basis ⇒ Float
Corrected cost basis.
-
#cost_basis ⇒ Float
Box 1e, Cost or other basis.
-
#cusip ⇒ String
CUSIP number.
-
#date_acquired ⇒ Date
Box 1b, Date acquired.
-
#date_of_sale ⇒ Date
Box 1c, Date sold or disposed.
-
#exception1 ⇒ TrueClass | FalseClass
This transaction is to be reported on Form 1040 Schedule D, either line 1a for short-term transactions or line 8a for long-term transactions.
-
#expired_option ⇒ ExpiredOptionType2
To indicate gain or loss resulted from option expiration.
-
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld.
-
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
Foreign account tax compliance.
-
#gross_or_net ⇒ SaleProceedsType1
Box 6, Reported to IRS: GROSS or NET.
-
#incomplete ⇒ TrueClass | FalseClass
This transaction is known to contain incomplete information.
-
#investment_sale_type ⇒ InvestmentSaleType
Type of investment sale.
-
#long_or_short ⇒ SaleTermType2
Box 2, LONG or SHORT.
-
#loss_not_allowed ⇒ TrueClass | FalseClass
Box 7, Loss not allowed based on proceeds.
-
#multiple ⇒ TrueClass | FalseClass
This transaction represents multiple transactions reported on a separate statement under Exception 2.
-
#noncovered_security ⇒ TrueClass | FalseClass
Box 5, Noncovered security.
-
#number_of_shares ⇒ Float
Number of shares.
-
#ordinary ⇒ TrueClass | FalseClass
Box 2, Ordinary.
-
#qof ⇒ TrueClass | FalseClass
Box 3, Qualified Opportunity Fund (QOF).
-
#sale_description ⇒ String
Box 1a, Description of property.
-
#sales_price ⇒ Float
Box 1d, Proceeds (not price per share).
-
#security_name ⇒ String
Security name.
-
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 14-16, State and Local tax withholding.
-
#tax_statement_id ⇒ String
ID for a PDF statement delivered in this
TaxStatementListadjacent to this tax form, which would contain the full details of the multiple transactions of thisSecurityDetailrecord. -
#various_dates_acquired ⇒ TrueClass | FalseClass
Box 1b, whether Form 8949 should reflect various acquisition dates.
-
#wash_sale_loss_disallowed ⇒ Float
Box 1g, Wash sale loss disallowed.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(multiple: SKIP, incomplete: SKIP, exception1: SKIP, tax_statement_id: SKIP, cusip: SKIP, checkbox_on_form8949: SKIP, security_name: SKIP, number_of_shares: SKIP, sale_description: SKIP, date_acquired: SKIP, various_dates_acquired: SKIP, date_of_sale: SKIP, sales_price: SKIP, accrued_market_discount: SKIP, adjustment_codes: SKIP, cost_basis: SKIP, corrected_cost_basis: SKIP, wash_sale_loss_disallowed: SKIP, long_or_short: SKIP, ordinary: SKIP, collectible: SKIP, qof: SKIP, federal_tax_withheld: SKIP, noncovered_security: SKIP, gross_or_net: SKIP, loss_not_allowed: SKIP, basis_reported: SKIP, state_and_local: SKIP, foreign_account_tax_compliance: SKIP, expired_option: SKIP, investment_sale_type: SKIP, additional_properties: nil) ⇒ SecurityDetailIrsForm1099B
constructor
A new instance of SecurityDetailIrsForm1099B.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(multiple: SKIP, incomplete: SKIP, exception1: SKIP, tax_statement_id: SKIP, cusip: SKIP, checkbox_on_form8949: SKIP, security_name: SKIP, number_of_shares: SKIP, sale_description: SKIP, date_acquired: SKIP, various_dates_acquired: SKIP, date_of_sale: SKIP, sales_price: SKIP, accrued_market_discount: SKIP, adjustment_codes: SKIP, cost_basis: SKIP, corrected_cost_basis: SKIP, wash_sale_loss_disallowed: SKIP, long_or_short: SKIP, ordinary: SKIP, collectible: SKIP, qof: SKIP, federal_tax_withheld: SKIP, noncovered_security: SKIP, gross_or_net: SKIP, loss_not_allowed: SKIP, basis_reported: SKIP, state_and_local: SKIP, foreign_account_tax_compliance: SKIP, expired_option: SKIP, investment_sale_type: SKIP, additional_properties: nil) ⇒ SecurityDetailIrsForm1099B
Returns a new instance of SecurityDetailIrsForm1099B.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 224 def initialize(multiple: SKIP, incomplete: SKIP, exception1: SKIP, tax_statement_id: SKIP, cusip: SKIP, checkbox_on_form8949: SKIP, security_name: SKIP, number_of_shares: SKIP, sale_description: SKIP, date_acquired: SKIP, various_dates_acquired: SKIP, date_of_sale: SKIP, sales_price: SKIP, accrued_market_discount: SKIP, adjustment_codes: SKIP, cost_basis: SKIP, corrected_cost_basis: SKIP, wash_sale_loss_disallowed: SKIP, long_or_short: SKIP, ordinary: SKIP, collectible: SKIP, qof: SKIP, federal_tax_withheld: SKIP, noncovered_security: SKIP, gross_or_net: SKIP, loss_not_allowed: SKIP, basis_reported: SKIP, state_and_local: SKIP, foreign_account_tax_compliance: SKIP, expired_option: SKIP, investment_sale_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @multiple = multiple unless multiple == SKIP @incomplete = incomplete unless incomplete == SKIP @exception1 = exception1 unless exception1 == SKIP @tax_statement_id = tax_statement_id unless tax_statement_id == SKIP @cusip = cusip unless cusip == SKIP @checkbox_on_form8949 = checkbox_on_form8949 unless checkbox_on_form8949 == SKIP @security_name = security_name unless security_name == SKIP @number_of_shares = number_of_shares unless number_of_shares == SKIP @sale_description = sale_description unless sale_description == SKIP @date_acquired = date_acquired unless date_acquired == SKIP @various_dates_acquired = various_dates_acquired unless various_dates_acquired == SKIP @date_of_sale = date_of_sale unless date_of_sale == SKIP @sales_price = sales_price unless sales_price == SKIP @accrued_market_discount = accrued_market_discount unless accrued_market_discount == SKIP @adjustment_codes = adjustment_codes unless adjustment_codes == SKIP @cost_basis = cost_basis unless cost_basis == SKIP @corrected_cost_basis = corrected_cost_basis unless corrected_cost_basis == SKIP unless wash_sale_loss_disallowed == SKIP @wash_sale_loss_disallowed = wash_sale_loss_disallowed end @long_or_short = long_or_short unless long_or_short == SKIP @ordinary = ordinary unless ordinary == SKIP @collectible = collectible unless collectible == SKIP @qof = qof unless qof == SKIP @federal_tax_withheld = federal_tax_withheld unless federal_tax_withheld == SKIP @noncovered_security = noncovered_security unless noncovered_security == SKIP @gross_or_net = gross_or_net unless gross_or_net == SKIP @loss_not_allowed = loss_not_allowed unless loss_not_allowed == SKIP @basis_reported = basis_reported unless basis_reported == SKIP @state_and_local = state_and_local unless state_and_local == SKIP unless foreign_account_tax_compliance == SKIP @foreign_account_tax_compliance = foreign_account_tax_compliance end @expired_option = expired_option unless expired_option == SKIP @investment_sale_type = investment_sale_type unless investment_sale_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#accrued_market_discount ⇒ Float
Box 1f, Accrued market discount
71 72 73 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 71 def accrued_market_discount @accrued_market_discount end |
#adjustment_codes ⇒ Array[CodeAndAmount]
Other adjustments (code and amount)
75 76 77 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 75 def adjustment_codes @adjustment_codes end |
#basis_reported ⇒ TrueClass | FalseClass
Box 12, Basis reported to IRS
125 126 127 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 125 def basis_reported @basis_reported end |
#checkbox_on_form8949 ⇒ String
Applicable checkbox on Form 8949. Use code A, B, D, E, or X
39 40 41 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 39 def checkbox_on_form8949 @checkbox_on_form8949 end |
#collectible ⇒ TrueClass | FalseClass
Box 3, Collectibles
101 102 103 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 101 def collectible @collectible end |
#corrected_cost_basis ⇒ Float
Corrected cost basis. May be supplied in lieu of adjustmentCode code B. If both adjustmentCodes and correctedCostBasis are supplied, costBasis plus adjustmentCode B should equal correctedCostBasis
85 86 87 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 85 def corrected_cost_basis @corrected_cost_basis end |
#cost_basis ⇒ Float
Box 1e, Cost or other basis
79 80 81 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 79 def cost_basis @cost_basis end |
#cusip ⇒ String
CUSIP number
35 36 37 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 35 def cusip @cusip end |
#date_acquired ⇒ Date
Box 1b, Date acquired
55 56 57 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 55 def date_acquired @date_acquired end |
#date_of_sale ⇒ Date
Box 1c, Date sold or disposed
63 64 65 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 63 def date_of_sale @date_of_sale end |
#exception1 ⇒ TrueClass | FalseClass
This transaction is to be reported on Form 1040 Schedule D, either line 1a for short-term transactions or line 8a for long-term transactions
25 26 27 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 25 def exception1 @exception1 end |
#expired_option ⇒ ExpiredOptionType2
To indicate gain or loss resulted from option expiration. If salesPrice (1d, proceeds) is zero, use PURCHASED. If costBasis (1e) is zero, use GRANTED
139 140 141 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 139 def expired_option @expired_option end |
#federal_tax_withheld ⇒ Float
Box 4, Federal income tax withheld
109 110 111 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 109 def federal_tax_withheld @federal_tax_withheld end |
#foreign_account_tax_compliance ⇒ TrueClass | FalseClass
Foreign account tax compliance
133 134 135 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 133 def foreign_account_tax_compliance @foreign_account_tax_compliance end |
#gross_or_net ⇒ SaleProceedsType1
Box 6, Reported to IRS: GROSS or NET
117 118 119 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 117 def gross_or_net @gross_or_net end |
#incomplete ⇒ TrueClass | FalseClass
This transaction is known to contain incomplete information
20 21 22 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 20 def incomplete @incomplete end |
#investment_sale_type ⇒ InvestmentSaleType
Type of investment sale
143 144 145 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 143 def investment_sale_type @investment_sale_type end |
#long_or_short ⇒ SaleTermType2
Box 2, LONG or SHORT
93 94 95 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 93 def long_or_short @long_or_short end |
#loss_not_allowed ⇒ TrueClass | FalseClass
Box 7, Loss not allowed based on proceeds
121 122 123 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 121 def loss_not_allowed @loss_not_allowed end |
#multiple ⇒ TrueClass | FalseClass
This transaction represents multiple transactions reported on a separate statement under Exception 2. Code M is shown on Form 8949 column (f)
16 17 18 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 16 def multiple @multiple end |
#noncovered_security ⇒ TrueClass | FalseClass
Box 5, Noncovered security
113 114 115 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 113 def noncovered_security @noncovered_security end |
#number_of_shares ⇒ Float
Number of shares
47 48 49 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 47 def number_of_shares @number_of_shares end |
#ordinary ⇒ TrueClass | FalseClass
Box 2, Ordinary
97 98 99 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 97 def ordinary @ordinary end |
#qof ⇒ TrueClass | FalseClass
Box 3, Qualified Opportunity Fund (QOF)
105 106 107 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 105 def qof @qof end |
#sale_description ⇒ String
Box 1a, Description of property
51 52 53 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 51 def sale_description @sale_description end |
#sales_price ⇒ Float
Box 1d, Proceeds (not price per share)
67 68 69 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 67 def sales_price @sales_price end |
#security_name ⇒ String
Security name
43 44 45 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 43 def security_name @security_name end |
#state_and_local ⇒ Array[StateAndLocalTaxWithholding]
Boxes 14-16, State and Local tax withholding
129 130 131 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 129 def state_and_local @state_and_local end |
#tax_statement_id ⇒ String
ID for a PDF statement delivered in this TaxStatementList adjacent to
this tax form, which would contain the full details of the multiple
transactions of this SecurityDetail record
31 32 33 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 31 def tax_statement_id @tax_statement_id end |
#various_dates_acquired ⇒ TrueClass | FalseClass
Box 1b, whether Form 8949 should reflect various acquisition dates
59 60 61 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 59 def various_dates_acquired @various_dates_acquired end |
#wash_sale_loss_disallowed ⇒ Float
Box 1g, Wash sale loss disallowed
89 90 91 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 89 def wash_sale_loss_disallowed @wash_sale_loss_disallowed end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 283 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. multiple = hash.key?('multiple') ? hash['multiple'] : SKIP incomplete = hash.key?('incomplete') ? hash['incomplete'] : SKIP exception1 = hash.key?('exception1') ? hash['exception1'] : SKIP tax_statement_id = hash.key?('taxStatementId') ? hash['taxStatementId'] : SKIP cusip = hash.key?('cusip') ? hash['cusip'] : SKIP checkbox_on_form8949 = hash.key?('checkboxOnForm8949') ? hash['checkboxOnForm8949'] : SKIP security_name = hash.key?('securityName') ? hash['securityName'] : SKIP number_of_shares = hash.key?('numberOfShares') ? hash['numberOfShares'] : SKIP sale_description = hash.key?('saleDescription') ? hash['saleDescription'] : SKIP date_acquired = hash.key?('dateAcquired') ? hash['dateAcquired'] : SKIP various_dates_acquired = hash.key?('variousDatesAcquired') ? hash['variousDatesAcquired'] : SKIP date_of_sale = hash.key?('dateOfSale') ? hash['dateOfSale'] : SKIP sales_price = hash.key?('salesPrice') ? hash['salesPrice'] : SKIP accrued_market_discount = hash.key?('accruedMarketDiscount') ? hash['accruedMarketDiscount'] : SKIP # Parameter is an array, so we need to iterate through it adjustment_codes = nil unless hash['adjustmentCodes'].nil? adjustment_codes = [] hash['adjustmentCodes'].each do |structure| adjustment_codes << (CodeAndAmount.from_hash(structure) if structure) end end adjustment_codes = SKIP unless hash.key?('adjustmentCodes') cost_basis = hash.key?('costBasis') ? hash['costBasis'] : SKIP corrected_cost_basis = hash.key?('correctedCostBasis') ? hash['correctedCostBasis'] : SKIP wash_sale_loss_disallowed = hash.key?('washSaleLossDisallowed') ? hash['washSaleLossDisallowed'] : SKIP long_or_short = hash.key?('longOrShort') ? hash['longOrShort'] : SKIP ordinary = hash.key?('ordinary') ? hash['ordinary'] : SKIP collectible = hash.key?('collectible') ? hash['collectible'] : SKIP qof = hash.key?('qof') ? hash['qof'] : SKIP federal_tax_withheld = hash.key?('federalTaxWithheld') ? hash['federalTaxWithheld'] : SKIP noncovered_security = hash.key?('noncoveredSecurity') ? hash['noncoveredSecurity'] : SKIP gross_or_net = hash.key?('grossOrNet') ? hash['grossOrNet'] : SKIP loss_not_allowed = hash.key?('lossNotAllowed') ? hash['lossNotAllowed'] : SKIP basis_reported = hash.key?('basisReported') ? hash['basisReported'] : SKIP # Parameter is an array, so we need to iterate through it state_and_local = nil unless hash['stateAndLocal'].nil? state_and_local = [] hash['stateAndLocal'].each do |structure| state_and_local << (StateAndLocalTaxWithholding.from_hash(structure) if structure) end end state_and_local = SKIP unless hash.key?('stateAndLocal') foreign_account_tax_compliance = hash.key?('foreignAccountTaxCompliance') ? hash['foreignAccountTaxCompliance'] : SKIP expired_option = hash.key?('expiredOption') ? hash['expiredOption'] : SKIP investment_sale_type = hash.key?('investmentSaleType') ? hash['investmentSaleType'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SecurityDetailIrsForm1099B.new(multiple: multiple, incomplete: incomplete, exception1: exception1, tax_statement_id: tax_statement_id, cusip: cusip, checkbox_on_form8949: checkbox_on_form8949, security_name: security_name, number_of_shares: number_of_shares, sale_description: sale_description, date_acquired: date_acquired, various_dates_acquired: various_dates_acquired, date_of_sale: date_of_sale, sales_price: sales_price, accrued_market_discount: accrued_market_discount, adjustment_codes: adjustment_codes, cost_basis: cost_basis, corrected_cost_basis: corrected_cost_basis, wash_sale_loss_disallowed: wash_sale_loss_disallowed, long_or_short: long_or_short, ordinary: ordinary, collectible: collectible, qof: qof, federal_tax_withheld: federal_tax_withheld, noncovered_security: noncovered_security, gross_or_net: gross_or_net, loss_not_allowed: loss_not_allowed, basis_reported: basis_reported, state_and_local: state_and_local, foreign_account_tax_compliance: foreign_account_tax_compliance, expired_option: expired_option, investment_sale_type: investment_sale_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 146 def self.names @_hash = {} if @_hash.nil? @_hash['multiple'] = 'multiple' @_hash['incomplete'] = 'incomplete' @_hash['exception1'] = 'exception1' @_hash['tax_statement_id'] = 'taxStatementId' @_hash['cusip'] = 'cusip' @_hash['checkbox_on_form8949'] = 'checkboxOnForm8949' @_hash['security_name'] = 'securityName' @_hash['number_of_shares'] = 'numberOfShares' @_hash['sale_description'] = 'saleDescription' @_hash['date_acquired'] = 'dateAcquired' @_hash['various_dates_acquired'] = 'variousDatesAcquired' @_hash['date_of_sale'] = 'dateOfSale' @_hash['sales_price'] = 'salesPrice' @_hash['accrued_market_discount'] = 'accruedMarketDiscount' @_hash['adjustment_codes'] = 'adjustmentCodes' @_hash['cost_basis'] = 'costBasis' @_hash['corrected_cost_basis'] = 'correctedCostBasis' @_hash['wash_sale_loss_disallowed'] = 'washSaleLossDisallowed' @_hash['long_or_short'] = 'longOrShort' @_hash['ordinary'] = 'ordinary' @_hash['collectible'] = 'collectible' @_hash['qof'] = 'qof' @_hash['federal_tax_withheld'] = 'federalTaxWithheld' @_hash['noncovered_security'] = 'noncoveredSecurity' @_hash['gross_or_net'] = 'grossOrNet' @_hash['loss_not_allowed'] = 'lossNotAllowed' @_hash['basis_reported'] = 'basisReported' @_hash['state_and_local'] = 'stateAndLocal' @_hash['foreign_account_tax_compliance'] = 'foreignAccountTaxCompliance' @_hash['expired_option'] = 'expiredOption' @_hash['investment_sale_type'] = 'investmentSaleType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
220 221 222 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 220 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 183 def self.optionals %w[ multiple incomplete exception1 tax_statement_id cusip checkbox_on_form8949 security_name number_of_shares sale_description date_acquired various_dates_acquired date_of_sale sales_price accrued_market_discount adjustment_codes cost_basis corrected_cost_basis wash_sale_loss_disallowed long_or_short ordinary collectible qof federal_tax_withheld noncovered_security gross_or_net loss_not_allowed basis_reported state_and_local foreign_account_tax_compliance expired_option investment_sale_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 414 def inspect class_name = self.class.name.split('::').last "<#{class_name} multiple: #{@multiple.inspect}, incomplete: #{@incomplete.inspect},"\ " exception1: #{@exception1.inspect}, tax_statement_id: #{@tax_statement_id.inspect}, cusip:"\ " #{@cusip.inspect}, checkbox_on_form8949: #{@checkbox_on_form8949.inspect}, security_name:"\ " #{@security_name.inspect}, number_of_shares: #{@number_of_shares.inspect},"\ " sale_description: #{@sale_description.inspect}, date_acquired: #{@date_acquired.inspect},"\ " various_dates_acquired: #{@various_dates_acquired.inspect}, date_of_sale:"\ " #{@date_of_sale.inspect}, sales_price: #{@sales_price.inspect}, accrued_market_discount:"\ " #{@accrued_market_discount.inspect}, adjustment_codes: #{@adjustment_codes.inspect},"\ " cost_basis: #{@cost_basis.inspect}, corrected_cost_basis:"\ " #{@corrected_cost_basis.inspect}, wash_sale_loss_disallowed:"\ " #{@wash_sale_loss_disallowed.inspect}, long_or_short: #{@long_or_short.inspect}, ordinary:"\ " #{@ordinary.inspect}, collectible: #{@collectible.inspect}, qof: #{@qof.inspect},"\ " federal_tax_withheld: #{@federal_tax_withheld.inspect}, noncovered_security:"\ " #{@noncovered_security.inspect}, gross_or_net: #{@gross_or_net.inspect}, loss_not_allowed:"\ " #{@loss_not_allowed.inspect}, basis_reported: #{@basis_reported.inspect}, state_and_local:"\ " #{@state_and_local.inspect}, foreign_account_tax_compliance:"\ " #{@foreign_account_tax_compliance.inspect}, expired_option: #{@expired_option.inspect},"\ " investment_sale_type: #{@investment_sale_type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/fdx_v660_api/models/security_detail_irs_form1099_b.rb', line 393 def to_s class_name = self.class.name.split('::').last "<#{class_name} multiple: #{@multiple}, incomplete: #{@incomplete}, exception1:"\ " #{@exception1}, tax_statement_id: #{@tax_statement_id}, cusip: #{@cusip},"\ " checkbox_on_form8949: #{@checkbox_on_form8949}, security_name: #{@security_name},"\ " number_of_shares: #{@number_of_shares}, sale_description: #{@sale_description},"\ " date_acquired: #{@date_acquired}, various_dates_acquired: #{@various_dates_acquired},"\ " date_of_sale: #{@date_of_sale}, sales_price: #{@sales_price}, accrued_market_discount:"\ " #{@accrued_market_discount}, adjustment_codes: #{@adjustment_codes}, cost_basis:"\ " #{@cost_basis}, corrected_cost_basis: #{@corrected_cost_basis}, wash_sale_loss_disallowed:"\ " #{@wash_sale_loss_disallowed}, long_or_short: #{@long_or_short}, ordinary: #{@ordinary},"\ " collectible: #{@collectible}, qof: #{@qof}, federal_tax_withheld:"\ " #{@federal_tax_withheld}, noncovered_security: #{@noncovered_security}, gross_or_net:"\ " #{@gross_or_net}, loss_not_allowed: #{@loss_not_allowed}, basis_reported:"\ " #{@basis_reported}, state_and_local: #{@state_and_local}, foreign_account_tax_compliance:"\ " #{@foreign_account_tax_compliance}, expired_option: #{@expired_option},"\ " investment_sale_type: #{@investment_sale_type}, additional_properties:"\ " #{@additional_properties}>" end |