Class: FdxV660Api::SecurityIdType
- Inherits:
-
Object
- Object
- FdxV660Api::SecurityIdType
- Defined in:
- lib/fdx_v660_api/models/security_id_type.rb
Overview
The source of the identifier for a security | Value | Description | |-----|-----| | CINS | CUSIP International Numbering System is a global securities identification numbering system that extends CUSIP outside North America | | CMC | Coin Market Cap | | CME | Chicago Mercantile Exchange | | CUSIP | Committee on Uniform Securities Identification Procedures | | ISIN | International Securities Identification Number | | ITSA | International Securities Identification Number Technical Committee | | NASDAQ | National Association of Securities Dealers Automated Quotations | | PROVIDER_CUSTOM | Data Provider Custom | | SEDOL | Stock Exchange Daily Official List | | SICC | Standard Identification Code for Institutional Investment | | VALOR | SIX Swiss Exchange | | WKN | Wertpapierkennnummer |
Constant Summary collapse
- SECURITY_ID_TYPE =
[ # TODO: Write general description for CINS CINS = 'CINS'.freeze, # TODO: Write general description for CMC CMC = 'CMC'.freeze, # TODO: Write general description for CME CME = 'CME'.freeze, # TODO: Write general description for CUSIP CUSIP = 'CUSIP'.freeze, # TODO: Write general description for ISIN ISIN = 'ISIN'.freeze, # TODO: Write general description for ITSA ITSA = 'ITSA'.freeze, # TODO: Write general description for NASDAQ NASDAQ = 'NASDAQ'.freeze, # TODO: Write general description for PROVIDER_CUSTOM PROVIDER_CUSTOM = 'PROVIDER_CUSTOM'.freeze, # TODO: Write general description for SEDOL SEDOL = 'SEDOL'.freeze, # TODO: Write general description for SICC SICC = 'SICC'.freeze, # TODO: Write general description for VALOR VALOR = 'VALOR'.freeze, # TODO: Write general description for WKN WKN = 'WKN'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = CINS) ⇒ Object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/fdx_v660_api/models/security_id_type.rb', line 64 def self.from_value(value, default_value = CINS) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'cins' then CINS when 'cmc' then CMC when 'cme' then CME when 'cusip' then CUSIP when 'isin' then ISIN when 'itsa' then ITSA when 'nasdaq' then NASDAQ when 'provider_custom' then PROVIDER_CUSTOM when 'sedol' then SEDOL when 'sicc' then SICC when 'valor' then VALOR when 'wkn' then WKN else default_value end end |
.validate(value) ⇒ Object
58 59 60 61 62 |
# File 'lib/fdx_v660_api/models/security_id_type.rb', line 58 def self.validate(value) return false if value.nil? true end |