Class: FdxV660Api::StateExemptIncome
- Defined in:
- lib/fdx_v660_api/models/state_exempt_income.rb
Overview
State exempt income details
Instance Attribute Summary collapse
-
#amount ⇒ Float
This state's exempt amount.
-
#percent ⇒ Float
This state's percent of total of enclosing fund.
-
#state_code ⇒ StateCode1
State two-digit code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(state_code: SKIP, percent: SKIP, amount: SKIP, additional_properties: nil) ⇒ StateExemptIncome
constructor
A new instance of StateExemptIncome.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(state_code: SKIP, percent: SKIP, amount: SKIP, additional_properties: nil) ⇒ StateExemptIncome
Returns a new instance of StateExemptIncome.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 47 def initialize(state_code: SKIP, percent: SKIP, amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @state_code = state_code unless state_code == SKIP @percent = percent unless percent == SKIP @amount = amount unless amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
This state's exempt amount. Total of enclosing fund times state's percent
22 23 24 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 22 def amount @amount end |
#percent ⇒ Float
This state's percent of total of enclosing fund
18 19 20 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 18 def percent @percent end |
#state_code ⇒ StateCode1
State two-digit code
14 15 16 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 14 def state_code @state_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. state_code = hash.key?('stateCode') ? hash['stateCode'] : SKIP percent = hash.key?('percent') ? hash['percent'] : SKIP amount = hash.key?('amount') ? hash['amount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. StateExemptIncome.new(state_code: state_code, percent: percent, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['state_code'] = 'stateCode' @_hash['percent'] = 'percent' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 34 def self.optionals %w[ state_code percent amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} state_code: #{@state_code.inspect}, percent: #{@percent.inspect}, amount:"\ " #{@amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/fdx_v660_api/models/state_exempt_income.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} state_code: #{@state_code}, percent: #{@percent}, amount: #{@amount},"\ " additional_properties: #{@additional_properties}>" end |