Class: FdxV660Api::SynchronizableArrayLinksEntity2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::SynchronizableArrayLinksEntity2
- Defined in:
- lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb
Overview
Resource URLs for navigating result sets
Instance Attribute Summary collapse
-
#mnext ⇒ HateoasLink1
Resource URL for retrieving next dataset.
-
#prev ⇒ HateoasLink2
Resource URL for retrieving previous dataset.
-
#updates ⇒ HateoasLink6
Resource URL for retrieving updates since last request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mnext: SKIP, prev: SKIP, updates: SKIP, additional_properties: nil) ⇒ SynchronizableArrayLinksEntity2
constructor
A new instance of SynchronizableArrayLinksEntity2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mnext: SKIP, prev: SKIP, updates: SKIP, additional_properties: nil) ⇒ SynchronizableArrayLinksEntity2
Returns a new instance of SynchronizableArrayLinksEntity2.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 47 def initialize(mnext: SKIP, prev: SKIP, updates: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mnext = mnext unless mnext == SKIP @prev = prev unless prev == SKIP @updates = updates unless updates == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mnext ⇒ HateoasLink1
Resource URL for retrieving next dataset
14 15 16 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 14 def mnext @mnext end |
#prev ⇒ HateoasLink2
Resource URL for retrieving previous dataset
18 19 20 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 18 def prev @prev end |
#updates ⇒ HateoasLink6
Resource URL for retrieving updates since last request
22 23 24 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 22 def updates @updates end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mnext = HateoasLink1.from_hash(hash['next']) if hash['next'] prev = HateoasLink2.from_hash(hash['prev']) if hash['prev'] updates = HateoasLink6.from_hash(hash['updates']) if hash['updates'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SynchronizableArrayLinksEntity2.new(mnext: mnext, prev: prev, updates: updates, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['mnext'] = 'next' @_hash['prev'] = 'prev' @_hash['updates'] = 'updates' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 34 def self.optionals %w[ mnext prev updates ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} mnext: #{@mnext.inspect}, prev: #{@prev.inspect}, updates:"\ " #{@updates.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/fdx_v660_api/models/synchronizable_array_links_entity2.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} mnext: #{@mnext}, prev: #{@prev}, updates: #{@updates},"\ " additional_properties: #{@additional_properties}>" end |