Class: FdxV660Api::TaxExemptIncomeStateAllocation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::TaxExemptIncomeStateAllocation
- Defined in:
- lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb
Overview
Tax exempt income by fund
Instance Attribute Summary collapse
-
#exempt_amount ⇒ Float
This fund's total amount of exempt interest dividends.
-
#fund_name ⇒ String
Name of fund.
-
#state_exempt_incomes ⇒ Array[StateExemptIncome]
Tax exempt income information by state.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fund_name: SKIP, exempt_amount: SKIP, state_exempt_incomes: SKIP, additional_properties: nil) ⇒ TaxExemptIncomeStateAllocation
constructor
A new instance of TaxExemptIncomeStateAllocation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fund_name: SKIP, exempt_amount: SKIP, state_exempt_incomes: SKIP, additional_properties: nil) ⇒ TaxExemptIncomeStateAllocation
Returns a new instance of TaxExemptIncomeStateAllocation.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 47 def initialize(fund_name: SKIP, exempt_amount: SKIP, state_exempt_incomes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @fund_name = fund_name unless fund_name == SKIP @exempt_amount = exempt_amount unless exempt_amount == SKIP @state_exempt_incomes = state_exempt_incomes unless state_exempt_incomes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#exempt_amount ⇒ Float
This fund's total amount of exempt interest dividends
18 19 20 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 18 def exempt_amount @exempt_amount end |
#fund_name ⇒ String
Name of fund
14 15 16 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 14 def fund_name @fund_name end |
#state_exempt_incomes ⇒ Array[StateExemptIncome]
Tax exempt income information by state
22 23 24 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 22 def state_exempt_incomes @state_exempt_incomes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fund_name = hash.key?('fundName') ? hash['fundName'] : SKIP exempt_amount = hash.key?('exemptAmount') ? hash['exemptAmount'] : SKIP # Parameter is an array, so we need to iterate through it state_exempt_incomes = nil unless hash['stateExemptIncomes'].nil? state_exempt_incomes = [] hash['stateExemptIncomes'].each do |structure| state_exempt_incomes << (StateExemptIncome.from_hash(structure) if structure) end end state_exempt_incomes = SKIP unless hash.key?('stateExemptIncomes') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxExemptIncomeStateAllocation.new(fund_name: fund_name, exempt_amount: exempt_amount, state_exempt_incomes: state_exempt_incomes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['fund_name'] = 'fundName' @_hash['exempt_amount'] = 'exemptAmount' @_hash['state_exempt_incomes'] = 'stateExemptIncomes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 34 def self.optionals %w[ fund_name exempt_amount state_exempt_incomes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} fund_name: #{@fund_name.inspect}, exempt_amount: #{@exempt_amount.inspect},"\ " state_exempt_incomes: #{@state_exempt_incomes.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 96 |
# File 'lib/fdx_v660_api/models/tax_exempt_income_state_allocation.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} fund_name: #{@fund_name}, exempt_amount: #{@exempt_amount},"\ " state_exempt_incomes: #{@state_exempt_incomes}, additional_properties:"\ " #{@additional_properties}>" end |