Class: FdxV660Api::TaxFormAttribute
- Defined in:
- lib/fdx_v660_api/models/tax_form_attribute.rb
Overview
An additional tax form attribute for use when a defined field is not available
Instance Attribute Summary collapse
-
#box_number ⇒ String
Box number on a tax form, if any.
-
#code ⇒ String
Tax form code for the given box number, if any.
-
#name ⇒ String
Name of attribute.
-
#value ⇒ String
Value of attribute.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, value: SKIP, box_number: SKIP, code: SKIP, additional_properties: nil) ⇒ TaxFormAttribute
constructor
A new instance of TaxFormAttribute.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, value: SKIP, box_number: SKIP, code: SKIP, additional_properties: nil) ⇒ TaxFormAttribute
Returns a new instance of TaxFormAttribute.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 54 def initialize(name: SKIP, value: SKIP, box_number: SKIP, code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @value = value unless value == SKIP @box_number = box_number unless box_number == SKIP @code = code unless code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#box_number ⇒ String
Box number on a tax form, if any
23 24 25 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 23 def box_number @box_number end |
#code ⇒ String
Tax form code for the given box number, if any
27 28 29 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 27 def code @code end |
#name ⇒ String
Name of attribute
15 16 17 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 15 def name @name end |
#value ⇒ String
Value of attribute
19 20 21 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 19 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP value = hash.key?('value') ? hash['value'] : SKIP box_number = hash.key?('boxNumber') ? hash['boxNumber'] : SKIP code = hash.key?('code') ? hash['code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxFormAttribute.new(name: name, value: value, box_number: box_number, code: code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['value'] = 'value' @_hash['box_number'] = 'boxNumber' @_hash['code'] = 'code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 46 47 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 40 def self.optionals %w[ name value box_number code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, value: #{@value.inspect}, box_number:"\ " #{@box_number.inspect}, code: #{@code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/fdx_v660_api/models/tax_form_attribute.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, value: #{@value}, box_number: #{@box_number}, code:"\ " #{@code}, additional_properties: #{@additional_properties}>" end |