Class: FdxV660Api::TransactionLimit
- Defined in:
- lib/fdx_v660_api/models/transaction_limit.rb
Overview
The various size limits on account transaction amounts
Instance Attribute Summary collapse
-
#maximum_amount ⇒ Float
The maximum amount which is permitted for a single transaction of this type.
-
#type ⇒ DepositTransactionType1
The type of transaction restricted by this limit, such as ATMWITHDRAWAL, BILLPAYMENT, CASHIERSCHECK, PERSONTOPERSON.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(maximum_amount: SKIP, type: SKIP, additional_properties: nil) ⇒ TransactionLimit
constructor
A new instance of TransactionLimit.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(maximum_amount: SKIP, type: SKIP, additional_properties: nil) ⇒ TransactionLimit
Returns a new instance of TransactionLimit.
43 44 45 46 47 48 49 50 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 43 def initialize(maximum_amount: SKIP, type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @maximum_amount = maximum_amount unless maximum_amount == SKIP @type = type unless type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#maximum_amount ⇒ Float
The maximum amount which is permitted for a single transaction of this type
15 16 17 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 15 def maximum_amount @maximum_amount end |
#type ⇒ DepositTransactionType1
The type of transaction restricted by this limit, such as ATMWITHDRAWAL, BILLPAYMENT, CASHIERSCHECK, PERSONTOPERSON
20 21 22 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 20 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. maximum_amount = hash.key?('maximumAmount') ? hash['maximumAmount'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionLimit.new(maximum_amount: maximum_amount, type: type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['maximum_amount'] = 'maximumAmount' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 31 def self.optionals %w[ maximum_amount type ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
75 76 77 78 79 80 81 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 75 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} maximum_amount: #{@maximum_amount.inspect}, type: #{@type.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/fdx_v660_api/models/transaction_limit.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} maximum_amount: #{@maximum_amount}, type: #{@type}, additional_properties:"\ " #{@additional_properties}>" end |