Class: FdxV660Api::TransactionRewardEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::TransactionRewardEntity
- Defined in:
- lib/fdx_v660_api/models/transaction_reward_entity.rb
Overview
Rewards earned on a transaction
Instance Attribute Summary collapse
-
#accrued ⇒ Float
Reward units accrued on this transaction.
-
#adjusted ⇒ Float
Reward units adjusted on this transaction.
-
#category_id ⇒ String
Long term persistent identity of the reward category.
-
#type ⇒ RewardType1
The type of the reward balance - CASHBACK, MILES, POINTS.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(category_id: SKIP, accrued: SKIP, adjusted: SKIP, type: SKIP, additional_properties: nil) ⇒ TransactionRewardEntity
constructor
A new instance of TransactionRewardEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category_id: SKIP, accrued: SKIP, adjusted: SKIP, type: SKIP, additional_properties: nil) ⇒ TransactionRewardEntity
Returns a new instance of TransactionRewardEntity.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 55 def initialize(category_id: SKIP, accrued: SKIP, adjusted: SKIP, type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @category_id = category_id unless category_id == SKIP @accrued = accrued unless accrued == SKIP @adjusted = adjusted unless adjusted == SKIP @type = type unless type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#accrued ⇒ Float
Reward units accrued on this transaction
20 21 22 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 20 def accrued @accrued end |
#adjusted ⇒ Float
Reward units adjusted on this transaction
24 25 26 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 24 def adjusted @adjusted end |
#category_id ⇒ String
Long term persistent identity of the reward category. This ID is mapped to a category definition returned by calling the getRewardProgramCategories operation
16 17 18 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 16 def category_id @category_id end |
#type ⇒ RewardType1
The type of the reward balance - CASHBACK, MILES, POINTS
28 29 30 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 28 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 68 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category_id = hash.key?('categoryId') ? hash['categoryId'] : SKIP accrued = hash.key?('accrued') ? hash['accrued'] : SKIP adjusted = hash.key?('adjusted') ? hash['adjusted'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionRewardEntity.new(category_id: category_id, accrued: accrued, adjusted: adjusted, type: type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['category_id'] = 'categoryId' @_hash['accrued'] = 'accrued' @_hash['adjusted'] = 'adjusted' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 47 48 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 41 def self.optionals %w[ category_id accrued adjusted type ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
94 95 96 97 98 99 100 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 94 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} category_id: #{@category_id.inspect}, accrued: #{@accrued.inspect},"\ " adjusted: #{@adjusted.inspect}, type: #{@type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/fdx_v660_api/models/transaction_reward_entity.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} category_id: #{@category_id}, accrued: #{@accrued}, adjusted: #{@adjusted},"\ " type: #{@type}, additional_properties: #{@additional_properties}>" end |