Class: FdxV660Api::UsGovernmentSecurityIncome1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FdxV660Api::UsGovernmentSecurityIncome1
- Defined in:
- lib/fdx_v660_api/models/us_government_security_income1.rb
Overview
Details of dividend income portion earned from a US government security
Instance Attribute Summary collapse
-
#agency_type ⇒ UsAgencyType2
US agency type.
-
#amount ⇒ Float
Amount of agency interest for this fund or security.
-
#percent ⇒ Float
Percent of total dividend from this fund or security, required if amount not given.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(agency_type: SKIP, percent: SKIP, amount: SKIP, additional_properties: nil) ⇒ UsGovernmentSecurityIncome1
constructor
A new instance of UsGovernmentSecurityIncome1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(agency_type: SKIP, percent: SKIP, amount: SKIP, additional_properties: nil) ⇒ UsGovernmentSecurityIncome1
Returns a new instance of UsGovernmentSecurityIncome1.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 49 def initialize(agency_type: SKIP, percent: SKIP, amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @agency_type = agency_type unless agency_type == SKIP @percent = percent unless percent == SKIP @amount = amount unless amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#agency_type ⇒ UsAgencyType2
US agency type
14 15 16 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 14 def agency_type @agency_type end |
#amount ⇒ Float
Amount of agency interest for this fund or security. Omit field for amount to be computed by recipient from returned percent value
24 25 26 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 24 def amount @amount end |
#percent ⇒ Float
Percent of total dividend from this fund or security, required if amount not given
19 20 21 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 19 def percent @percent end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. agency_type = hash.key?('agencyType') ? hash['agencyType'] : SKIP percent = hash.key?('percent') ? hash['percent'] : SKIP amount = hash.key?('amount') ? hash['amount'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UsGovernmentSecurityIncome1.new(agency_type: agency_type, percent: percent, amount: amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['agency_type'] = 'agencyType' @_hash['percent'] = 'percent' @_hash['amount'] = 'amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 42 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 36 def self.optionals %w[ agency_type percent amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} agency_type: #{@agency_type.inspect}, percent: #{@percent.inspect}, amount:"\ " #{@amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/fdx_v660_api/models/us_government_security_income1.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} agency_type: #{@agency_type}, percent: #{@percent}, amount: #{@amount},"\ " additional_properties: #{@additional_properties}>" end |